""" Cisco_IOS_XR_clns_isis_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR clns\-isis package operational data.

This module contains definitions
for the following management objects\:
  isis\: IS\-IS operational data

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IsisAdjBfdState(Enum):
    """
    IsisAdjBfdState

    Current BFD state of an adjacency

    .. data:: isis_adj_bfd_no_state = 0

    	No BFD session created

    .. data:: isis_adj_bfd_down_state = 1

    	BFD session is DOWN

    .. data:: isis_adj_bfd_init_state = 2

    	Waiting for BFD session to come UP

    .. data:: isis_adj_bfd_up_state = 3

    	BFD session is UP

    """

    isis_adj_bfd_no_state = Enum.YLeaf(0, "isis-adj-bfd-no-state")

    isis_adj_bfd_down_state = Enum.YLeaf(1, "isis-adj-bfd-down-state")

    isis_adj_bfd_init_state = Enum.YLeaf(2, "isis-adj-bfd-init-state")

    isis_adj_bfd_up_state = Enum.YLeaf(3, "isis-adj-bfd-up-state")


class IsisAdjState(Enum):
    """
    IsisAdjState

    Isis adj state

    .. data:: isis_adj_up_state = 0

    	Adjacency up

    .. data:: isis_adj_init_state = 1

    	Adjacency initializing

    .. data:: isis_adj_failed_state = 2

    	Adjacency down/failed

    """

    isis_adj_up_state = Enum.YLeaf(0, "isis-adj-up-state")

    isis_adj_init_state = Enum.YLeaf(1, "isis-adj-init-state")

    isis_adj_failed_state = Enum.YLeaf(2, "isis-adj-failed-state")


class IsisAdjStateReason(Enum):
    """
    IsisAdjStateReason

    Isis adj state reason

    .. data:: isis_adj_up_nsf_restart = 0

    	NSF Restart

    .. data:: isis_adj_up_new_adj = 1

    	New adjacency

    .. data:: isis_adj_up_restarted = 2

    	Restarted

    .. data:: isis_adj_up_nsf_restored = 3

    	Restored during NSF

    .. data:: isis_adj_up_chkpt_restored = 4

    	Restored from checkpoint

    .. data:: isis_adj_init_reason = 5

    	Into INIT

    .. data:: isis_adj_init_neighbor_forgot = 6

    	Neighbor forgot us

    .. data:: isis_adj_down_hold_time = 7

    	Holdtime expired

    .. data:: isis_adj_down_if_down = 8

    	Interface state going down

    .. data:: isis_adj_down_cfg_mismatch = 9

    	Area address/level mismatch

    .. data:: isis_adj_down_circ_id = 10

    	Circuit ID changed

    .. data:: isis_adj_down_nsf_ack_fail = 11

    	NSF could not CSNP Ack P2P adjacency

    .. data:: isis_adj_down_db_clear = 12

    	Clear of the Adjacency DB

    .. data:: isis_adj_down_no_common_topology = 13

    	Neighbors have no common link topology

    .. data:: isis_adj_down_restart_tlv_missing = 14

    	Restart TLV missing during IETF NSF restart

    .. data:: isis_adj_down_bfd_down = 15

    	BFD session has gone DOWN

    .. data:: isis_adj_down_3way_down = 16

    	3-way state down

    """

    isis_adj_up_nsf_restart = Enum.YLeaf(0, "isis-adj-up-nsf-restart")

    isis_adj_up_new_adj = Enum.YLeaf(1, "isis-adj-up-new-adj")

    isis_adj_up_restarted = Enum.YLeaf(2, "isis-adj-up-restarted")

    isis_adj_up_nsf_restored = Enum.YLeaf(3, "isis-adj-up-nsf-restored")

    isis_adj_up_chkpt_restored = Enum.YLeaf(4, "isis-adj-up-chkpt-restored")

    isis_adj_init_reason = Enum.YLeaf(5, "isis-adj-init-reason")

    isis_adj_init_neighbor_forgot = Enum.YLeaf(6, "isis-adj-init-neighbor-forgot")

    isis_adj_down_hold_time = Enum.YLeaf(7, "isis-adj-down-hold-time")

    isis_adj_down_if_down = Enum.YLeaf(8, "isis-adj-down-if-down")

    isis_adj_down_cfg_mismatch = Enum.YLeaf(9, "isis-adj-down-cfg-mismatch")

    isis_adj_down_circ_id = Enum.YLeaf(10, "isis-adj-down-circ-id")

    isis_adj_down_nsf_ack_fail = Enum.YLeaf(11, "isis-adj-down-nsf-ack-fail")

    isis_adj_down_db_clear = Enum.YLeaf(12, "isis-adj-down-db-clear")

    isis_adj_down_no_common_topology = Enum.YLeaf(13, "isis-adj-down-no-common-topology")

    isis_adj_down_restart_tlv_missing = Enum.YLeaf(14, "isis-adj-down-restart-tlv-missing")

    isis_adj_down_bfd_down = Enum.YLeaf(15, "isis-adj-down-bfd-down")

    isis_adj_down_3way_down = Enum.YLeaf(16, "isis-adj-down-3way-down")


class IsisAdjTopoChange(Enum):
    """
    IsisAdjTopoChange

    Per\-topology change type for an adjacency

    .. data:: isis_adj_topo_up_change = 0

    	Topology up

    .. data:: isis_adj_topo_next_hop_change = 1

    	Topology next-hop changed

    .. data:: isis_adj_topo_down_change = 2

    	Topology down

    """

    isis_adj_topo_up_change = Enum.YLeaf(0, "isis-adj-topo-up-change")

    isis_adj_topo_next_hop_change = Enum.YLeaf(1, "isis-adj-topo-next-hop-change")

    isis_adj_topo_down_change = Enum.YLeaf(2, "isis-adj-topo-down-change")


class IsisAdjTopoStatus(Enum):
    """
    IsisAdjTopoStatus

    Status of a topology in an adjacency

    .. data:: isis_adj_topo_status_ok = 0

    	Topology is included in adjacency

    .. data:: isis_adj_topo_status_intf_not_configured = 1

    	Topology is not configured on the interface

    .. data:: isis_adj_topo_status_intf_not_running = 2

    	Topology is not running on the interface

    .. data:: isis_adj_topo_status_init_state = 3

    	Adjacency is in INIT state

    .. data:: isis_adj_topo_status_neighbor_doesnt_participate = 4

    	Neighbor doesn't participate in topology

    .. data:: isis_adj_topo_status_ipv4_address_tlv_missing = 5

    	Neighbor IIH doesn't contain IPv4 address TLV

    .. data:: isis_adj_topo_status_ipv4_address_tlv_empty = 6

    	Neighbor's IPv4 address TLV is empty

    .. data:: isis_adj_topo_status_ipv6_address_tlv_missing = 7

    	Neighbor IIH doesn't contain IPv6 address TLV

    .. data:: isis_adj_topo_status_ipv6_address_tlv_empty = 8

    	Neighbor's IPv6 address TLV is empty

    .. data:: isis_adj_topo_status_ipv4_address_matches_ours = 9

    	Neighbor's IPv4 address matches ours

    .. data:: isis_adj_topo_status_ipv6_address_matches_ours = 10

    	Neighbor's IPv6 address matches ours

    .. data:: isis_adj_topo_status_ipv4_address_subnet_mismatch = 11

    	Neighbor's IPv4 address is in a different

    	subnet to ours

    .. data:: isis_adj_topo_status_ipv6_address_not_link_local = 12

    	Neighbor's IPv6 address is not link local

    """

    isis_adj_topo_status_ok = Enum.YLeaf(0, "isis-adj-topo-status-ok")

    isis_adj_topo_status_intf_not_configured = Enum.YLeaf(1, "isis-adj-topo-status-intf-not-configured")

    isis_adj_topo_status_intf_not_running = Enum.YLeaf(2, "isis-adj-topo-status-intf-not-running")

    isis_adj_topo_status_init_state = Enum.YLeaf(3, "isis-adj-topo-status-init-state")

    isis_adj_topo_status_neighbor_doesnt_participate = Enum.YLeaf(4, "isis-adj-topo-status-neighbor-doesnt-participate")

    isis_adj_topo_status_ipv4_address_tlv_missing = Enum.YLeaf(5, "isis-adj-topo-status-ipv4-address-tlv-missing")

    isis_adj_topo_status_ipv4_address_tlv_empty = Enum.YLeaf(6, "isis-adj-topo-status-ipv4-address-tlv-empty")

    isis_adj_topo_status_ipv6_address_tlv_missing = Enum.YLeaf(7, "isis-adj-topo-status-ipv6-address-tlv-missing")

    isis_adj_topo_status_ipv6_address_tlv_empty = Enum.YLeaf(8, "isis-adj-topo-status-ipv6-address-tlv-empty")

    isis_adj_topo_status_ipv4_address_matches_ours = Enum.YLeaf(9, "isis-adj-topo-status-ipv4-address-matches-ours")

    isis_adj_topo_status_ipv6_address_matches_ours = Enum.YLeaf(10, "isis-adj-topo-status-ipv6-address-matches-ours")

    isis_adj_topo_status_ipv4_address_subnet_mismatch = Enum.YLeaf(11, "isis-adj-topo-status-ipv4-address-subnet-mismatch")

    isis_adj_topo_status_ipv6_address_not_link_local = Enum.YLeaf(12, "isis-adj-topo-status-ipv6-address-not-link-local")


class IsisAfId(Enum):
    """
    IsisAfId

    Isis af id

    .. data:: ipv4 = 0

    	IPv4

    .. data:: ipv6 = 1

    	IPv6

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")


class IsisEnabled(Enum):
    """
    IsisEnabled

    Isis enabled

    .. data:: isis_disabled = 0

    	Disabled

    .. data:: isis_enabled = 1

    	Enabled

    """

    isis_disabled = Enum.YLeaf(0, "isis-disabled")

    isis_enabled = Enum.YLeaf(1, "isis-enabled")


class IsisErrLogLevel(Enum):
    """
    IsisErrLogLevel

    Isis err log level

    .. data:: isis_err_log_level_info = 0

    	isis err log level info

    .. data:: isis_err_log_level_warn = 1

    	isis err log level warn

    .. data:: isis_err_log_level_critical = 2

    	isis err log level critical

    """

    isis_err_log_level_info = Enum.YLeaf(0, "isis-err-log-level-info")

    isis_err_log_level_warn = Enum.YLeaf(1, "isis-err-log-level-warn")

    isis_err_log_level_critical = Enum.YLeaf(2, "isis-err-log-level-critical")


class IsisIfAdjFormDisabledReason(Enum):
    """
    IsisIfAdjFormDisabledReason

    Isis if adj form disabled reason

    .. data:: isis_intf_adj_form_disabled_cfg_passive = 0

    	isis intf adj form disabled cfg passive

    .. data:: isis_intf_adj_form_disabled_no_topo_participate = 1

    	isis intf adj form disabled no topo participate

    .. data:: isis_intf_adj_form_disabled_add_to_intf_stack_fail = 2

    	isis intf adj form disabled add to intf stack

    	fail

    .. data:: isis_intf_adj_form_disabled_clns_io = 3

    	isis intf adj form disabled clns io

    .. data:: isis_intf_adj_form_disabled_internal_error = 4

    	isis intf adj form disabled internal error

    """

    isis_intf_adj_form_disabled_cfg_passive = Enum.YLeaf(0, "isis-intf-adj-form-disabled-cfg-passive")

    isis_intf_adj_form_disabled_no_topo_participate = Enum.YLeaf(1, "isis-intf-adj-form-disabled-no-topo-participate")

    isis_intf_adj_form_disabled_add_to_intf_stack_fail = Enum.YLeaf(2, "isis-intf-adj-form-disabled-add-to-intf-stack-fail")

    isis_intf_adj_form_disabled_clns_io = Enum.YLeaf(3, "isis-intf-adj-form-disabled-clns-io")

    isis_intf_adj_form_disabled_internal_error = Enum.YLeaf(4, "isis-intf-adj-form-disabled-internal-error")


class IsisIfAdvPrefixDisabledReason(Enum):
    """
    IsisIfAdvPrefixDisabledReason

    Isis if adv prefix disabled reason

    .. data:: isis_intf_adv_prefix_disabled_if_cfg_suppressed = 0

    	isis intf adv prefix disabled if cfg suppressed

    .. data:: isis_intf_adv_prefix_disabled_no_topo_participate = 1

    	isis intf adv prefix disabled no topo

    	participate

    .. data:: isis_intf_adv_prefix_disabled_internal_error = 2

    	isis intf adv prefix disabled internal error

    """

    isis_intf_adv_prefix_disabled_if_cfg_suppressed = Enum.YLeaf(0, "isis-intf-adv-prefix-disabled-if-cfg-suppressed")

    isis_intf_adv_prefix_disabled_no_topo_participate = Enum.YLeaf(1, "isis-intf-adv-prefix-disabled-no-topo-participate")

    isis_intf_adv_prefix_disabled_internal_error = Enum.YLeaf(2, "isis-intf-adv-prefix-disabled-internal-error")


class IsisIfAfDisabledReason(Enum):
    """
    IsisIfAfDisabledReason

    Isis if af disabled reason

    .. data:: isis_intf_af_disabled_no_topo_enabled = 0

    	isis intf af disabled no topo enabled

    .. data:: isis_intf_af_disabled_internal_error = 1

    	isis intf af disabled internal error

    """

    isis_intf_af_disabled_no_topo_enabled = Enum.YLeaf(0, "isis-intf-af-disabled-no-topo-enabled")

    isis_intf_af_disabled_internal_error = Enum.YLeaf(1, "isis-intf-af-disabled-internal-error")


class IsisIfAfFwdAddrUnknownReason(Enum):
    """
    IsisIfAfFwdAddrUnknownReason

    Isis if af fwd addr unknown reason

    .. data:: isis_intf_af_fwd_addr_unknown_cfg_passive = 0

    	isis intf af fwd addr unknown cfg passive

    .. data:: isis_intf_af_fwd_addr_unknown_proto_doesnt_exist = 1

    	isis intf af fwd addr unknown proto doesnt

    	exist

    .. data:: isis_intf_af_fwd_addr_unknown_next_hop_reg_error = 2

    	isis intf af fwd addr unknown next hop reg

    	error

    .. data:: isis_intf_af_fwd_addr_unknown_no_link_local_add = 3

    	isis intf af fwd addr unknown no link local add

    .. data:: isis_intf_af_fwd_addr_unknown_af_not_up = 4

    	isis intf af fwd addr unknown af not up

    .. data:: isis_intf_af_fwd_addr_unknown_vrf_enabled = 5

    	isis intf af fwd addr unknown vrf enabled

    .. data:: isis_intf_af_fwd_addr_unknown_internal_error = 6

    	isis intf af fwd addr unknown internal error

    """

    isis_intf_af_fwd_addr_unknown_cfg_passive = Enum.YLeaf(0, "isis-intf-af-fwd-addr-unknown-cfg-passive")

    isis_intf_af_fwd_addr_unknown_proto_doesnt_exist = Enum.YLeaf(1, "isis-intf-af-fwd-addr-unknown-proto-doesnt-exist")

    isis_intf_af_fwd_addr_unknown_next_hop_reg_error = Enum.YLeaf(2, "isis-intf-af-fwd-addr-unknown-next-hop-reg-error")

    isis_intf_af_fwd_addr_unknown_no_link_local_add = Enum.YLeaf(3, "isis-intf-af-fwd-addr-unknown-no-link-local-add")

    isis_intf_af_fwd_addr_unknown_af_not_up = Enum.YLeaf(4, "isis-intf-af-fwd-addr-unknown-af-not-up")

    isis_intf_af_fwd_addr_unknown_vrf_enabled = Enum.YLeaf(5, "isis-intf-af-fwd-addr-unknown-vrf-enabled")

    isis_intf_af_fwd_addr_unknown_internal_error = Enum.YLeaf(6, "isis-intf-af-fwd-addr-unknown-internal-error")


class IsisIfAfPrefixUnknownReason(Enum):
    """
    IsisIfAfPrefixUnknownReason

    Isis if af prefix unknown reason

    .. data:: isis_intf_af_prefix_unknown_adv_suppressed = 0

    	isis intf af prefix unknown adv suppressed

    .. data:: isis_intf_af_prefix_unknown_global_addr_reg_error = 1

    	isis intf af prefix unknown global addr reg

    	error

    .. data:: isis_intf_af_prefix_unknown_internal_error = 2

    	isis intf af prefix unknown internal error

    """

    isis_intf_af_prefix_unknown_adv_suppressed = Enum.YLeaf(0, "isis-intf-af-prefix-unknown-adv-suppressed")

    isis_intf_af_prefix_unknown_global_addr_reg_error = Enum.YLeaf(1, "isis-intf-af-prefix-unknown-global-addr-reg-error")

    isis_intf_af_prefix_unknown_internal_error = Enum.YLeaf(2, "isis-intf-af-prefix-unknown-internal-error")


class IsisIfAfProtoDownReason(Enum):
    """
    IsisIfAfProtoDownReason

    Isis if af proto down reason

    .. data:: isis_intf_af_proto_down_imd_conn_fail = 0

    	isis intf af proto down imd conn fail

    .. data:: isis_intf_af_proto_down_imd_node_doesnt_exist = 1

    	isis intf af proto down imd node doesnt exist

    .. data:: isis_intf_af_proto_down_imd_exist_reg_error = 2

    	isis intf af proto down imd exist reg error

    .. data:: isis_intf_af_proto_down_imd_state_reg_error = 3

    	isis intf af proto down imd state reg error

    .. data:: isis_intf_af_proto_down_af_not_up = 4

    	isis intf af proto down af not up

    .. data:: isis_intf_af_proto_down_internal_error = 5

    	isis intf af proto down internal error

    """

    isis_intf_af_proto_down_imd_conn_fail = Enum.YLeaf(0, "isis-intf-af-proto-down-imd-conn-fail")

    isis_intf_af_proto_down_imd_node_doesnt_exist = Enum.YLeaf(1, "isis-intf-af-proto-down-imd-node-doesnt-exist")

    isis_intf_af_proto_down_imd_exist_reg_error = Enum.YLeaf(2, "isis-intf-af-proto-down-imd-exist-reg-error")

    isis_intf_af_proto_down_imd_state_reg_error = Enum.YLeaf(3, "isis-intf-af-proto-down-imd-state-reg-error")

    isis_intf_af_proto_down_af_not_up = Enum.YLeaf(4, "isis-intf-af-proto-down-af-not-up")

    isis_intf_af_proto_down_internal_error = Enum.YLeaf(5, "isis-intf-af-proto-down-internal-error")


class IsisIfClnsMtuInvalidReason(Enum):
    """
    IsisIfClnsMtuInvalidReason

    Isis if clns mtu invalid reason

    .. data:: isis_intf_clns_mtu_invalid_too_sm_all = 0

    	isis intf clns mtu invalid too sm all

    .. data:: isis_intf_clns_mtu_invalid_internal_error = 1

    	isis intf clns mtu invalid internal error

    """

    isis_intf_clns_mtu_invalid_too_sm_all = Enum.YLeaf(0, "isis-intf-clns-mtu-invalid-too-sm-all")

    isis_intf_clns_mtu_invalid_internal_error = Enum.YLeaf(1, "isis-intf-clns-mtu-invalid-internal-error")


class IsisIfClnsProtoDownReason(Enum):
    """
    IsisIfClnsProtoDownReason

    Isis if clns proto down reason

    .. data:: isis_intf_clns_proto_down_add_to_intf_stack_fail = 0

    	isis intf clns proto down add to intf stack

    	fail

    .. data:: isis_intf_clns_proto_down_no_imd_conn = 1

    	isis intf clns proto down no imd conn

    .. data:: isis_intf_clns_proto_down_imd_node_doesnt_exist = 2

    	isis intf clns proto down imd node doesnt exist

    .. data:: isis_intf_clns_proto_down_imd_exist_reg_error = 3

    	isis intf clns proto down imd exist reg error

    .. data:: isis_intf_clns_proto_down_imd_state_reg_error = 4

    	isis intf clns proto down imd state reg error

    .. data:: isis_intf_clns_proto_down_clns_not_up = 5

    	isis intf clns proto down clns not up

    """

    isis_intf_clns_proto_down_add_to_intf_stack_fail = Enum.YLeaf(0, "isis-intf-clns-proto-down-add-to-intf-stack-fail")

    isis_intf_clns_proto_down_no_imd_conn = Enum.YLeaf(1, "isis-intf-clns-proto-down-no-imd-conn")

    isis_intf_clns_proto_down_imd_node_doesnt_exist = Enum.YLeaf(2, "isis-intf-clns-proto-down-imd-node-doesnt-exist")

    isis_intf_clns_proto_down_imd_exist_reg_error = Enum.YLeaf(3, "isis-intf-clns-proto-down-imd-exist-reg-error")

    isis_intf_clns_proto_down_imd_state_reg_error = Enum.YLeaf(4, "isis-intf-clns-proto-down-imd-state-reg-error")

    isis_intf_clns_proto_down_clns_not_up = Enum.YLeaf(5, "isis-intf-clns-proto-down-clns-not-up")


class IsisIfClnsSnpaUnknownReason(Enum):
    """
    IsisIfClnsSnpaUnknownReason

    Isis if clns snpa unknown reason

    .. data:: isis_intf_clns_snpa_unknown_access_error = 0

    	isis intf clns snpa unknown access error

    .. data:: isis_intf_clns_snpa_unknown_not_lan = 1

    	isis intf clns snpa unknown not lan

    .. data:: isis_intf_clns_snpa_unknown_internal_error = 2

    	isis intf clns snpa unknown internal error

    """

    isis_intf_clns_snpa_unknown_access_error = Enum.YLeaf(0, "isis-intf-clns-snpa-unknown-access-error")

    isis_intf_clns_snpa_unknown_not_lan = Enum.YLeaf(1, "isis-intf-clns-snpa-unknown-not-lan")

    isis_intf_clns_snpa_unknown_internal_error = Enum.YLeaf(2, "isis-intf-clns-snpa-unknown-internal-error")


class IsisIfDisabledReason(Enum):
    """
    IsisIfDisabledReason

    Isis if disabled reason

    .. data:: isis_intf_disabled_no_net_cfg = 0

    	isis intf disabled no net cfg

    .. data:: isis_intf_disabled_area_missing = 1

    	isis intf disabled area missing

    .. data:: isis_intf_disabled_no_area_running = 2

    	isis intf disabled no area running

    .. data:: isis_intf_disabled_no_topos_cfg = 3

    	isis intf disabled no topos cfg

    .. data:: isis_intf_disabled_no_imd_conn = 4

    	isis intf disabled no imd conn

    .. data:: isis_intf_disabled_imd_reg_error = 5

    	isis intf disabled imd reg error

    .. data:: isis_intf_disabled_level_mismatch = 6

    	isis intf disabled level mismatch

    .. data:: isis_intf_disabled_base_caps_error = 7

    	isis intf disabled base caps error

    .. data:: isis_intf_disabled_intf_doesnt_exist = 8

    	isis intf disabled intf doesnt exist

    .. data:: isis_intf_disabled_intf_shutdown = 9

    	isis intf disabled intf shutdown

    .. data:: isis_intf_disabled_internal_error = 10

    	isis intf disabled internal error

    """

    isis_intf_disabled_no_net_cfg = Enum.YLeaf(0, "isis-intf-disabled-no-net-cfg")

    isis_intf_disabled_area_missing = Enum.YLeaf(1, "isis-intf-disabled-area-missing")

    isis_intf_disabled_no_area_running = Enum.YLeaf(2, "isis-intf-disabled-no-area-running")

    isis_intf_disabled_no_topos_cfg = Enum.YLeaf(3, "isis-intf-disabled-no-topos-cfg")

    isis_intf_disabled_no_imd_conn = Enum.YLeaf(4, "isis-intf-disabled-no-imd-conn")

    isis_intf_disabled_imd_reg_error = Enum.YLeaf(5, "isis-intf-disabled-imd-reg-error")

    isis_intf_disabled_level_mismatch = Enum.YLeaf(6, "isis-intf-disabled-level-mismatch")

    isis_intf_disabled_base_caps_error = Enum.YLeaf(7, "isis-intf-disabled-base-caps-error")

    isis_intf_disabled_intf_doesnt_exist = Enum.YLeaf(8, "isis-intf-disabled-intf-doesnt-exist")

    isis_intf_disabled_intf_shutdown = Enum.YLeaf(9, "isis-intf-disabled-intf-shutdown")

    isis_intf_disabled_internal_error = Enum.YLeaf(10, "isis-intf-disabled-internal-error")


class IsisIfMcastInvalidReason(Enum):
    """
    IsisIfMcastInvalidReason

    Isis if mcast invalid reason

    .. data:: isis_intf_mcast_invalid_join_error = 0

    	Error when attempting to join this multicast

    	group

    .. data:: isis_intf_mcast_invalid_internal_error = 1

    	Internal error

    .. data:: isis_intf_mcast_invalid_not_yet_needed = 2

    	Multicast group membership not yet requested

    """

    isis_intf_mcast_invalid_join_error = Enum.YLeaf(0, "isis-intf-mcast-invalid-join-error")

    isis_intf_mcast_invalid_internal_error = Enum.YLeaf(1, "isis-intf-mcast-invalid-internal-error")

    isis_intf_mcast_invalid_not_yet_needed = Enum.YLeaf(2, "isis-intf-mcast-invalid-not-yet-needed")


class IsisIfTopoAdjFormDisabledReason(Enum):
    """
    IsisIfTopoAdjFormDisabledReason

    Isis if topo adj form disabled reason

    .. data:: isis_intf_topo_adj_form_disabled_intf_passive = 0

    	isis intf topo adj form disabled intf passive

    .. data:: isis_intf_topo_adj_form_disabled_af_not_up = 1

    	isis intf topo adj form disabled af not up

    .. data:: isis_intf_topo_adj_form_disabled_af_fwd_addr_unknown = 2

    	isis intf topo adj form disabled af fwd addr

    	unknown

    .. data:: isis_intf_topo_adj_form_disabled_topo_not_cfg = 3

    	isis intf topo adj form disabled topo not cfg

    .. data:: isis_intf_topo_adj_form_disabled_topo_can_not_participate = 4

    	isis intf topo adj form disabled topo can not

    	participate

    .. data:: isis_intf_topo_adj_form_disabled_idle = 5

    	isis intf topo adj form disabled idle

    .. data:: isis_intf_topo_adj_form_disabled_internal_error = 6

    	isis intf topo adj form disabled internal error

    .. data:: isis_intf_topo_adj_form_disabled_mtu = 7

    	isis intf topo adj form disabled mtu

    .. data:: isis_intf_topo_adj_form_disabled_snpa = 8

    	isis intf topo adj form disabled snpa

    .. data:: isis_intf_topo_adj_form_disabled_mcast = 9

    	isis intf topo adj form disabled mcast

    """

    isis_intf_topo_adj_form_disabled_intf_passive = Enum.YLeaf(0, "isis-intf-topo-adj-form-disabled-intf-passive")

    isis_intf_topo_adj_form_disabled_af_not_up = Enum.YLeaf(1, "isis-intf-topo-adj-form-disabled-af-not-up")

    isis_intf_topo_adj_form_disabled_af_fwd_addr_unknown = Enum.YLeaf(2, "isis-intf-topo-adj-form-disabled-af-fwd-addr-unknown")

    isis_intf_topo_adj_form_disabled_topo_not_cfg = Enum.YLeaf(3, "isis-intf-topo-adj-form-disabled-topo-not-cfg")

    isis_intf_topo_adj_form_disabled_topo_can_not_participate = Enum.YLeaf(4, "isis-intf-topo-adj-form-disabled-topo-can-not-participate")

    isis_intf_topo_adj_form_disabled_idle = Enum.YLeaf(5, "isis-intf-topo-adj-form-disabled-idle")

    isis_intf_topo_adj_form_disabled_internal_error = Enum.YLeaf(6, "isis-intf-topo-adj-form-disabled-internal-error")

    isis_intf_topo_adj_form_disabled_mtu = Enum.YLeaf(7, "isis-intf-topo-adj-form-disabled-mtu")

    isis_intf_topo_adj_form_disabled_snpa = Enum.YLeaf(8, "isis-intf-topo-adj-form-disabled-snpa")

    isis_intf_topo_adj_form_disabled_mcast = Enum.YLeaf(9, "isis-intf-topo-adj-form-disabled-mcast")


class IsisIfTopoAdvPrefixDisabledReason(Enum):
    """
    IsisIfTopoAdvPrefixDisabledReason

    Isis if topo adv prefix disabled reason

    .. data:: isis_intf_topo_adv_prefix_disabled_intf_suppressed = 0

    	isis intf topo adv prefix disabled intf

    	suppressed

    .. data:: isis_intf_topo_adv_prefix_disabled_af_not_up = 1

    	isis intf topo adv prefix disabled af not up

    .. data:: isis_intf_topo_adv_prefix_disabled_af_prefixes_unknown = 2

    	isis intf topo adv prefix disabled af prefixes

    	unknown

    .. data:: isis_intf_topo_adv_prefix_disabled_internal_error = 3

    	isis intf topo adv prefix disabled internal

    	error

    """

    isis_intf_topo_adv_prefix_disabled_intf_suppressed = Enum.YLeaf(0, "isis-intf-topo-adv-prefix-disabled-intf-suppressed")

    isis_intf_topo_adv_prefix_disabled_af_not_up = Enum.YLeaf(1, "isis-intf-topo-adv-prefix-disabled-af-not-up")

    isis_intf_topo_adv_prefix_disabled_af_prefixes_unknown = Enum.YLeaf(2, "isis-intf-topo-adv-prefix-disabled-af-prefixes-unknown")

    isis_intf_topo_adv_prefix_disabled_internal_error = Enum.YLeaf(3, "isis-intf-topo-adv-prefix-disabled-internal-error")


class IsisIfTopoDisabledReason(Enum):
    """
    IsisIfTopoDisabledReason

    Isis if topo disabled reason

    .. data:: isis_intf_topo_disabled_not_cfg = 0

    	isis intf topo disabled not cfg

    .. data:: isis_intf_topo_disabled_internal_error = 1

    	isis intf topo disabled internal error

    """

    isis_intf_topo_disabled_not_cfg = Enum.YLeaf(0, "isis-intf-topo-disabled-not-cfg")

    isis_intf_topo_disabled_internal_error = Enum.YLeaf(1, "isis-intf-topo-disabled-internal-error")


class IsisKnown(Enum):
    """
    IsisKnown

    Isis known

    .. data:: isis_unknown = 0

    	Unknown

    .. data:: isis_known = 1

    	Known

    """

    isis_unknown = Enum.YLeaf(0, "isis-unknown")

    isis_known = Enum.YLeaf(1, "isis-known")


class IsisLevel(Enum):
    """
    IsisLevel

    Isis level

    .. data:: isis_level0 = 0

    	isis level0

    .. data:: isis_level1 = 1

    	isis level1

    .. data:: isis_level2 = 2

    	isis level2

    """

    isis_level0 = Enum.YLeaf(0, "isis-level0")

    isis_level1 = Enum.YLeaf(1, "isis-level1")

    isis_level2 = Enum.YLeaf(2, "isis-level2")


class IsisLevels(Enum):
    """
    IsisLevels

    Isis levels

    .. data:: isis_levels_none = 0

    	isis levels none

    .. data:: isis_levels_1 = 1

    	isis levels 1

    .. data:: isis_levels_2 = 2

    	isis levels 2

    .. data:: isis_levels_12 = 3

    	isis levels 12

    .. data:: isis_levels_total = 4

    	isis levels total

    """

    isis_levels_none = Enum.YLeaf(0, "isis-levels-none")

    isis_levels_1 = Enum.YLeaf(1, "isis-levels-1")

    isis_levels_2 = Enum.YLeaf(2, "isis-levels-2")

    isis_levels_12 = Enum.YLeaf(3, "isis-levels-12")

    isis_levels_total = Enum.YLeaf(4, "isis-levels-total")


class IsisLspDbOp(Enum):
    """
    IsisLspDbOp

    Isis lsp db op

    .. data:: isis_lsp_db_clear = 0

    	Clear the LSP database

    .. data:: isis_lsp_db_insert_new_lsp = 1

    	Insertion of new LSP

    .. data:: isis_lsp_db_replace_lsp_with_lsp = 2

    	LSP replacing LSP

    .. data:: isis_lsp_db_purge_lsp = 3

    	LSP purged by the local system

    .. data:: isis_lsp_db_delete_lsp = 4

    	Removal of the LSP from the database

    """

    isis_lsp_db_clear = Enum.YLeaf(0, "isis-lsp-db-clear")

    isis_lsp_db_insert_new_lsp = Enum.YLeaf(1, "isis-lsp-db-insert-new-lsp")

    isis_lsp_db_replace_lsp_with_lsp = Enum.YLeaf(2, "isis-lsp-db-replace-lsp-with-lsp")

    isis_lsp_db_purge_lsp = Enum.YLeaf(3, "isis-lsp-db-purge-lsp")

    isis_lsp_db_delete_lsp = Enum.YLeaf(4, "isis-lsp-db-delete-lsp")


class IsisLspTrigger(Enum):
    """
    IsisLspTrigger

    Isis lsp trigger

    .. data:: isis_lsp_trig_config = 0

    	Any configuration change

    .. data:: isis_lsp_trig_newadj = 1

    	New adjacency came up

    .. data:: isis_lsp_trig_deladj = 2

    	Adjacency went down

    .. data:: isis_lsp_trig_dr_change = 3

    	DIS changed, or pseudonode changed

    .. data:: isis_lsp_trig_area_set = 4

    	Active area set changed

    .. data:: isis_lsp_trig_attach = 5

    	Attached bit changed state

    .. data:: isis_lsp_trig_hippity = 6

    	LSPDB overload bit changed state

    .. data:: isis_lsp_trig_regen = 7

    	LSP regeneration

    .. data:: isis_lsp_trig_ip_if_up = 8

    	Directly connected IP prefix up

    .. data:: isis_lsp_trig_ip_if_down = 9

    	Directly connected IP prefix down

    .. data:: isis_lsp_trig_ip_inter_area = 10

    	Interarea IP route appeared or gone

    .. data:: isis_lsp_trig_ip_external = 11

    	Redistributed IP route appeared or gone

    .. data:: isis_lsp_trig_ip_external_full = 12

    	Full IP redistribution

    .. data:: isis_lsp_trig_ip_def_orig = 13

    	Default information originate changed

    .. data:: isis_lsp_trig_ip_addr_chg = 14

    	IP interface address changed

    .. data:: isis_lsp_trig_te_info = 15

    	TE bandwidth resource information

    .. data:: isis_lsp_trig_te_pce_info = 16

    	TE PCE information

    .. data:: isis_lsp_trig_te_fa_info = 17

    	TE forwarding adjacency information

    .. data:: isis_lsp_trig_nsr_fo = 18

    	NSR FO is done

    .. data:: isis_lsp_trig_pn_cancel = 19

    	Pseudo-node generation canceled

    .. data:: isis_lsp_trig_lkgp = 20

    	Link-group offset metric change

    .. data:: isis_lsp_trig_pp = 21

    	Proactive Protection metric change

    """

    isis_lsp_trig_config = Enum.YLeaf(0, "isis-lsp-trig-config")

    isis_lsp_trig_newadj = Enum.YLeaf(1, "isis-lsp-trig-newadj")

    isis_lsp_trig_deladj = Enum.YLeaf(2, "isis-lsp-trig-deladj")

    isis_lsp_trig_dr_change = Enum.YLeaf(3, "isis-lsp-trig-dr-change")

    isis_lsp_trig_area_set = Enum.YLeaf(4, "isis-lsp-trig-area-set")

    isis_lsp_trig_attach = Enum.YLeaf(5, "isis-lsp-trig-attach")

    isis_lsp_trig_hippity = Enum.YLeaf(6, "isis-lsp-trig-hippity")

    isis_lsp_trig_regen = Enum.YLeaf(7, "isis-lsp-trig-regen")

    isis_lsp_trig_ip_if_up = Enum.YLeaf(8, "isis-lsp-trig-ip-if-up")

    isis_lsp_trig_ip_if_down = Enum.YLeaf(9, "isis-lsp-trig-ip-if-down")

    isis_lsp_trig_ip_inter_area = Enum.YLeaf(10, "isis-lsp-trig-ip-inter-area")

    isis_lsp_trig_ip_external = Enum.YLeaf(11, "isis-lsp-trig-ip-external")

    isis_lsp_trig_ip_external_full = Enum.YLeaf(12, "isis-lsp-trig-ip-external-full")

    isis_lsp_trig_ip_def_orig = Enum.YLeaf(13, "isis-lsp-trig-ip-def-orig")

    isis_lsp_trig_ip_addr_chg = Enum.YLeaf(14, "isis-lsp-trig-ip-addr-chg")

    isis_lsp_trig_te_info = Enum.YLeaf(15, "isis-lsp-trig-te-info")

    isis_lsp_trig_te_pce_info = Enum.YLeaf(16, "isis-lsp-trig-te-pce-info")

    isis_lsp_trig_te_fa_info = Enum.YLeaf(17, "isis-lsp-trig-te-fa-info")

    isis_lsp_trig_nsr_fo = Enum.YLeaf(18, "isis-lsp-trig-nsr-fo")

    isis_lsp_trig_pn_cancel = Enum.YLeaf(19, "isis-lsp-trig-pn-cancel")

    isis_lsp_trig_lkgp = Enum.YLeaf(20, "isis-lsp-trig-lkgp")

    isis_lsp_trig_pp = Enum.YLeaf(21, "isis-lsp-trig-pp")


class IsisMediaClass(Enum):
    """
    IsisMediaClass

    Isis media class

    .. data:: isis_media_class_lan = 0

    	LAN

    .. data:: isis_media_class_p2p = 1

    	P2P

    .. data:: isis_media_class_loop_back = 2

    	Loopback

    """

    isis_media_class_lan = Enum.YLeaf(0, "isis-media-class-lan")

    isis_media_class_p2p = Enum.YLeaf(1, "isis-media-class-p2p")

    isis_media_class_loop_back = Enum.YLeaf(2, "isis-media-class-loop-back")


class IsisMetricMode(Enum):
    """
    IsisMetricMode

    Isis metric mode

    .. data:: isis_metric_mode_fixed = 0

    	Fixed

    .. data:: isis_metric_mode_relative = 1

    	Relative

    .. data:: isis_metric_mode_absolute = 2

    	Absolute

    """

    isis_metric_mode_fixed = Enum.YLeaf(0, "isis-metric-mode-fixed")

    isis_metric_mode_relative = Enum.YLeaf(1, "isis-metric-mode-relative")

    isis_metric_mode_absolute = Enum.YLeaf(2, "isis-metric-mode-absolute")


class IsisMetricStyle(Enum):
    """
    IsisMetricStyle

    Isis metric style

    .. data:: isis_metric_style_narrow = 0

    	old-style (ISO 10589) metrics

    .. data:: isis_metric_style_wide = 1

    	new-style 32-bit metrics

    .. data:: isis_metric_style_transition = 2

    	send/accept both forms of metric

    """

    isis_metric_style_narrow = Enum.YLeaf(0, "isis-metric-style-narrow")

    isis_metric_style_wide = Enum.YLeaf(1, "isis-metric-style-wide")

    isis_metric_style_transition = Enum.YLeaf(2, "isis-metric-style-transition")


class IsisNsfFlavor(Enum):
    """
    IsisNsfFlavor

    Isis nsf flavor

    .. data:: isis_nsf_flav_or_none = 0

    	NSF not configured

    .. data:: isis_nsf_flav_or_cisco = 1

    	Cisco-proprietary NSF

    .. data:: isis_nsf_flav_or_ietf = 2

    	IETF-standard NSF

    .. data:: isis_nsf_flav_or_nsr = 3

    	Cisco-proprietary NSR

    """

    isis_nsf_flav_or_none = Enum.YLeaf(0, "isis-nsf-flav-or-none")

    isis_nsf_flav_or_cisco = Enum.YLeaf(1, "isis-nsf-flav-or-cisco")

    isis_nsf_flav_or_ietf = Enum.YLeaf(2, "isis-nsf-flav-or-ietf")

    isis_nsf_flav_or_nsr = Enum.YLeaf(3, "isis-nsf-flav-or-nsr")


class IsisPrefixOrigin(Enum):
    """
    IsisPrefixOrigin

    Isis prefix origin

    .. data:: isis_prefix_origin_l1_summary_null = 0

    	Level 1 Summary Null Route

    .. data:: isis_prefix_origin_l1 = 1

    	Level 1 Route

    .. data:: isis_prefix_origin_l2_summary_null = 2

    	Level 2 Summary Null Route

    .. data:: isis_prefix_origin_l2 = 3

    	Level 2 Route

    .. data:: isis_prefix_origin_inter_area_summary_null = 4

    	Level 1 Interarea Summary Null Route

    .. data:: isis_prefix_origin_inter_area = 5

    	Level 1 Interarea Route

    .. data:: isis_prefix_origin_default_nearest_attached = 6

    	Nearest Attached Default Route

    """

    isis_prefix_origin_l1_summary_null = Enum.YLeaf(0, "isis-prefix-origin-l1-summary-null")

    isis_prefix_origin_l1 = Enum.YLeaf(1, "isis-prefix-origin-l1")

    isis_prefix_origin_l2_summary_null = Enum.YLeaf(2, "isis-prefix-origin-l2-summary-null")

    isis_prefix_origin_l2 = Enum.YLeaf(3, "isis-prefix-origin-l2")

    isis_prefix_origin_inter_area_summary_null = Enum.YLeaf(4, "isis-prefix-origin-inter-area-summary-null")

    isis_prefix_origin_inter_area = Enum.YLeaf(5, "isis-prefix-origin-inter-area")

    isis_prefix_origin_default_nearest_attached = Enum.YLeaf(6, "isis-prefix-origin-default-nearest-attached")


class IsisPrefixPriority(Enum):
    """
    IsisPrefixPriority

    Isis prefix priority

    .. data:: isis_prefix_priority_critical = 0

    	Critical priority prefixes

    .. data:: isis_prefix_priority_high = 1

    	High priority prefixes

    .. data:: isis_prefix_priority_med = 2

    	Medium priority prefixes

    .. data:: isis_prefix_priority_low = 3

    	Low priority prefixes

    """

    isis_prefix_priority_critical = Enum.YLeaf(0, "isis-prefix-priority-critical")

    isis_prefix_priority_high = Enum.YLeaf(1, "isis-prefix-priority-high")

    isis_prefix_priority_med = Enum.YLeaf(2, "isis-prefix-priority-med")

    isis_prefix_priority_low = Enum.YLeaf(3, "isis-prefix-priority-low")


class IsisReachable(Enum):
    """
    IsisReachable

    Isis reachable

    .. data:: isis_unreachable = 0

    	Unreachable

    .. data:: isis_reachable = 1

    	Reachable

    """

    isis_unreachable = Enum.YLeaf(0, "isis-unreachable")

    isis_reachable = Enum.YLeaf(1, "isis-reachable")


class IsisRedistProto(Enum):
    """
    IsisRedistProto

    Isis redist proto

    .. data:: isis_redist_connected = 0

    	Redistributed protocol is Connected

    .. data:: isis_redist_static = 1

    	Redistributed protocol is Static

    .. data:: isis_redist_ospf = 2

    	Redistributed protocol is OSPF

    .. data:: isis_redist_bgp = 3

    	Redistributed protocol is BGP

    .. data:: isis_redist_isis = 4

    	Redistributed protocol is IS-IS

    .. data:: isis_redist_ospfv3 = 5

    	Redistributed protocol is OSPFv3

    .. data:: isis_redist_rip = 6

    	Redistributed protocol is RIP

    .. data:: isis_redist_eigrp = 7

    	Redistributed protocol is EIGRP

    .. data:: isis_redist_subscriber = 8

    	Redistributed protocol is Subscriber

    .. data:: isis_redist_application = 9

    	Redistributed protocol is Application

    .. data:: isis_redist_mobile = 10

    	Redistributed protocol is Mobile

    """

    isis_redist_connected = Enum.YLeaf(0, "isis-redist-connected")

    isis_redist_static = Enum.YLeaf(1, "isis-redist-static")

    isis_redist_ospf = Enum.YLeaf(2, "isis-redist-ospf")

    isis_redist_bgp = Enum.YLeaf(3, "isis-redist-bgp")

    isis_redist_isis = Enum.YLeaf(4, "isis-redist-isis")

    isis_redist_ospfv3 = Enum.YLeaf(5, "isis-redist-ospfv3")

    isis_redist_rip = Enum.YLeaf(6, "isis-redist-rip")

    isis_redist_eigrp = Enum.YLeaf(7, "isis-redist-eigrp")

    isis_redist_subscriber = Enum.YLeaf(8, "isis-redist-subscriber")

    isis_redist_application = Enum.YLeaf(9, "isis-redist-application")

    isis_redist_mobile = Enum.YLeaf(10, "isis-redist-mobile")


class IsisShRouteAdvOrigin(Enum):
    """
    IsisShRouteAdvOrigin

    Origin of a prefix advertisement

    .. data:: isis_sh_route_adv_origin_interface = 0

    	IS-IS interface prefix

    .. data:: isis_sh_route_adv_origin_redistributed = 1

    	Redistributed prefix

    .. data:: isis_sh_route_adv_origin_native = 2

    	Native prefix

    .. data:: isis_sh_route_adv_origin_summary = 3

    	Summary prefix

    .. data:: isis_sh_route_adv_origin_default = 4

    	Explicit origination of default prefix

    """

    isis_sh_route_adv_origin_interface = Enum.YLeaf(0, "isis-sh-route-adv-origin-interface")

    isis_sh_route_adv_origin_redistributed = Enum.YLeaf(1, "isis-sh-route-adv-origin-redistributed")

    isis_sh_route_adv_origin_native = Enum.YLeaf(2, "isis-sh-route-adv-origin-native")

    isis_sh_route_adv_origin_summary = Enum.YLeaf(3, "isis-sh-route-adv-origin-summary")

    isis_sh_route_adv_origin_default = Enum.YLeaf(4, "isis-sh-route-adv-origin-default")


class IsisShTeLink(Enum):
    """
    IsisShTeLink

    Isis sh te link

    .. data:: isis_sh_te_link_p2p = 0

    	Tunnel is absolute

    .. data:: isis_sh_te_link_broadcast = 1

    	Broadcast link

    """

    isis_sh_te_link_p2p = Enum.YLeaf(0, "isis-sh-te-link-p2p")

    isis_sh_te_link_broadcast = Enum.YLeaf(1, "isis-sh-te-link-broadcast")


class IsisShTePceFloodingScope(Enum):
    """
    IsisShTePceFloodingScope

    Isis sh te pce flooding scope

    .. data:: none = 0

    	Flooding is disabled

    .. data:: area = 1

    	Area wide flooding

    .. data:: domain = 2

    	Domain wide flooding

    """

    none = Enum.YLeaf(0, "none")

    area = Enum.YLeaf(1, "area")

    domain = Enum.YLeaf(2, "domain")


class IsisSpfClass(Enum):
    """
    IsisSpfClass

    Types of route calculation

    .. data:: isis_spf_frr_sr_u_loop = 0

    	Remote microloop avoidance SPF

    .. data:: isis_spf_frr_per_link = 1

    	FRR per-link SPF

    .. data:: isis_spf_partial = 2

    	PRC

    .. data:: isis_spf_frr_per_prefix = 3

    	FRR per-prefix SPF

    .. data:: isis_spf_ucmp_calc = 4

    	UCMP SPF

    .. data:: isis_spf_next_hop = 5

    	Next Hop

    .. data:: isis_spf_incremental = 6

    	Incremental SPF

    .. data:: isis_spf_full = 7

    	Full SPF

    """

    isis_spf_frr_sr_u_loop = Enum.YLeaf(0, "isis-spf-frr-sr-u-loop")

    isis_spf_frr_per_link = Enum.YLeaf(1, "isis-spf-frr-per-link")

    isis_spf_partial = Enum.YLeaf(2, "isis-spf-partial")

    isis_spf_frr_per_prefix = Enum.YLeaf(3, "isis-spf-frr-per-prefix")

    isis_spf_ucmp_calc = Enum.YLeaf(4, "isis-spf-ucmp-calc")

    isis_spf_next_hop = Enum.YLeaf(5, "isis-spf-next-hop")

    isis_spf_incremental = Enum.YLeaf(6, "isis-spf-incremental")

    isis_spf_full = Enum.YLeaf(7, "isis-spf-full")


class IsisSpfTrigger(Enum):
    """
    IsisSpfTrigger

    Isis spf trigger

    .. data:: isis_spf_trig_config = 0

    	Configuration change

    .. data:: isis_spf_trig_nsr_fo = 1

    	NSR FO is done

    .. data:: isis_spf_trig_periodic = 2

    	Periodic SPF

    .. data:: isis_spf_trig_clear = 3

    	Cleared route table

    .. data:: isis_spf_trig_newadj = 4

    	New adjacency

    .. data:: isis_spf_trig_deladj = 5

    	Deleted adjacency

    .. data:: isis_spf_trig_next_hop = 6

    	IP nexthop address change

    .. data:: isis_spf_trig_metric = 7

    	Changed interface metric

    .. data:: isis_spf_trig_dis = 8

    	Change to elected DIS

    .. data:: isis_spf_trig_frr_per_link = 9

    	Change to per-link FRR config

    .. data:: isis_spf_trig_frr_per_prefix = 10

    	Change to per-prefix FRR config

    .. data:: isis_spf_trig_ucmp = 11

    	Change to UCMP config/calculation

    .. data:: isis_spf_trig_new_tunnel = 12

    	New TE Autoroute Tunnel

    .. data:: isis_spf_trig_del_tunnel = 13

    	Deleted TE Autoroute Tunnel

    .. data:: isis_spf_trig_chg_tunnel = 14

    	Changed TE Autoroute Tunnel

    .. data:: isis_spf_trig_new_node = 15

    	New LSP zero which participates in topology

    .. data:: isis_spf_trig_del_node = 16

    	New LSP zero which no longer participates in

    	topology

    .. data:: isis_spf_trig_newlsp = 17

    	Previously unseen LSP fragment

    .. data:: isis_spf_trig_lsp_expiry = 18

    	LSP expired

    .. data:: isis_spf_trig_attach_set = 19

    	Attached bit set

    .. data:: isis_spf_trig_attach_clr = 20

    	Attached bit cleared

    .. data:: isis_spf_trig_overload_set = 21

    	Overload bit set

    .. data:: isis_spf_trig_overload_clr = 22

    	Overload bit cleared

    .. data:: isis_spf_trig_link_good = 23

    	Good news link TLV content change

    .. data:: isis_spf_trig_link_bad = 24

    	Bad news link TLV content change

    .. data:: isis_spf_trig_prefix_good = 25

    	Good news prefix TLV content change

    .. data:: isis_spf_trig_prefix_bad = 26

    	Bad news prefix TLV content change

    .. data:: isis_spf_trig_prefix = 27

    	Neutral (neither good nor bad news) prefix TLV

    	content change

    .. data:: isis_spf_trig_area_addr = 28

    	Area address TLV content change

    .. data:: isis_spf_trig_ip_addr = 29

    	IP address TLV content change

    .. data:: isis_spf_trig_rtrid = 30

    	Router id TLV content change

    .. data:: isis_spf_trig_prefix_policy = 31

    	Prefix policy change

    """

    isis_spf_trig_config = Enum.YLeaf(0, "isis-spf-trig-config")

    isis_spf_trig_nsr_fo = Enum.YLeaf(1, "isis-spf-trig-nsr-fo")

    isis_spf_trig_periodic = Enum.YLeaf(2, "isis-spf-trig-periodic")

    isis_spf_trig_clear = Enum.YLeaf(3, "isis-spf-trig-clear")

    isis_spf_trig_newadj = Enum.YLeaf(4, "isis-spf-trig-newadj")

    isis_spf_trig_deladj = Enum.YLeaf(5, "isis-spf-trig-deladj")

    isis_spf_trig_next_hop = Enum.YLeaf(6, "isis-spf-trig-next-hop")

    isis_spf_trig_metric = Enum.YLeaf(7, "isis-spf-trig-metric")

    isis_spf_trig_dis = Enum.YLeaf(8, "isis-spf-trig-dis")

    isis_spf_trig_frr_per_link = Enum.YLeaf(9, "isis-spf-trig-frr-per-link")

    isis_spf_trig_frr_per_prefix = Enum.YLeaf(10, "isis-spf-trig-frr-per-prefix")

    isis_spf_trig_ucmp = Enum.YLeaf(11, "isis-spf-trig-ucmp")

    isis_spf_trig_new_tunnel = Enum.YLeaf(12, "isis-spf-trig-new-tunnel")

    isis_spf_trig_del_tunnel = Enum.YLeaf(13, "isis-spf-trig-del-tunnel")

    isis_spf_trig_chg_tunnel = Enum.YLeaf(14, "isis-spf-trig-chg-tunnel")

    isis_spf_trig_new_node = Enum.YLeaf(15, "isis-spf-trig-new-node")

    isis_spf_trig_del_node = Enum.YLeaf(16, "isis-spf-trig-del-node")

    isis_spf_trig_newlsp = Enum.YLeaf(17, "isis-spf-trig-newlsp")

    isis_spf_trig_lsp_expiry = Enum.YLeaf(18, "isis-spf-trig-lsp-expiry")

    isis_spf_trig_attach_set = Enum.YLeaf(19, "isis-spf-trig-attach-set")

    isis_spf_trig_attach_clr = Enum.YLeaf(20, "isis-spf-trig-attach-clr")

    isis_spf_trig_overload_set = Enum.YLeaf(21, "isis-spf-trig-overload-set")

    isis_spf_trig_overload_clr = Enum.YLeaf(22, "isis-spf-trig-overload-clr")

    isis_spf_trig_link_good = Enum.YLeaf(23, "isis-spf-trig-link-good")

    isis_spf_trig_link_bad = Enum.YLeaf(24, "isis-spf-trig-link-bad")

    isis_spf_trig_prefix_good = Enum.YLeaf(25, "isis-spf-trig-prefix-good")

    isis_spf_trig_prefix_bad = Enum.YLeaf(26, "isis-spf-trig-prefix-bad")

    isis_spf_trig_prefix = Enum.YLeaf(27, "isis-spf-trig-prefix")

    isis_spf_trig_area_addr = Enum.YLeaf(28, "isis-spf-trig-area-addr")

    isis_spf_trig_ip_addr = Enum.YLeaf(29, "isis-spf-trig-ip-addr")

    isis_spf_trig_rtrid = Enum.YLeaf(30, "isis-spf-trig-rtrid")

    isis_spf_trig_prefix_policy = Enum.YLeaf(31, "isis-spf-trig-prefix-policy")


class IsisStartupStatus(Enum):
    """
    IsisStartupStatus

    Isis startup status

    .. data:: isis_startup_ssm_active = 0

    	Startup-state-machine controlled restart in

    	progress

    .. data:: isis_startup_ssm_complete = 1

    	Startup-state-machine controlled restart

    	complete

    .. data:: isis_startup_ssm_aborted = 2

    	Startup-state-machine controlled restart

    	aborted

    .. data:: isis_startup_ssm_not_run = 3

    	Startup-state-machine controlled not attempted

    """

    isis_startup_ssm_active = Enum.YLeaf(0, "isis-startup-ssm-active")

    isis_startup_ssm_complete = Enum.YLeaf(1, "isis-startup-ssm-complete")

    isis_startup_ssm_aborted = Enum.YLeaf(2, "isis-startup-ssm-aborted")

    isis_startup_ssm_not_run = Enum.YLeaf(3, "isis-startup-ssm-not-run")


class IsisSubAfId(Enum):
    """
    IsisSubAfId

    Isis sub af id

    .. data:: unicast = 0

    	Unicast

    .. data:: multicast = 1

    	Multicast

    """

    unicast = Enum.YLeaf(0, "unicast")

    multicast = Enum.YLeaf(1, "multicast")


class IsisTilfaComputation(Enum):
    """
    IsisTilfaComputation

    Isis tilfa computation

    .. data:: isis_tilfa_comp_none = 0

    	isis tilfa comp none

    .. data:: isis_tilfa_comp_link = 1

    	isis tilfa comp link

    .. data:: isis_tilfa_comp_node = 2

    	isis tilfa comp node

    .. data:: isis_tilfa_comp_srlg = 3

    	isis tilfa comp srlg

    .. data:: isis_tilfa_comp_node_srlg = 4

    	isis tilfa comp node srlg

    """

    isis_tilfa_comp_none = Enum.YLeaf(0, "isis-tilfa-comp-none")

    isis_tilfa_comp_link = Enum.YLeaf(1, "isis-tilfa-comp-link")

    isis_tilfa_comp_node = Enum.YLeaf(2, "isis-tilfa-comp-node")

    isis_tilfa_comp_srlg = Enum.YLeaf(3, "isis-tilfa-comp-srlg")

    isis_tilfa_comp_node_srlg = Enum.YLeaf(4, "isis-tilfa-comp-node-srlg")


class IsisUloopAvoidance(Enum):
    """
    IsisUloopAvoidance

    Isis uloop avoidance

    .. data:: isis_u_loop_avoidance_type_none = 0

    	No MicroLoop avoidance

    .. data:: isis_u_loop_avoidance_type_all = 1

    	Apply MicroLoop avoidance for all prefixes

    .. data:: isis_u_loop_avoidance_type_protected = 2

    	Apply MicroLoop avoidance only for protected

    	prefixes

    .. data:: isis_u_loop_avoidance_type_sr = 3

    	Segment Routing MicroLoop avoidance for All

    	single-link changes

    """

    isis_u_loop_avoidance_type_none = Enum.YLeaf(0, "isis-u-loop-avoidance-type-none")

    isis_u_loop_avoidance_type_all = Enum.YLeaf(1, "isis-u-loop-avoidance-type-all")

    isis_u_loop_avoidance_type_protected = Enum.YLeaf(2, "isis-u-loop-avoidance-type-protected")

    isis_u_loop_avoidance_type_sr = Enum.YLeaf(3, "isis-u-loop-avoidance-type-sr")


class IsisUloopEvent(Enum):
    """
    IsisUloopEvent

    Isis uloop event

    .. data:: isis_u_loop_event_none = 0

    	isis u loop event none

    .. data:: isis_u_loop_event_link_down = 1

    	isis u loop event link down

    .. data:: isis_u_loop_event_link_up = 2

    	isis u loop event link up

    .. data:: isis_u_loop_event_ol_bit_set = 3

    	isis u loop event ol bit set

    .. data:: isis_u_loop_event_ol_bit_unset = 4

    	isis u loop event ol bit unset

    """

    isis_u_loop_event_none = Enum.YLeaf(0, "isis-u-loop-event-none")

    isis_u_loop_event_link_down = Enum.YLeaf(1, "isis-u-loop-event-link-down")

    isis_u_loop_event_link_up = Enum.YLeaf(2, "isis-u-loop-event-link-up")

    isis_u_loop_event_ol_bit_set = Enum.YLeaf(3, "isis-u-loop-event-ol-bit-set")

    isis_u_loop_event_ol_bit_unset = Enum.YLeaf(4, "isis-u-loop-event-ol-bit-unset")


class IsisUp(Enum):
    """
    IsisUp

    Isis up

    .. data:: isis_down = 0

    	Down

    .. data:: isis_up = 1

    	Up

    """

    isis_down = Enum.YLeaf(0, "isis-down")

    isis_up = Enum.YLeaf(1, "isis-up")


class IsisValid(Enum):
    """
    IsisValid

    Isis valid

    .. data:: isis_invalid = 0

    	Invalid

    .. data:: isis_valid = 1

    	Valid

    """

    isis_invalid = Enum.YLeaf(0, "isis-invalid")

    isis_valid = Enum.YLeaf(1, "isis-valid")


class SrmsMiAfEB(Enum):
    """
    SrmsMiAfEB

    Srms mi af e b

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")


class SrmsMiFlagEB(Enum):
    """
    SrmsMiFlagEB

    Srms mi flag e b

    .. data:: false = 0

    	False

    .. data:: true = 1

    	True

    """

    false = Enum.YLeaf(0, "false")

    true = Enum.YLeaf(1, "true")


class SrmsMiSrcEB(Enum):
    """
    SrmsMiSrcEB

    Srms mi src e b

    .. data:: none = 0

    	None

    .. data:: local = 1

    	Local

    .. data:: remote = 2

    	Remote

    """

    none = Enum.YLeaf(0, "none")

    local = Enum.YLeaf(1, "local")

    remote = Enum.YLeaf(2, "remote")



class Isis(Entity):
    """
    IS\-IS operational data
    
    .. attribute:: instances
    
    	Per\-instance operational data
    	**type**\:   :py:class:`Instances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances>`
    
    

    """

    _prefix = 'clns-isis-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Isis, self).__init__()
        self._top_entity = None

        self.yang_name = "isis"
        self.yang_parent_name = "Cisco-IOS-XR-clns-isis-oper"

        self.instances = Isis.Instances()
        self.instances.parent = self
        self._children_name_map["instances"] = "instances"
        self._children_yang_names.add("instances")


    class Instances(Entity):
        """
        Per\-instance operational data
        
        .. attribute:: instance
        
        	IS\-IS instance
        	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance>`
        
        

        """

        _prefix = 'clns-isis-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Isis.Instances, self).__init__()

            self.yang_name = "instances"
            self.yang_parent_name = "isis"

            self.instance = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Isis.Instances, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Isis.Instances, self).__setattr__(name, value)


        class Instance(Entity):
            """
            IS\-IS instance
            
            .. attribute:: instance_name  <key>
            
            	Instance identifier
            	**type**\:  str
            
            	**length:** 1..40
            
            .. attribute:: checkpoint_adjacencies
            
            	Checkpointed adjacency table
            	**type**\:   :py:class:`CheckpointAdjacencies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies>`
            
            .. attribute:: checkpoint_interfaces
            
            	Checkpointed interface table
            	**type**\:   :py:class:`CheckpointInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointInterfaces>`
            
            .. attribute:: checkpoint_lsps
            
            	Checkpointed LSP table
            	**type**\:   :py:class:`CheckpointLsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointLsps>`
            
            .. attribute:: checkpoint_te_tunnels
            
            	Checkpointed TE tunnel table
            	**type**\:   :py:class:`CheckpointTeTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointTeTunnels>`
            
            .. attribute:: error_log
            
            	Log of errors and warnings
            	**type**\:   :py:class:`ErrorLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog>`
            
            .. attribute:: host_names
            
            	Hostname table
            	**type**\:   :py:class:`HostNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.HostNames>`
            
            .. attribute:: interface_statistics
            
            	Interface statistics table
            	**type**\:   :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics>`
            
            .. attribute:: interfaces
            
            	Interface table
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces>`
            
            .. attribute:: levels
            
            	Level table
            	**type**\:   :py:class:`Levels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels>`
            
            .. attribute:: mesh_groups
            
            	Mesh\-group information
            	**type**\:   :py:class:`MeshGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups>`
            
            .. attribute:: neighbor_summaries
            
            	Neighbor\-summary table
            	**type**\:   :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries>`
            
            .. attribute:: neighbors
            
            	Neighbor table
            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors>`
            
            .. attribute:: nsr_statistics
            
            	NSR Statistics information
            	**type**\:   :py:class:`NsrStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics>`
            
            .. attribute:: nsr_status
            
            	NSR Status information
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus>`
            
            .. attribute:: protocol
            
            	Basic protocol information about an IS\-IS instance
            	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol>`
            
            .. attribute:: srms
            
            	Segment Routing Mapping Server operational data
            	**type**\:   :py:class:`Srms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms>`
            
            .. attribute:: statistics_global
            
            	Per\-instance statistics
            	**type**\:   :py:class:`StatisticsGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal>`
            
            .. attribute:: topologies
            
            	Topology table
            	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies>`
            
            

            """

            _prefix = 'clns-isis-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Isis.Instances.Instance, self).__init__()

                self.yang_name = "instance"
                self.yang_parent_name = "instances"

                self.instance_name = YLeaf(YType.str, "instance-name")

                self.checkpoint_adjacencies = Isis.Instances.Instance.CheckpointAdjacencies()
                self.checkpoint_adjacencies.parent = self
                self._children_name_map["checkpoint_adjacencies"] = "checkpoint-adjacencies"
                self._children_yang_names.add("checkpoint-adjacencies")

                self.checkpoint_interfaces = Isis.Instances.Instance.CheckpointInterfaces()
                self.checkpoint_interfaces.parent = self
                self._children_name_map["checkpoint_interfaces"] = "checkpoint-interfaces"
                self._children_yang_names.add("checkpoint-interfaces")

                self.checkpoint_lsps = Isis.Instances.Instance.CheckpointLsps()
                self.checkpoint_lsps.parent = self
                self._children_name_map["checkpoint_lsps"] = "checkpoint-lsps"
                self._children_yang_names.add("checkpoint-lsps")

                self.checkpoint_te_tunnels = Isis.Instances.Instance.CheckpointTeTunnels()
                self.checkpoint_te_tunnels.parent = self
                self._children_name_map["checkpoint_te_tunnels"] = "checkpoint-te-tunnels"
                self._children_yang_names.add("checkpoint-te-tunnels")

                self.error_log = Isis.Instances.Instance.ErrorLog()
                self.error_log.parent = self
                self._children_name_map["error_log"] = "error-log"
                self._children_yang_names.add("error-log")

                self.host_names = Isis.Instances.Instance.HostNames()
                self.host_names.parent = self
                self._children_name_map["host_names"] = "host-names"
                self._children_yang_names.add("host-names")

                self.interface_statistics = Isis.Instances.Instance.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"
                self._children_yang_names.add("interface-statistics")

                self.interfaces = Isis.Instances.Instance.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")

                self.levels = Isis.Instances.Instance.Levels()
                self.levels.parent = self
                self._children_name_map["levels"] = "levels"
                self._children_yang_names.add("levels")

                self.mesh_groups = Isis.Instances.Instance.MeshGroups()
                self.mesh_groups.parent = self
                self._children_name_map["mesh_groups"] = "mesh-groups"
                self._children_yang_names.add("mesh-groups")

                self.neighbor_summaries = Isis.Instances.Instance.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                self._children_yang_names.add("neighbor-summaries")

                self.neighbors = Isis.Instances.Instance.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"
                self._children_yang_names.add("neighbors")

                self.nsr_statistics = Isis.Instances.Instance.NsrStatistics()
                self.nsr_statistics.parent = self
                self._children_name_map["nsr_statistics"] = "nsr-statistics"
                self._children_yang_names.add("nsr-statistics")

                self.nsr_status = Isis.Instances.Instance.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"
                self._children_yang_names.add("nsr-status")

                self.protocol = Isis.Instances.Instance.Protocol()
                self.protocol.parent = self
                self._children_name_map["protocol"] = "protocol"
                self._children_yang_names.add("protocol")

                self.srms = Isis.Instances.Instance.Srms()
                self.srms.parent = self
                self._children_name_map["srms"] = "srms"
                self._children_yang_names.add("srms")

                self.statistics_global = Isis.Instances.Instance.StatisticsGlobal()
                self.statistics_global.parent = self
                self._children_name_map["statistics_global"] = "statistics-global"
                self._children_yang_names.add("statistics-global")

                self.topologies = Isis.Instances.Instance.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"
                self._children_yang_names.add("topologies")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("instance_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Isis.Instances.Instance, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Isis.Instances.Instance, self).__setattr__(name, value)


            class Neighbors(Entity):
                """
                Neighbor table
                
                .. attribute:: neighbor
                
                	A single neighbor router
                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "instance"

                    self.neighbor = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.Neighbors, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.Neighbors, self).__setattr__(name, value)


                class Neighbor(Entity):
                    """
                    A single neighbor router
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: neighbor_active_area_address
                    
                    	Active area addresses
                    	**type**\: list of    :py:class:`NeighborActiveAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress>`
                    
                    .. attribute:: neighbor_circuit_type
                    
                    	Circuit type
                    	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: neighbor_holdtime
                    
                    	Time (s) until neighbor declared down if no IIH received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_ietf_nsf_capable_flag
                    
                    	TRUE if neighbor is IETF\-NSF capable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_media_type
                    
                    	Link media type
                    	**type**\:   :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                    
                    .. attribute:: neighbor_per_address_family_data
                    
                    	Per address\-family data
                    	**type**\: list of    :py:class:`NeighborPerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData>`
                    
                    .. attribute:: neighbor_snpa
                    
                    	Neighbor SNPA
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: neighbor_state
                    
                    	Neighbor (adjacency) state
                    	**type**\:   :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                    
                    .. attribute:: neighbor_system_id
                    
                    	Neighbor system ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: neighbor_uptime
                    
                    	How long the neighbor has been up (s)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_uptime_valid_flag
                    
                    	TRUE if NeighborUptime is set
                    	**type**\:  bool
                    
                    .. attribute:: nsr_standby
                    
                    	ISIS NSR STANDBY
                    	**type**\:  bool
                    
                    .. attribute:: system_id
                    
                    	System ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: topologies_supported
                    
                    	Topologies supported by both neighbor and local system
                    	**type**\: list of    :py:class:`TopologiesSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.local_interface = YLeaf(YType.str, "local-interface")

                        self.neighbor_circuit_type = YLeaf(YType.enumeration, "neighbor-circuit-type")

                        self.neighbor_holdtime = YLeaf(YType.uint32, "neighbor-holdtime")

                        self.neighbor_ietf_nsf_capable_flag = YLeaf(YType.uint32, "neighbor-ietf-nsf-capable-flag")

                        self.neighbor_media_type = YLeaf(YType.enumeration, "neighbor-media-type")

                        self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                        self.neighbor_uptime = YLeaf(YType.uint32, "neighbor-uptime")

                        self.neighbor_uptime_valid_flag = YLeaf(YType.boolean, "neighbor-uptime-valid-flag")

                        self.nsr_standby = YLeaf(YType.boolean, "nsr-standby")

                        self.system_id = YLeaf(YType.str, "system-id")

                        self.neighbor_active_area_address = YList(self)
                        self.neighbor_per_address_family_data = YList(self)
                        self.topologies_supported = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "local_interface",
                                        "neighbor_circuit_type",
                                        "neighbor_holdtime",
                                        "neighbor_ietf_nsf_capable_flag",
                                        "neighbor_media_type",
                                        "neighbor_snpa",
                                        "neighbor_state",
                                        "neighbor_system_id",
                                        "neighbor_uptime",
                                        "neighbor_uptime_valid_flag",
                                        "nsr_standby",
                                        "system_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Neighbors.Neighbor, self).__setattr__(name, value)


                    class NeighborActiveAreaAddress(Entity):
                        """
                        Active area addresses
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress, self).__init__()

                            self.yang_name = "neighbor-active-area-address"
                            self.yang_parent_name = "neighbor"

                            self.entry = YLeaf(YType.str, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-active-area-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix


                    class TopologiesSupported(Entity):
                        """
                        Topologies supported by both neighbor and local
                        system
                        
                        .. attribute:: af_name
                        
                        	AF name
                        	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: saf_name
                        
                        	Sub\-AF name
                        	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                        
                        .. attribute:: topology_name
                        
                        	Topology Name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported, self).__init__()

                            self.yang_name = "topologies-supported"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "saf_name",
                                            "topology_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topologies-supported" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix


                    class NeighborPerAddressFamilyData(Entity):
                        """
                        Per address\-family data
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: ipv4
                        
                        	IPV4 neighbor info
                        	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPV6 neighbor info
                        	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData, self).__init__()

                            self.yang_name = "neighbor-per-address-family-data"
                            self.yang_parent_name = "neighbor"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._children_yang_names.add("ipv4")

                            self.ipv6 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._children_yang_names.add("ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData, self).__setattr__(name, value)


                        class Ipv4(Entity):
                            """
                            IPV4 neighbor info
                            
                            .. attribute:: adjacency_sid
                            
                            	Adjacency SID
                            	**type**\:   :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid>`
                            
                            .. attribute:: interface_address
                            
                            	Adjacency interface addresses
                            	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress>`
                            
                            .. attribute:: next_hop
                            
                            	Adjacency next hop
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: non_frr_adjacency_sid
                            
                            	Adjacency SID not eligible for FRR protection
                            	**type**\:   :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid>`
                            
                            .. attribute:: underlying_adjacency_sid
                            
                            	Per bundle member Adjacency sid
                            	**type**\: list of    :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid>`
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of    :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "neighbor-per-address-family-data"

                                self.next_hop = YLeaf(YType.str, "next-hop")

                                self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid()
                                self.adjacency_sid.parent = self
                                self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                self._children_yang_names.add("adjacency-sid")

                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                self.non_frr_adjacency_sid.parent = self
                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                self._children_yang_names.add("non-frr-adjacency-sid")

                                self.interface_address = YList(self)
                                self.underlying_adjacency_sid = YList(self)
                                self.underlying_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4, self).__setattr__(name, value)


                            class AdjacencySid(Entity):
                                """
                                Adjacency SID
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid, self).__init__()

                                    self.yang_name = "adjacency-sid"
                                    self.yang_parent_name = "ipv4"

                                    self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                    self._children_yang_names.add("adjacency-sid-backup")

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._children_yang_names.add("adjacency-sid-backup-te")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid, self).__setattr__(name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup-te" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_value.is_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_value.yfilter != YFilter.not_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "adjacency-sid-backup"):
                                        if (self.adjacency_sid_backup is None):
                                            self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                        return self.adjacency_sid_backup

                                    if (child_yang_name == "adjacency-sid-backup-te"):
                                        if (self.adjacency_sid_backup_te is None):
                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                        return self.adjacency_sid_backup_te

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-value"):
                                        self.adjacency_sid_value = value
                                        self.adjacency_sid_value.value_namespace = name_space
                                        self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                            class NonFrrAdjacencySid(Entity):
                                """
                                Adjacency SID not eligible for FRR protection
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__init__()

                                    self.yang_name = "non-frr-adjacency-sid"
                                    self.yang_parent_name = "ipv4"

                                    self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                    self._children_yang_names.add("adjacency-sid-backup")

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._children_yang_names.add("adjacency-sid-backup-te")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__setattr__(name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "non-frr-adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "non-frr-adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup-te" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_value.is_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_value.yfilter != YFilter.not_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "non-frr-adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "adjacency-sid-backup"):
                                        if (self.adjacency_sid_backup is None):
                                            self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                        return self.adjacency_sid_backup

                                    if (child_yang_name == "adjacency-sid-backup-te"):
                                        if (self.adjacency_sid_backup_te is None):
                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                        return self.adjacency_sid_backup_te

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-value"):
                                        self.adjacency_sid_value = value
                                        self.adjacency_sid_value.value_namespace = name_space
                                        self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                            class InterfaceAddress(Entity):
                                """
                                Adjacency interface addresses
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress, self).__init__()

                                    self.yang_name = "interface-address"
                                    self.yang_parent_name = "ipv4"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "ipv4"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "underlying-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class UnderlyingAdjacencySid(Entity):
                                """
                                Per bundle member Adjacency sid
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__init__()

                                    self.yang_name = "underlying-adjacency-sid"
                                    self.yang_parent_name = "ipv4"

                                    self.entry = YLeaf(YType.uint32, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "underlying-adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_address:
                                    if (c.has_data()):
                                        return True
                                for c in self.underlying_adjacency_sid:
                                    if (c.has_data()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.next_hop.is_set or
                                    (self.adjacency_sid is not None and self.adjacency_sid.has_data()) or
                                    (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_data()))

                            def has_operation(self):
                                for c in self.interface_address:
                                    if (c.has_operation()):
                                        return True
                                for c in self.underlying_adjacency_sid:
                                    if (c.has_operation()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop.yfilter != YFilter.not_set or
                                    (self.adjacency_sid is not None and self.adjacency_sid.has_operation()) or
                                    (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "adjacency-sid"):
                                    if (self.adjacency_sid is None):
                                        self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                    return self.adjacency_sid

                                if (child_yang_name == "interface-address"):
                                    for c in self.interface_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_address.append(c)
                                    return c

                                if (child_yang_name == "non-frr-adjacency-sid"):
                                    if (self.non_frr_adjacency_sid is None):
                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                    return self.non_frr_adjacency_sid

                                if (child_yang_name == "underlying-adjacency-sid"):
                                    for c in self.underlying_adjacency_sid:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.underlying_adjacency_sid.append(c)
                                    return c

                                if (child_yang_name == "underlying-interface"):
                                    for c in self.underlying_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.underlying_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adjacency-sid" or name == "interface-address" or name == "non-frr-adjacency-sid" or name == "underlying-adjacency-sid" or name == "underlying-interface" or name == "next-hop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop"):
                                    self.next_hop = value
                                    self.next_hop.value_namespace = name_space
                                    self.next_hop.value_namespace_prefix = name_space_prefix


                        class Ipv6(Entity):
                            """
                            IPV6 neighbor info
                            
                            .. attribute:: adjacency_sid
                            
                            	Adjacency SID
                            	**type**\:   :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid>`
                            
                            .. attribute:: interface_address
                            
                            	Adjacency interface addresses
                            	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress>`
                            
                            .. attribute:: next_hop
                            
                            	Adjacency next hop
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: non_frr_adjacency_sid
                            
                            	Adjacency SID not eligible for FRR protection
                            	**type**\:   :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid>`
                            
                            .. attribute:: underlying_adjacency_sid
                            
                            	Per bundle member Adjacency sid
                            	**type**\: list of    :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid>`
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of    :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "neighbor-per-address-family-data"

                                self.next_hop = YLeaf(YType.str, "next-hop")

                                self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid()
                                self.adjacency_sid.parent = self
                                self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                self._children_yang_names.add("adjacency-sid")

                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                self.non_frr_adjacency_sid.parent = self
                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                self._children_yang_names.add("non-frr-adjacency-sid")

                                self.interface_address = YList(self)
                                self.underlying_adjacency_sid = YList(self)
                                self.underlying_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("next_hop") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6, self).__setattr__(name, value)


                            class AdjacencySid(Entity):
                                """
                                Adjacency SID
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid, self).__init__()

                                    self.yang_name = "adjacency-sid"
                                    self.yang_parent_name = "ipv6"

                                    self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                    self._children_yang_names.add("adjacency-sid-backup")

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._children_yang_names.add("adjacency-sid-backup-te")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid, self).__setattr__(name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup-te" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_value.is_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_value.yfilter != YFilter.not_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "adjacency-sid-backup"):
                                        if (self.adjacency_sid_backup is None):
                                            self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                        return self.adjacency_sid_backup

                                    if (child_yang_name == "adjacency-sid-backup-te"):
                                        if (self.adjacency_sid_backup_te is None):
                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                        return self.adjacency_sid_backup_te

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-value"):
                                        self.adjacency_sid_value = value
                                        self.adjacency_sid_value.value_namespace = name_space
                                        self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                            class NonFrrAdjacencySid(Entity):
                                """
                                Adjacency SID not eligible for FRR protection
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__init__()

                                    self.yang_name = "non-frr-adjacency-sid"
                                    self.yang_parent_name = "ipv6"

                                    self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                    self._children_yang_names.add("adjacency-sid-backup")

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._children_yang_names.add("adjacency-sid-backup-te")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_sid_value") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__setattr__(name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "non-frr-adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "non-frr-adjacency-sid"

                                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                                        self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                        self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                        self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                        self.backup_label_stack = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("backup_interface",
                                                        "backup_label_stack_size",
                                                        "backup_nexthop",
                                                        "backup_node_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup-label-stack" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.backup_interface.is_set or
                                            self.backup_label_stack_size.is_set or
                                            self.backup_nexthop.is_set or
                                            self.backup_node_address.is_set)

                                    def has_operation(self):
                                        for c in self.backup_label_stack:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.backup_interface.yfilter != YFilter.not_set or
                                            self.backup_label_stack_size.yfilter != YFilter.not_set or
                                            self.backup_nexthop.yfilter != YFilter.not_set or
                                            self.backup_node_address.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "adjacency-sid-backup-te" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                        if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                        if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                        if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup-label-stack"):
                                            for c in self.backup_label_stack:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup_label_stack.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "backup-interface"):
                                            self.backup_interface = value
                                            self.backup_interface.value_namespace = name_space
                                            self.backup_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-label-stack-size"):
                                            self.backup_label_stack_size = value
                                            self.backup_label_stack_size.value_namespace = name_space
                                            self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-nexthop"):
                                            self.backup_nexthop = value
                                            self.backup_nexthop.value_namespace = name_space
                                            self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                        if(value_path == "backup-node-address"):
                                            self.backup_node_address = value
                                            self.backup_node_address.value_namespace = name_space
                                            self.backup_node_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_sid_value.is_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_sid_value.yfilter != YFilter.not_set or
                                        (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                        (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "non-frr-adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "adjacency-sid-backup"):
                                        if (self.adjacency_sid_backup is None):
                                            self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                        return self.adjacency_sid_backup

                                    if (child_yang_name == "adjacency-sid-backup-te"):
                                        if (self.adjacency_sid_backup_te is None):
                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                        return self.adjacency_sid_backup_te

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-sid-value"):
                                        self.adjacency_sid_value = value
                                        self.adjacency_sid_value.value_namespace = name_space
                                        self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                            class InterfaceAddress(Entity):
                                """
                                Adjacency interface addresses
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress, self).__init__()

                                    self.yang_name = "interface-address"
                                    self.yang_parent_name = "ipv6"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "interface-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "ipv6"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "underlying-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class UnderlyingAdjacencySid(Entity):
                                """
                                Per bundle member Adjacency sid
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__init__()

                                    self.yang_name = "underlying-adjacency-sid"
                                    self.yang_parent_name = "ipv6"

                                    self.entry = YLeaf(YType.uint32, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "underlying-adjacency-sid" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.interface_address:
                                    if (c.has_data()):
                                        return True
                                for c in self.underlying_adjacency_sid:
                                    if (c.has_data()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.next_hop.is_set or
                                    (self.adjacency_sid is not None and self.adjacency_sid.has_data()) or
                                    (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_data()))

                            def has_operation(self):
                                for c in self.interface_address:
                                    if (c.has_operation()):
                                        return True
                                for c in self.underlying_adjacency_sid:
                                    if (c.has_operation()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.next_hop.yfilter != YFilter.not_set or
                                    (self.adjacency_sid is not None and self.adjacency_sid.has_operation()) or
                                    (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.next_hop.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "adjacency-sid"):
                                    if (self.adjacency_sid is None):
                                        self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                    return self.adjacency_sid

                                if (child_yang_name == "interface-address"):
                                    for c in self.interface_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.interface_address.append(c)
                                    return c

                                if (child_yang_name == "non-frr-adjacency-sid"):
                                    if (self.non_frr_adjacency_sid is None):
                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                    return self.non_frr_adjacency_sid

                                if (child_yang_name == "underlying-adjacency-sid"):
                                    for c in self.underlying_adjacency_sid:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.underlying_adjacency_sid.append(c)
                                    return c

                                if (child_yang_name == "underlying-interface"):
                                    for c in self.underlying_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.underlying_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adjacency-sid" or name == "interface-address" or name == "non-frr-adjacency-sid" or name == "underlying-adjacency-sid" or name == "underlying-interface" or name == "next-hop"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "next-hop"):
                                    self.next_hop = value
                                    self.next_hop.value_namespace = name_space
                                    self.next_hop.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                (self.ipv4 is not None and self.ipv4.has_data()) or
                                (self.ipv6 is not None and self.ipv6.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                (self.ipv4 is not None and self.ipv4.has_operation()) or
                                (self.ipv6 is not None and self.ipv6.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "neighbor-per-address-family-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4"):
                                if (self.ipv4 is None):
                                    self.ipv4 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                return self.ipv4

                            if (child_yang_name == "ipv6"):
                                if (self.ipv6 is None):
                                    self.ipv6 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6()
                                    self.ipv6.parent = self
                                    self._children_name_map["ipv6"] = "ipv6"
                                return self.ipv6

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4" or name == "ipv6" or name == "af-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.neighbor_active_area_address:
                            if (c.has_data()):
                                return True
                        for c in self.neighbor_per_address_family_data:
                            if (c.has_data()):
                                return True
                        for c in self.topologies_supported:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.local_interface.is_set or
                            self.neighbor_circuit_type.is_set or
                            self.neighbor_holdtime.is_set or
                            self.neighbor_ietf_nsf_capable_flag.is_set or
                            self.neighbor_media_type.is_set or
                            self.neighbor_snpa.is_set or
                            self.neighbor_state.is_set or
                            self.neighbor_system_id.is_set or
                            self.neighbor_uptime.is_set or
                            self.neighbor_uptime_valid_flag.is_set or
                            self.nsr_standby.is_set or
                            self.system_id.is_set)

                    def has_operation(self):
                        for c in self.neighbor_active_area_address:
                            if (c.has_operation()):
                                return True
                        for c in self.neighbor_per_address_family_data:
                            if (c.has_operation()):
                                return True
                        for c in self.topologies_supported:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.local_interface.yfilter != YFilter.not_set or
                            self.neighbor_circuit_type.yfilter != YFilter.not_set or
                            self.neighbor_holdtime.yfilter != YFilter.not_set or
                            self.neighbor_ietf_nsf_capable_flag.yfilter != YFilter.not_set or
                            self.neighbor_media_type.yfilter != YFilter.not_set or
                            self.neighbor_snpa.yfilter != YFilter.not_set or
                            self.neighbor_state.yfilter != YFilter.not_set or
                            self.neighbor_system_id.yfilter != YFilter.not_set or
                            self.neighbor_uptime.yfilter != YFilter.not_set or
                            self.neighbor_uptime_valid_flag.yfilter != YFilter.not_set or
                            self.nsr_standby.yfilter != YFilter.not_set or
                            self.system_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.local_interface.is_set or self.local_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_interface.get_name_leafdata())
                        if (self.neighbor_circuit_type.is_set or self.neighbor_circuit_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_circuit_type.get_name_leafdata())
                        if (self.neighbor_holdtime.is_set or self.neighbor_holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_holdtime.get_name_leafdata())
                        if (self.neighbor_ietf_nsf_capable_flag.is_set or self.neighbor_ietf_nsf_capable_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_ietf_nsf_capable_flag.get_name_leafdata())
                        if (self.neighbor_media_type.is_set or self.neighbor_media_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_media_type.get_name_leafdata())
                        if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                        if (self.neighbor_state.is_set or self.neighbor_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_state.get_name_leafdata())
                        if (self.neighbor_system_id.is_set or self.neighbor_system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_system_id.get_name_leafdata())
                        if (self.neighbor_uptime.is_set or self.neighbor_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_uptime.get_name_leafdata())
                        if (self.neighbor_uptime_valid_flag.is_set or self.neighbor_uptime_valid_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.neighbor_uptime_valid_flag.get_name_leafdata())
                        if (self.nsr_standby.is_set or self.nsr_standby.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nsr_standby.get_name_leafdata())
                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "neighbor-active-area-address"):
                            for c in self.neighbor_active_area_address:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_active_area_address.append(c)
                            return c

                        if (child_yang_name == "neighbor-per-address-family-data"):
                            for c in self.neighbor_per_address_family_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.neighbor_per_address_family_data.append(c)
                            return c

                        if (child_yang_name == "topologies-supported"):
                            for c in self.topologies_supported:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.topologies_supported.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "neighbor-active-area-address" or name == "neighbor-per-address-family-data" or name == "topologies-supported" or name == "interface-name" or name == "local-interface" or name == "neighbor-circuit-type" or name == "neighbor-holdtime" or name == "neighbor-ietf-nsf-capable-flag" or name == "neighbor-media-type" or name == "neighbor-snpa" or name == "neighbor-state" or name == "neighbor-system-id" or name == "neighbor-uptime" or name == "neighbor-uptime-valid-flag" or name == "nsr-standby" or name == "system-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-interface"):
                            self.local_interface = value
                            self.local_interface.value_namespace = name_space
                            self.local_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-circuit-type"):
                            self.neighbor_circuit_type = value
                            self.neighbor_circuit_type.value_namespace = name_space
                            self.neighbor_circuit_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-holdtime"):
                            self.neighbor_holdtime = value
                            self.neighbor_holdtime.value_namespace = name_space
                            self.neighbor_holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-ietf-nsf-capable-flag"):
                            self.neighbor_ietf_nsf_capable_flag = value
                            self.neighbor_ietf_nsf_capable_flag.value_namespace = name_space
                            self.neighbor_ietf_nsf_capable_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-media-type"):
                            self.neighbor_media_type = value
                            self.neighbor_media_type.value_namespace = name_space
                            self.neighbor_media_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-snpa"):
                            self.neighbor_snpa = value
                            self.neighbor_snpa.value_namespace = name_space
                            self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-state"):
                            self.neighbor_state = value
                            self.neighbor_state.value_namespace = name_space
                            self.neighbor_state.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-system-id"):
                            self.neighbor_system_id = value
                            self.neighbor_system_id.value_namespace = name_space
                            self.neighbor_system_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-uptime"):
                            self.neighbor_uptime = value
                            self.neighbor_uptime.value_namespace = name_space
                            self.neighbor_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "neighbor-uptime-valid-flag"):
                            self.neighbor_uptime_valid_flag = value
                            self.neighbor_uptime_valid_flag.value_namespace = name_space
                            self.neighbor_uptime_valid_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "nsr-standby"):
                            self.nsr_standby = value
                            self.nsr_standby.value_namespace = name_space
                            self.nsr_standby.value_namespace_prefix = name_space_prefix
                        if(value_path == "system-id"):
                            self.system_id = value
                            self.system_id.value_namespace = name_space
                            self.system_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbors" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor"):
                        for c in self.neighbor:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Neighbors.Neighbor()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class HostNames(Entity):
                """
                Hostname table
                
                .. attribute:: host_name
                
                	Hostname table entry
                	**type**\: list of    :py:class:`HostName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.HostNames.HostName>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.HostNames, self).__init__()

                    self.yang_name = "host-names"
                    self.yang_parent_name = "instance"

                    self.host_name = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.HostNames, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.HostNames, self).__setattr__(name, value)


                class HostName(Entity):
                    """
                    Hostname table entry
                    
                    .. attribute:: system_id  <key>
                    
                    	System ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: host_levels
                    
                    	Host levels
                    	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: host_name
                    
                    	Host name
                    	**type**\:  str
                    
                    .. attribute:: local_is_flag
                    
                    	TRUE if this is the local IS
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.HostNames.HostName, self).__init__()

                        self.yang_name = "host-name"
                        self.yang_parent_name = "host-names"

                        self.system_id = YLeaf(YType.str, "system-id")

                        self.host_levels = YLeaf(YType.enumeration, "host-levels")

                        self.host_name = YLeaf(YType.str, "host-name")

                        self.local_is_flag = YLeaf(YType.boolean, "local-is-flag")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("system_id",
                                        "host_levels",
                                        "host_name",
                                        "local_is_flag") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.HostNames.HostName, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.HostNames.HostName, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.system_id.is_set or
                            self.host_levels.is_set or
                            self.host_name.is_set or
                            self.local_is_flag.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.system_id.yfilter != YFilter.not_set or
                            self.host_levels.yfilter != YFilter.not_set or
                            self.host_name.yfilter != YFilter.not_set or
                            self.local_is_flag.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "host-name" + "[system-id='" + self.system_id.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_id.get_name_leafdata())
                        if (self.host_levels.is_set or self.host_levels.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_levels.get_name_leafdata())
                        if (self.host_name.is_set or self.host_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_name.get_name_leafdata())
                        if (self.local_is_flag.is_set or self.local_is_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_is_flag.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "system-id" or name == "host-levels" or name == "host-name" or name == "local-is-flag"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "system-id"):
                            self.system_id = value
                            self.system_id.value_namespace = name_space
                            self.system_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-levels"):
                            self.host_levels = value
                            self.host_levels.value_namespace = name_space
                            self.host_levels.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-name"):
                            self.host_name = value
                            self.host_name.value_namespace = name_space
                            self.host_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-is-flag"):
                            self.local_is_flag = value
                            self.local_is_flag.value_namespace = name_space
                            self.local_is_flag.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.host_name:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.host_name:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "host-names" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "host-name"):
                        for c in self.host_name:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.HostNames.HostName()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.host_name.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "host-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class StatisticsGlobal(Entity):
                """
                Per\-instance statistics
                
                .. attribute:: per_area_data
                
                	Per\-area data
                	**type**\: list of    :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData>`
                
                .. attribute:: statistics
                
                	Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.StatisticsGlobal, self).__init__()

                    self.yang_name = "statistics-global"
                    self.yang_parent_name = "instance"

                    self.statistics = Isis.Instances.Instance.StatisticsGlobal.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.per_area_data = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.StatisticsGlobal, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.StatisticsGlobal, self).__setattr__(name, value)


                class Statistics(Entity):
                    """
                    Statistics
                    
                    .. attribute:: avg_csnp_process_time
                    
                    	Average CSNP process time
                    	**type**\:   :py:class:`AvgCsnpProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime>`
                    
                    .. attribute:: avg_csnp_recv_rate
                    
                    	Average csnp receive rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_csnp_send_rate
                    
                    	Average csnp send rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_csnp_transmit_time
                    
                    	Average CSNP transmit time
                    	**type**\:   :py:class:`AvgCsnpTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime>`
                    
                    .. attribute:: avg_hello_process_time
                    
                    	Average hello process time
                    	**type**\:   :py:class:`AvgHelloProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime>`
                    
                    .. attribute:: avg_hello_recv_rate
                    
                    	Average hello receive rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_hello_send_rate
                    
                    	Average hello send rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_hello_transmit_time
                    
                    	Average hello transmit time
                    	**type**\:   :py:class:`AvgHelloTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime>`
                    
                    .. attribute:: avg_lsp_process_time
                    
                    	Average LSP process time
                    	**type**\:   :py:class:`AvgLspProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime>`
                    
                    .. attribute:: avg_lsp_recv_rate
                    
                    	Average LSP receive rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_lsp_send_rate
                    
                    	Average LSP send rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_lsp_transmit_time
                    
                    	Average LSP transmit time
                    	**type**\:   :py:class:`AvgLspTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime>`
                    
                    .. attribute:: avg_psnp_process_time
                    
                    	Average PSNP process time
                    	**type**\:   :py:class:`AvgPsnpProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime>`
                    
                    .. attribute:: avg_psnp_recv_rate
                    
                    	Average psnp receive rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_psnp_send_rate
                    
                    	Average psnp send rate in packets per second
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_psnp_transmit_time
                    
                    	Average PSNP transmit time
                    	**type**\:   :py:class:`AvgPsnpTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime>`
                    
                    .. attribute:: fast_csnp_cache_update_count
                    
                    	Fast\-CSNP cache updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_csnp_lookup_count
                    
                    	Fast\-CSNP cache lookups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_csnp_lookup_hit_count
                    
                    	Fast\-CSNP cache hits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_psnp_lookup_count
                    
                    	Fast\-PSNP cache lookups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_psnp_lookup_hit_count
                    
                    	Fast\-PSNP cache hits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: iih_dropped_count
                    
                    	IIHs dropped \- Not Used
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_checksum_lsp_count
                    
                    	LSPs received with invalid checksum
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lsp_dropped_count
                    
                    	LSPs dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_iih_queue_length
                    
                    	Maximum IIH queue length \- Not Used
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_pdu_queue_length
                    
                    	Maximum update PDU queue length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pdu_queue_length
                    
                    	Update PDU queue length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: snp_dropped_count
                    
                    	SNPs dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: zero_holdtime_lsp_count
                    
                    	LSPs received with holdtime 0
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "statistics-global"

                        self.avg_csnp_recv_rate = YLeaf(YType.uint32, "avg-csnp-recv-rate")

                        self.avg_csnp_send_rate = YLeaf(YType.uint32, "avg-csnp-send-rate")

                        self.avg_hello_recv_rate = YLeaf(YType.uint32, "avg-hello-recv-rate")

                        self.avg_hello_send_rate = YLeaf(YType.uint32, "avg-hello-send-rate")

                        self.avg_lsp_recv_rate = YLeaf(YType.uint32, "avg-lsp-recv-rate")

                        self.avg_lsp_send_rate = YLeaf(YType.uint32, "avg-lsp-send-rate")

                        self.avg_psnp_recv_rate = YLeaf(YType.uint32, "avg-psnp-recv-rate")

                        self.avg_psnp_send_rate = YLeaf(YType.uint32, "avg-psnp-send-rate")

                        self.fast_csnp_cache_update_count = YLeaf(YType.uint32, "fast-csnp-cache-update-count")

                        self.fast_csnp_lookup_count = YLeaf(YType.uint32, "fast-csnp-lookup-count")

                        self.fast_csnp_lookup_hit_count = YLeaf(YType.uint32, "fast-csnp-lookup-hit-count")

                        self.fast_psnp_lookup_count = YLeaf(YType.uint32, "fast-psnp-lookup-count")

                        self.fast_psnp_lookup_hit_count = YLeaf(YType.uint32, "fast-psnp-lookup-hit-count")

                        self.iih_dropped_count = YLeaf(YType.uint32, "iih-dropped-count")

                        self.invalid_checksum_lsp_count = YLeaf(YType.uint32, "invalid-checksum-lsp-count")

                        self.lsp_dropped_count = YLeaf(YType.uint32, "lsp-dropped-count")

                        self.maximum_iih_queue_length = YLeaf(YType.uint32, "maximum-iih-queue-length")

                        self.maximum_pdu_queue_length = YLeaf(YType.uint32, "maximum-pdu-queue-length")

                        self.pdu_queue_length = YLeaf(YType.uint32, "pdu-queue-length")

                        self.snp_dropped_count = YLeaf(YType.uint32, "snp-dropped-count")

                        self.zero_holdtime_lsp_count = YLeaf(YType.uint32, "zero-holdtime-lsp-count")

                        self.avg_csnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime()
                        self.avg_csnp_process_time.parent = self
                        self._children_name_map["avg_csnp_process_time"] = "avg-csnp-process-time"
                        self._children_yang_names.add("avg-csnp-process-time")

                        self.avg_csnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime()
                        self.avg_csnp_transmit_time.parent = self
                        self._children_name_map["avg_csnp_transmit_time"] = "avg-csnp-transmit-time"
                        self._children_yang_names.add("avg-csnp-transmit-time")

                        self.avg_hello_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime()
                        self.avg_hello_process_time.parent = self
                        self._children_name_map["avg_hello_process_time"] = "avg-hello-process-time"
                        self._children_yang_names.add("avg-hello-process-time")

                        self.avg_hello_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime()
                        self.avg_hello_transmit_time.parent = self
                        self._children_name_map["avg_hello_transmit_time"] = "avg-hello-transmit-time"
                        self._children_yang_names.add("avg-hello-transmit-time")

                        self.avg_lsp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime()
                        self.avg_lsp_process_time.parent = self
                        self._children_name_map["avg_lsp_process_time"] = "avg-lsp-process-time"
                        self._children_yang_names.add("avg-lsp-process-time")

                        self.avg_lsp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime()
                        self.avg_lsp_transmit_time.parent = self
                        self._children_name_map["avg_lsp_transmit_time"] = "avg-lsp-transmit-time"
                        self._children_yang_names.add("avg-lsp-transmit-time")

                        self.avg_psnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime()
                        self.avg_psnp_process_time.parent = self
                        self._children_name_map["avg_psnp_process_time"] = "avg-psnp-process-time"
                        self._children_yang_names.add("avg-psnp-process-time")

                        self.avg_psnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime()
                        self.avg_psnp_transmit_time.parent = self
                        self._children_name_map["avg_psnp_transmit_time"] = "avg-psnp-transmit-time"
                        self._children_yang_names.add("avg-psnp-transmit-time")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("avg_csnp_recv_rate",
                                        "avg_csnp_send_rate",
                                        "avg_hello_recv_rate",
                                        "avg_hello_send_rate",
                                        "avg_lsp_recv_rate",
                                        "avg_lsp_send_rate",
                                        "avg_psnp_recv_rate",
                                        "avg_psnp_send_rate",
                                        "fast_csnp_cache_update_count",
                                        "fast_csnp_lookup_count",
                                        "fast_csnp_lookup_hit_count",
                                        "fast_psnp_lookup_count",
                                        "fast_psnp_lookup_hit_count",
                                        "iih_dropped_count",
                                        "invalid_checksum_lsp_count",
                                        "lsp_dropped_count",
                                        "maximum_iih_queue_length",
                                        "maximum_pdu_queue_length",
                                        "pdu_queue_length",
                                        "snp_dropped_count",
                                        "zero_holdtime_lsp_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.StatisticsGlobal.Statistics, self).__setattr__(name, value)


                    class AvgHelloProcessTime(Entity):
                        """
                        Average hello process time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime, self).__init__()

                            self.yang_name = "avg-hello-process-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-hello-process-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgCsnpProcessTime(Entity):
                        """
                        Average CSNP process time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime, self).__init__()

                            self.yang_name = "avg-csnp-process-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-csnp-process-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgPsnpProcessTime(Entity):
                        """
                        Average PSNP process time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime, self).__init__()

                            self.yang_name = "avg-psnp-process-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-psnp-process-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgLspProcessTime(Entity):
                        """
                        Average LSP process time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime, self).__init__()

                            self.yang_name = "avg-lsp-process-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-lsp-process-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgHelloTransmitTime(Entity):
                        """
                        Average hello transmit time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime, self).__init__()

                            self.yang_name = "avg-hello-transmit-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-hello-transmit-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgCsnpTransmitTime(Entity):
                        """
                        Average CSNP transmit time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime, self).__init__()

                            self.yang_name = "avg-csnp-transmit-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-csnp-transmit-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgPsnpTransmitTime(Entity):
                        """
                        Average PSNP transmit time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime, self).__init__()

                            self.yang_name = "avg-psnp-transmit-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-psnp-transmit-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix


                    class AvgLspTransmitTime(Entity):
                        """
                        Average LSP transmit time
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime, self).__init__()

                            self.yang_name = "avg-lsp-transmit-time"
                            self.yang_parent_name = "statistics"

                            self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                            self.seconds = YLeaf(YType.uint32, "seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("nano_seconds",
                                            "seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.nano_seconds.is_set or
                                self.seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.nano_seconds.yfilter != YFilter.not_set or
                                self.seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "avg-lsp-transmit-time" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                            if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "nano-seconds" or name == "seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "nano-seconds"):
                                self.nano_seconds = value
                                self.nano_seconds.value_namespace = name_space
                                self.nano_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "seconds"):
                                self.seconds = value
                                self.seconds.value_namespace = name_space
                                self.seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.avg_csnp_recv_rate.is_set or
                            self.avg_csnp_send_rate.is_set or
                            self.avg_hello_recv_rate.is_set or
                            self.avg_hello_send_rate.is_set or
                            self.avg_lsp_recv_rate.is_set or
                            self.avg_lsp_send_rate.is_set or
                            self.avg_psnp_recv_rate.is_set or
                            self.avg_psnp_send_rate.is_set or
                            self.fast_csnp_cache_update_count.is_set or
                            self.fast_csnp_lookup_count.is_set or
                            self.fast_csnp_lookup_hit_count.is_set or
                            self.fast_psnp_lookup_count.is_set or
                            self.fast_psnp_lookup_hit_count.is_set or
                            self.iih_dropped_count.is_set or
                            self.invalid_checksum_lsp_count.is_set or
                            self.lsp_dropped_count.is_set or
                            self.maximum_iih_queue_length.is_set or
                            self.maximum_pdu_queue_length.is_set or
                            self.pdu_queue_length.is_set or
                            self.snp_dropped_count.is_set or
                            self.zero_holdtime_lsp_count.is_set or
                            (self.avg_csnp_process_time is not None and self.avg_csnp_process_time.has_data()) or
                            (self.avg_csnp_transmit_time is not None and self.avg_csnp_transmit_time.has_data()) or
                            (self.avg_hello_process_time is not None and self.avg_hello_process_time.has_data()) or
                            (self.avg_hello_transmit_time is not None and self.avg_hello_transmit_time.has_data()) or
                            (self.avg_lsp_process_time is not None and self.avg_lsp_process_time.has_data()) or
                            (self.avg_lsp_transmit_time is not None and self.avg_lsp_transmit_time.has_data()) or
                            (self.avg_psnp_process_time is not None and self.avg_psnp_process_time.has_data()) or
                            (self.avg_psnp_transmit_time is not None and self.avg_psnp_transmit_time.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.avg_csnp_recv_rate.yfilter != YFilter.not_set or
                            self.avg_csnp_send_rate.yfilter != YFilter.not_set or
                            self.avg_hello_recv_rate.yfilter != YFilter.not_set or
                            self.avg_hello_send_rate.yfilter != YFilter.not_set or
                            self.avg_lsp_recv_rate.yfilter != YFilter.not_set or
                            self.avg_lsp_send_rate.yfilter != YFilter.not_set or
                            self.avg_psnp_recv_rate.yfilter != YFilter.not_set or
                            self.avg_psnp_send_rate.yfilter != YFilter.not_set or
                            self.fast_csnp_cache_update_count.yfilter != YFilter.not_set or
                            self.fast_csnp_lookup_count.yfilter != YFilter.not_set or
                            self.fast_csnp_lookup_hit_count.yfilter != YFilter.not_set or
                            self.fast_psnp_lookup_count.yfilter != YFilter.not_set or
                            self.fast_psnp_lookup_hit_count.yfilter != YFilter.not_set or
                            self.iih_dropped_count.yfilter != YFilter.not_set or
                            self.invalid_checksum_lsp_count.yfilter != YFilter.not_set or
                            self.lsp_dropped_count.yfilter != YFilter.not_set or
                            self.maximum_iih_queue_length.yfilter != YFilter.not_set or
                            self.maximum_pdu_queue_length.yfilter != YFilter.not_set or
                            self.pdu_queue_length.yfilter != YFilter.not_set or
                            self.snp_dropped_count.yfilter != YFilter.not_set or
                            self.zero_holdtime_lsp_count.yfilter != YFilter.not_set or
                            (self.avg_csnp_process_time is not None and self.avg_csnp_process_time.has_operation()) or
                            (self.avg_csnp_transmit_time is not None and self.avg_csnp_transmit_time.has_operation()) or
                            (self.avg_hello_process_time is not None and self.avg_hello_process_time.has_operation()) or
                            (self.avg_hello_transmit_time is not None and self.avg_hello_transmit_time.has_operation()) or
                            (self.avg_lsp_process_time is not None and self.avg_lsp_process_time.has_operation()) or
                            (self.avg_lsp_transmit_time is not None and self.avg_lsp_transmit_time.has_operation()) or
                            (self.avg_psnp_process_time is not None and self.avg_psnp_process_time.has_operation()) or
                            (self.avg_psnp_transmit_time is not None and self.avg_psnp_transmit_time.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "statistics" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.avg_csnp_recv_rate.is_set or self.avg_csnp_recv_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_csnp_recv_rate.get_name_leafdata())
                        if (self.avg_csnp_send_rate.is_set or self.avg_csnp_send_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_csnp_send_rate.get_name_leafdata())
                        if (self.avg_hello_recv_rate.is_set or self.avg_hello_recv_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_hello_recv_rate.get_name_leafdata())
                        if (self.avg_hello_send_rate.is_set or self.avg_hello_send_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_hello_send_rate.get_name_leafdata())
                        if (self.avg_lsp_recv_rate.is_set or self.avg_lsp_recv_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_lsp_recv_rate.get_name_leafdata())
                        if (self.avg_lsp_send_rate.is_set or self.avg_lsp_send_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_lsp_send_rate.get_name_leafdata())
                        if (self.avg_psnp_recv_rate.is_set or self.avg_psnp_recv_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_psnp_recv_rate.get_name_leafdata())
                        if (self.avg_psnp_send_rate.is_set or self.avg_psnp_send_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.avg_psnp_send_rate.get_name_leafdata())
                        if (self.fast_csnp_cache_update_count.is_set or self.fast_csnp_cache_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_csnp_cache_update_count.get_name_leafdata())
                        if (self.fast_csnp_lookup_count.is_set or self.fast_csnp_lookup_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_csnp_lookup_count.get_name_leafdata())
                        if (self.fast_csnp_lookup_hit_count.is_set or self.fast_csnp_lookup_hit_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_csnp_lookup_hit_count.get_name_leafdata())
                        if (self.fast_psnp_lookup_count.is_set or self.fast_psnp_lookup_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_psnp_lookup_count.get_name_leafdata())
                        if (self.fast_psnp_lookup_hit_count.is_set or self.fast_psnp_lookup_hit_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.fast_psnp_lookup_hit_count.get_name_leafdata())
                        if (self.iih_dropped_count.is_set or self.iih_dropped_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.iih_dropped_count.get_name_leafdata())
                        if (self.invalid_checksum_lsp_count.is_set or self.invalid_checksum_lsp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_checksum_lsp_count.get_name_leafdata())
                        if (self.lsp_dropped_count.is_set or self.lsp_dropped_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_dropped_count.get_name_leafdata())
                        if (self.maximum_iih_queue_length.is_set or self.maximum_iih_queue_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_iih_queue_length.get_name_leafdata())
                        if (self.maximum_pdu_queue_length.is_set or self.maximum_pdu_queue_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.maximum_pdu_queue_length.get_name_leafdata())
                        if (self.pdu_queue_length.is_set or self.pdu_queue_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.pdu_queue_length.get_name_leafdata())
                        if (self.snp_dropped_count.is_set or self.snp_dropped_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.snp_dropped_count.get_name_leafdata())
                        if (self.zero_holdtime_lsp_count.is_set or self.zero_holdtime_lsp_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.zero_holdtime_lsp_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "avg-csnp-process-time"):
                            if (self.avg_csnp_process_time is None):
                                self.avg_csnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime()
                                self.avg_csnp_process_time.parent = self
                                self._children_name_map["avg_csnp_process_time"] = "avg-csnp-process-time"
                            return self.avg_csnp_process_time

                        if (child_yang_name == "avg-csnp-transmit-time"):
                            if (self.avg_csnp_transmit_time is None):
                                self.avg_csnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime()
                                self.avg_csnp_transmit_time.parent = self
                                self._children_name_map["avg_csnp_transmit_time"] = "avg-csnp-transmit-time"
                            return self.avg_csnp_transmit_time

                        if (child_yang_name == "avg-hello-process-time"):
                            if (self.avg_hello_process_time is None):
                                self.avg_hello_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime()
                                self.avg_hello_process_time.parent = self
                                self._children_name_map["avg_hello_process_time"] = "avg-hello-process-time"
                            return self.avg_hello_process_time

                        if (child_yang_name == "avg-hello-transmit-time"):
                            if (self.avg_hello_transmit_time is None):
                                self.avg_hello_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime()
                                self.avg_hello_transmit_time.parent = self
                                self._children_name_map["avg_hello_transmit_time"] = "avg-hello-transmit-time"
                            return self.avg_hello_transmit_time

                        if (child_yang_name == "avg-lsp-process-time"):
                            if (self.avg_lsp_process_time is None):
                                self.avg_lsp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime()
                                self.avg_lsp_process_time.parent = self
                                self._children_name_map["avg_lsp_process_time"] = "avg-lsp-process-time"
                            return self.avg_lsp_process_time

                        if (child_yang_name == "avg-lsp-transmit-time"):
                            if (self.avg_lsp_transmit_time is None):
                                self.avg_lsp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime()
                                self.avg_lsp_transmit_time.parent = self
                                self._children_name_map["avg_lsp_transmit_time"] = "avg-lsp-transmit-time"
                            return self.avg_lsp_transmit_time

                        if (child_yang_name == "avg-psnp-process-time"):
                            if (self.avg_psnp_process_time is None):
                                self.avg_psnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime()
                                self.avg_psnp_process_time.parent = self
                                self._children_name_map["avg_psnp_process_time"] = "avg-psnp-process-time"
                            return self.avg_psnp_process_time

                        if (child_yang_name == "avg-psnp-transmit-time"):
                            if (self.avg_psnp_transmit_time is None):
                                self.avg_psnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime()
                                self.avg_psnp_transmit_time.parent = self
                                self._children_name_map["avg_psnp_transmit_time"] = "avg-psnp-transmit-time"
                            return self.avg_psnp_transmit_time

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "avg-csnp-process-time" or name == "avg-csnp-transmit-time" or name == "avg-hello-process-time" or name == "avg-hello-transmit-time" or name == "avg-lsp-process-time" or name == "avg-lsp-transmit-time" or name == "avg-psnp-process-time" or name == "avg-psnp-transmit-time" or name == "avg-csnp-recv-rate" or name == "avg-csnp-send-rate" or name == "avg-hello-recv-rate" or name == "avg-hello-send-rate" or name == "avg-lsp-recv-rate" or name == "avg-lsp-send-rate" or name == "avg-psnp-recv-rate" or name == "avg-psnp-send-rate" or name == "fast-csnp-cache-update-count" or name == "fast-csnp-lookup-count" or name == "fast-csnp-lookup-hit-count" or name == "fast-psnp-lookup-count" or name == "fast-psnp-lookup-hit-count" or name == "iih-dropped-count" or name == "invalid-checksum-lsp-count" or name == "lsp-dropped-count" or name == "maximum-iih-queue-length" or name == "maximum-pdu-queue-length" or name == "pdu-queue-length" or name == "snp-dropped-count" or name == "zero-holdtime-lsp-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "avg-csnp-recv-rate"):
                            self.avg_csnp_recv_rate = value
                            self.avg_csnp_recv_rate.value_namespace = name_space
                            self.avg_csnp_recv_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-csnp-send-rate"):
                            self.avg_csnp_send_rate = value
                            self.avg_csnp_send_rate.value_namespace = name_space
                            self.avg_csnp_send_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-hello-recv-rate"):
                            self.avg_hello_recv_rate = value
                            self.avg_hello_recv_rate.value_namespace = name_space
                            self.avg_hello_recv_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-hello-send-rate"):
                            self.avg_hello_send_rate = value
                            self.avg_hello_send_rate.value_namespace = name_space
                            self.avg_hello_send_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-lsp-recv-rate"):
                            self.avg_lsp_recv_rate = value
                            self.avg_lsp_recv_rate.value_namespace = name_space
                            self.avg_lsp_recv_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-lsp-send-rate"):
                            self.avg_lsp_send_rate = value
                            self.avg_lsp_send_rate.value_namespace = name_space
                            self.avg_lsp_send_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-psnp-recv-rate"):
                            self.avg_psnp_recv_rate = value
                            self.avg_psnp_recv_rate.value_namespace = name_space
                            self.avg_psnp_recv_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "avg-psnp-send-rate"):
                            self.avg_psnp_send_rate = value
                            self.avg_psnp_send_rate.value_namespace = name_space
                            self.avg_psnp_send_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-csnp-cache-update-count"):
                            self.fast_csnp_cache_update_count = value
                            self.fast_csnp_cache_update_count.value_namespace = name_space
                            self.fast_csnp_cache_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-csnp-lookup-count"):
                            self.fast_csnp_lookup_count = value
                            self.fast_csnp_lookup_count.value_namespace = name_space
                            self.fast_csnp_lookup_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-csnp-lookup-hit-count"):
                            self.fast_csnp_lookup_hit_count = value
                            self.fast_csnp_lookup_hit_count.value_namespace = name_space
                            self.fast_csnp_lookup_hit_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-psnp-lookup-count"):
                            self.fast_psnp_lookup_count = value
                            self.fast_psnp_lookup_count.value_namespace = name_space
                            self.fast_psnp_lookup_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "fast-psnp-lookup-hit-count"):
                            self.fast_psnp_lookup_hit_count = value
                            self.fast_psnp_lookup_hit_count.value_namespace = name_space
                            self.fast_psnp_lookup_hit_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "iih-dropped-count"):
                            self.iih_dropped_count = value
                            self.iih_dropped_count.value_namespace = name_space
                            self.iih_dropped_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-checksum-lsp-count"):
                            self.invalid_checksum_lsp_count = value
                            self.invalid_checksum_lsp_count.value_namespace = name_space
                            self.invalid_checksum_lsp_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-dropped-count"):
                            self.lsp_dropped_count = value
                            self.lsp_dropped_count.value_namespace = name_space
                            self.lsp_dropped_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-iih-queue-length"):
                            self.maximum_iih_queue_length = value
                            self.maximum_iih_queue_length.value_namespace = name_space
                            self.maximum_iih_queue_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "maximum-pdu-queue-length"):
                            self.maximum_pdu_queue_length = value
                            self.maximum_pdu_queue_length.value_namespace = name_space
                            self.maximum_pdu_queue_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "pdu-queue-length"):
                            self.pdu_queue_length = value
                            self.pdu_queue_length.value_namespace = name_space
                            self.pdu_queue_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "snp-dropped-count"):
                            self.snp_dropped_count = value
                            self.snp_dropped_count.value_namespace = name_space
                            self.snp_dropped_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "zero-holdtime-lsp-count"):
                            self.zero_holdtime_lsp_count = value
                            self.zero_holdtime_lsp_count.value_namespace = name_space
                            self.zero_holdtime_lsp_count.value_namespace_prefix = name_space_prefix


                class PerAreaData(Entity):
                    """
                    Per\-area data
                    
                    .. attribute:: level
                    
                    	Level this data applies to
                    	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: per_topology_data
                    
                    	Per\-topoogy statistics
                    	**type**\: list of    :py:class:`PerTopologyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData, self).__init__()

                        self.yang_name = "per-area-data"
                        self.yang_parent_name = "statistics-global"

                        self.level = YLeaf(YType.enumeration, "level")

                        self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.per_topology_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("level") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData, self).__setattr__(name, value)


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: system_lsp_build_count
                        
                        	Number of times system LSP rebuilt
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: system_lsp_refresh_count
                        
                        	Number of times system LSP refreshed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "per-area-data"

                            self.system_lsp_build_count = YLeaf(YType.uint32, "system-lsp-build-count")

                            self.system_lsp_refresh_count = YLeaf(YType.uint32, "system-lsp-refresh-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("system_lsp_build_count",
                                            "system_lsp_refresh_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.system_lsp_build_count.is_set or
                                self.system_lsp_refresh_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.system_lsp_build_count.yfilter != YFilter.not_set or
                                self.system_lsp_refresh_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.system_lsp_build_count.is_set or self.system_lsp_build_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.system_lsp_build_count.get_name_leafdata())
                            if (self.system_lsp_refresh_count.is_set or self.system_lsp_refresh_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.system_lsp_refresh_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "system-lsp-build-count" or name == "system-lsp-refresh-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "system-lsp-build-count"):
                                self.system_lsp_build_count = value
                                self.system_lsp_build_count.value_namespace = name_space
                                self.system_lsp_build_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "system-lsp-refresh-count"):
                                self.system_lsp_refresh_count = value
                                self.system_lsp_refresh_count.value_namespace = name_space
                                self.system_lsp_refresh_count.value_namespace_prefix = name_space_prefix


                    class PerTopologyData(Entity):
                        """
                        Per\-topoogy statistics
                        
                        .. attribute:: id
                        
                        	Topology ID
                        	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData, self).__init__()

                            self.yang_name = "per-topology-data"
                            self.yang_parent_name = "per-area-data"

                            self.id = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id()
                            self.id.parent = self
                            self._children_name_map["id"] = "id"
                            self._children_yang_names.add("id")

                            self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")


                        class Id(Entity):
                            """
                            Topology ID
                            
                            .. attribute:: af_name
                            
                            	AF name
                            	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                            
                            .. attribute:: saf_name
                            
                            	Sub\-AF name
                            	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                            
                            .. attribute:: topology_name
                            
                            	Topology Name
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id, self).__init__()

                                self.yang_name = "id"
                                self.yang_parent_name = "per-topology-data"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.saf_name = YLeaf(YType.enumeration, "saf-name")

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "saf_name",
                                                "topology_name",
                                                "vrf_name") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.saf_name.is_set or
                                    self.topology_name.is_set or
                                    self.vrf_name.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.saf_name.yfilter != YFilter.not_set or
                                    self.topology_name.yfilter != YFilter.not_set or
                                    self.vrf_name.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "id" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.saf_name.get_name_leafdata())
                                if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.topology_name.get_name_leafdata())
                                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "saf-name"):
                                    self.saf_name = value
                                    self.saf_name.value_namespace = name_space
                                    self.saf_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "topology-name"):
                                    self.topology_name = value
                                    self.topology_name.value_namespace = name_space
                                    self.topology_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-name"):
                                    self.vrf_name = value
                                    self.vrf_name.value_namespace = name_space
                                    self.vrf_name.value_namespace_prefix = name_space_prefix


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: ispf_run_count
                            
                            	Number of ISPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nhc_run_count
                            
                            	Number of Next Hop Calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: periodic_run_count
                            
                            	Number of periodic SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prc_run_count
                            
                            	Number of PRCs run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_run_count
                            
                            	Number of full SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "per-topology-data"

                                self.ispf_run_count = YLeaf(YType.uint32, "ispf-run-count")

                                self.nhc_run_count = YLeaf(YType.uint32, "nhc-run-count")

                                self.periodic_run_count = YLeaf(YType.uint32, "periodic-run-count")

                                self.prc_run_count = YLeaf(YType.uint32, "prc-run-count")

                                self.spf_run_count = YLeaf(YType.uint32, "spf-run-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ispf_run_count",
                                                "nhc_run_count",
                                                "periodic_run_count",
                                                "prc_run_count",
                                                "spf_run_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ispf_run_count.is_set or
                                    self.nhc_run_count.is_set or
                                    self.periodic_run_count.is_set or
                                    self.prc_run_count.is_set or
                                    self.spf_run_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ispf_run_count.yfilter != YFilter.not_set or
                                    self.nhc_run_count.yfilter != YFilter.not_set or
                                    self.periodic_run_count.yfilter != YFilter.not_set or
                                    self.prc_run_count.yfilter != YFilter.not_set or
                                    self.spf_run_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ispf_run_count.is_set or self.ispf_run_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ispf_run_count.get_name_leafdata())
                                if (self.nhc_run_count.is_set or self.nhc_run_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nhc_run_count.get_name_leafdata())
                                if (self.periodic_run_count.is_set or self.periodic_run_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.periodic_run_count.get_name_leafdata())
                                if (self.prc_run_count.is_set or self.prc_run_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prc_run_count.get_name_leafdata())
                                if (self.spf_run_count.is_set or self.spf_run_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.spf_run_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ispf-run-count" or name == "nhc-run-count" or name == "periodic-run-count" or name == "prc-run-count" or name == "spf-run-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ispf-run-count"):
                                    self.ispf_run_count = value
                                    self.ispf_run_count.value_namespace = name_space
                                    self.ispf_run_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "nhc-run-count"):
                                    self.nhc_run_count = value
                                    self.nhc_run_count.value_namespace = name_space
                                    self.nhc_run_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "periodic-run-count"):
                                    self.periodic_run_count = value
                                    self.periodic_run_count.value_namespace = name_space
                                    self.periodic_run_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "prc-run-count"):
                                    self.prc_run_count = value
                                    self.prc_run_count.value_namespace = name_space
                                    self.prc_run_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "spf-run-count"):
                                    self.spf_run_count = value
                                    self.spf_run_count.value_namespace = name_space
                                    self.spf_run_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.id is not None and self.id.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.id is not None and self.id.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "per-topology-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "id"):
                                if (self.id is None):
                                    self.id = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                return self.id

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "id" or name == "statistics"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        for c in self.per_topology_data:
                            if (c.has_data()):
                                return True
                        return (
                            self.level.is_set or
                            (self.statistics is not None and self.statistics.has_data()))

                    def has_operation(self):
                        for c in self.per_topology_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set or
                            (self.statistics is not None and self.statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "per-area-data" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "per-topology-data"):
                            for c in self.per_topology_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.per_topology_data.append(c)
                            return c

                        if (child_yang_name == "statistics"):
                            if (self.statistics is None):
                                self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                            return self.statistics

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "per-topology-data" or name == "statistics" or name == "level"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.per_area_data:
                        if (c.has_data()):
                            return True
                    return (self.statistics is not None and self.statistics.has_data())

                def has_operation(self):
                    for c in self.per_area_data:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.statistics is not None and self.statistics.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "statistics-global" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "per-area-data"):
                        for c in self.per_area_data:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.StatisticsGlobal.PerAreaData()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.per_area_data.append(c)
                        return c

                    if (child_yang_name == "statistics"):
                        if (self.statistics is None):
                            self.statistics = Isis.Instances.Instance.StatisticsGlobal.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                        return self.statistics

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "per-area-data" or name == "statistics"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Levels(Entity):
                """
                Level table
                
                .. attribute:: level
                
                	Per\-level operational data
                	**type**\: list of    :py:class:`Level <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Levels, self).__init__()

                    self.yang_name = "levels"
                    self.yang_parent_name = "instance"

                    self.level = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.Levels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.Levels, self).__setattr__(name, value)


                class Level(Entity):
                    """
                    Per\-level operational data
                    
                    .. attribute:: level  <key>
                    
                    	Level
                    	**type**\:   :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: adjacencies
                    
                    	Adjacency table
                    	**type**\:   :py:class:`Adjacencies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies>`
                    
                    .. attribute:: adjacency_log
                    
                    	Log of adjacency changes within a single level
                    	**type**\:   :py:class:`AdjacencyLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog>`
                    
                    .. attribute:: database_log
                    
                    	Database\-log for a single level
                    	**type**\:   :py:class:`DatabaseLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog>`
                    
                    .. attribute:: detailed_lsps
                    
                    	Detailed LSP table. Use to retrieve LSPs with TLV content
                    	**type**\:   :py:class:`DetailedLsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps>`
                    
                    .. attribute:: lsp_log
                    
                    	LSP\-log for a single level
                    	**type**\:   :py:class:`LspLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog>`
                    
                    .. attribute:: lsp_table_summary
                    
                    	Summary information for one level's LSP database
                    	**type**\:   :py:class:`LspTableSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary>`
                    
                    .. attribute:: lsps
                    
                    	LSP table
                    	**type**\:   :py:class:`Lsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Levels.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "levels"

                        self.level = YLeaf(YType.enumeration, "level")

                        self.adjacencies = Isis.Instances.Instance.Levels.Level.Adjacencies()
                        self.adjacencies.parent = self
                        self._children_name_map["adjacencies"] = "adjacencies"
                        self._children_yang_names.add("adjacencies")

                        self.adjacency_log = Isis.Instances.Instance.Levels.Level.AdjacencyLog()
                        self.adjacency_log.parent = self
                        self._children_name_map["adjacency_log"] = "adjacency-log"
                        self._children_yang_names.add("adjacency-log")

                        self.database_log = Isis.Instances.Instance.Levels.Level.DatabaseLog()
                        self.database_log.parent = self
                        self._children_name_map["database_log"] = "database-log"
                        self._children_yang_names.add("database-log")

                        self.detailed_lsps = Isis.Instances.Instance.Levels.Level.DetailedLsps()
                        self.detailed_lsps.parent = self
                        self._children_name_map["detailed_lsps"] = "detailed-lsps"
                        self._children_yang_names.add("detailed-lsps")

                        self.lsp_log = Isis.Instances.Instance.Levels.Level.LspLog()
                        self.lsp_log.parent = self
                        self._children_name_map["lsp_log"] = "lsp-log"
                        self._children_yang_names.add("lsp-log")

                        self.lsp_table_summary = Isis.Instances.Instance.Levels.Level.LspTableSummary()
                        self.lsp_table_summary.parent = self
                        self._children_name_map["lsp_table_summary"] = "lsp-table-summary"
                        self._children_yang_names.add("lsp-table-summary")

                        self.lsps = Isis.Instances.Instance.Levels.Level.Lsps()
                        self.lsps.parent = self
                        self._children_name_map["lsps"] = "lsps"
                        self._children_yang_names.add("lsps")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("level") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Levels.Level, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Levels.Level, self).__setattr__(name, value)


                    class AdjacencyLog(Entity):
                        """
                        Log of adjacency changes within a single
                        level
                        
                        .. attribute:: log_entry
                        
                        	Adjacency Log entries
                        	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.AdjacencyLog, self).__init__()

                            self.yang_name = "adjacency-log"
                            self.yang_parent_name = "level"

                            self.log_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog, self).__setattr__(name, value)


                        class LogEntry(Entity):
                            """
                            Adjacency Log entries
                            
                            .. attribute:: adj_log_neighbor_system_id
                            
                            	Neighbor system ID
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: adjacency_per_topology_change
                            
                            	Per\-topology changes
                            	**type**\: list of    :py:class:`AdjacencyPerTopologyChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange>`
                            
                            .. attribute:: cur_adj_state
                            
                            	Current adjacency state
                            	**type**\:   :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            .. attribute:: prev_adj_state
                            
                            	Previous adjacency state
                            	**type**\:   :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: state_reason
                            
                            	Reason adjacency changed state
                            	**type**\:   :py:class:`IsisAdjStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjStateReason>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "adjacency-log"

                                self.adj_log_neighbor_system_id = YLeaf(YType.str, "adj-log-neighbor-system-id")

                                self.cur_adj_state = YLeaf(YType.enumeration, "cur-adj-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.prev_adj_state = YLeaf(YType.enumeration, "prev-adj-state")

                                self.state_reason = YLeaf(YType.enumeration, "state-reason")

                                self.generic_data = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"
                                self._children_yang_names.add("generic-data")

                                self.adjacency_per_topology_change = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("adj_log_neighbor_system_id",
                                                "cur_adj_state",
                                                "interface_name",
                                                "prev_adj_state",
                                                "state_reason") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry, self).__setattr__(name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._children_yang_names.add("timestamp")


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"

                                        self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nano_seconds",
                                                        "seconds") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nano_seconds.is_set or
                                            self.seconds.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nano_seconds.yfilter != YFilter.not_set or
                                            self.seconds.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timestamp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.seconds.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nano-seconds" or name == "seconds"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nano-seconds"):
                                            self.nano_seconds = value
                                            self.nano_seconds.value_namespace = name_space
                                            self.nano_seconds.value_namespace_prefix = name_space_prefix
                                        if(value_path == "seconds"):
                                            self.seconds = value
                                            self.seconds.value_namespace = name_space
                                            self.seconds.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (self.timestamp is not None and self.timestamp.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.timestamp is not None and self.timestamp.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "generic-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "timestamp"):
                                        if (self.timestamp is None):
                                            self.timestamp = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                        return self.timestamp

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "timestamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class AdjacencyPerTopologyChange(Entity):
                                """
                                Per\-topology changes
                                
                                .. attribute:: change
                                
                                	Change
                                	**type**\:   :py:class:`IsisAdjTopoChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjTopoChange>`
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange, self).__init__()

                                    self.yang_name = "adjacency-per-topology-change"
                                    self.yang_parent_name = "log-entry"

                                    self.change = YLeaf(YType.enumeration, "change")

                                    self.id = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                    self._children_yang_names.add("id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("change") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange, self).__setattr__(name, value)


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "adjacency-per-topology-change"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                                        self.topology_name = YLeaf(YType.str, "topology-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "saf_name",
                                                        "topology_name",
                                                        "vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.saf_name.is_set or
                                            self.topology_name.is_set or
                                            self.vrf_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.saf_name.yfilter != YFilter.not_set or
                                            self.topology_name.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saf-name"):
                                            self.saf_name = value
                                            self.saf_name.value_namespace = name_space
                                            self.saf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-name"):
                                            self.topology_name = value
                                            self.topology_name.value_namespace = name_space
                                            self.topology_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.change.is_set or
                                        (self.id is not None and self.id.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.change.yfilter != YFilter.not_set or
                                        (self.id is not None and self.id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-per-topology-change" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.change.is_set or self.change.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.change.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "id"):
                                        if (self.id is None):
                                            self.id = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id()
                                            self.id.parent = self
                                            self._children_name_map["id"] = "id"
                                        return self.id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "id" or name == "change"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "change"):
                                        self.change = value
                                        self.change.value_namespace = name_space
                                        self.change.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.adjacency_per_topology_change:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.adj_log_neighbor_system_id.is_set or
                                    self.cur_adj_state.is_set or
                                    self.interface_name.is_set or
                                    self.prev_adj_state.is_set or
                                    self.state_reason.is_set or
                                    (self.generic_data is not None and self.generic_data.has_data()))

                            def has_operation(self):
                                for c in self.adjacency_per_topology_change:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.adj_log_neighbor_system_id.yfilter != YFilter.not_set or
                                    self.cur_adj_state.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.prev_adj_state.yfilter != YFilter.not_set or
                                    self.state_reason.yfilter != YFilter.not_set or
                                    (self.generic_data is not None and self.generic_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "log-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.adj_log_neighbor_system_id.is_set or self.adj_log_neighbor_system_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_log_neighbor_system_id.get_name_leafdata())
                                if (self.cur_adj_state.is_set or self.cur_adj_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.cur_adj_state.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.prev_adj_state.is_set or self.prev_adj_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prev_adj_state.get_name_leafdata())
                                if (self.state_reason.is_set or self.state_reason.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state_reason.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "adjacency-per-topology-change"):
                                    for c in self.adjacency_per_topology_change:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.adjacency_per_topology_change.append(c)
                                    return c

                                if (child_yang_name == "generic-data"):
                                    if (self.generic_data is None):
                                        self.generic_data = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                    return self.generic_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adjacency-per-topology-change" or name == "generic-data" or name == "adj-log-neighbor-system-id" or name == "cur-adj-state" or name == "interface-name" or name == "prev-adj-state" or name == "state-reason"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "adj-log-neighbor-system-id"):
                                    self.adj_log_neighbor_system_id = value
                                    self.adj_log_neighbor_system_id.value_namespace = name_space
                                    self.adj_log_neighbor_system_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "cur-adj-state"):
                                    self.cur_adj_state = value
                                    self.cur_adj_state.value_namespace = name_space
                                    self.cur_adj_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "prev-adj-state"):
                                    self.prev_adj_state = value
                                    self.prev_adj_state.value_namespace = name_space
                                    self.prev_adj_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "state-reason"):
                                    self.state_reason = value
                                    self.state_reason.value_namespace = name_space
                                    self.state_reason.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.log_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.log_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "adjacency-log" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "log-entry"):
                                for c in self.log_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.log_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "log-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class LspTableSummary(Entity):
                        """
                        Summary information for one level's LSP
                        database
                        
                        .. attribute:: all_fragment_lsp_stats
                        
                        	Statistics for all LSP fragments
                        	**type**\:   :py:class:`AllFragmentLspStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats>`
                        
                        .. attribute:: fragment0lsp_stats
                        
                        	Statistics for fragment 0 LSPs
                        	**type**\:   :py:class:`Fragment0LspStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.LspTableSummary, self).__init__()

                            self.yang_name = "lsp-table-summary"
                            self.yang_parent_name = "level"

                            self.all_fragment_lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats()
                            self.all_fragment_lsp_stats.parent = self
                            self._children_name_map["all_fragment_lsp_stats"] = "all-fragment-lsp-stats"
                            self._children_yang_names.add("all-fragment-lsp-stats")

                            self.fragment0lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats()
                            self.fragment0lsp_stats.parent = self
                            self._children_name_map["fragment0lsp_stats"] = "fragment0lsp-stats"
                            self._children_yang_names.add("fragment0lsp-stats")


                        class Fragment0LspStats(Entity):
                            """
                            Statistics for fragment 0 LSPs
                            
                            .. attribute:: node_counters
                            
                            	Summary by class of node
                            	**type**\:   :py:class:`NodeCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters>`
                            
                            .. attribute:: per_topology_counter
                            
                            	Per topology counters
                            	**type**\: list of    :py:class:`PerTopologyCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats, self).__init__()

                                self.yang_name = "fragment0lsp-stats"
                                self.yang_parent_name = "lsp-table-summary"

                                self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters()
                                self.node_counters.parent = self
                                self._children_name_map["node_counters"] = "node-counters"
                                self._children_yang_names.add("node-counters")

                                self.per_topology_counter = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats, self).__setattr__(name, value)


                            class NodeCounters(Entity):
                                """
                                Summary by class of node
                                
                                .. attribute:: pseudo_node_lsp_count
                                
                                	Pseudonode LSPs
                                	**type**\:   :py:class:`PseudoNodeLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount>`
                                
                                .. attribute:: route_lsp_count
                                
                                	Router LSPs
                                	**type**\:   :py:class:`RouteLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters, self).__init__()

                                    self.yang_name = "node-counters"
                                    self.yang_parent_name = "fragment0lsp-stats"

                                    self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount()
                                    self.pseudo_node_lsp_count.parent = self
                                    self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                    self._children_yang_names.add("pseudo-node-lsp-count")

                                    self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount()
                                    self.route_lsp_count.parent = self
                                    self._children_name_map["route_lsp_count"] = "route-lsp-count"
                                    self._children_yang_names.add("route-lsp-count")


                                class RouteLspCount(Entity):
                                    """
                                    Router LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount, self).__init__()

                                        self.yang_name = "route-lsp-count"
                                        self.yang_parent_name = "node-counters"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix


                                class PseudoNodeLspCount(Entity):
                                    """
                                    Pseudonode LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount, self).__init__()

                                        self.yang_name = "pseudo-node-lsp-count"
                                        self.yang_parent_name = "node-counters"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudo-node-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.pseudo_node_lsp_count is not None and self.pseudo_node_lsp_count.has_data()) or
                                        (self.route_lsp_count is not None and self.route_lsp_count.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.pseudo_node_lsp_count is not None and self.pseudo_node_lsp_count.has_operation()) or
                                        (self.route_lsp_count is not None and self.route_lsp_count.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pseudo-node-lsp-count"):
                                        if (self.pseudo_node_lsp_count is None):
                                            self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.PseudoNodeLspCount()
                                            self.pseudo_node_lsp_count.parent = self
                                            self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                        return self.pseudo_node_lsp_count

                                    if (child_yang_name == "route-lsp-count"):
                                        if (self.route_lsp_count is None):
                                            self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters.RouteLspCount()
                                            self.route_lsp_count.parent = self
                                            self._children_name_map["route_lsp_count"] = "route-lsp-count"
                                        return self.route_lsp_count

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pseudo-node-lsp-count" or name == "route-lsp-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PerTopologyCounter(Entity):
                                """
                                Per topology counters
                                
                                .. attribute:: attached_lsp_count
                                
                                	Number of LSPs with their per\-topology attached bit set
                                	**type**\:   :py:class:`AttachedLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount>`
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id>`
                                
                                .. attribute:: overloaded_lsp_count
                                
                                	Number of LSPs with their per\-topology overload bit set
                                	**type**\:   :py:class:`OverloadedLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter, self).__init__()

                                    self.yang_name = "per-topology-counter"
                                    self.yang_parent_name = "fragment0lsp-stats"

                                    self.attached_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount()
                                    self.attached_lsp_count.parent = self
                                    self._children_name_map["attached_lsp_count"] = "attached-lsp-count"
                                    self._children_yang_names.add("attached-lsp-count")

                                    self.id = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                    self._children_yang_names.add("id")

                                    self.overloaded_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount()
                                    self.overloaded_lsp_count.parent = self
                                    self._children_name_map["overloaded_lsp_count"] = "overloaded-lsp-count"
                                    self._children_yang_names.add("overloaded-lsp-count")


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "per-topology-counter"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                                        self.topology_name = YLeaf(YType.str, "topology-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "saf_name",
                                                        "topology_name",
                                                        "vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.saf_name.is_set or
                                            self.topology_name.is_set or
                                            self.vrf_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.saf_name.yfilter != YFilter.not_set or
                                            self.topology_name.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saf-name"):
                                            self.saf_name = value
                                            self.saf_name.value_namespace = name_space
                                            self.saf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-name"):
                                            self.topology_name = value
                                            self.topology_name.value_namespace = name_space
                                            self.topology_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix


                                class OverloadedLspCount(Entity):
                                    """
                                    Number of LSPs with their per\-topology overload
                                    bit set
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount, self).__init__()

                                        self.yang_name = "overloaded-lsp-count"
                                        self.yang_parent_name = "per-topology-counter"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "overloaded-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix


                                class AttachedLspCount(Entity):
                                    """
                                    Number of LSPs with their per\-topology attached
                                    bit set
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount, self).__init__()

                                        self.yang_name = "attached-lsp-count"
                                        self.yang_parent_name = "per-topology-counter"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "attached-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.attached_lsp_count is not None and self.attached_lsp_count.has_data()) or
                                        (self.id is not None and self.id.has_data()) or
                                        (self.overloaded_lsp_count is not None and self.overloaded_lsp_count.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.attached_lsp_count is not None and self.attached_lsp_count.has_operation()) or
                                        (self.id is not None and self.id.has_operation()) or
                                        (self.overloaded_lsp_count is not None and self.overloaded_lsp_count.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-topology-counter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "attached-lsp-count"):
                                        if (self.attached_lsp_count is None):
                                            self.attached_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.AttachedLspCount()
                                            self.attached_lsp_count.parent = self
                                            self._children_name_map["attached_lsp_count"] = "attached-lsp-count"
                                        return self.attached_lsp_count

                                    if (child_yang_name == "id"):
                                        if (self.id is None):
                                            self.id = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.Id()
                                            self.id.parent = self
                                            self._children_name_map["id"] = "id"
                                        return self.id

                                    if (child_yang_name == "overloaded-lsp-count"):
                                        if (self.overloaded_lsp_count is None):
                                            self.overloaded_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter.OverloadedLspCount()
                                            self.overloaded_lsp_count.parent = self
                                            self._children_name_map["overloaded_lsp_count"] = "overloaded-lsp-count"
                                        return self.overloaded_lsp_count

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "attached-lsp-count" or name == "id" or name == "overloaded-lsp-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                for c in self.per_topology_counter:
                                    if (c.has_data()):
                                        return True
                                return (self.node_counters is not None and self.node_counters.has_data())

                            def has_operation(self):
                                for c in self.per_topology_counter:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.node_counters is not None and self.node_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "fragment0lsp-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "node-counters"):
                                    if (self.node_counters is None):
                                        self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.NodeCounters()
                                        self.node_counters.parent = self
                                        self._children_name_map["node_counters"] = "node-counters"
                                    return self.node_counters

                                if (child_yang_name == "per-topology-counter"):
                                    for c in self.per_topology_counter:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats.PerTopologyCounter()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_topology_counter.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "node-counters" or name == "per-topology-counter"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class AllFragmentLspStats(Entity):
                            """
                            Statistics for all LSP fragments
                            
                            .. attribute:: node_counters
                            
                            	Summary by class of node
                            	**type**\:   :py:class:`NodeCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats, self).__init__()

                                self.yang_name = "all-fragment-lsp-stats"
                                self.yang_parent_name = "lsp-table-summary"

                                self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters()
                                self.node_counters.parent = self
                                self._children_name_map["node_counters"] = "node-counters"
                                self._children_yang_names.add("node-counters")


                            class NodeCounters(Entity):
                                """
                                Summary by class of node
                                
                                .. attribute:: pseudo_node_lsp_count
                                
                                	Pseudonode LSPs
                                	**type**\:   :py:class:`PseudoNodeLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount>`
                                
                                .. attribute:: route_lsp_count
                                
                                	Router LSPs
                                	**type**\:   :py:class:`RouteLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters, self).__init__()

                                    self.yang_name = "node-counters"
                                    self.yang_parent_name = "all-fragment-lsp-stats"

                                    self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount()
                                    self.pseudo_node_lsp_count.parent = self
                                    self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                    self._children_yang_names.add("pseudo-node-lsp-count")

                                    self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount()
                                    self.route_lsp_count.parent = self
                                    self._children_name_map["route_lsp_count"] = "route-lsp-count"
                                    self._children_yang_names.add("route-lsp-count")


                                class RouteLspCount(Entity):
                                    """
                                    Router LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount, self).__init__()

                                        self.yang_name = "route-lsp-count"
                                        self.yang_parent_name = "node-counters"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "route-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix


                                class PseudoNodeLspCount(Entity):
                                    """
                                    Pseudonode LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount, self).__init__()

                                        self.yang_name = "pseudo-node-lsp-count"
                                        self.yang_parent_name = "node-counters"

                                        self.active_lsp_count = YLeaf(YType.uint32, "active-lsp-count")

                                        self.purged_lsp_count = YLeaf(YType.uint32, "purged-lsp-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("active_lsp_count",
                                                        "purged_lsp_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.active_lsp_count.is_set or
                                            self.purged_lsp_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.active_lsp_count.yfilter != YFilter.not_set or
                                            self.purged_lsp_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudo-node-lsp-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.active_lsp_count.is_set or self.active_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.active_lsp_count.get_name_leafdata())
                                        if (self.purged_lsp_count.is_set or self.purged_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.purged_lsp_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "active-lsp-count" or name == "purged-lsp-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "active-lsp-count"):
                                            self.active_lsp_count = value
                                            self.active_lsp_count.value_namespace = name_space
                                            self.active_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "purged-lsp-count"):
                                            self.purged_lsp_count = value
                                            self.purged_lsp_count.value_namespace = name_space
                                            self.purged_lsp_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.pseudo_node_lsp_count is not None and self.pseudo_node_lsp_count.has_data()) or
                                        (self.route_lsp_count is not None and self.route_lsp_count.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.pseudo_node_lsp_count is not None and self.pseudo_node_lsp_count.has_operation()) or
                                        (self.route_lsp_count is not None and self.route_lsp_count.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "node-counters" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pseudo-node-lsp-count"):
                                        if (self.pseudo_node_lsp_count is None):
                                            self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount()
                                            self.pseudo_node_lsp_count.parent = self
                                            self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                        return self.pseudo_node_lsp_count

                                    if (child_yang_name == "route-lsp-count"):
                                        if (self.route_lsp_count is None):
                                            self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount()
                                            self.route_lsp_count.parent = self
                                            self._children_name_map["route_lsp_count"] = "route-lsp-count"
                                        return self.route_lsp_count

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pseudo-node-lsp-count" or name == "route-lsp-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (self.node_counters is not None and self.node_counters.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.node_counters is not None and self.node_counters.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "all-fragment-lsp-stats" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "node-counters"):
                                    if (self.node_counters is None):
                                        self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters()
                                        self.node_counters.parent = self
                                        self._children_name_map["node_counters"] = "node-counters"
                                    return self.node_counters

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "node-counters"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.all_fragment_lsp_stats is not None and self.all_fragment_lsp_stats.has_data()) or
                                (self.fragment0lsp_stats is not None and self.fragment0lsp_stats.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.all_fragment_lsp_stats is not None and self.all_fragment_lsp_stats.has_operation()) or
                                (self.fragment0lsp_stats is not None and self.fragment0lsp_stats.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsp-table-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "all-fragment-lsp-stats"):
                                if (self.all_fragment_lsp_stats is None):
                                    self.all_fragment_lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats()
                                    self.all_fragment_lsp_stats.parent = self
                                    self._children_name_map["all_fragment_lsp_stats"] = "all-fragment-lsp-stats"
                                return self.all_fragment_lsp_stats

                            if (child_yang_name == "fragment0lsp-stats"):
                                if (self.fragment0lsp_stats is None):
                                    self.fragment0lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0LspStats()
                                    self.fragment0lsp_stats.parent = self
                                    self._children_name_map["fragment0lsp_stats"] = "fragment0lsp-stats"
                                return self.fragment0lsp_stats

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "all-fragment-lsp-stats" or name == "fragment0lsp-stats"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Adjacencies(Entity):
                        """
                        Adjacency table
                        
                        .. attribute:: adjacency
                        
                        	A single IS\-IS adjacency
                        	**type**\: list of    :py:class:`Adjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.Adjacencies, self).__init__()

                            self.yang_name = "adjacencies"
                            self.yang_parent_name = "level"

                            self.adjacency = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies, self).__setattr__(name, value)


                        class Adjacency(Entity):
                            """
                            A single IS\-IS adjacency
                            
                            .. attribute:: adj_ipv4bfd_retry_count
                            
                            	IPv4 BFD retry counter
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv4bfd_retry_exp
                            
                            	Time to expiration of IPv4 BFD retry timer (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv4bfd_retry_running
                            
                            	Is IPv4 BFD retry timer running
                            	**type**\:  bool
                            
                            .. attribute:: adj_ipv6bfd_retry_count
                            
                            	IPv6 BFD retry counter
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv6bfd_retry_exp
                            
                            	Time to expiration of IPv6 BFD retry timer (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv6bfd_retry_running
                            
                            	Is IPv6 BFD retry timer running
                            	**type**\:  bool
                            
                            .. attribute:: adjacency_area_address
                            
                            	Area addresses active over this adjacency
                            	**type**\: list of    :py:class:`AdjacencyAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress>`
                            
                            .. attribute:: adjacency_bfd_state
                            
                            	Adjacency IPv4 BFD state
                            	**type**\:   :py:class:`IsisAdjBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjBfdState>`
                            
                            .. attribute:: adjacency_checkpoint_object_id
                            
                            	Adjacency checkpoint object ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_dispriority
                            
                            	Priority of DIS on this LAN. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_holdtime
                            
                            	Time (s) until adjacency declared down if no IIH received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_ietf_nsf_capable_flag
                            
                            	TRUE if neighbor is IETF\-NSF capable
                            	**type**\:  bool
                            
                            .. attribute:: adjacency_interface
                            
                            	Local interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: adjacency_ipv6bfd_state
                            
                            	Adjacency IPv6 BFD state
                            	**type**\:   :py:class:`IsisAdjBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjBfdState>`
                            
                            .. attribute:: adjacency_local_priority
                            
                            	Local IS priority. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_media_type
                            
                            	Link media type
                            	**type**\:   :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                            
                            .. attribute:: adjacency_neighbor_priority
                            
                            	Neighbor IS priority. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_per_address_family_data
                            
                            	Per\-address\-family data
                            	**type**\: list of    :py:class:`AdjacencyPerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData>`
                            
                            .. attribute:: adjacency_snpa
                            
                            	Neighbor SNPA
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: adjacency_state
                            
                            	Adjacency state
                            	**type**\:   :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: adjacency_system_id
                            
                            	Neighbor system ID
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: adjacency_topology
                            
                            	Per\-topology data
                            	**type**\: list of    :py:class:`AdjacencyTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology>`
                            
                            .. attribute:: adjacency_uptime
                            
                            	How long the adjacency has been up (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_uptime_valid_flag
                            
                            	TRUE if AdjacencyUptime is set
                            	**type**\:  bool
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: local_dis_flag
                            
                            	TRUE if local system is DIS. Valid only if AdjacencyMediaType is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_dis_flag
                            
                            	TRUE if neighbor is DIS. Valid only if AdjacencyMediaType is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\:  bool
                            
                            .. attribute:: nsr_standby
                            
                            	ISIS NSR STANDBY
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: system_id
                            
                            	System ID
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency, self).__init__()

                                self.yang_name = "adjacency"
                                self.yang_parent_name = "adjacencies"

                                self.adj_ipv4bfd_retry_count = YLeaf(YType.uint32, "adj-ipv4bfd-retry-count")

                                self.adj_ipv4bfd_retry_exp = YLeaf(YType.uint32, "adj-ipv4bfd-retry-exp")

                                self.adj_ipv4bfd_retry_running = YLeaf(YType.boolean, "adj-ipv4bfd-retry-running")

                                self.adj_ipv6bfd_retry_count = YLeaf(YType.uint32, "adj-ipv6bfd-retry-count")

                                self.adj_ipv6bfd_retry_exp = YLeaf(YType.uint32, "adj-ipv6bfd-retry-exp")

                                self.adj_ipv6bfd_retry_running = YLeaf(YType.boolean, "adj-ipv6bfd-retry-running")

                                self.adjacency_bfd_state = YLeaf(YType.enumeration, "adjacency-bfd-state")

                                self.adjacency_checkpoint_object_id = YLeaf(YType.uint32, "adjacency-checkpoint-object-id")

                                self.adjacency_dispriority = YLeaf(YType.uint8, "adjacency-dispriority")

                                self.adjacency_holdtime = YLeaf(YType.uint32, "adjacency-holdtime")

                                self.adjacency_ietf_nsf_capable_flag = YLeaf(YType.boolean, "adjacency-ietf-nsf-capable-flag")

                                self.adjacency_interface = YLeaf(YType.str, "adjacency-interface")

                                self.adjacency_ipv6bfd_state = YLeaf(YType.enumeration, "adjacency-ipv6bfd-state")

                                self.adjacency_local_priority = YLeaf(YType.uint8, "adjacency-local-priority")

                                self.adjacency_media_type = YLeaf(YType.enumeration, "adjacency-media-type")

                                self.adjacency_neighbor_priority = YLeaf(YType.uint8, "adjacency-neighbor-priority")

                                self.adjacency_snpa = YLeaf(YType.str, "adjacency-snpa")

                                self.adjacency_state = YLeaf(YType.enumeration, "adjacency-state")

                                self.adjacency_system_id = YLeaf(YType.str, "adjacency-system-id")

                                self.adjacency_uptime = YLeaf(YType.uint32, "adjacency-uptime")

                                self.adjacency_uptime_valid_flag = YLeaf(YType.boolean, "adjacency-uptime-valid-flag")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.local_dis_flag = YLeaf(YType.boolean, "local-dis-flag")

                                self.neighbor_dis_flag = YLeaf(YType.boolean, "neighbor-dis-flag")

                                self.nsr_standby = YLeaf(YType.uint8, "nsr-standby")

                                self.system_id = YLeaf(YType.str, "system-id")

                                self.adjacency_area_address = YList(self)
                                self.adjacency_per_address_family_data = YList(self)
                                self.adjacency_topology = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("adj_ipv4bfd_retry_count",
                                                "adj_ipv4bfd_retry_exp",
                                                "adj_ipv4bfd_retry_running",
                                                "adj_ipv6bfd_retry_count",
                                                "adj_ipv6bfd_retry_exp",
                                                "adj_ipv6bfd_retry_running",
                                                "adjacency_bfd_state",
                                                "adjacency_checkpoint_object_id",
                                                "adjacency_dispriority",
                                                "adjacency_holdtime",
                                                "adjacency_ietf_nsf_capable_flag",
                                                "adjacency_interface",
                                                "adjacency_ipv6bfd_state",
                                                "adjacency_local_priority",
                                                "adjacency_media_type",
                                                "adjacency_neighbor_priority",
                                                "adjacency_snpa",
                                                "adjacency_state",
                                                "adjacency_system_id",
                                                "adjacency_uptime",
                                                "adjacency_uptime_valid_flag",
                                                "interface_name",
                                                "local_dis_flag",
                                                "neighbor_dis_flag",
                                                "nsr_standby",
                                                "system_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency, self).__setattr__(name, value)


                            class AdjacencyAreaAddress(Entity):
                                """
                                Area addresses active over this adjacency
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress, self).__init__()

                                    self.yang_name = "adjacency-area-address"
                                    self.yang_parent_name = "adjacency"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-area-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class AdjacencyTopology(Entity):
                                """
                                Per\-topology data
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id>`
                                
                                .. attribute:: parallel_p2p_link_suppressed_flag
                                
                                	TRUE if suppressed parallel point\-to\-point link
                                	**type**\:  bool
                                
                                .. attribute:: topology_status
                                
                                	Status of topology in adjacency
                                	**type**\:   :py:class:`IsisAdjTopoStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjTopoStatus>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology, self).__init__()

                                    self.yang_name = "adjacency-topology"
                                    self.yang_parent_name = "adjacency"

                                    self.parallel_p2p_link_suppressed_flag = YLeaf(YType.boolean, "parallel-p2p-link-suppressed-flag")

                                    self.topology_status = YLeaf(YType.enumeration, "topology-status")

                                    self.id = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                    self._children_yang_names.add("id")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("parallel_p2p_link_suppressed_flag",
                                                    "topology_status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology, self).__setattr__(name, value)


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "adjacency-topology"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                                        self.topology_name = YLeaf(YType.str, "topology-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "saf_name",
                                                        "topology_name",
                                                        "vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.saf_name.is_set or
                                            self.topology_name.is_set or
                                            self.vrf_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.saf_name.yfilter != YFilter.not_set or
                                            self.topology_name.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saf-name"):
                                            self.saf_name = value
                                            self.saf_name.value_namespace = name_space
                                            self.saf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-name"):
                                            self.topology_name = value
                                            self.topology_name.value_namespace = name_space
                                            self.topology_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.parallel_p2p_link_suppressed_flag.is_set or
                                        self.topology_status.is_set or
                                        (self.id is not None and self.id.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.parallel_p2p_link_suppressed_flag.yfilter != YFilter.not_set or
                                        self.topology_status.yfilter != YFilter.not_set or
                                        (self.id is not None and self.id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-topology" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.parallel_p2p_link_suppressed_flag.is_set or self.parallel_p2p_link_suppressed_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.parallel_p2p_link_suppressed_flag.get_name_leafdata())
                                    if (self.topology_status.is_set or self.topology_status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.topology_status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "id"):
                                        if (self.id is None):
                                            self.id = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id()
                                            self.id.parent = self
                                            self._children_name_map["id"] = "id"
                                        return self.id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "id" or name == "parallel-p2p-link-suppressed-flag" or name == "topology-status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "parallel-p2p-link-suppressed-flag"):
                                        self.parallel_p2p_link_suppressed_flag = value
                                        self.parallel_p2p_link_suppressed_flag.value_namespace = name_space
                                        self.parallel_p2p_link_suppressed_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "topology-status"):
                                        self.topology_status = value
                                        self.topology_status.value_namespace = name_space
                                        self.topology_status.value_namespace_prefix = name_space_prefix


                            class AdjacencyPerAddressFamilyData(Entity):
                                """
                                Per\-address\-family data
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                
                                .. attribute:: ipv4
                                
                                	IPV4 neighbor info
                                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4>`
                                
                                .. attribute:: ipv6
                                
                                	IPV6 neighbor info
                                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData, self).__init__()

                                    self.yang_name = "adjacency-per-address-family-data"
                                    self.yang_parent_name = "adjacency"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                    self._children_yang_names.add("ipv4")

                                    self.ipv6 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6()
                                    self.ipv6.parent = self
                                    self._children_name_map["ipv6"] = "ipv6"
                                    self._children_yang_names.add("ipv6")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData, self).__setattr__(name, value)


                                class Ipv4(Entity):
                                    """
                                    IPV4 neighbor info
                                    
                                    .. attribute:: adjacency_sid
                                    
                                    	Adjacency SID
                                    	**type**\:   :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid>`
                                    
                                    .. attribute:: interface_address
                                    
                                    	Adjacency interface addresses
                                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress>`
                                    
                                    .. attribute:: next_hop
                                    
                                    	Adjacency next hop
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: non_frr_adjacency_sid
                                    
                                    	Adjacency SID not eligible for FRR protection
                                    	**type**\:   :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid>`
                                    
                                    .. attribute:: underlying_adjacency_sid
                                    
                                    	Per bundle member Adjacency sid
                                    	**type**\: list of    :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid>`
                                    
                                    .. attribute:: underlying_interface
                                    
                                    	Underlying interface list for bundle interfaces
                                    	**type**\: list of    :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "adjacency-per-address-family-data"

                                        self.next_hop = YLeaf(YType.str, "next-hop")

                                        self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                        self._children_yang_names.add("adjacency-sid")

                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                        self._children_yang_names.add("non-frr-adjacency-sid")

                                        self.interface_address = YList(self)
                                        self.underlying_adjacency_sid = YList(self)
                                        self.underlying_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4, self).__setattr__(name, value)


                                    class AdjacencySid(Entity):
                                        """
                                        Adjacency SID
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid, self).__init__()

                                            self.yang_name = "adjacency-sid"
                                            self.yang_parent_name = "ipv4"

                                            self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                            self._children_yang_names.add("adjacency-sid-backup")

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._children_yang_names.add("adjacency-sid-backup-te")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("adjacency_sid_value") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid, self).__setattr__(name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup-te" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.adjacency_sid_value.is_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.adjacency_sid_value.yfilter != YFilter.not_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "adjacency-sid-backup"):
                                                if (self.adjacency_sid_backup is None):
                                                    self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                                    self.adjacency_sid_backup.parent = self
                                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                                return self.adjacency_sid_backup

                                            if (child_yang_name == "adjacency-sid-backup-te"):
                                                if (self.adjacency_sid_backup_te is None):
                                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                                    self.adjacency_sid_backup_te.parent = self
                                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                                return self.adjacency_sid_backup_te

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "adjacency-sid-value"):
                                                self.adjacency_sid_value = value
                                                self.adjacency_sid_value.value_namespace = name_space
                                                self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                                    class NonFrrAdjacencySid(Entity):
                                        """
                                        Adjacency SID not eligible for FRR protection
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__init__()

                                            self.yang_name = "non-frr-adjacency-sid"
                                            self.yang_parent_name = "ipv4"

                                            self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                            self._children_yang_names.add("adjacency-sid-backup")

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._children_yang_names.add("adjacency-sid-backup-te")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("adjacency_sid_value") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__setattr__(name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "non-frr-adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "non-frr-adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup-te" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.adjacency_sid_value.is_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.adjacency_sid_value.yfilter != YFilter.not_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "non-frr-adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "adjacency-sid-backup"):
                                                if (self.adjacency_sid_backup is None):
                                                    self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                                    self.adjacency_sid_backup.parent = self
                                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                                return self.adjacency_sid_backup

                                            if (child_yang_name == "adjacency-sid-backup-te"):
                                                if (self.adjacency_sid_backup_te is None):
                                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                                    self.adjacency_sid_backup_te.parent = self
                                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                                return self.adjacency_sid_backup_te

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "adjacency-sid-value"):
                                                self.adjacency_sid_value = value
                                                self.adjacency_sid_value.value_namespace = name_space
                                                self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                                    class InterfaceAddress(Entity):
                                        """
                                        Adjacency interface addresses
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress, self).__init__()

                                            self.yang_name = "interface-address"
                                            self.yang_parent_name = "ipv4"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class UnderlyingInterface(Entity):
                                        """
                                        Underlying interface list for bundle interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__init__()

                                            self.yang_name = "underlying-interface"
                                            self.yang_parent_name = "ipv4"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "underlying-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class UnderlyingAdjacencySid(Entity):
                                        """
                                        Per bundle member Adjacency sid
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__init__()

                                            self.yang_name = "underlying-adjacency-sid"
                                            self.yang_parent_name = "ipv4"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "underlying-adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.underlying_adjacency_sid:
                                            if (c.has_data()):
                                                return True
                                        for c in self.underlying_interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.next_hop.is_set or
                                            (self.adjacency_sid is not None and self.adjacency_sid.has_data()) or
                                            (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_data()))

                                    def has_operation(self):
                                        for c in self.interface_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.underlying_adjacency_sid:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.underlying_interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop.yfilter != YFilter.not_set or
                                            (self.adjacency_sid is not None and self.adjacency_sid.has_operation()) or
                                            (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipv4" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "adjacency-sid"):
                                            if (self.adjacency_sid is None):
                                                self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid()
                                                self.adjacency_sid.parent = self
                                                self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                            return self.adjacency_sid

                                        if (child_yang_name == "interface-address"):
                                            for c in self.interface_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_address.append(c)
                                            return c

                                        if (child_yang_name == "non-frr-adjacency-sid"):
                                            if (self.non_frr_adjacency_sid is None):
                                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                                self.non_frr_adjacency_sid.parent = self
                                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                            return self.non_frr_adjacency_sid

                                        if (child_yang_name == "underlying-adjacency-sid"):
                                            for c in self.underlying_adjacency_sid:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.underlying_adjacency_sid.append(c)
                                            return c

                                        if (child_yang_name == "underlying-interface"):
                                            for c in self.underlying_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.underlying_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "adjacency-sid" or name == "interface-address" or name == "non-frr-adjacency-sid" or name == "underlying-adjacency-sid" or name == "underlying-interface" or name == "next-hop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop"):
                                            self.next_hop = value
                                            self.next_hop.value_namespace = name_space
                                            self.next_hop.value_namespace_prefix = name_space_prefix


                                class Ipv6(Entity):
                                    """
                                    IPV6 neighbor info
                                    
                                    .. attribute:: adjacency_sid
                                    
                                    	Adjacency SID
                                    	**type**\:   :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid>`
                                    
                                    .. attribute:: interface_address
                                    
                                    	Adjacency interface addresses
                                    	**type**\: list of    :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress>`
                                    
                                    .. attribute:: next_hop
                                    
                                    	Adjacency next hop
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: non_frr_adjacency_sid
                                    
                                    	Adjacency SID not eligible for FRR protection
                                    	**type**\:   :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid>`
                                    
                                    .. attribute:: underlying_adjacency_sid
                                    
                                    	Per bundle member Adjacency sid
                                    	**type**\: list of    :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid>`
                                    
                                    .. attribute:: underlying_interface
                                    
                                    	Underlying interface list for bundle interfaces
                                    	**type**\: list of    :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "adjacency-per-address-family-data"

                                        self.next_hop = YLeaf(YType.str, "next-hop")

                                        self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                        self._children_yang_names.add("adjacency-sid")

                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                        self._children_yang_names.add("non-frr-adjacency-sid")

                                        self.interface_address = YList(self)
                                        self.underlying_adjacency_sid = YList(self)
                                        self.underlying_interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("next_hop") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6, self).__setattr__(name, value)


                                    class AdjacencySid(Entity):
                                        """
                                        Adjacency SID
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid, self).__init__()

                                            self.yang_name = "adjacency-sid"
                                            self.yang_parent_name = "ipv6"

                                            self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                            self._children_yang_names.add("adjacency-sid-backup")

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._children_yang_names.add("adjacency-sid-backup-te")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("adjacency_sid_value") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid, self).__setattr__(name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup-te" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.adjacency_sid_value.is_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.adjacency_sid_value.yfilter != YFilter.not_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "adjacency-sid-backup"):
                                                if (self.adjacency_sid_backup is None):
                                                    self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                                    self.adjacency_sid_backup.parent = self
                                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                                return self.adjacency_sid_backup

                                            if (child_yang_name == "adjacency-sid-backup-te"):
                                                if (self.adjacency_sid_backup_te is None):
                                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                                    self.adjacency_sid_backup_te.parent = self
                                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                                return self.adjacency_sid_backup_te

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "adjacency-sid-value"):
                                                self.adjacency_sid_value = value
                                                self.adjacency_sid_value.value_namespace = name_space
                                                self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                                    class NonFrrAdjacencySid(Entity):
                                        """
                                        Adjacency SID not eligible for FRR protection
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:   :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:   :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__init__()

                                            self.yang_name = "non-frr-adjacency-sid"
                                            self.yang_parent_name = "ipv6"

                                            self.adjacency_sid_value = YLeaf(YType.uint32, "adjacency-sid-value")

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                            self._children_yang_names.add("adjacency-sid-backup")

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._children_yang_names.add("adjacency-sid-backup-te")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("adjacency_sid_value") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__setattr__(name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "non-frr-adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of    :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "non-frr-adjacency-sid"

                                                self.backup_interface = YLeaf(YType.str, "backup-interface")

                                                self.backup_label_stack_size = YLeaf(YType.uint8, "backup-label-stack-size")

                                                self.backup_nexthop = YLeaf(YType.str, "backup-nexthop")

                                                self.backup_node_address = YLeaf(YType.str, "backup-node-address")

                                                self.backup_label_stack = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("backup_interface",
                                                                "backup_label_stack_size",
                                                                "backup_nexthop",
                                                                "backup_node_address") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__setattr__(name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "backup-label-stack" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.backup_interface.is_set or
                                                    self.backup_label_stack_size.is_set or
                                                    self.backup_nexthop.is_set or
                                                    self.backup_node_address.is_set)

                                            def has_operation(self):
                                                for c in self.backup_label_stack:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.backup_interface.yfilter != YFilter.not_set or
                                                    self.backup_label_stack_size.yfilter != YFilter.not_set or
                                                    self.backup_nexthop.yfilter != YFilter.not_set or
                                                    self.backup_node_address.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-sid-backup-te" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_interface.get_name_leafdata())
                                                if (self.backup_label_stack_size.is_set or self.backup_label_stack_size.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_label_stack_size.get_name_leafdata())
                                                if (self.backup_nexthop.is_set or self.backup_nexthop.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_nexthop.get_name_leafdata())
                                                if (self.backup_node_address.is_set or self.backup_node_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.backup_node_address.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "backup-label-stack"):
                                                    for c in self.backup_label_stack:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.backup_label_stack.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "backup-label-stack" or name == "backup-interface" or name == "backup-label-stack-size" or name == "backup-nexthop" or name == "backup-node-address"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "backup-interface"):
                                                    self.backup_interface = value
                                                    self.backup_interface.value_namespace = name_space
                                                    self.backup_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-label-stack-size"):
                                                    self.backup_label_stack_size = value
                                                    self.backup_label_stack_size.value_namespace = name_space
                                                    self.backup_label_stack_size.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-nexthop"):
                                                    self.backup_nexthop = value
                                                    self.backup_nexthop.value_namespace = name_space
                                                    self.backup_nexthop.value_namespace_prefix = name_space_prefix
                                                if(value_path == "backup-node-address"):
                                                    self.backup_node_address = value
                                                    self.backup_node_address.value_namespace = name_space
                                                    self.backup_node_address.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.adjacency_sid_value.is_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_data()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.adjacency_sid_value.yfilter != YFilter.not_set or
                                                (self.adjacency_sid_backup is not None and self.adjacency_sid_backup.has_operation()) or
                                                (self.adjacency_sid_backup_te is not None and self.adjacency_sid_backup_te.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "non-frr-adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.adjacency_sid_value.is_set or self.adjacency_sid_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.adjacency_sid_value.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "adjacency-sid-backup"):
                                                if (self.adjacency_sid_backup is None):
                                                    self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                                    self.adjacency_sid_backup.parent = self
                                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"
                                                return self.adjacency_sid_backup

                                            if (child_yang_name == "adjacency-sid-backup-te"):
                                                if (self.adjacency_sid_backup_te is None):
                                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                                    self.adjacency_sid_backup_te.parent = self
                                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                                return self.adjacency_sid_backup_te

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "adjacency-sid-backup" or name == "adjacency-sid-backup-te" or name == "adjacency-sid-value"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "adjacency-sid-value"):
                                                self.adjacency_sid_value = value
                                                self.adjacency_sid_value.value_namespace = name_space
                                                self.adjacency_sid_value.value_namespace_prefix = name_space_prefix


                                    class InterfaceAddress(Entity):
                                        """
                                        Adjacency interface addresses
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress, self).__init__()

                                            self.yang_name = "interface-address"
                                            self.yang_parent_name = "ipv6"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface-address" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class UnderlyingInterface(Entity):
                                        """
                                        Underlying interface list for bundle interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__init__()

                                            self.yang_name = "underlying-interface"
                                            self.yang_parent_name = "ipv6"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "underlying-interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class UnderlyingAdjacencySid(Entity):
                                        """
                                        Per bundle member Adjacency sid
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__init__()

                                            self.yang_name = "underlying-adjacency-sid"
                                            self.yang_parent_name = "ipv6"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "underlying-adjacency-sid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface_address:
                                            if (c.has_data()):
                                                return True
                                        for c in self.underlying_adjacency_sid:
                                            if (c.has_data()):
                                                return True
                                        for c in self.underlying_interface:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.next_hop.is_set or
                                            (self.adjacency_sid is not None and self.adjacency_sid.has_data()) or
                                            (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_data()))

                                    def has_operation(self):
                                        for c in self.interface_address:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.underlying_adjacency_sid:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.underlying_interface:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.next_hop.yfilter != YFilter.not_set or
                                            (self.adjacency_sid is not None and self.adjacency_sid.has_operation()) or
                                            (self.non_frr_adjacency_sid is not None and self.non_frr_adjacency_sid.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipv6" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.next_hop.is_set or self.next_hop.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_hop.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "adjacency-sid"):
                                            if (self.adjacency_sid is None):
                                                self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid()
                                                self.adjacency_sid.parent = self
                                                self._children_name_map["adjacency_sid"] = "adjacency-sid"
                                            return self.adjacency_sid

                                        if (child_yang_name == "interface-address"):
                                            for c in self.interface_address:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface_address.append(c)
                                            return c

                                        if (child_yang_name == "non-frr-adjacency-sid"):
                                            if (self.non_frr_adjacency_sid is None):
                                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                                self.non_frr_adjacency_sid.parent = self
                                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"
                                            return self.non_frr_adjacency_sid

                                        if (child_yang_name == "underlying-adjacency-sid"):
                                            for c in self.underlying_adjacency_sid:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.underlying_adjacency_sid.append(c)
                                            return c

                                        if (child_yang_name == "underlying-interface"):
                                            for c in self.underlying_interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.underlying_interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "adjacency-sid" or name == "interface-address" or name == "non-frr-adjacency-sid" or name == "underlying-adjacency-sid" or name == "underlying-interface" or name == "next-hop"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "next-hop"):
                                            self.next_hop = value
                                            self.next_hop.value_namespace = name_space
                                            self.next_hop.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        (self.ipv4 is not None and self.ipv4.has_data()) or
                                        (self.ipv6 is not None and self.ipv6.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        (self.ipv4 is not None and self.ipv4.has_operation()) or
                                        (self.ipv6 is not None and self.ipv6.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-per-address-family-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ipv4"):
                                        if (self.ipv4 is None):
                                            self.ipv4 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4()
                                            self.ipv4.parent = self
                                            self._children_name_map["ipv4"] = "ipv4"
                                        return self.ipv4

                                    if (child_yang_name == "ipv6"):
                                        if (self.ipv6 is None):
                                            self.ipv6 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6()
                                            self.ipv6.parent = self
                                            self._children_name_map["ipv6"] = "ipv6"
                                        return self.ipv6

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4" or name == "ipv6" or name == "af-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.adjacency_area_address:
                                    if (c.has_data()):
                                        return True
                                for c in self.adjacency_per_address_family_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.adjacency_topology:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.adj_ipv4bfd_retry_count.is_set or
                                    self.adj_ipv4bfd_retry_exp.is_set or
                                    self.adj_ipv4bfd_retry_running.is_set or
                                    self.adj_ipv6bfd_retry_count.is_set or
                                    self.adj_ipv6bfd_retry_exp.is_set or
                                    self.adj_ipv6bfd_retry_running.is_set or
                                    self.adjacency_bfd_state.is_set or
                                    self.adjacency_checkpoint_object_id.is_set or
                                    self.adjacency_dispriority.is_set or
                                    self.adjacency_holdtime.is_set or
                                    self.adjacency_ietf_nsf_capable_flag.is_set or
                                    self.adjacency_interface.is_set or
                                    self.adjacency_ipv6bfd_state.is_set or
                                    self.adjacency_local_priority.is_set or
                                    self.adjacency_media_type.is_set or
                                    self.adjacency_neighbor_priority.is_set or
                                    self.adjacency_snpa.is_set or
                                    self.adjacency_state.is_set or
                                    self.adjacency_system_id.is_set or
                                    self.adjacency_uptime.is_set or
                                    self.adjacency_uptime_valid_flag.is_set or
                                    self.interface_name.is_set or
                                    self.local_dis_flag.is_set or
                                    self.neighbor_dis_flag.is_set or
                                    self.nsr_standby.is_set or
                                    self.system_id.is_set)

                            def has_operation(self):
                                for c in self.adjacency_area_address:
                                    if (c.has_operation()):
                                        return True
                                for c in self.adjacency_per_address_family_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.adjacency_topology:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.adj_ipv4bfd_retry_count.yfilter != YFilter.not_set or
                                    self.adj_ipv4bfd_retry_exp.yfilter != YFilter.not_set or
                                    self.adj_ipv4bfd_retry_running.yfilter != YFilter.not_set or
                                    self.adj_ipv6bfd_retry_count.yfilter != YFilter.not_set or
                                    self.adj_ipv6bfd_retry_exp.yfilter != YFilter.not_set or
                                    self.adj_ipv6bfd_retry_running.yfilter != YFilter.not_set or
                                    self.adjacency_bfd_state.yfilter != YFilter.not_set or
                                    self.adjacency_checkpoint_object_id.yfilter != YFilter.not_set or
                                    self.adjacency_dispriority.yfilter != YFilter.not_set or
                                    self.adjacency_holdtime.yfilter != YFilter.not_set or
                                    self.adjacency_ietf_nsf_capable_flag.yfilter != YFilter.not_set or
                                    self.adjacency_interface.yfilter != YFilter.not_set or
                                    self.adjacency_ipv6bfd_state.yfilter != YFilter.not_set or
                                    self.adjacency_local_priority.yfilter != YFilter.not_set or
                                    self.adjacency_media_type.yfilter != YFilter.not_set or
                                    self.adjacency_neighbor_priority.yfilter != YFilter.not_set or
                                    self.adjacency_snpa.yfilter != YFilter.not_set or
                                    self.adjacency_state.yfilter != YFilter.not_set or
                                    self.adjacency_system_id.yfilter != YFilter.not_set or
                                    self.adjacency_uptime.yfilter != YFilter.not_set or
                                    self.adjacency_uptime_valid_flag.yfilter != YFilter.not_set or
                                    self.interface_name.yfilter != YFilter.not_set or
                                    self.local_dis_flag.yfilter != YFilter.not_set or
                                    self.neighbor_dis_flag.yfilter != YFilter.not_set or
                                    self.nsr_standby.yfilter != YFilter.not_set or
                                    self.system_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "adjacency" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.adj_ipv4bfd_retry_count.is_set or self.adj_ipv4bfd_retry_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv4bfd_retry_count.get_name_leafdata())
                                if (self.adj_ipv4bfd_retry_exp.is_set or self.adj_ipv4bfd_retry_exp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv4bfd_retry_exp.get_name_leafdata())
                                if (self.adj_ipv4bfd_retry_running.is_set or self.adj_ipv4bfd_retry_running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv4bfd_retry_running.get_name_leafdata())
                                if (self.adj_ipv6bfd_retry_count.is_set or self.adj_ipv6bfd_retry_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv6bfd_retry_count.get_name_leafdata())
                                if (self.adj_ipv6bfd_retry_exp.is_set or self.adj_ipv6bfd_retry_exp.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv6bfd_retry_exp.get_name_leafdata())
                                if (self.adj_ipv6bfd_retry_running.is_set or self.adj_ipv6bfd_retry_running.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adj_ipv6bfd_retry_running.get_name_leafdata())
                                if (self.adjacency_bfd_state.is_set or self.adjacency_bfd_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_bfd_state.get_name_leafdata())
                                if (self.adjacency_checkpoint_object_id.is_set or self.adjacency_checkpoint_object_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_checkpoint_object_id.get_name_leafdata())
                                if (self.adjacency_dispriority.is_set or self.adjacency_dispriority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_dispriority.get_name_leafdata())
                                if (self.adjacency_holdtime.is_set or self.adjacency_holdtime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_holdtime.get_name_leafdata())
                                if (self.adjacency_ietf_nsf_capable_flag.is_set or self.adjacency_ietf_nsf_capable_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_ietf_nsf_capable_flag.get_name_leafdata())
                                if (self.adjacency_interface.is_set or self.adjacency_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_interface.get_name_leafdata())
                                if (self.adjacency_ipv6bfd_state.is_set or self.adjacency_ipv6bfd_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_ipv6bfd_state.get_name_leafdata())
                                if (self.adjacency_local_priority.is_set or self.adjacency_local_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_local_priority.get_name_leafdata())
                                if (self.adjacency_media_type.is_set or self.adjacency_media_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_media_type.get_name_leafdata())
                                if (self.adjacency_neighbor_priority.is_set or self.adjacency_neighbor_priority.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_neighbor_priority.get_name_leafdata())
                                if (self.adjacency_snpa.is_set or self.adjacency_snpa.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_snpa.get_name_leafdata())
                                if (self.adjacency_state.is_set or self.adjacency_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_state.get_name_leafdata())
                                if (self.adjacency_system_id.is_set or self.adjacency_system_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_system_id.get_name_leafdata())
                                if (self.adjacency_uptime.is_set or self.adjacency_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_uptime.get_name_leafdata())
                                if (self.adjacency_uptime_valid_flag.is_set or self.adjacency_uptime_valid_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.adjacency_uptime_valid_flag.get_name_leafdata())
                                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                                if (self.local_dis_flag.is_set or self.local_dis_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_dis_flag.get_name_leafdata())
                                if (self.neighbor_dis_flag.is_set or self.neighbor_dis_flag.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.neighbor_dis_flag.get_name_leafdata())
                                if (self.nsr_standby.is_set or self.nsr_standby.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nsr_standby.get_name_leafdata())
                                if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.system_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "adjacency-area-address"):
                                    for c in self.adjacency_area_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.adjacency_area_address.append(c)
                                    return c

                                if (child_yang_name == "adjacency-per-address-family-data"):
                                    for c in self.adjacency_per_address_family_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.adjacency_per_address_family_data.append(c)
                                    return c

                                if (child_yang_name == "adjacency-topology"):
                                    for c in self.adjacency_topology:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.adjacency_topology.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adjacency-area-address" or name == "adjacency-per-address-family-data" or name == "adjacency-topology" or name == "adj-ipv4bfd-retry-count" or name == "adj-ipv4bfd-retry-exp" or name == "adj-ipv4bfd-retry-running" or name == "adj-ipv6bfd-retry-count" or name == "adj-ipv6bfd-retry-exp" or name == "adj-ipv6bfd-retry-running" or name == "adjacency-bfd-state" or name == "adjacency-checkpoint-object-id" or name == "adjacency-dispriority" or name == "adjacency-holdtime" or name == "adjacency-ietf-nsf-capable-flag" or name == "adjacency-interface" or name == "adjacency-ipv6bfd-state" or name == "adjacency-local-priority" or name == "adjacency-media-type" or name == "adjacency-neighbor-priority" or name == "adjacency-snpa" or name == "adjacency-state" or name == "adjacency-system-id" or name == "adjacency-uptime" or name == "adjacency-uptime-valid-flag" or name == "interface-name" or name == "local-dis-flag" or name == "neighbor-dis-flag" or name == "nsr-standby" or name == "system-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "adj-ipv4bfd-retry-count"):
                                    self.adj_ipv4bfd_retry_count = value
                                    self.adj_ipv4bfd_retry_count.value_namespace = name_space
                                    self.adj_ipv4bfd_retry_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-ipv4bfd-retry-exp"):
                                    self.adj_ipv4bfd_retry_exp = value
                                    self.adj_ipv4bfd_retry_exp.value_namespace = name_space
                                    self.adj_ipv4bfd_retry_exp.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-ipv4bfd-retry-running"):
                                    self.adj_ipv4bfd_retry_running = value
                                    self.adj_ipv4bfd_retry_running.value_namespace = name_space
                                    self.adj_ipv4bfd_retry_running.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-ipv6bfd-retry-count"):
                                    self.adj_ipv6bfd_retry_count = value
                                    self.adj_ipv6bfd_retry_count.value_namespace = name_space
                                    self.adj_ipv6bfd_retry_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-ipv6bfd-retry-exp"):
                                    self.adj_ipv6bfd_retry_exp = value
                                    self.adj_ipv6bfd_retry_exp.value_namespace = name_space
                                    self.adj_ipv6bfd_retry_exp.value_namespace_prefix = name_space_prefix
                                if(value_path == "adj-ipv6bfd-retry-running"):
                                    self.adj_ipv6bfd_retry_running = value
                                    self.adj_ipv6bfd_retry_running.value_namespace = name_space
                                    self.adj_ipv6bfd_retry_running.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-bfd-state"):
                                    self.adjacency_bfd_state = value
                                    self.adjacency_bfd_state.value_namespace = name_space
                                    self.adjacency_bfd_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-checkpoint-object-id"):
                                    self.adjacency_checkpoint_object_id = value
                                    self.adjacency_checkpoint_object_id.value_namespace = name_space
                                    self.adjacency_checkpoint_object_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-dispriority"):
                                    self.adjacency_dispriority = value
                                    self.adjacency_dispriority.value_namespace = name_space
                                    self.adjacency_dispriority.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-holdtime"):
                                    self.adjacency_holdtime = value
                                    self.adjacency_holdtime.value_namespace = name_space
                                    self.adjacency_holdtime.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-ietf-nsf-capable-flag"):
                                    self.adjacency_ietf_nsf_capable_flag = value
                                    self.adjacency_ietf_nsf_capable_flag.value_namespace = name_space
                                    self.adjacency_ietf_nsf_capable_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-interface"):
                                    self.adjacency_interface = value
                                    self.adjacency_interface.value_namespace = name_space
                                    self.adjacency_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-ipv6bfd-state"):
                                    self.adjacency_ipv6bfd_state = value
                                    self.adjacency_ipv6bfd_state.value_namespace = name_space
                                    self.adjacency_ipv6bfd_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-local-priority"):
                                    self.adjacency_local_priority = value
                                    self.adjacency_local_priority.value_namespace = name_space
                                    self.adjacency_local_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-media-type"):
                                    self.adjacency_media_type = value
                                    self.adjacency_media_type.value_namespace = name_space
                                    self.adjacency_media_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-neighbor-priority"):
                                    self.adjacency_neighbor_priority = value
                                    self.adjacency_neighbor_priority.value_namespace = name_space
                                    self.adjacency_neighbor_priority.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-snpa"):
                                    self.adjacency_snpa = value
                                    self.adjacency_snpa.value_namespace = name_space
                                    self.adjacency_snpa.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-state"):
                                    self.adjacency_state = value
                                    self.adjacency_state.value_namespace = name_space
                                    self.adjacency_state.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-system-id"):
                                    self.adjacency_system_id = value
                                    self.adjacency_system_id.value_namespace = name_space
                                    self.adjacency_system_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-uptime"):
                                    self.adjacency_uptime = value
                                    self.adjacency_uptime.value_namespace = name_space
                                    self.adjacency_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "adjacency-uptime-valid-flag"):
                                    self.adjacency_uptime_valid_flag = value
                                    self.adjacency_uptime_valid_flag.value_namespace = name_space
                                    self.adjacency_uptime_valid_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name"):
                                    self.interface_name = value
                                    self.interface_name.value_namespace = name_space
                                    self.interface_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-dis-flag"):
                                    self.local_dis_flag = value
                                    self.local_dis_flag.value_namespace = name_space
                                    self.local_dis_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "neighbor-dis-flag"):
                                    self.neighbor_dis_flag = value
                                    self.neighbor_dis_flag.value_namespace = name_space
                                    self.neighbor_dis_flag.value_namespace_prefix = name_space_prefix
                                if(value_path == "nsr-standby"):
                                    self.nsr_standby = value
                                    self.nsr_standby.value_namespace = name_space
                                    self.nsr_standby.value_namespace_prefix = name_space_prefix
                                if(value_path == "system-id"):
                                    self.system_id = value
                                    self.system_id.value_namespace = name_space
                                    self.system_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.adjacency:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.adjacency:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "adjacencies" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "adjacency"):
                                for c in self.adjacency:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.adjacency.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "adjacency"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DetailedLsps(Entity):
                        """
                        Detailed LSP table. Use to retrieve LSPs
                        with TLV content.
                        
                        .. attribute:: detailed_lsp
                        
                        	An IS\-IS LSP with detailed TLV data included
                        	**type**\: list of    :py:class:`DetailedLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.DetailedLsps, self).__init__()

                            self.yang_name = "detailed-lsps"
                            self.yang_parent_name = "level"

                            self.detailed_lsp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.DetailedLsps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.DetailedLsps, self).__setattr__(name, value)


                        class DetailedLsp(Entity):
                            """
                            An IS\-IS LSP with detailed TLV data
                            included
                            
                            .. attribute:: lsp_id  <key>
                            
                            	LSP ID
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                            
                            .. attribute:: lsp_body
                            
                            	LSP as received/sent over the wire, starting from the LSP ID field
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: lsp_header_data
                            
                            	Information from the LSP header
                            	**type**\:   :py:class:`LspHeaderData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp, self).__init__()

                                self.yang_name = "detailed-lsp"
                                self.yang_parent_name = "detailed-lsps"

                                self.lsp_id = YLeaf(YType.str, "lsp-id")

                                self.lsp_body = YLeaf(YType.str, "lsp-body")

                                self.lsp_header_data = Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData()
                                self.lsp_header_data.parent = self
                                self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                self._children_yang_names.add("lsp-header-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lsp_id",
                                                "lsp_body") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp, self).__setattr__(name, value)


                            class LspHeaderData(Entity):
                                """
                                Information from the LSP header
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\:  bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\:  bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_parition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\:  bool
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData, self).__init__()

                                    self.yang_name = "lsp-header-data"
                                    self.yang_parent_name = "detailed-lsp"

                                    self.local_lsp_flag = YLeaf(YType.boolean, "local-lsp-flag")

                                    self.lsp_active_flag = YLeaf(YType.boolean, "lsp-active-flag")

                                    self.lsp_attached_flag = YLeaf(YType.boolean, "lsp-attached-flag")

                                    self.lsp_checksum = YLeaf(YType.uint16, "lsp-checksum")

                                    self.lsp_holdtime = YLeaf(YType.uint16, "lsp-holdtime")

                                    self.lsp_id = YLeaf(YType.str, "lsp-id")

                                    self.lsp_length = YLeaf(YType.uint16, "lsp-length")

                                    self.lsp_level = YLeaf(YType.enumeration, "lsp-level")

                                    self.lsp_nonv1a_flag = YLeaf(YType.uint16, "lsp-nonv1a-flag")

                                    self.lsp_overloaded_flag = YLeaf(YType.boolean, "lsp-overloaded-flag")

                                    self.lsp_parition_repair_supported_flag = YLeaf(YType.boolean, "lsp-parition-repair-supported-flag")

                                    self.lsp_sequence_number = YLeaf(YType.uint32, "lsp-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_lsp_flag",
                                                    "lsp_active_flag",
                                                    "lsp_attached_flag",
                                                    "lsp_checksum",
                                                    "lsp_holdtime",
                                                    "lsp_id",
                                                    "lsp_length",
                                                    "lsp_level",
                                                    "lsp_nonv1a_flag",
                                                    "lsp_overloaded_flag",
                                                    "lsp_parition_repair_supported_flag",
                                                    "lsp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_lsp_flag.is_set or
                                        self.lsp_active_flag.is_set or
                                        self.lsp_attached_flag.is_set or
                                        self.lsp_checksum.is_set or
                                        self.lsp_holdtime.is_set or
                                        self.lsp_id.is_set or
                                        self.lsp_length.is_set or
                                        self.lsp_level.is_set or
                                        self.lsp_nonv1a_flag.is_set or
                                        self.lsp_overloaded_flag.is_set or
                                        self.lsp_parition_repair_supported_flag.is_set or
                                        self.lsp_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_lsp_flag.yfilter != YFilter.not_set or
                                        self.lsp_active_flag.yfilter != YFilter.not_set or
                                        self.lsp_attached_flag.yfilter != YFilter.not_set or
                                        self.lsp_checksum.yfilter != YFilter.not_set or
                                        self.lsp_holdtime.yfilter != YFilter.not_set or
                                        self.lsp_id.yfilter != YFilter.not_set or
                                        self.lsp_length.yfilter != YFilter.not_set or
                                        self.lsp_level.yfilter != YFilter.not_set or
                                        self.lsp_nonv1a_flag.yfilter != YFilter.not_set or
                                        self.lsp_overloaded_flag.yfilter != YFilter.not_set or
                                        self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set or
                                        self.lsp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsp-header-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_lsp_flag.is_set or self.local_lsp_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_lsp_flag.get_name_leafdata())
                                    if (self.lsp_active_flag.is_set or self.lsp_active_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_active_flag.get_name_leafdata())
                                    if (self.lsp_attached_flag.is_set or self.lsp_attached_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_attached_flag.get_name_leafdata())
                                    if (self.lsp_checksum.is_set or self.lsp_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_checksum.get_name_leafdata())
                                    if (self.lsp_holdtime.is_set or self.lsp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_holdtime.get_name_leafdata())
                                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                    if (self.lsp_length.is_set or self.lsp_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_length.get_name_leafdata())
                                    if (self.lsp_level.is_set or self.lsp_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_level.get_name_leafdata())
                                    if (self.lsp_nonv1a_flag.is_set or self.lsp_nonv1a_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_nonv1a_flag.get_name_leafdata())
                                    if (self.lsp_overloaded_flag.is_set or self.lsp_overloaded_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_overloaded_flag.get_name_leafdata())
                                    if (self.lsp_parition_repair_supported_flag.is_set or self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_parition_repair_supported_flag.get_name_leafdata())
                                    if (self.lsp_sequence_number.is_set or self.lsp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-lsp-flag" or name == "lsp-active-flag" or name == "lsp-attached-flag" or name == "lsp-checksum" or name == "lsp-holdtime" or name == "lsp-id" or name == "lsp-length" or name == "lsp-level" or name == "lsp-nonv1a-flag" or name == "lsp-overloaded-flag" or name == "lsp-parition-repair-supported-flag" or name == "lsp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-lsp-flag"):
                                        self.local_lsp_flag = value
                                        self.local_lsp_flag.value_namespace = name_space
                                        self.local_lsp_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-active-flag"):
                                        self.lsp_active_flag = value
                                        self.lsp_active_flag.value_namespace = name_space
                                        self.lsp_active_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-attached-flag"):
                                        self.lsp_attached_flag = value
                                        self.lsp_attached_flag.value_namespace = name_space
                                        self.lsp_attached_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-checksum"):
                                        self.lsp_checksum = value
                                        self.lsp_checksum.value_namespace = name_space
                                        self.lsp_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-holdtime"):
                                        self.lsp_holdtime = value
                                        self.lsp_holdtime.value_namespace = name_space
                                        self.lsp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-id"):
                                        self.lsp_id = value
                                        self.lsp_id.value_namespace = name_space
                                        self.lsp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-length"):
                                        self.lsp_length = value
                                        self.lsp_length.value_namespace = name_space
                                        self.lsp_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-level"):
                                        self.lsp_level = value
                                        self.lsp_level.value_namespace = name_space
                                        self.lsp_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-nonv1a-flag"):
                                        self.lsp_nonv1a_flag = value
                                        self.lsp_nonv1a_flag.value_namespace = name_space
                                        self.lsp_nonv1a_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-overloaded-flag"):
                                        self.lsp_overloaded_flag = value
                                        self.lsp_overloaded_flag.value_namespace = name_space
                                        self.lsp_overloaded_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-parition-repair-supported-flag"):
                                        self.lsp_parition_repair_supported_flag = value
                                        self.lsp_parition_repair_supported_flag.value_namespace = name_space
                                        self.lsp_parition_repair_supported_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-sequence-number"):
                                        self.lsp_sequence_number = value
                                        self.lsp_sequence_number.value_namespace = name_space
                                        self.lsp_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.lsp_id.is_set or
                                    self.lsp_body.is_set or
                                    (self.lsp_header_data is not None and self.lsp_header_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lsp_id.yfilter != YFilter.not_set or
                                    self.lsp_body.yfilter != YFilter.not_set or
                                    (self.lsp_header_data is not None and self.lsp_header_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "detailed-lsp" + "[lsp-id='" + self.lsp_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                if (self.lsp_body.is_set or self.lsp_body.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_body.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsp-header-data"):
                                    if (self.lsp_header_data is None):
                                        self.lsp_header_data = Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData()
                                        self.lsp_header_data.parent = self
                                        self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                    return self.lsp_header_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsp-header-data" or name == "lsp-id" or name == "lsp-body"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lsp-id"):
                                    self.lsp_id = value
                                    self.lsp_id.value_namespace = name_space
                                    self.lsp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsp-body"):
                                    self.lsp_body = value
                                    self.lsp_body.value_namespace = name_space
                                    self.lsp_body.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.detailed_lsp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.detailed_lsp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "detailed-lsps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "detailed-lsp"):
                                for c in self.detailed_lsp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.detailed_lsp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "detailed-lsp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Lsps(Entity):
                        """
                        LSP table
                        
                        .. attribute:: lsp
                        
                        	An IS\-IS LSP (header information only)
                        	**type**\: list of    :py:class:`Lsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps.Lsp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.Lsps, self).__init__()

                            self.yang_name = "lsps"
                            self.yang_parent_name = "level"

                            self.lsp = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.Lsps, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.Lsps, self).__setattr__(name, value)


                        class Lsp(Entity):
                            """
                            An IS\-IS LSP (header information only)
                            
                            .. attribute:: lsp_id  <key>
                            
                            	LSP ID
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                            
                            .. attribute:: lsp_body
                            
                            	LSP as received/sent over the wire, starting from the LSP ID field
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: lsp_header_data
                            
                            	Information from the LSP header
                            	**type**\:   :py:class:`LspHeaderData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp, self).__init__()

                                self.yang_name = "lsp"
                                self.yang_parent_name = "lsps"

                                self.lsp_id = YLeaf(YType.str, "lsp-id")

                                self.lsp_body = YLeaf(YType.str, "lsp-body")

                                self.lsp_header_data = Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData()
                                self.lsp_header_data.parent = self
                                self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                self._children_yang_names.add("lsp-header-data")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lsp_id",
                                                "lsp_body") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp, self).__setattr__(name, value)


                            class LspHeaderData(Entity):
                                """
                                Information from the LSP header
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\:  bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\:  bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_parition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\:  bool
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData, self).__init__()

                                    self.yang_name = "lsp-header-data"
                                    self.yang_parent_name = "lsp"

                                    self.local_lsp_flag = YLeaf(YType.boolean, "local-lsp-flag")

                                    self.lsp_active_flag = YLeaf(YType.boolean, "lsp-active-flag")

                                    self.lsp_attached_flag = YLeaf(YType.boolean, "lsp-attached-flag")

                                    self.lsp_checksum = YLeaf(YType.uint16, "lsp-checksum")

                                    self.lsp_holdtime = YLeaf(YType.uint16, "lsp-holdtime")

                                    self.lsp_id = YLeaf(YType.str, "lsp-id")

                                    self.lsp_length = YLeaf(YType.uint16, "lsp-length")

                                    self.lsp_level = YLeaf(YType.enumeration, "lsp-level")

                                    self.lsp_nonv1a_flag = YLeaf(YType.uint16, "lsp-nonv1a-flag")

                                    self.lsp_overloaded_flag = YLeaf(YType.boolean, "lsp-overloaded-flag")

                                    self.lsp_parition_repair_supported_flag = YLeaf(YType.boolean, "lsp-parition-repair-supported-flag")

                                    self.lsp_sequence_number = YLeaf(YType.uint32, "lsp-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_lsp_flag",
                                                    "lsp_active_flag",
                                                    "lsp_attached_flag",
                                                    "lsp_checksum",
                                                    "lsp_holdtime",
                                                    "lsp_id",
                                                    "lsp_length",
                                                    "lsp_level",
                                                    "lsp_nonv1a_flag",
                                                    "lsp_overloaded_flag",
                                                    "lsp_parition_repair_supported_flag",
                                                    "lsp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_lsp_flag.is_set or
                                        self.lsp_active_flag.is_set or
                                        self.lsp_attached_flag.is_set or
                                        self.lsp_checksum.is_set or
                                        self.lsp_holdtime.is_set or
                                        self.lsp_id.is_set or
                                        self.lsp_length.is_set or
                                        self.lsp_level.is_set or
                                        self.lsp_nonv1a_flag.is_set or
                                        self.lsp_overloaded_flag.is_set or
                                        self.lsp_parition_repair_supported_flag.is_set or
                                        self.lsp_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_lsp_flag.yfilter != YFilter.not_set or
                                        self.lsp_active_flag.yfilter != YFilter.not_set or
                                        self.lsp_attached_flag.yfilter != YFilter.not_set or
                                        self.lsp_checksum.yfilter != YFilter.not_set or
                                        self.lsp_holdtime.yfilter != YFilter.not_set or
                                        self.lsp_id.yfilter != YFilter.not_set or
                                        self.lsp_length.yfilter != YFilter.not_set or
                                        self.lsp_level.yfilter != YFilter.not_set or
                                        self.lsp_nonv1a_flag.yfilter != YFilter.not_set or
                                        self.lsp_overloaded_flag.yfilter != YFilter.not_set or
                                        self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set or
                                        self.lsp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsp-header-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_lsp_flag.is_set or self.local_lsp_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_lsp_flag.get_name_leafdata())
                                    if (self.lsp_active_flag.is_set or self.lsp_active_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_active_flag.get_name_leafdata())
                                    if (self.lsp_attached_flag.is_set or self.lsp_attached_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_attached_flag.get_name_leafdata())
                                    if (self.lsp_checksum.is_set or self.lsp_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_checksum.get_name_leafdata())
                                    if (self.lsp_holdtime.is_set or self.lsp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_holdtime.get_name_leafdata())
                                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                    if (self.lsp_length.is_set or self.lsp_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_length.get_name_leafdata())
                                    if (self.lsp_level.is_set or self.lsp_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_level.get_name_leafdata())
                                    if (self.lsp_nonv1a_flag.is_set or self.lsp_nonv1a_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_nonv1a_flag.get_name_leafdata())
                                    if (self.lsp_overloaded_flag.is_set or self.lsp_overloaded_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_overloaded_flag.get_name_leafdata())
                                    if (self.lsp_parition_repair_supported_flag.is_set or self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_parition_repair_supported_flag.get_name_leafdata())
                                    if (self.lsp_sequence_number.is_set or self.lsp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-lsp-flag" or name == "lsp-active-flag" or name == "lsp-attached-flag" or name == "lsp-checksum" or name == "lsp-holdtime" or name == "lsp-id" or name == "lsp-length" or name == "lsp-level" or name == "lsp-nonv1a-flag" or name == "lsp-overloaded-flag" or name == "lsp-parition-repair-supported-flag" or name == "lsp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-lsp-flag"):
                                        self.local_lsp_flag = value
                                        self.local_lsp_flag.value_namespace = name_space
                                        self.local_lsp_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-active-flag"):
                                        self.lsp_active_flag = value
                                        self.lsp_active_flag.value_namespace = name_space
                                        self.lsp_active_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-attached-flag"):
                                        self.lsp_attached_flag = value
                                        self.lsp_attached_flag.value_namespace = name_space
                                        self.lsp_attached_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-checksum"):
                                        self.lsp_checksum = value
                                        self.lsp_checksum.value_namespace = name_space
                                        self.lsp_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-holdtime"):
                                        self.lsp_holdtime = value
                                        self.lsp_holdtime.value_namespace = name_space
                                        self.lsp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-id"):
                                        self.lsp_id = value
                                        self.lsp_id.value_namespace = name_space
                                        self.lsp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-length"):
                                        self.lsp_length = value
                                        self.lsp_length.value_namespace = name_space
                                        self.lsp_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-level"):
                                        self.lsp_level = value
                                        self.lsp_level.value_namespace = name_space
                                        self.lsp_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-nonv1a-flag"):
                                        self.lsp_nonv1a_flag = value
                                        self.lsp_nonv1a_flag.value_namespace = name_space
                                        self.lsp_nonv1a_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-overloaded-flag"):
                                        self.lsp_overloaded_flag = value
                                        self.lsp_overloaded_flag.value_namespace = name_space
                                        self.lsp_overloaded_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-parition-repair-supported-flag"):
                                        self.lsp_parition_repair_supported_flag = value
                                        self.lsp_parition_repair_supported_flag.value_namespace = name_space
                                        self.lsp_parition_repair_supported_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-sequence-number"):
                                        self.lsp_sequence_number = value
                                        self.lsp_sequence_number.value_namespace = name_space
                                        self.lsp_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.lsp_id.is_set or
                                    self.lsp_body.is_set or
                                    (self.lsp_header_data is not None and self.lsp_header_data.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lsp_id.yfilter != YFilter.not_set or
                                    self.lsp_body.yfilter != YFilter.not_set or
                                    (self.lsp_header_data is not None and self.lsp_header_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsp" + "[lsp-id='" + self.lsp_id.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                if (self.lsp_body.is_set or self.lsp_body.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_body.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "lsp-header-data"):
                                    if (self.lsp_header_data is None):
                                        self.lsp_header_data = Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData()
                                        self.lsp_header_data.parent = self
                                        self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                    return self.lsp_header_data

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "lsp-header-data" or name == "lsp-id" or name == "lsp-body"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lsp-id"):
                                    self.lsp_id = value
                                    self.lsp_id.value_namespace = name_space
                                    self.lsp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsp-body"):
                                    self.lsp_body = value
                                    self.lsp_body.value_namespace = name_space
                                    self.lsp_body.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.lsp:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.lsp:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsps" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "lsp"):
                                for c in self.lsp:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.Lsps.Lsp()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.lsp.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lsp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class LspLog(Entity):
                        """
                        LSP\-log for a single level
                        
                        .. attribute:: log_entry
                        
                        	Log entries
                        	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.LspLog, self).__init__()

                            self.yang_name = "lsp-log"
                            self.yang_parent_name = "level"

                            self.log_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.LspLog, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.LspLog, self).__setattr__(name, value)


                        class LogEntry(Entity):
                            """
                            Log entries
                            
                            .. attribute:: delayed_trigger_count
                            
                            	Number of delayed triggers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData>`
                            
                            .. attribute:: log_interface
                            
                            	Appropriate interface, if any
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: pseudo_node_number
                            
                            	Pseudo\-node number
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: trigger
                            
                            	Triggers applying to this log entry
                            	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger>`
                            
                            .. attribute:: trigger_count
                            
                            	Number of triggers on this run. May not be equal to the number of trigger event types if one or more trigger events has occurred more than once
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "lsp-log"

                                self.delayed_trigger_count = YLeaf(YType.uint32, "delayed-trigger-count")

                                self.log_interface = YLeaf(YType.str, "log-interface")

                                self.pseudo_node_number = YLeaf(YType.uint8, "pseudo-node-number")

                                self.trigger_count = YLeaf(YType.uint32, "trigger-count")

                                self.generic_data = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"
                                self._children_yang_names.add("generic-data")

                                self.trigger = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("delayed_trigger_count",
                                                "log_interface",
                                                "pseudo_node_number",
                                                "trigger_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry, self).__setattr__(name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._children_yang_names.add("timestamp")


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"

                                        self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nano_seconds",
                                                        "seconds") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nano_seconds.is_set or
                                            self.seconds.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nano_seconds.yfilter != YFilter.not_set or
                                            self.seconds.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timestamp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.seconds.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nano-seconds" or name == "seconds"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nano-seconds"):
                                            self.nano_seconds = value
                                            self.nano_seconds.value_namespace = name_space
                                            self.nano_seconds.value_namespace_prefix = name_space_prefix
                                        if(value_path == "seconds"):
                                            self.seconds = value
                                            self.seconds.value_namespace = name_space
                                            self.seconds.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (self.timestamp is not None and self.timestamp.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.timestamp is not None and self.timestamp.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "generic-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "timestamp"):
                                        if (self.timestamp is None):
                                            self.timestamp = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                        return self.timestamp

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "timestamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Trigger(Entity):
                                """
                                Triggers applying to this log entry.
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:   :py:class:`IsisLspTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLspTrigger>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger, self).__init__()

                                    self.yang_name = "trigger"
                                    self.yang_parent_name = "log-entry"

                                    self.entry = YLeaf(YType.enumeration, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "trigger" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.trigger:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.delayed_trigger_count.is_set or
                                    self.log_interface.is_set or
                                    self.pseudo_node_number.is_set or
                                    self.trigger_count.is_set or
                                    (self.generic_data is not None and self.generic_data.has_data()))

                            def has_operation(self):
                                for c in self.trigger:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.delayed_trigger_count.yfilter != YFilter.not_set or
                                    self.log_interface.yfilter != YFilter.not_set or
                                    self.pseudo_node_number.yfilter != YFilter.not_set or
                                    self.trigger_count.yfilter != YFilter.not_set or
                                    (self.generic_data is not None and self.generic_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "log-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.delayed_trigger_count.is_set or self.delayed_trigger_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.delayed_trigger_count.get_name_leafdata())
                                if (self.log_interface.is_set or self.log_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.log_interface.get_name_leafdata())
                                if (self.pseudo_node_number.is_set or self.pseudo_node_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pseudo_node_number.get_name_leafdata())
                                if (self.trigger_count.is_set or self.trigger_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.trigger_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "generic-data"):
                                    if (self.generic_data is None):
                                        self.generic_data = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                    return self.generic_data

                                if (child_yang_name == "trigger"):
                                    for c in self.trigger:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.trigger.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "generic-data" or name == "trigger" or name == "delayed-trigger-count" or name == "log-interface" or name == "pseudo-node-number" or name == "trigger-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "delayed-trigger-count"):
                                    self.delayed_trigger_count = value
                                    self.delayed_trigger_count.value_namespace = name_space
                                    self.delayed_trigger_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "log-interface"):
                                    self.log_interface = value
                                    self.log_interface.value_namespace = name_space
                                    self.log_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "pseudo-node-number"):
                                    self.pseudo_node_number = value
                                    self.pseudo_node_number.value_namespace = name_space
                                    self.pseudo_node_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "trigger-count"):
                                    self.trigger_count = value
                                    self.trigger_count.value_namespace = name_space
                                    self.trigger_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.log_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.log_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "lsp-log" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "log-entry"):
                                for c in self.log_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.log_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "log-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class DatabaseLog(Entity):
                        """
                        Database\-log for a single level
                        
                        .. attribute:: log_entry
                        
                        	Entries
                        	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.DatabaseLog, self).__init__()

                            self.yang_name = "database-log"
                            self.yang_parent_name = "level"

                            self.log_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Levels.Level.DatabaseLog, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog, self).__setattr__(name, value)


                        class LogEntry(Entity):
                            """
                            Entries
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData>`
                            
                            .. attribute:: lspdb_operation
                            
                            	Operation applying to this entry
                            	**type**\:   :py:class:`IsisLspDbOp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLspDbOp>`
                            
                            .. attribute:: new_lsp_entry
                            
                            	Entry being inserted or the updated version of an old entry
                            	**type**\:   :py:class:`NewLspEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry>`
                            
                            .. attribute:: old_lsp_entry
                            
                            	Entry being replaced
                            	**type**\:   :py:class:`OldLspEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "database-log"

                                self.lspdb_operation = YLeaf(YType.enumeration, "lspdb-operation")

                                self.generic_data = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"
                                self._children_yang_names.add("generic-data")

                                self.new_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry()
                                self.new_lsp_entry.parent = self
                                self._children_name_map["new_lsp_entry"] = "new-lsp-entry"
                                self._children_yang_names.add("new-lsp-entry")

                                self.old_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry()
                                self.old_lsp_entry.parent = self
                                self._children_name_map["old_lsp_entry"] = "old-lsp-entry"
                                self._children_yang_names.add("old-lsp-entry")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lspdb_operation") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry, self).__setattr__(name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._children_yang_names.add("timestamp")


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"

                                        self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("nano_seconds",
                                                        "seconds") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.nano_seconds.is_set or
                                            self.seconds.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.nano_seconds.yfilter != YFilter.not_set or
                                            self.seconds.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "timestamp" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.seconds.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "nano-seconds" or name == "seconds"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "nano-seconds"):
                                            self.nano_seconds = value
                                            self.nano_seconds.value_namespace = name_space
                                            self.nano_seconds.value_namespace_prefix = name_space_prefix
                                        if(value_path == "seconds"):
                                            self.seconds = value
                                            self.seconds.value_namespace = name_space
                                            self.seconds.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (self.timestamp is not None and self.timestamp.has_data())

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.timestamp is not None and self.timestamp.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "generic-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "timestamp"):
                                        if (self.timestamp is None):
                                            self.timestamp = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                        return self.timestamp

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "timestamp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class NewLspEntry(Entity):
                                """
                                Entry being inserted or the updated version of
                                an old entry.
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\:  bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\:  bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_parition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\:  bool
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry, self).__init__()

                                    self.yang_name = "new-lsp-entry"
                                    self.yang_parent_name = "log-entry"

                                    self.local_lsp_flag = YLeaf(YType.boolean, "local-lsp-flag")

                                    self.lsp_active_flag = YLeaf(YType.boolean, "lsp-active-flag")

                                    self.lsp_attached_flag = YLeaf(YType.boolean, "lsp-attached-flag")

                                    self.lsp_checksum = YLeaf(YType.uint16, "lsp-checksum")

                                    self.lsp_holdtime = YLeaf(YType.uint16, "lsp-holdtime")

                                    self.lsp_id = YLeaf(YType.str, "lsp-id")

                                    self.lsp_length = YLeaf(YType.uint16, "lsp-length")

                                    self.lsp_level = YLeaf(YType.enumeration, "lsp-level")

                                    self.lsp_nonv1a_flag = YLeaf(YType.uint16, "lsp-nonv1a-flag")

                                    self.lsp_overloaded_flag = YLeaf(YType.boolean, "lsp-overloaded-flag")

                                    self.lsp_parition_repair_supported_flag = YLeaf(YType.boolean, "lsp-parition-repair-supported-flag")

                                    self.lsp_sequence_number = YLeaf(YType.uint32, "lsp-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_lsp_flag",
                                                    "lsp_active_flag",
                                                    "lsp_attached_flag",
                                                    "lsp_checksum",
                                                    "lsp_holdtime",
                                                    "lsp_id",
                                                    "lsp_length",
                                                    "lsp_level",
                                                    "lsp_nonv1a_flag",
                                                    "lsp_overloaded_flag",
                                                    "lsp_parition_repair_supported_flag",
                                                    "lsp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_lsp_flag.is_set or
                                        self.lsp_active_flag.is_set or
                                        self.lsp_attached_flag.is_set or
                                        self.lsp_checksum.is_set or
                                        self.lsp_holdtime.is_set or
                                        self.lsp_id.is_set or
                                        self.lsp_length.is_set or
                                        self.lsp_level.is_set or
                                        self.lsp_nonv1a_flag.is_set or
                                        self.lsp_overloaded_flag.is_set or
                                        self.lsp_parition_repair_supported_flag.is_set or
                                        self.lsp_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_lsp_flag.yfilter != YFilter.not_set or
                                        self.lsp_active_flag.yfilter != YFilter.not_set or
                                        self.lsp_attached_flag.yfilter != YFilter.not_set or
                                        self.lsp_checksum.yfilter != YFilter.not_set or
                                        self.lsp_holdtime.yfilter != YFilter.not_set or
                                        self.lsp_id.yfilter != YFilter.not_set or
                                        self.lsp_length.yfilter != YFilter.not_set or
                                        self.lsp_level.yfilter != YFilter.not_set or
                                        self.lsp_nonv1a_flag.yfilter != YFilter.not_set or
                                        self.lsp_overloaded_flag.yfilter != YFilter.not_set or
                                        self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set or
                                        self.lsp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "new-lsp-entry" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_lsp_flag.is_set or self.local_lsp_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_lsp_flag.get_name_leafdata())
                                    if (self.lsp_active_flag.is_set or self.lsp_active_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_active_flag.get_name_leafdata())
                                    if (self.lsp_attached_flag.is_set or self.lsp_attached_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_attached_flag.get_name_leafdata())
                                    if (self.lsp_checksum.is_set or self.lsp_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_checksum.get_name_leafdata())
                                    if (self.lsp_holdtime.is_set or self.lsp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_holdtime.get_name_leafdata())
                                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                    if (self.lsp_length.is_set or self.lsp_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_length.get_name_leafdata())
                                    if (self.lsp_level.is_set or self.lsp_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_level.get_name_leafdata())
                                    if (self.lsp_nonv1a_flag.is_set or self.lsp_nonv1a_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_nonv1a_flag.get_name_leafdata())
                                    if (self.lsp_overloaded_flag.is_set or self.lsp_overloaded_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_overloaded_flag.get_name_leafdata())
                                    if (self.lsp_parition_repair_supported_flag.is_set or self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_parition_repair_supported_flag.get_name_leafdata())
                                    if (self.lsp_sequence_number.is_set or self.lsp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-lsp-flag" or name == "lsp-active-flag" or name == "lsp-attached-flag" or name == "lsp-checksum" or name == "lsp-holdtime" or name == "lsp-id" or name == "lsp-length" or name == "lsp-level" or name == "lsp-nonv1a-flag" or name == "lsp-overloaded-flag" or name == "lsp-parition-repair-supported-flag" or name == "lsp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-lsp-flag"):
                                        self.local_lsp_flag = value
                                        self.local_lsp_flag.value_namespace = name_space
                                        self.local_lsp_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-active-flag"):
                                        self.lsp_active_flag = value
                                        self.lsp_active_flag.value_namespace = name_space
                                        self.lsp_active_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-attached-flag"):
                                        self.lsp_attached_flag = value
                                        self.lsp_attached_flag.value_namespace = name_space
                                        self.lsp_attached_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-checksum"):
                                        self.lsp_checksum = value
                                        self.lsp_checksum.value_namespace = name_space
                                        self.lsp_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-holdtime"):
                                        self.lsp_holdtime = value
                                        self.lsp_holdtime.value_namespace = name_space
                                        self.lsp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-id"):
                                        self.lsp_id = value
                                        self.lsp_id.value_namespace = name_space
                                        self.lsp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-length"):
                                        self.lsp_length = value
                                        self.lsp_length.value_namespace = name_space
                                        self.lsp_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-level"):
                                        self.lsp_level = value
                                        self.lsp_level.value_namespace = name_space
                                        self.lsp_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-nonv1a-flag"):
                                        self.lsp_nonv1a_flag = value
                                        self.lsp_nonv1a_flag.value_namespace = name_space
                                        self.lsp_nonv1a_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-overloaded-flag"):
                                        self.lsp_overloaded_flag = value
                                        self.lsp_overloaded_flag.value_namespace = name_space
                                        self.lsp_overloaded_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-parition-repair-supported-flag"):
                                        self.lsp_parition_repair_supported_flag = value
                                        self.lsp_parition_repair_supported_flag.value_namespace = name_space
                                        self.lsp_parition_repair_supported_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-sequence-number"):
                                        self.lsp_sequence_number = value
                                        self.lsp_sequence_number.value_namespace = name_space
                                        self.lsp_sequence_number.value_namespace_prefix = name_space_prefix


                            class OldLspEntry(Entity):
                                """
                                Entry being replaced.
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\:  bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\:  bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\:  bool
                                
                                .. attribute:: lsp_parition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\:  bool
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry, self).__init__()

                                    self.yang_name = "old-lsp-entry"
                                    self.yang_parent_name = "log-entry"

                                    self.local_lsp_flag = YLeaf(YType.boolean, "local-lsp-flag")

                                    self.lsp_active_flag = YLeaf(YType.boolean, "lsp-active-flag")

                                    self.lsp_attached_flag = YLeaf(YType.boolean, "lsp-attached-flag")

                                    self.lsp_checksum = YLeaf(YType.uint16, "lsp-checksum")

                                    self.lsp_holdtime = YLeaf(YType.uint16, "lsp-holdtime")

                                    self.lsp_id = YLeaf(YType.str, "lsp-id")

                                    self.lsp_length = YLeaf(YType.uint16, "lsp-length")

                                    self.lsp_level = YLeaf(YType.enumeration, "lsp-level")

                                    self.lsp_nonv1a_flag = YLeaf(YType.uint16, "lsp-nonv1a-flag")

                                    self.lsp_overloaded_flag = YLeaf(YType.boolean, "lsp-overloaded-flag")

                                    self.lsp_parition_repair_supported_flag = YLeaf(YType.boolean, "lsp-parition-repair-supported-flag")

                                    self.lsp_sequence_number = YLeaf(YType.uint32, "lsp-sequence-number")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("local_lsp_flag",
                                                    "lsp_active_flag",
                                                    "lsp_attached_flag",
                                                    "lsp_checksum",
                                                    "lsp_holdtime",
                                                    "lsp_id",
                                                    "lsp_length",
                                                    "lsp_level",
                                                    "lsp_nonv1a_flag",
                                                    "lsp_overloaded_flag",
                                                    "lsp_parition_repair_supported_flag",
                                                    "lsp_sequence_number") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.local_lsp_flag.is_set or
                                        self.lsp_active_flag.is_set or
                                        self.lsp_attached_flag.is_set or
                                        self.lsp_checksum.is_set or
                                        self.lsp_holdtime.is_set or
                                        self.lsp_id.is_set or
                                        self.lsp_length.is_set or
                                        self.lsp_level.is_set or
                                        self.lsp_nonv1a_flag.is_set or
                                        self.lsp_overloaded_flag.is_set or
                                        self.lsp_parition_repair_supported_flag.is_set or
                                        self.lsp_sequence_number.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.local_lsp_flag.yfilter != YFilter.not_set or
                                        self.lsp_active_flag.yfilter != YFilter.not_set or
                                        self.lsp_attached_flag.yfilter != YFilter.not_set or
                                        self.lsp_checksum.yfilter != YFilter.not_set or
                                        self.lsp_holdtime.yfilter != YFilter.not_set or
                                        self.lsp_id.yfilter != YFilter.not_set or
                                        self.lsp_length.yfilter != YFilter.not_set or
                                        self.lsp_level.yfilter != YFilter.not_set or
                                        self.lsp_nonv1a_flag.yfilter != YFilter.not_set or
                                        self.lsp_overloaded_flag.yfilter != YFilter.not_set or
                                        self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set or
                                        self.lsp_sequence_number.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "old-lsp-entry" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.local_lsp_flag.is_set or self.local_lsp_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.local_lsp_flag.get_name_leafdata())
                                    if (self.lsp_active_flag.is_set or self.lsp_active_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_active_flag.get_name_leafdata())
                                    if (self.lsp_attached_flag.is_set or self.lsp_attached_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_attached_flag.get_name_leafdata())
                                    if (self.lsp_checksum.is_set or self.lsp_checksum.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_checksum.get_name_leafdata())
                                    if (self.lsp_holdtime.is_set or self.lsp_holdtime.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_holdtime.get_name_leafdata())
                                    if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_id.get_name_leafdata())
                                    if (self.lsp_length.is_set or self.lsp_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_length.get_name_leafdata())
                                    if (self.lsp_level.is_set or self.lsp_level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_level.get_name_leafdata())
                                    if (self.lsp_nonv1a_flag.is_set or self.lsp_nonv1a_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_nonv1a_flag.get_name_leafdata())
                                    if (self.lsp_overloaded_flag.is_set or self.lsp_overloaded_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_overloaded_flag.get_name_leafdata())
                                    if (self.lsp_parition_repair_supported_flag.is_set or self.lsp_parition_repair_supported_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_parition_repair_supported_flag.get_name_leafdata())
                                    if (self.lsp_sequence_number.is_set or self.lsp_sequence_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_sequence_number.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "local-lsp-flag" or name == "lsp-active-flag" or name == "lsp-attached-flag" or name == "lsp-checksum" or name == "lsp-holdtime" or name == "lsp-id" or name == "lsp-length" or name == "lsp-level" or name == "lsp-nonv1a-flag" or name == "lsp-overloaded-flag" or name == "lsp-parition-repair-supported-flag" or name == "lsp-sequence-number"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "local-lsp-flag"):
                                        self.local_lsp_flag = value
                                        self.local_lsp_flag.value_namespace = name_space
                                        self.local_lsp_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-active-flag"):
                                        self.lsp_active_flag = value
                                        self.lsp_active_flag.value_namespace = name_space
                                        self.lsp_active_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-attached-flag"):
                                        self.lsp_attached_flag = value
                                        self.lsp_attached_flag.value_namespace = name_space
                                        self.lsp_attached_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-checksum"):
                                        self.lsp_checksum = value
                                        self.lsp_checksum.value_namespace = name_space
                                        self.lsp_checksum.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-holdtime"):
                                        self.lsp_holdtime = value
                                        self.lsp_holdtime.value_namespace = name_space
                                        self.lsp_holdtime.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-id"):
                                        self.lsp_id = value
                                        self.lsp_id.value_namespace = name_space
                                        self.lsp_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-length"):
                                        self.lsp_length = value
                                        self.lsp_length.value_namespace = name_space
                                        self.lsp_length.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-level"):
                                        self.lsp_level = value
                                        self.lsp_level.value_namespace = name_space
                                        self.lsp_level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-nonv1a-flag"):
                                        self.lsp_nonv1a_flag = value
                                        self.lsp_nonv1a_flag.value_namespace = name_space
                                        self.lsp_nonv1a_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-overloaded-flag"):
                                        self.lsp_overloaded_flag = value
                                        self.lsp_overloaded_flag.value_namespace = name_space
                                        self.lsp_overloaded_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-parition-repair-supported-flag"):
                                        self.lsp_parition_repair_supported_flag = value
                                        self.lsp_parition_repair_supported_flag.value_namespace = name_space
                                        self.lsp_parition_repair_supported_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-sequence-number"):
                                        self.lsp_sequence_number = value
                                        self.lsp_sequence_number.value_namespace = name_space
                                        self.lsp_sequence_number.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.lspdb_operation.is_set or
                                    (self.generic_data is not None and self.generic_data.has_data()) or
                                    (self.new_lsp_entry is not None and self.new_lsp_entry.has_data()) or
                                    (self.old_lsp_entry is not None and self.old_lsp_entry.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lspdb_operation.yfilter != YFilter.not_set or
                                    (self.generic_data is not None and self.generic_data.has_operation()) or
                                    (self.new_lsp_entry is not None and self.new_lsp_entry.has_operation()) or
                                    (self.old_lsp_entry is not None and self.old_lsp_entry.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "log-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lspdb_operation.is_set or self.lspdb_operation.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lspdb_operation.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "generic-data"):
                                    if (self.generic_data is None):
                                        self.generic_data = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                    return self.generic_data

                                if (child_yang_name == "new-lsp-entry"):
                                    if (self.new_lsp_entry is None):
                                        self.new_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry()
                                        self.new_lsp_entry.parent = self
                                        self._children_name_map["new_lsp_entry"] = "new-lsp-entry"
                                    return self.new_lsp_entry

                                if (child_yang_name == "old-lsp-entry"):
                                    if (self.old_lsp_entry is None):
                                        self.old_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry()
                                        self.old_lsp_entry.parent = self
                                        self._children_name_map["old_lsp_entry"] = "old-lsp-entry"
                                    return self.old_lsp_entry

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "generic-data" or name == "new-lsp-entry" or name == "old-lsp-entry" or name == "lspdb-operation"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lspdb-operation"):
                                    self.lspdb_operation = value
                                    self.lspdb_operation.value_namespace = name_space
                                    self.lspdb_operation.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.log_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.log_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "database-log" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "log-entry"):
                                for c in self.log_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.log_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "log-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.level.is_set or
                            (self.adjacencies is not None and self.adjacencies.has_data()) or
                            (self.adjacency_log is not None and self.adjacency_log.has_data()) or
                            (self.database_log is not None and self.database_log.has_data()) or
                            (self.detailed_lsps is not None and self.detailed_lsps.has_data()) or
                            (self.lsp_log is not None and self.lsp_log.has_data()) or
                            (self.lsp_table_summary is not None and self.lsp_table_summary.has_data()) or
                            (self.lsps is not None and self.lsps.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set or
                            (self.adjacencies is not None and self.adjacencies.has_operation()) or
                            (self.adjacency_log is not None and self.adjacency_log.has_operation()) or
                            (self.database_log is not None and self.database_log.has_operation()) or
                            (self.detailed_lsps is not None and self.detailed_lsps.has_operation()) or
                            (self.lsp_log is not None and self.lsp_log.has_operation()) or
                            (self.lsp_table_summary is not None and self.lsp_table_summary.has_operation()) or
                            (self.lsps is not None and self.lsps.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "level" + "[level='" + self.level.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "adjacencies"):
                            if (self.adjacencies is None):
                                self.adjacencies = Isis.Instances.Instance.Levels.Level.Adjacencies()
                                self.adjacencies.parent = self
                                self._children_name_map["adjacencies"] = "adjacencies"
                            return self.adjacencies

                        if (child_yang_name == "adjacency-log"):
                            if (self.adjacency_log is None):
                                self.adjacency_log = Isis.Instances.Instance.Levels.Level.AdjacencyLog()
                                self.adjacency_log.parent = self
                                self._children_name_map["adjacency_log"] = "adjacency-log"
                            return self.adjacency_log

                        if (child_yang_name == "database-log"):
                            if (self.database_log is None):
                                self.database_log = Isis.Instances.Instance.Levels.Level.DatabaseLog()
                                self.database_log.parent = self
                                self._children_name_map["database_log"] = "database-log"
                            return self.database_log

                        if (child_yang_name == "detailed-lsps"):
                            if (self.detailed_lsps is None):
                                self.detailed_lsps = Isis.Instances.Instance.Levels.Level.DetailedLsps()
                                self.detailed_lsps.parent = self
                                self._children_name_map["detailed_lsps"] = "detailed-lsps"
                            return self.detailed_lsps

                        if (child_yang_name == "lsp-log"):
                            if (self.lsp_log is None):
                                self.lsp_log = Isis.Instances.Instance.Levels.Level.LspLog()
                                self.lsp_log.parent = self
                                self._children_name_map["lsp_log"] = "lsp-log"
                            return self.lsp_log

                        if (child_yang_name == "lsp-table-summary"):
                            if (self.lsp_table_summary is None):
                                self.lsp_table_summary = Isis.Instances.Instance.Levels.Level.LspTableSummary()
                                self.lsp_table_summary.parent = self
                                self._children_name_map["lsp_table_summary"] = "lsp-table-summary"
                            return self.lsp_table_summary

                        if (child_yang_name == "lsps"):
                            if (self.lsps is None):
                                self.lsps = Isis.Instances.Instance.Levels.Level.Lsps()
                                self.lsps.parent = self
                                self._children_name_map["lsps"] = "lsps"
                            return self.lsps

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "adjacencies" or name == "adjacency-log" or name == "database-log" or name == "detailed-lsps" or name == "lsp-log" or name == "lsp-table-summary" or name == "lsps" or name == "level"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.level:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.level:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "levels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "level"):
                        for c in self.level:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Levels.Level()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.level.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "level"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Topologies(Entity):
                """
                Topology table
                
                .. attribute:: topology
                
                	Per\-topology data
                	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "instance"

                    self.topology = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.Topologies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.Topologies, self).__setattr__(name, value)


                class Topology(Entity):
                    """
                    Per\-topology data
                    
                    .. attribute:: af_name
                    
                    	Address family
                    	**type**\:   :py:class:`IsisAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisAddressFamily>`
                    
                    .. attribute:: frr_summary
                    
                    	FRR summary information for a particular IS\-IS topology
                    	**type**\:   :py:class:`FrrSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary>`
                    
                    .. attribute:: ipv4_routes
                    
                    	IPv4 local route table
                    	**type**\:   :py:class:`Ipv4Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes>`
                    
                    .. attribute:: ipv4frr_backups
                    
                    	IPv4 FRR table
                    	**type**\:   :py:class:`Ipv4FrrBackups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups>`
                    
                    .. attribute:: ipv6_routes
                    
                    	IPv6 local route
                    	**type**\:   :py:class:`Ipv6Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes>`
                    
                    .. attribute:: ipv6frr_backups
                    
                    	IPv6 FRR table
                    	**type**\:   :py:class:`Ipv6FrrBackups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups>`
                    
                    .. attribute:: saf_name
                    
                    	Sub address family
                    	**type**\:   :py:class:`IsisSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisSubAddressFamily>`
                    
                    .. attribute:: topology_levels
                    
                    	Per\-topology level table
                    	**type**\:   :py:class:`TopologyLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels>`
                    
                    .. attribute:: topology_name
                    
                    	Topology Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                        self.topology_name = YLeaf(YType.str, "topology-name")

                        self.frr_summary = Isis.Instances.Instance.Topologies.Topology.FrrSummary()
                        self.frr_summary.parent = self
                        self._children_name_map["frr_summary"] = "frr-summary"
                        self._children_yang_names.add("frr-summary")

                        self.ipv4_routes = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes()
                        self.ipv4_routes.parent = self
                        self._children_name_map["ipv4_routes"] = "ipv4-routes"
                        self._children_yang_names.add("ipv4-routes")

                        self.ipv4frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups()
                        self.ipv4frr_backups.parent = self
                        self._children_name_map["ipv4frr_backups"] = "ipv4frr-backups"
                        self._children_yang_names.add("ipv4frr-backups")

                        self.ipv6_routes = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes()
                        self.ipv6_routes.parent = self
                        self._children_name_map["ipv6_routes"] = "ipv6-routes"
                        self._children_yang_names.add("ipv6-routes")

                        self.ipv6frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups()
                        self.ipv6frr_backups.parent = self
                        self._children_name_map["ipv6frr_backups"] = "ipv6frr-backups"
                        self._children_yang_names.add("ipv6frr-backups")

                        self.topology_levels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels()
                        self.topology_levels.parent = self
                        self._children_name_map["topology_levels"] = "topology-levels"
                        self._children_yang_names.add("topology-levels")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("af_name",
                                        "saf_name",
                                        "topology_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Topologies.Topology, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Topologies.Topology, self).__setattr__(name, value)


                    class FrrSummary(Entity):
                        """
                        FRR summary information for a particular
                        IS\-IS topology
                        
                        .. attribute:: level1_prefixes
                        
                        	FRR summary for prefixes reachable in L1
                        	**type**\:   :py:class:`Level1Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes>`
                        
                        .. attribute:: level2_prefixes
                        
                        	FRR summary for prefixes reachable in L2
                        	**type**\:   :py:class:`Level2Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes>`
                        
                        .. attribute:: unreachable_prefixes
                        
                        	Unreachable prefixes
                        	**type**\:   :py:class:`UnreachablePrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary, self).__init__()

                            self.yang_name = "frr-summary"
                            self.yang_parent_name = "topology"

                            self.level1_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes()
                            self.level1_prefixes.parent = self
                            self._children_name_map["level1_prefixes"] = "level1-prefixes"
                            self._children_yang_names.add("level1-prefixes")

                            self.level2_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes()
                            self.level2_prefixes.parent = self
                            self._children_name_map["level2_prefixes"] = "level2-prefixes"
                            self._children_yang_names.add("level2-prefixes")

                            self.unreachable_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes()
                            self.unreachable_prefixes.parent = self
                            self._children_name_map["unreachable_prefixes"] = "unreachable-prefixes"
                            self._children_yang_names.add("unreachable-prefixes")


                        class Level1Prefixes(Entity):
                            """
                            FRR summary for prefixes reachable in L1
                            
                            .. attribute:: all_paths_protected
                            
                            	Number of prefixes with all paths having FRR backup
                            	**type**\:   :py:class:`AllPathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected>`
                            
                            .. attribute:: some_paths_protected
                            
                            	Number of prefixes with some paths having FRR backup
                            	**type**\:   :py:class:`SomePathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected>`
                            
                            .. attribute:: unprotected
                            
                            	Number of reachable prefixes without FRR backup
                            	**type**\:   :py:class:`Unprotected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes, self).__init__()

                                self.yang_name = "level1-prefixes"
                                self.yang_parent_name = "frr-summary"

                                self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected()
                                self.all_paths_protected.parent = self
                                self._children_name_map["all_paths_protected"] = "all-paths-protected"
                                self._children_yang_names.add("all-paths-protected")

                                self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected()
                                self.some_paths_protected.parent = self
                                self._children_name_map["some_paths_protected"] = "some-paths-protected"
                                self._children_yang_names.add("some-paths-protected")

                                self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected()
                                self.unprotected.parent = self
                                self._children_name_map["unprotected"] = "unprotected"
                                self._children_yang_names.add("unprotected")


                            class AllPathsProtected(Entity):
                                """
                                Number of prefixes with all paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected, self).__init__()

                                    self.yang_name = "all-paths-protected"
                                    self.yang_parent_name = "level1-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "all-paths-protected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix


                            class SomePathsProtected(Entity):
                                """
                                Number of prefixes with some paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected, self).__init__()

                                    self.yang_name = "some-paths-protected"
                                    self.yang_parent_name = "level1-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "some-paths-protected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix


                            class Unprotected(Entity):
                                """
                                Number of reachable prefixes without FRR backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected, self).__init__()

                                    self.yang_name = "unprotected"
                                    self.yang_parent_name = "level1-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unprotected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.all_paths_protected is not None and self.all_paths_protected.has_data()) or
                                    (self.some_paths_protected is not None and self.some_paths_protected.has_data()) or
                                    (self.unprotected is not None and self.unprotected.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.all_paths_protected is not None and self.all_paths_protected.has_operation()) or
                                    (self.some_paths_protected is not None and self.some_paths_protected.has_operation()) or
                                    (self.unprotected is not None and self.unprotected.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "level1-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "all-paths-protected"):
                                    if (self.all_paths_protected is None):
                                        self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected()
                                        self.all_paths_protected.parent = self
                                        self._children_name_map["all_paths_protected"] = "all-paths-protected"
                                    return self.all_paths_protected

                                if (child_yang_name == "some-paths-protected"):
                                    if (self.some_paths_protected is None):
                                        self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected()
                                        self.some_paths_protected.parent = self
                                        self._children_name_map["some_paths_protected"] = "some-paths-protected"
                                    return self.some_paths_protected

                                if (child_yang_name == "unprotected"):
                                    if (self.unprotected is None):
                                        self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected()
                                        self.unprotected.parent = self
                                        self._children_name_map["unprotected"] = "unprotected"
                                    return self.unprotected

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "all-paths-protected" or name == "some-paths-protected" or name == "unprotected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class Level2Prefixes(Entity):
                            """
                            FRR summary for prefixes reachable in L2
                            
                            .. attribute:: all_paths_protected
                            
                            	Number of prefixes with all paths having FRR backup
                            	**type**\:   :py:class:`AllPathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected>`
                            
                            .. attribute:: some_paths_protected
                            
                            	Number of prefixes with some paths having FRR backup
                            	**type**\:   :py:class:`SomePathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected>`
                            
                            .. attribute:: unprotected
                            
                            	Number of reachable prefixes without FRR backup
                            	**type**\:   :py:class:`Unprotected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes, self).__init__()

                                self.yang_name = "level2-prefixes"
                                self.yang_parent_name = "frr-summary"

                                self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected()
                                self.all_paths_protected.parent = self
                                self._children_name_map["all_paths_protected"] = "all-paths-protected"
                                self._children_yang_names.add("all-paths-protected")

                                self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected()
                                self.some_paths_protected.parent = self
                                self._children_name_map["some_paths_protected"] = "some-paths-protected"
                                self._children_yang_names.add("some-paths-protected")

                                self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected()
                                self.unprotected.parent = self
                                self._children_name_map["unprotected"] = "unprotected"
                                self._children_yang_names.add("unprotected")


                            class AllPathsProtected(Entity):
                                """
                                Number of prefixes with all paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected, self).__init__()

                                    self.yang_name = "all-paths-protected"
                                    self.yang_parent_name = "level2-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "all-paths-protected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix


                            class SomePathsProtected(Entity):
                                """
                                Number of prefixes with some paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected, self).__init__()

                                    self.yang_name = "some-paths-protected"
                                    self.yang_parent_name = "level2-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "some-paths-protected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix


                            class Unprotected(Entity):
                                """
                                Number of reachable prefixes without FRR backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected, self).__init__()

                                    self.yang_name = "unprotected"
                                    self.yang_parent_name = "level2-prefixes"

                                    self.critical = YLeaf(YType.uint32, "critical")

                                    self.high = YLeaf(YType.uint32, "high")

                                    self.low = YLeaf(YType.uint32, "low")

                                    self.medium = YLeaf(YType.uint32, "medium")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("critical",
                                                    "high",
                                                    "low",
                                                    "medium") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.critical.is_set or
                                        self.high.is_set or
                                        self.low.is_set or
                                        self.medium.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.critical.yfilter != YFilter.not_set or
                                        self.high.yfilter != YFilter.not_set or
                                        self.low.yfilter != YFilter.not_set or
                                        self.medium.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unprotected" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.high.get_name_leafdata())
                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.low.get_name_leafdata())
                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "critical"):
                                        self.critical = value
                                        self.critical.value_namespace = name_space
                                        self.critical.value_namespace_prefix = name_space_prefix
                                    if(value_path == "high"):
                                        self.high = value
                                        self.high.value_namespace = name_space
                                        self.high.value_namespace_prefix = name_space_prefix
                                    if(value_path == "low"):
                                        self.low = value
                                        self.low.value_namespace = name_space
                                        self.low.value_namespace_prefix = name_space_prefix
                                    if(value_path == "medium"):
                                        self.medium = value
                                        self.medium.value_namespace = name_space
                                        self.medium.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    (self.all_paths_protected is not None and self.all_paths_protected.has_data()) or
                                    (self.some_paths_protected is not None and self.some_paths_protected.has_data()) or
                                    (self.unprotected is not None and self.unprotected.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.all_paths_protected is not None and self.all_paths_protected.has_operation()) or
                                    (self.some_paths_protected is not None and self.some_paths_protected.has_operation()) or
                                    (self.unprotected is not None and self.unprotected.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "level2-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "all-paths-protected"):
                                    if (self.all_paths_protected is None):
                                        self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected()
                                        self.all_paths_protected.parent = self
                                        self._children_name_map["all_paths_protected"] = "all-paths-protected"
                                    return self.all_paths_protected

                                if (child_yang_name == "some-paths-protected"):
                                    if (self.some_paths_protected is None):
                                        self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected()
                                        self.some_paths_protected.parent = self
                                        self._children_name_map["some_paths_protected"] = "some-paths-protected"
                                    return self.some_paths_protected

                                if (child_yang_name == "unprotected"):
                                    if (self.unprotected is None):
                                        self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected()
                                        self.unprotected.parent = self
                                        self._children_name_map["unprotected"] = "unprotected"
                                    return self.unprotected

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "all-paths-protected" or name == "some-paths-protected" or name == "unprotected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class UnreachablePrefixes(Entity):
                            """
                            Unreachable prefixes
                            
                            .. attribute:: critical
                            
                            	Critical priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high
                            
                            	High priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low
                            
                            	Low priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: medium
                            
                            	Medium priority
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes, self).__init__()

                                self.yang_name = "unreachable-prefixes"
                                self.yang_parent_name = "frr-summary"

                                self.critical = YLeaf(YType.uint32, "critical")

                                self.high = YLeaf(YType.uint32, "high")

                                self.low = YLeaf(YType.uint32, "low")

                                self.medium = YLeaf(YType.uint32, "medium")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("critical",
                                                "high",
                                                "low",
                                                "medium") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.critical.is_set or
                                    self.high.is_set or
                                    self.low.is_set or
                                    self.medium.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.critical.yfilter != YFilter.not_set or
                                    self.high.yfilter != YFilter.not_set or
                                    self.low.yfilter != YFilter.not_set or
                                    self.medium.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unreachable-prefixes" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.critical.get_name_leafdata())
                                if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.high.get_name_leafdata())
                                if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.low.get_name_leafdata())
                                if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.medium.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "critical"):
                                    self.critical = value
                                    self.critical.value_namespace = name_space
                                    self.critical.value_namespace_prefix = name_space_prefix
                                if(value_path == "high"):
                                    self.high = value
                                    self.high.value_namespace = name_space
                                    self.high.value_namespace_prefix = name_space_prefix
                                if(value_path == "low"):
                                    self.low = value
                                    self.low.value_namespace = name_space
                                    self.low.value_namespace_prefix = name_space_prefix
                                if(value_path == "medium"):
                                    self.medium = value
                                    self.medium.value_namespace = name_space
                                    self.medium.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                (self.level1_prefixes is not None and self.level1_prefixes.has_data()) or
                                (self.level2_prefixes is not None and self.level2_prefixes.has_data()) or
                                (self.unreachable_prefixes is not None and self.unreachable_prefixes.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.level1_prefixes is not None and self.level1_prefixes.has_operation()) or
                                (self.level2_prefixes is not None and self.level2_prefixes.has_operation()) or
                                (self.unreachable_prefixes is not None and self.unreachable_prefixes.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "frr-summary" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "level1-prefixes"):
                                if (self.level1_prefixes is None):
                                    self.level1_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes()
                                    self.level1_prefixes.parent = self
                                    self._children_name_map["level1_prefixes"] = "level1-prefixes"
                                return self.level1_prefixes

                            if (child_yang_name == "level2-prefixes"):
                                if (self.level2_prefixes is None):
                                    self.level2_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes()
                                    self.level2_prefixes.parent = self
                                    self._children_name_map["level2_prefixes"] = "level2-prefixes"
                                return self.level2_prefixes

                            if (child_yang_name == "unreachable-prefixes"):
                                if (self.unreachable_prefixes is None):
                                    self.unreachable_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes()
                                    self.unreachable_prefixes.parent = self
                                    self._children_name_map["unreachable_prefixes"] = "unreachable-prefixes"
                                return self.unreachable_prefixes

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "level1-prefixes" or name == "level2-prefixes" or name == "unreachable-prefixes"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class TopologyLevels(Entity):
                        """
                        Per\-topology level table
                        
                        .. attribute:: topology_level
                        
                        	Per\-level topology operational data
                        	**type**\: list of    :py:class:`TopologyLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels, self).__init__()

                            self.yang_name = "topology-levels"
                            self.yang_parent_name = "topology"

                            self.topology_level = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels, self).__setattr__(name, value)


                        class TopologyLevel(Entity):
                            """
                            Per\-level topology operational data
                            
                            .. attribute:: level  <key>
                            
                            	Level
                            	**type**\:   :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                            
                            .. attribute:: ipv4_link_topologies
                            
                            	IPv4 IS Topology table
                            	**type**\:   :py:class:`Ipv4LinkTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies>`
                            
                            .. attribute:: ipv6_link_topologies
                            
                            	IPv6 IS Topology table
                            	**type**\:   :py:class:`Ipv6LinkTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies>`
                            
                            .. attribute:: spf_log
                            
                            	Log of route calculations for a single level and topology
                            	**type**\:   :py:class:`SpfLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog>`
                            
                            .. attribute:: te_adjacency_log
                            
                            	TE adjacency\-log for a single level and topology. Only available within the IPv4 Unicast topology
                            	**type**\:   :py:class:`TeAdjacencyLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog>`
                            
                            .. attribute:: te_advertisements
                            
                            	TE advertisements for a single level and topology. Only available within the IPv4 Unicast topology
                            	**type**\:   :py:class:`TeAdvertisements <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements>`
                            
                            .. attribute:: te_tunnels
                            
                            	TE tunnels table. Only available within the IPv4 Unicast topology
                            	**type**\:   :py:class:`TeTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels>`
                            
                            .. attribute:: topology_summary
                            
                            	Summary information for a particular IS Topology
                            	**type**\:   :py:class:`TopologySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel, self).__init__()

                                self.yang_name = "topology-level"
                                self.yang_parent_name = "topology-levels"

                                self.level = YLeaf(YType.enumeration, "level")

                                self.ipv4_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies()
                                self.ipv4_link_topologies.parent = self
                                self._children_name_map["ipv4_link_topologies"] = "ipv4-link-topologies"
                                self._children_yang_names.add("ipv4-link-topologies")

                                self.ipv6_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies()
                                self.ipv6_link_topologies.parent = self
                                self._children_name_map["ipv6_link_topologies"] = "ipv6-link-topologies"
                                self._children_yang_names.add("ipv6-link-topologies")

                                self.spf_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog()
                                self.spf_log.parent = self
                                self._children_name_map["spf_log"] = "spf-log"
                                self._children_yang_names.add("spf-log")

                                self.te_adjacency_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog()
                                self.te_adjacency_log.parent = self
                                self._children_name_map["te_adjacency_log"] = "te-adjacency-log"
                                self._children_yang_names.add("te-adjacency-log")

                                self.te_advertisements = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements()
                                self.te_advertisements.parent = self
                                self._children_name_map["te_advertisements"] = "te-advertisements"
                                self._children_yang_names.add("te-advertisements")

                                self.te_tunnels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels()
                                self.te_tunnels.parent = self
                                self._children_name_map["te_tunnels"] = "te-tunnels"
                                self._children_yang_names.add("te-tunnels")

                                self.topology_summary = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary()
                                self.topology_summary.parent = self
                                self._children_name_map["topology_summary"] = "topology-summary"
                                self._children_yang_names.add("topology-summary")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("level") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel, self).__setattr__(name, value)


                            class TeAdvertisements(Entity):
                                """
                                TE advertisements for a single level and
                                topology. Only available within the IPv4
                                Unicast topology.
                                
                                .. attribute:: te_adv
                                
                                	List of TE advertisement entries
                                	**type**\: list of    :py:class:`TeAdv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv>`
                                
                                .. attribute:: te_adv_data_present
                                
                                	Indicates whether any TE advertisements are present
                                	**type**\:  bool
                                
                                .. attribute:: te_local_router_id
                                
                                	Local TE router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: te_system_id
                                
                                	Local system ID
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                
                                .. attribute:: tepceadv
                                
                                	TE PCE advertisements
                                	**type**\:   :py:class:`Tepceadv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements, self).__init__()

                                    self.yang_name = "te-advertisements"
                                    self.yang_parent_name = "topology-level"

                                    self.te_adv_data_present = YLeaf(YType.boolean, "te-adv-data-present")

                                    self.te_local_router_id = YLeaf(YType.str, "te-local-router-id")

                                    self.te_system_id = YLeaf(YType.str, "te-system-id")

                                    self.tepceadv = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv()
                                    self.tepceadv.parent = self
                                    self._children_name_map["tepceadv"] = "tepceadv"
                                    self._children_yang_names.add("tepceadv")

                                    self.te_adv = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("te_adv_data_present",
                                                    "te_local_router_id",
                                                    "te_system_id") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements, self).__setattr__(name, value)


                                class Tepceadv(Entity):
                                    """
                                    TE PCE advertisements
                                    
                                    .. attribute:: pce_address_ipv4
                                    
                                    	IPv4 PCE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pce_adv_data_present
                                    
                                    	Indicates whether any PCE advertisements are present
                                    	**type**\:  bool
                                    
                                    .. attribute:: pce_flooding_scope
                                    
                                    	Flooding scope for PCE advertisement
                                    	**type**\:   :py:class:`IsisShTePceFloodingScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShTePceFloodingScope>`
                                    
                                    .. attribute:: pce_path_scope_bits
                                    
                                    	PCE path scope bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pce_path_scope_prefs
                                    
                                    	PCE path scope preferences
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv, self).__init__()

                                        self.yang_name = "tepceadv"
                                        self.yang_parent_name = "te-advertisements"

                                        self.pce_address_ipv4 = YLeaf(YType.str, "pce-address-ipv4")

                                        self.pce_adv_data_present = YLeaf(YType.boolean, "pce-adv-data-present")

                                        self.pce_flooding_scope = YLeaf(YType.enumeration, "pce-flooding-scope")

                                        self.pce_path_scope_bits = YLeaf(YType.uint8, "pce-path-scope-bits")

                                        self.pce_path_scope_prefs = YLeaf(YType.uint16, "pce-path-scope-prefs")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("pce_address_ipv4",
                                                        "pce_adv_data_present",
                                                        "pce_flooding_scope",
                                                        "pce_path_scope_bits",
                                                        "pce_path_scope_prefs") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.pce_address_ipv4.is_set or
                                            self.pce_adv_data_present.is_set or
                                            self.pce_flooding_scope.is_set or
                                            self.pce_path_scope_bits.is_set or
                                            self.pce_path_scope_prefs.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.pce_address_ipv4.yfilter != YFilter.not_set or
                                            self.pce_adv_data_present.yfilter != YFilter.not_set or
                                            self.pce_flooding_scope.yfilter != YFilter.not_set or
                                            self.pce_path_scope_bits.yfilter != YFilter.not_set or
                                            self.pce_path_scope_prefs.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tepceadv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.pce_address_ipv4.is_set or self.pce_address_ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pce_address_ipv4.get_name_leafdata())
                                        if (self.pce_adv_data_present.is_set or self.pce_adv_data_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pce_adv_data_present.get_name_leafdata())
                                        if (self.pce_flooding_scope.is_set or self.pce_flooding_scope.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pce_flooding_scope.get_name_leafdata())
                                        if (self.pce_path_scope_bits.is_set or self.pce_path_scope_bits.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pce_path_scope_bits.get_name_leafdata())
                                        if (self.pce_path_scope_prefs.is_set or self.pce_path_scope_prefs.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pce_path_scope_prefs.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "pce-address-ipv4" or name == "pce-adv-data-present" or name == "pce-flooding-scope" or name == "pce-path-scope-bits" or name == "pce-path-scope-prefs"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "pce-address-ipv4"):
                                            self.pce_address_ipv4 = value
                                            self.pce_address_ipv4.value_namespace = name_space
                                            self.pce_address_ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pce-adv-data-present"):
                                            self.pce_adv_data_present = value
                                            self.pce_adv_data_present.value_namespace = name_space
                                            self.pce_adv_data_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pce-flooding-scope"):
                                            self.pce_flooding_scope = value
                                            self.pce_flooding_scope.value_namespace = name_space
                                            self.pce_flooding_scope.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pce-path-scope-bits"):
                                            self.pce_path_scope_bits = value
                                            self.pce_path_scope_bits.value_namespace = name_space
                                            self.pce_path_scope_bits.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pce-path-scope-prefs"):
                                            self.pce_path_scope_prefs = value
                                            self.pce_path_scope_prefs.value_namespace = name_space
                                            self.pce_path_scope_prefs.value_namespace_prefix = name_space_prefix


                                class TeAdv(Entity):
                                    """
                                    List of TE advertisement entries
                                    
                                    .. attribute:: link_type
                                    
                                    	Link type
                                    	**type**\:   :py:class:`IsisShTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShTeLink>`
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_affinity
                                    
                                    	Affinity bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_ext_admin_num
                                    
                                    	TE Ext Admin Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_ext_admin_sub
                                    
                                    	TE Extended Admin Group
                                    	**type**\: list of    :py:class:`TeExtAdminSub <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: te_physical_link_bandwidth
                                    
                                    	Physical link bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_reserved_link_bandwidth
                                    
                                    	Reservable link bandwidth in global pool
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_sub_tlv
                                    
                                    	List of TE sub TLVs
                                    	**type**\: list of    :py:class:`TeSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv>`
                                    
                                    .. attribute:: te_sub_tlv_data_present
                                    
                                    	Indicates whether any TE sub TLVs are present
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_subpool_reserved_link_bandwidth
                                    
                                    	Reservable link bandwidth in subpool
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_subpool_transmitted_bandwidth
                                    
                                    	Bandwidth in use in subpool
                                    	**type**\: list of    :py:class:`TeSubpoolTransmittedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth>`
                                    
                                    .. attribute:: te_transmitted_bandwidth
                                    
                                    	Bandwidth in use in global pool
                                    	**type**\: list of    :py:class:`TeTransmittedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv, self).__init__()

                                        self.yang_name = "te-adv"
                                        self.yang_parent_name = "te-advertisements"

                                        self.link_type = YLeaf(YType.enumeration, "link-type")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")

                                        self.te_affinity = YLeaf(YType.uint32, "te-affinity")

                                        self.te_ext_admin_num = YLeaf(YType.uint32, "te-ext-admin-num")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.te_neighbor_ip_address = YLeaf(YType.str, "te-neighbor-ip-address")

                                        self.te_neighbor_system_id = YLeaf(YType.str, "te-neighbor-system-id")

                                        self.te_physical_link_bandwidth = YLeaf(YType.uint32, "te-physical-link-bandwidth")

                                        self.te_reserved_link_bandwidth = YLeaf(YType.uint32, "te-reserved-link-bandwidth")

                                        self.te_sub_tlv_data_present = YLeaf(YType.boolean, "te-sub-tlv-data-present")

                                        self.te_subpool_reserved_link_bandwidth = YLeaf(YType.uint32, "te-subpool-reserved-link-bandwidth")

                                        self.te_ext_admin_sub = YList(self)
                                        self.te_sub_tlv = YList(self)
                                        self.te_subpool_transmitted_bandwidth = YList(self)
                                        self.te_transmitted_bandwidth = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("link_type",
                                                        "local_ip_address",
                                                        "te_affinity",
                                                        "te_ext_admin_num",
                                                        "te_metric",
                                                        "te_neighbor_ip_address",
                                                        "te_neighbor_system_id",
                                                        "te_physical_link_bandwidth",
                                                        "te_reserved_link_bandwidth",
                                                        "te_sub_tlv_data_present",
                                                        "te_subpool_reserved_link_bandwidth") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv, self).__setattr__(name, value)


                                    class TeTransmittedBandwidth(Entity):
                                        """
                                        Bandwidth in use in global pool
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth, self).__init__()

                                            self.yang_name = "te-transmitted-bandwidth"
                                            self.yang_parent_name = "te-adv"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "te-transmitted-bandwidth" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class TeSubpoolTransmittedBandwidth(Entity):
                                        """
                                        Bandwidth in use in subpool
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth, self).__init__()

                                            self.yang_name = "te-subpool-transmitted-bandwidth"
                                            self.yang_parent_name = "te-adv"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "te-subpool-transmitted-bandwidth" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class TeExtAdminSub(Entity):
                                        """
                                        TE Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub, self).__init__()

                                            self.yang_name = "te-ext-admin-sub"
                                            self.yang_parent_name = "te-adv"

                                            self.entry = YLeaf(YType.uint32, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "te-ext-admin-sub" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix


                                    class TeSubTlv(Entity):
                                        """
                                        List of TE sub TLVs
                                        
                                        .. attribute:: te_sub_tlv_length
                                        
                                        	Length of sub TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: te_sub_tlv_type
                                        
                                        	Type of sub TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: te_sub_tlv_value
                                        
                                        	Value of sub TLV
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv, self).__init__()

                                            self.yang_name = "te-sub-tlv"
                                            self.yang_parent_name = "te-adv"

                                            self.te_sub_tlv_length = YLeaf(YType.uint16, "te-sub-tlv-length")

                                            self.te_sub_tlv_type = YLeaf(YType.uint16, "te-sub-tlv-type")

                                            self.te_sub_tlv_value = YLeaf(YType.str, "te-sub-tlv-value")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("te_sub_tlv_length",
                                                            "te_sub_tlv_type",
                                                            "te_sub_tlv_value") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.te_sub_tlv_length.is_set or
                                                self.te_sub_tlv_type.is_set or
                                                self.te_sub_tlv_value.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.te_sub_tlv_length.yfilter != YFilter.not_set or
                                                self.te_sub_tlv_type.yfilter != YFilter.not_set or
                                                self.te_sub_tlv_value.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "te-sub-tlv" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.te_sub_tlv_length.is_set or self.te_sub_tlv_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_sub_tlv_length.get_name_leafdata())
                                            if (self.te_sub_tlv_type.is_set or self.te_sub_tlv_type.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_sub_tlv_type.get_name_leafdata())
                                            if (self.te_sub_tlv_value.is_set or self.te_sub_tlv_value.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.te_sub_tlv_value.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "te-sub-tlv-length" or name == "te-sub-tlv-type" or name == "te-sub-tlv-value"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "te-sub-tlv-length"):
                                                self.te_sub_tlv_length = value
                                                self.te_sub_tlv_length.value_namespace = name_space
                                                self.te_sub_tlv_length.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-sub-tlv-type"):
                                                self.te_sub_tlv_type = value
                                                self.te_sub_tlv_type.value_namespace = name_space
                                                self.te_sub_tlv_type.value_namespace_prefix = name_space_prefix
                                            if(value_path == "te-sub-tlv-value"):
                                                self.te_sub_tlv_value = value
                                                self.te_sub_tlv_value.value_namespace = name_space
                                                self.te_sub_tlv_value.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.te_ext_admin_sub:
                                            if (c.has_data()):
                                                return True
                                        for c in self.te_sub_tlv:
                                            if (c.has_data()):
                                                return True
                                        for c in self.te_subpool_transmitted_bandwidth:
                                            if (c.has_data()):
                                                return True
                                        for c in self.te_transmitted_bandwidth:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.link_type.is_set or
                                            self.local_ip_address.is_set or
                                            self.te_affinity.is_set or
                                            self.te_ext_admin_num.is_set or
                                            self.te_metric.is_set or
                                            self.te_neighbor_ip_address.is_set or
                                            self.te_neighbor_system_id.is_set or
                                            self.te_physical_link_bandwidth.is_set or
                                            self.te_reserved_link_bandwidth.is_set or
                                            self.te_sub_tlv_data_present.is_set or
                                            self.te_subpool_reserved_link_bandwidth.is_set)

                                    def has_operation(self):
                                        for c in self.te_ext_admin_sub:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.te_sub_tlv:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.te_subpool_transmitted_bandwidth:
                                            if (c.has_operation()):
                                                return True
                                        for c in self.te_transmitted_bandwidth:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.link_type.yfilter != YFilter.not_set or
                                            self.local_ip_address.yfilter != YFilter.not_set or
                                            self.te_affinity.yfilter != YFilter.not_set or
                                            self.te_ext_admin_num.yfilter != YFilter.not_set or
                                            self.te_metric.yfilter != YFilter.not_set or
                                            self.te_neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.te_neighbor_system_id.yfilter != YFilter.not_set or
                                            self.te_physical_link_bandwidth.yfilter != YFilter.not_set or
                                            self.te_reserved_link_bandwidth.yfilter != YFilter.not_set or
                                            self.te_sub_tlv_data_present.yfilter != YFilter.not_set or
                                            self.te_subpool_reserved_link_bandwidth.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "te-adv" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.link_type.is_set or self.link_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.link_type.get_name_leafdata())
                                        if (self.local_ip_address.is_set or self.local_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.local_ip_address.get_name_leafdata())
                                        if (self.te_affinity.is_set or self.te_affinity.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_affinity.get_name_leafdata())
                                        if (self.te_ext_admin_num.is_set or self.te_ext_admin_num.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_ext_admin_num.get_name_leafdata())
                                        if (self.te_metric.is_set or self.te_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_metric.get_name_leafdata())
                                        if (self.te_neighbor_ip_address.is_set or self.te_neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_neighbor_ip_address.get_name_leafdata())
                                        if (self.te_neighbor_system_id.is_set or self.te_neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_neighbor_system_id.get_name_leafdata())
                                        if (self.te_physical_link_bandwidth.is_set or self.te_physical_link_bandwidth.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_physical_link_bandwidth.get_name_leafdata())
                                        if (self.te_reserved_link_bandwidth.is_set or self.te_reserved_link_bandwidth.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_reserved_link_bandwidth.get_name_leafdata())
                                        if (self.te_sub_tlv_data_present.is_set or self.te_sub_tlv_data_present.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_sub_tlv_data_present.get_name_leafdata())
                                        if (self.te_subpool_reserved_link_bandwidth.is_set or self.te_subpool_reserved_link_bandwidth.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_subpool_reserved_link_bandwidth.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "te-ext-admin-sub"):
                                            for c in self.te_ext_admin_sub:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.te_ext_admin_sub.append(c)
                                            return c

                                        if (child_yang_name == "te-sub-tlv"):
                                            for c in self.te_sub_tlv:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.te_sub_tlv.append(c)
                                            return c

                                        if (child_yang_name == "te-subpool-transmitted-bandwidth"):
                                            for c in self.te_subpool_transmitted_bandwidth:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.te_subpool_transmitted_bandwidth.append(c)
                                            return c

                                        if (child_yang_name == "te-transmitted-bandwidth"):
                                            for c in self.te_transmitted_bandwidth:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.te_transmitted_bandwidth.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "te-ext-admin-sub" or name == "te-sub-tlv" or name == "te-subpool-transmitted-bandwidth" or name == "te-transmitted-bandwidth" or name == "link-type" or name == "local-ip-address" or name == "te-affinity" or name == "te-ext-admin-num" or name == "te-metric" or name == "te-neighbor-ip-address" or name == "te-neighbor-system-id" or name == "te-physical-link-bandwidth" or name == "te-reserved-link-bandwidth" or name == "te-sub-tlv-data-present" or name == "te-subpool-reserved-link-bandwidth"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "link-type"):
                                            self.link_type = value
                                            self.link_type.value_namespace = name_space
                                            self.link_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "local-ip-address"):
                                            self.local_ip_address = value
                                            self.local_ip_address.value_namespace = name_space
                                            self.local_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-affinity"):
                                            self.te_affinity = value
                                            self.te_affinity.value_namespace = name_space
                                            self.te_affinity.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-ext-admin-num"):
                                            self.te_ext_admin_num = value
                                            self.te_ext_admin_num.value_namespace = name_space
                                            self.te_ext_admin_num.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-metric"):
                                            self.te_metric = value
                                            self.te_metric.value_namespace = name_space
                                            self.te_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-neighbor-ip-address"):
                                            self.te_neighbor_ip_address = value
                                            self.te_neighbor_ip_address.value_namespace = name_space
                                            self.te_neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-neighbor-system-id"):
                                            self.te_neighbor_system_id = value
                                            self.te_neighbor_system_id.value_namespace = name_space
                                            self.te_neighbor_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-physical-link-bandwidth"):
                                            self.te_physical_link_bandwidth = value
                                            self.te_physical_link_bandwidth.value_namespace = name_space
                                            self.te_physical_link_bandwidth.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-reserved-link-bandwidth"):
                                            self.te_reserved_link_bandwidth = value
                                            self.te_reserved_link_bandwidth.value_namespace = name_space
                                            self.te_reserved_link_bandwidth.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-sub-tlv-data-present"):
                                            self.te_sub_tlv_data_present = value
                                            self.te_sub_tlv_data_present.value_namespace = name_space
                                            self.te_sub_tlv_data_present.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-subpool-reserved-link-bandwidth"):
                                            self.te_subpool_reserved_link_bandwidth = value
                                            self.te_subpool_reserved_link_bandwidth.value_namespace = name_space
                                            self.te_subpool_reserved_link_bandwidth.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.te_adv:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.te_adv_data_present.is_set or
                                        self.te_local_router_id.is_set or
                                        self.te_system_id.is_set or
                                        (self.tepceadv is not None and self.tepceadv.has_data()))

                                def has_operation(self):
                                    for c in self.te_adv:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.te_adv_data_present.yfilter != YFilter.not_set or
                                        self.te_local_router_id.yfilter != YFilter.not_set or
                                        self.te_system_id.yfilter != YFilter.not_set or
                                        (self.tepceadv is not None and self.tepceadv.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "te-advertisements" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.te_adv_data_present.is_set or self.te_adv_data_present.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_adv_data_present.get_name_leafdata())
                                    if (self.te_local_router_id.is_set or self.te_local_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_local_router_id.get_name_leafdata())
                                    if (self.te_system_id.is_set or self.te_system_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.te_system_id.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "te-adv"):
                                        for c in self.te_adv:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.te_adv.append(c)
                                        return c

                                    if (child_yang_name == "tepceadv"):
                                        if (self.tepceadv is None):
                                            self.tepceadv = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv()
                                            self.tepceadv.parent = self
                                            self._children_name_map["tepceadv"] = "tepceadv"
                                        return self.tepceadv

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "te-adv" or name == "tepceadv" or name == "te-adv-data-present" or name == "te-local-router-id" or name == "te-system-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "te-adv-data-present"):
                                        self.te_adv_data_present = value
                                        self.te_adv_data_present.value_namespace = name_space
                                        self.te_adv_data_present.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-local-router-id"):
                                        self.te_local_router_id = value
                                        self.te_local_router_id.value_namespace = name_space
                                        self.te_local_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "te-system-id"):
                                        self.te_system_id = value
                                        self.te_system_id.value_namespace = name_space
                                        self.te_system_id.value_namespace_prefix = name_space_prefix


                            class TeAdjacencyLog(Entity):
                                """
                                TE adjacency\-log for a single level and
                                topology. Only available within the IPv4
                                Unicast topology.
                                
                                .. attribute:: log_entry
                                
                                	Log entries
                                	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog, self).__init__()

                                    self.yang_name = "te-adjacency-log"
                                    self.yang_parent_name = "topology-level"

                                    self.log_entry = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog, self).__setattr__(name, value)


                                class LogEntry(Entity):
                                    """
                                    Log entries
                                    
                                    .. attribute:: generic_data
                                    
                                    	Generic entry data
                                    	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData>`
                                    
                                    .. attribute:: log_interface
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor ip address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status
                                    
                                    	Up (TRUE) or down
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_log_neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry, self).__init__()

                                        self.yang_name = "log-entry"
                                        self.yang_parent_name = "te-adjacency-log"

                                        self.log_interface = YLeaf(YType.str, "log-interface")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.status = YLeaf(YType.boolean, "status")

                                        self.te_log_neighbor_system_id = YLeaf(YType.str, "te-log-neighbor-system-id")

                                        self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                        self._children_yang_names.add("generic-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("log_interface",
                                                        "neighbor_ip_address",
                                                        "status",
                                                        "te_log_neighbor_system_id") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry, self).__setattr__(name, value)


                                    class GenericData(Entity):
                                        """
                                        Generic entry data
                                        
                                        .. attribute:: timestamp
                                        
                                        	Time in UTC relative to Jan 1st, 1970
                                        	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData, self).__init__()

                                            self.yang_name = "generic-data"
                                            self.yang_parent_name = "log-entry"

                                            self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                            self._children_yang_names.add("timestamp")


                                        class Timestamp(Entity):
                                            """
                                            Time in UTC relative to Jan 1st, 1970
                                            
                                            .. attribute:: nano_seconds
                                            
                                            	Timestamp value (nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Timestamp value (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp, self).__init__()

                                                self.yang_name = "timestamp"
                                                self.yang_parent_name = "generic-data"

                                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nano_seconds",
                                                                "seconds") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nano_seconds.is_set or
                                                    self.seconds.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nano_seconds.yfilter != YFilter.not_set or
                                                    self.seconds.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "timestamp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nano-seconds" or name == "seconds"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nano-seconds"):
                                                    self.nano_seconds = value
                                                    self.nano_seconds.value_namespace = name_space
                                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                                if(value_path == "seconds"):
                                                    self.seconds = value
                                                    self.seconds.value_namespace = name_space
                                                    self.seconds.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (self.timestamp is not None and self.timestamp.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.timestamp is not None and self.timestamp.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "generic-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "timestamp"):
                                                if (self.timestamp is None):
                                                    self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp()
                                                    self.timestamp.parent = self
                                                    self._children_name_map["timestamp"] = "timestamp"
                                                return self.timestamp

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "timestamp"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.log_interface.is_set or
                                            self.neighbor_ip_address.is_set or
                                            self.status.is_set or
                                            self.te_log_neighbor_system_id.is_set or
                                            (self.generic_data is not None and self.generic_data.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.log_interface.yfilter != YFilter.not_set or
                                            self.neighbor_ip_address.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            self.te_log_neighbor_system_id.yfilter != YFilter.not_set or
                                            (self.generic_data is not None and self.generic_data.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "log-entry" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.log_interface.is_set or self.log_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.log_interface.get_name_leafdata())
                                        if (self.neighbor_ip_address.is_set or self.neighbor_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.neighbor_ip_address.get_name_leafdata())
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())
                                        if (self.te_log_neighbor_system_id.is_set or self.te_log_neighbor_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_log_neighbor_system_id.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "generic-data"):
                                            if (self.generic_data is None):
                                                self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData()
                                                self.generic_data.parent = self
                                                self._children_name_map["generic_data"] = "generic-data"
                                            return self.generic_data

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "generic-data" or name == "log-interface" or name == "neighbor-ip-address" or name == "status" or name == "te-log-neighbor-system-id"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "log-interface"):
                                            self.log_interface = value
                                            self.log_interface.value_namespace = name_space
                                            self.log_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "neighbor-ip-address"):
                                            self.neighbor_ip_address = value
                                            self.neighbor_ip_address.value_namespace = name_space
                                            self.neighbor_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-log-neighbor-system-id"):
                                            self.te_log_neighbor_system_id = value
                                            self.te_log_neighbor_system_id.value_namespace = name_space
                                            self.te_log_neighbor_system_id.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.log_entry:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.log_entry:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "te-adjacency-log" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "log-entry"):
                                        for c in self.log_entry:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.log_entry.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "log-entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class SpfLog(Entity):
                                """
                                Log of route calculations for a single
                                level and topology
                                
                                .. attribute:: log_entry
                                
                                	SPF Log entries
                                	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog, self).__init__()

                                    self.yang_name = "spf-log"
                                    self.yang_parent_name = "topology-level"

                                    self.log_entry = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog, self).__setattr__(name, value)


                                class LogEntry(Entity):
                                    """
                                    SPF Log entries
                                    
                                    .. attribute:: class_
                                    
                                    	Type of calculation
                                    	**type**\:   :py:class:`IsisSpfClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSpfClass>`
                                    
                                    .. attribute:: generic_data
                                    
                                    	Generic entry data
                                    	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData>`
                                    
                                    .. attribute:: next_wait_interval
                                    
                                    	Minimum time from end of this route calculation until the start of the next, in milliseconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: route_update_statistics
                                    
                                    	Statistics for the route update phase
                                    	**type**\:   :py:class:`RouteUpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics>`
                                    
                                    .. attribute:: spt_calculation_statistics
                                    
                                    	Statistics for the SPT calculation phase
                                    	**type**\:   :py:class:`SptCalculationStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics>`
                                    
                                    .. attribute:: triggers
                                    
                                    	Trigger information
                                    	**type**\:   :py:class:`Triggers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers>`
                                    
                                    .. attribute:: updated_lsp_count
                                    
                                    	Number of LSPs which arrived during the route calculation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: wait_enforced
                                    
                                    	Time between the first trigger and the start of the route calculation, in milliseconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry, self).__init__()

                                        self.yang_name = "log-entry"
                                        self.yang_parent_name = "spf-log"

                                        self.class_ = YLeaf(YType.enumeration, "class")

                                        self.next_wait_interval = YLeaf(YType.uint32, "next-wait-interval")

                                        self.updated_lsp_count = YLeaf(YType.uint32, "updated-lsp-count")

                                        self.wait_enforced = YLeaf(YType.uint32, "wait-enforced")

                                        self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                        self._children_yang_names.add("generic-data")

                                        self.route_update_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics()
                                        self.route_update_statistics.parent = self
                                        self._children_name_map["route_update_statistics"] = "route-update-statistics"
                                        self._children_yang_names.add("route-update-statistics")

                                        self.spt_calculation_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics()
                                        self.spt_calculation_statistics.parent = self
                                        self._children_name_map["spt_calculation_statistics"] = "spt-calculation-statistics"
                                        self._children_yang_names.add("spt-calculation-statistics")

                                        self.triggers = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers()
                                        self.triggers.parent = self
                                        self._children_name_map["triggers"] = "triggers"
                                        self._children_yang_names.add("triggers")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("class_",
                                                        "next_wait_interval",
                                                        "updated_lsp_count",
                                                        "wait_enforced") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry, self).__setattr__(name, value)


                                    class GenericData(Entity):
                                        """
                                        Generic entry data.
                                        
                                        .. attribute:: timestamp
                                        
                                        	Time in UTC relative to Jan 1st, 1970
                                        	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData, self).__init__()

                                            self.yang_name = "generic-data"
                                            self.yang_parent_name = "log-entry"

                                            self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                            self._children_yang_names.add("timestamp")


                                        class Timestamp(Entity):
                                            """
                                            Time in UTC relative to Jan 1st, 1970
                                            
                                            .. attribute:: nano_seconds
                                            
                                            	Timestamp value (nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Timestamp value (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp, self).__init__()

                                                self.yang_name = "timestamp"
                                                self.yang_parent_name = "generic-data"

                                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                                self.seconds = YLeaf(YType.uint32, "seconds")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("nano_seconds",
                                                                "seconds") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.nano_seconds.is_set or
                                                    self.seconds.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.nano_seconds.yfilter != YFilter.not_set or
                                                    self.seconds.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "timestamp" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nano-seconds" or name == "seconds"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "nano-seconds"):
                                                    self.nano_seconds = value
                                                    self.nano_seconds.value_namespace = name_space
                                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                                if(value_path == "seconds"):
                                                    self.seconds = value
                                                    self.seconds.value_namespace = name_space
                                                    self.seconds.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (self.timestamp is not None and self.timestamp.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.timestamp is not None and self.timestamp.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "generic-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "timestamp"):
                                                if (self.timestamp is None):
                                                    self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp()
                                                    self.timestamp.parent = self
                                                    self._children_name_map["timestamp"] = "timestamp"
                                                return self.timestamp

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "timestamp"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class Triggers(Entity):
                                        """
                                        Trigger information
                                        
                                        .. attribute:: first_trigger_lsp_id
                                        
                                        	ID of the first LSP to trigger the calculation, if any
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                        
                                        .. attribute:: is_sr_uloop_calculation
                                        
                                        	Is this SR micro loop calculation?
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sr_uloop_link_down
                                        
                                        	Is this SR micro loop calculation for link down?
                                        	**type**\:  bool
                                        
                                        .. attribute:: trigger
                                        
                                        	Triggers applying to this log entry
                                        	**type**\: list of    :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger>`
                                        
                                        .. attribute:: trigger_link
                                        
                                        	ID of a changed link in the first trigger LSP, if any
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                        
                                        .. attribute:: trigger_next_hop_id
                                        
                                        	ID of a changed next hop, if any
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                        
                                        .. attribute:: trigger_prefix
                                        
                                        	ID of a changed prefix in the first trigger LSP, if any
                                        	**type**\:   :py:class:`TriggerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix>`
                                        
                                        .. attribute:: unique_trigger_count
                                        
                                        	Number of unique triggers on this run
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers, self).__init__()

                                            self.yang_name = "triggers"
                                            self.yang_parent_name = "log-entry"

                                            self.first_trigger_lsp_id = YLeaf(YType.str, "first-trigger-lsp-id")

                                            self.is_sr_uloop_calculation = YLeaf(YType.boolean, "is-sr-uloop-calculation")

                                            self.is_sr_uloop_link_down = YLeaf(YType.boolean, "is-sr-uloop-link-down")

                                            self.trigger_link = YLeaf(YType.str, "trigger-link")

                                            self.trigger_next_hop_id = YLeaf(YType.str, "trigger-next-hop-id")

                                            self.unique_trigger_count = YLeaf(YType.uint32, "unique-trigger-count")

                                            self.trigger_prefix = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix()
                                            self.trigger_prefix.parent = self
                                            self._children_name_map["trigger_prefix"] = "trigger-prefix"
                                            self._children_yang_names.add("trigger-prefix")

                                            self.trigger = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("first_trigger_lsp_id",
                                                            "is_sr_uloop_calculation",
                                                            "is_sr_uloop_link_down",
                                                            "trigger_link",
                                                            "trigger_next_hop_id",
                                                            "unique_trigger_count") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers, self).__setattr__(name, value)


                                        class TriggerPrefix(Entity):
                                            """
                                            ID of a changed prefix in the first trigger LSP,
                                            if any
                                            
                                            .. attribute:: af_name
                                            
                                            	AFName
                                            	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                            
                                            .. attribute:: ipv4
                                            
                                            	ipv4
                                            	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4>`
                                            
                                            .. attribute:: ipv6
                                            
                                            	ipv6
                                            	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix, self).__init__()

                                                self.yang_name = "trigger-prefix"
                                                self.yang_parent_name = "triggers"

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.ipv4 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"
                                                self._children_yang_names.add("ipv4")

                                                self.ipv6 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6()
                                                self.ipv6.parent = self
                                                self._children_name_map["ipv6"] = "ipv6"
                                                self._children_yang_names.add("ipv6")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("af_name") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix, self).__setattr__(name, value)


                                            class Ipv4(Entity):
                                                """
                                                ipv4
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "trigger-prefix"

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("prefix",
                                                                    "prefix_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipv4" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "prefix" or name == "prefix-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix


                                            class Ipv6(Entity):
                                                """
                                                ipv6
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6, self).__init__()

                                                    self.yang_name = "ipv6"
                                                    self.yang_parent_name = "trigger-prefix"

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("prefix",
                                                                    "prefix_length") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.prefix.is_set or
                                                        self.prefix_length.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.prefix.yfilter != YFilter.not_set or
                                                        self.prefix_length.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "ipv6" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "prefix" or name == "prefix-length"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "prefix"):
                                                        self.prefix = value
                                                        self.prefix.value_namespace = name_space
                                                        self.prefix.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-length"):
                                                        self.prefix_length = value
                                                        self.prefix_length.value_namespace = name_space
                                                        self.prefix_length.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.af_name.is_set or
                                                    (self.ipv4 is not None and self.ipv4.has_data()) or
                                                    (self.ipv6 is not None and self.ipv6.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.af_name.yfilter != YFilter.not_set or
                                                    (self.ipv4 is not None and self.ipv4.has_operation()) or
                                                    (self.ipv6 is not None and self.ipv6.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "trigger-prefix" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.af_name.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "ipv4"):
                                                    if (self.ipv4 is None):
                                                        self.ipv4 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4()
                                                        self.ipv4.parent = self
                                                        self._children_name_map["ipv4"] = "ipv4"
                                                    return self.ipv4

                                                if (child_yang_name == "ipv6"):
                                                    if (self.ipv6 is None):
                                                        self.ipv6 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6()
                                                        self.ipv6.parent = self
                                                        self._children_name_map["ipv6"] = "ipv6"
                                                    return self.ipv6

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "ipv4" or name == "ipv6" or name == "af-name"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "af-name"):
                                                    self.af_name = value
                                                    self.af_name.value_namespace = name_space
                                                    self.af_name.value_namespace_prefix = name_space_prefix


                                        class Trigger(Entity):
                                            """
                                            Triggers applying to this log entry
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:   :py:class:`IsisSpfTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSpfTrigger>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger, self).__init__()

                                                self.yang_name = "trigger"
                                                self.yang_parent_name = "triggers"

                                                self.entry = YLeaf(YType.enumeration, "entry")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("entry") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger, self).__setattr__(name, value)

                                            def has_data(self):
                                                return self.entry.is_set

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.entry.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "trigger" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.entry.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "entry"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "entry"):
                                                    self.entry = value
                                                    self.entry.value_namespace = name_space
                                                    self.entry.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.trigger:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.first_trigger_lsp_id.is_set or
                                                self.is_sr_uloop_calculation.is_set or
                                                self.is_sr_uloop_link_down.is_set or
                                                self.trigger_link.is_set or
                                                self.trigger_next_hop_id.is_set or
                                                self.unique_trigger_count.is_set or
                                                (self.trigger_prefix is not None and self.trigger_prefix.has_data()))

                                        def has_operation(self):
                                            for c in self.trigger:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.first_trigger_lsp_id.yfilter != YFilter.not_set or
                                                self.is_sr_uloop_calculation.yfilter != YFilter.not_set or
                                                self.is_sr_uloop_link_down.yfilter != YFilter.not_set or
                                                self.trigger_link.yfilter != YFilter.not_set or
                                                self.trigger_next_hop_id.yfilter != YFilter.not_set or
                                                self.unique_trigger_count.yfilter != YFilter.not_set or
                                                (self.trigger_prefix is not None and self.trigger_prefix.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "triggers" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.first_trigger_lsp_id.is_set or self.first_trigger_lsp_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.first_trigger_lsp_id.get_name_leafdata())
                                            if (self.is_sr_uloop_calculation.is_set or self.is_sr_uloop_calculation.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sr_uloop_calculation.get_name_leafdata())
                                            if (self.is_sr_uloop_link_down.is_set or self.is_sr_uloop_link_down.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_sr_uloop_link_down.get_name_leafdata())
                                            if (self.trigger_link.is_set or self.trigger_link.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.trigger_link.get_name_leafdata())
                                            if (self.trigger_next_hop_id.is_set or self.trigger_next_hop_id.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.trigger_next_hop_id.get_name_leafdata())
                                            if (self.unique_trigger_count.is_set or self.unique_trigger_count.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.unique_trigger_count.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "trigger"):
                                                for c in self.trigger:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.trigger.append(c)
                                                return c

                                            if (child_yang_name == "trigger-prefix"):
                                                if (self.trigger_prefix is None):
                                                    self.trigger_prefix = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix()
                                                    self.trigger_prefix.parent = self
                                                    self._children_name_map["trigger_prefix"] = "trigger-prefix"
                                                return self.trigger_prefix

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "trigger" or name == "trigger-prefix" or name == "first-trigger-lsp-id" or name == "is-sr-uloop-calculation" or name == "is-sr-uloop-link-down" or name == "trigger-link" or name == "trigger-next-hop-id" or name == "unique-trigger-count"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "first-trigger-lsp-id"):
                                                self.first_trigger_lsp_id = value
                                                self.first_trigger_lsp_id.value_namespace = name_space
                                                self.first_trigger_lsp_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sr-uloop-calculation"):
                                                self.is_sr_uloop_calculation = value
                                                self.is_sr_uloop_calculation.value_namespace = name_space
                                                self.is_sr_uloop_calculation.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-sr-uloop-link-down"):
                                                self.is_sr_uloop_link_down = value
                                                self.is_sr_uloop_link_down.value_namespace = name_space
                                                self.is_sr_uloop_link_down.value_namespace_prefix = name_space_prefix
                                            if(value_path == "trigger-link"):
                                                self.trigger_link = value
                                                self.trigger_link.value_namespace = name_space
                                                self.trigger_link.value_namespace_prefix = name_space_prefix
                                            if(value_path == "trigger-next-hop-id"):
                                                self.trigger_next_hop_id = value
                                                self.trigger_next_hop_id.value_namespace = name_space
                                                self.trigger_next_hop_id.value_namespace_prefix = name_space_prefix
                                            if(value_path == "unique-trigger-count"):
                                                self.unique_trigger_count = value
                                                self.unique_trigger_count.value_namespace = name_space
                                                self.unique_trigger_count.value_namespace_prefix = name_space_prefix


                                    class SptCalculationStatistics(Entity):
                                        """
                                        Statistics for the SPT calculation phase
                                        
                                        .. attribute:: duration
                                        
                                        	Duration of the SPT calculation
                                        	**type**\:   :py:class:`Duration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration>`
                                        
                                        .. attribute:: node_counts
                                        
                                        	Node counts
                                        	**type**\:   :py:class:`NodeCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics, self).__init__()

                                            self.yang_name = "spt-calculation-statistics"
                                            self.yang_parent_name = "log-entry"

                                            self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration()
                                            self.duration.parent = self
                                            self._children_name_map["duration"] = "duration"
                                            self._children_yang_names.add("duration")

                                            self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts()
                                            self.node_counts.parent = self
                                            self._children_name_map["node_counts"] = "node-counts"
                                            self._children_yang_names.add("node-counts")


                                        class Duration(Entity):
                                            """
                                            Duration of the SPT calculation
                                            
                                            .. attribute:: cpu_duration
                                            
                                            	CPU time duration in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: real_duration
                                            
                                            	Real time duration in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration, self).__init__()

                                                self.yang_name = "duration"
                                                self.yang_parent_name = "spt-calculation-statistics"

                                                self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                self.real_duration = YLeaf(YType.uint32, "real-duration")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cpu_duration",
                                                                "real_duration") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cpu_duration.is_set or
                                                    self.real_duration.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cpu_duration.yfilter != YFilter.not_set or
                                                    self.real_duration.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "duration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cpu-duration" or name == "real-duration"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cpu-duration"):
                                                    self.cpu_duration = value
                                                    self.cpu_duration.value_namespace = name_space
                                                    self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                if(value_path == "real-duration"):
                                                    self.real_duration = value
                                                    self.real_duration.value_namespace = name_space
                                                    self.real_duration.value_namespace_prefix = name_space_prefix


                                        class NodeCounts(Entity):
                                            """
                                            Node counts
                                            
                                            .. attribute:: added
                                            
                                            	Number of nodes added to the SPT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of nodes deleted from the SPT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified
                                            
                                            	Number of modified nodes (first hop and/or metric change)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable nodes in the database
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: touched
                                            
                                            	Number of nodes touched whilst calculating the SPT
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable nodes in the database
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts, self).__init__()

                                                self.yang_name = "node-counts"
                                                self.yang_parent_name = "spt-calculation-statistics"

                                                self.added = YLeaf(YType.uint32, "added")

                                                self.deleted = YLeaf(YType.uint32, "deleted")

                                                self.modified = YLeaf(YType.uint32, "modified")

                                                self.reachable = YLeaf(YType.uint32, "reachable")

                                                self.touched = YLeaf(YType.uint32, "touched")

                                                self.unreachable = YLeaf(YType.uint32, "unreachable")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("added",
                                                                "deleted",
                                                                "modified",
                                                                "reachable",
                                                                "touched",
                                                                "unreachable") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.added.is_set or
                                                    self.deleted.is_set or
                                                    self.modified.is_set or
                                                    self.reachable.is_set or
                                                    self.touched.is_set or
                                                    self.unreachable.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.added.yfilter != YFilter.not_set or
                                                    self.deleted.yfilter != YFilter.not_set or
                                                    self.modified.yfilter != YFilter.not_set or
                                                    self.reachable.yfilter != YFilter.not_set or
                                                    self.touched.yfilter != YFilter.not_set or
                                                    self.unreachable.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "node-counts" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.added.is_set or self.added.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.added.get_name_leafdata())
                                                if (self.deleted.is_set or self.deleted.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.deleted.get_name_leafdata())
                                                if (self.modified.is_set or self.modified.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.modified.get_name_leafdata())
                                                if (self.reachable.is_set or self.reachable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.reachable.get_name_leafdata())
                                                if (self.touched.is_set or self.touched.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.touched.get_name_leafdata())
                                                if (self.unreachable.is_set or self.unreachable.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.unreachable.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "added" or name == "deleted" or name == "modified" or name == "reachable" or name == "touched" or name == "unreachable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "added"):
                                                    self.added = value
                                                    self.added.value_namespace = name_space
                                                    self.added.value_namespace_prefix = name_space_prefix
                                                if(value_path == "deleted"):
                                                    self.deleted = value
                                                    self.deleted.value_namespace = name_space
                                                    self.deleted.value_namespace_prefix = name_space_prefix
                                                if(value_path == "modified"):
                                                    self.modified = value
                                                    self.modified.value_namespace = name_space
                                                    self.modified.value_namespace_prefix = name_space_prefix
                                                if(value_path == "reachable"):
                                                    self.reachable = value
                                                    self.reachable.value_namespace = name_space
                                                    self.reachable.value_namespace_prefix = name_space_prefix
                                                if(value_path == "touched"):
                                                    self.touched = value
                                                    self.touched.value_namespace = name_space
                                                    self.touched.value_namespace_prefix = name_space_prefix
                                                if(value_path == "unreachable"):
                                                    self.unreachable = value
                                                    self.unreachable.value_namespace = name_space
                                                    self.unreachable.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.duration is not None and self.duration.has_data()) or
                                                (self.node_counts is not None and self.node_counts.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.duration is not None and self.duration.has_operation()) or
                                                (self.node_counts is not None and self.node_counts.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "spt-calculation-statistics" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "duration"):
                                                if (self.duration is None):
                                                    self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration()
                                                    self.duration.parent = self
                                                    self._children_name_map["duration"] = "duration"
                                                return self.duration

                                            if (child_yang_name == "node-counts"):
                                                if (self.node_counts is None):
                                                    self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts()
                                                    self.node_counts.parent = self
                                                    self._children_name_map["node_counts"] = "node-counts"
                                                return self.node_counts

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "duration" or name == "node-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class RouteUpdateStatistics(Entity):
                                        """
                                        Statistics for the route update phase
                                        
                                        .. attribute:: duration
                                        
                                        	Duration of the routing table update
                                        	**type**\:   :py:class:`Duration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration>`
                                        
                                        .. attribute:: duration_breakdown
                                        
                                        	Breakdown of the time taken by the routing table update
                                        	**type**\:   :py:class:`DurationBreakdown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown>`
                                        
                                        .. attribute:: item_counts
                                        
                                        	Prefix item counts
                                        	**type**\:   :py:class:`ItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts>`
                                        
                                        .. attribute:: node_counts
                                        
                                        	Node counts
                                        	**type**\:   :py:class:`NodeCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts>`
                                        
                                        .. attribute:: rib_batch_counts
                                        
                                        	Number of RIB batches sent
                                        	**type**\:   :py:class:`RibBatchCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts>`
                                        
                                        .. attribute:: route_counts
                                        
                                        	Distinct prefix counts
                                        	**type**\:   :py:class:`RouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics, self).__init__()

                                            self.yang_name = "route-update-statistics"
                                            self.yang_parent_name = "log-entry"

                                            self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration()
                                            self.duration.parent = self
                                            self._children_name_map["duration"] = "duration"
                                            self._children_yang_names.add("duration")

                                            self.duration_breakdown = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown()
                                            self.duration_breakdown.parent = self
                                            self._children_name_map["duration_breakdown"] = "duration-breakdown"
                                            self._children_yang_names.add("duration-breakdown")

                                            self.item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts()
                                            self.item_counts.parent = self
                                            self._children_name_map["item_counts"] = "item-counts"
                                            self._children_yang_names.add("item-counts")

                                            self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts()
                                            self.node_counts.parent = self
                                            self._children_name_map["node_counts"] = "node-counts"
                                            self._children_yang_names.add("node-counts")

                                            self.rib_batch_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts()
                                            self.rib_batch_counts.parent = self
                                            self._children_name_map["rib_batch_counts"] = "rib-batch-counts"
                                            self._children_yang_names.add("rib-batch-counts")

                                            self.route_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts()
                                            self.route_counts.parent = self
                                            self._children_name_map["route_counts"] = "route-counts"
                                            self._children_yang_names.add("route-counts")


                                        class Duration(Entity):
                                            """
                                            Duration of the routing table update
                                            
                                            .. attribute:: cpu_duration
                                            
                                            	CPU time duration in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: real_duration
                                            
                                            	Real time duration in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration, self).__init__()

                                                self.yang_name = "duration"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                self.real_duration = YLeaf(YType.uint32, "real-duration")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("cpu_duration",
                                                                "real_duration") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.cpu_duration.is_set or
                                                    self.real_duration.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.cpu_duration.yfilter != YFilter.not_set or
                                                    self.real_duration.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "duration" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "cpu-duration" or name == "real-duration"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "cpu-duration"):
                                                    self.cpu_duration = value
                                                    self.cpu_duration.value_namespace = name_space
                                                    self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                if(value_path == "real-duration"):
                                                    self.real_duration = value
                                                    self.real_duration.value_namespace = name_space
                                                    self.real_duration.value_namespace_prefix = name_space_prefix


                                        class DurationBreakdown(Entity):
                                            """
                                            Breakdown of the time taken by the routing table
                                            update
                                            
                                            .. attribute:: global_rib_build
                                            
                                            	Time to build the update to send to the global RIB
                                            	**type**\:   :py:class:`GlobalRibBuild <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild>`
                                            
                                            .. attribute:: global_rib_send
                                            
                                            	Time to send the update to the global RIB
                                            	**type**\:   :py:class:`GlobalRibSend <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend>`
                                            
                                            .. attribute:: local_rib_update
                                            
                                            	Time to update IS\-IS's local RIB
                                            	**type**\:   :py:class:`LocalRibUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown, self).__init__()

                                                self.yang_name = "duration-breakdown"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.global_rib_build = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild()
                                                self.global_rib_build.parent = self
                                                self._children_name_map["global_rib_build"] = "global-rib-build"
                                                self._children_yang_names.add("global-rib-build")

                                                self.global_rib_send = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend()
                                                self.global_rib_send.parent = self
                                                self._children_name_map["global_rib_send"] = "global-rib-send"
                                                self._children_yang_names.add("global-rib-send")

                                                self.local_rib_update = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate()
                                                self.local_rib_update.parent = self
                                                self._children_name_map["local_rib_update"] = "local-rib-update"
                                                self._children_yang_names.add("local-rib-update")


                                            class LocalRibUpdate(Entity):
                                                """
                                                Time to update IS\-IS's local RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:   :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:   :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:   :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:   :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate, self).__init__()

                                                    self.yang_name = "local-rib-update"
                                                    self.yang_parent_name = "duration-breakdown"

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"
                                                    self._children_yang_names.add("critical")

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"
                                                    self._children_yang_names.add("high")

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._children_yang_names.add("low")

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"
                                                    self._children_yang_names.add("medium")


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "local-rib-update"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "critical" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "local-rib-update"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "high" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "local-rib-update"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "medium" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "local-rib-update"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "low" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.critical is not None and self.critical.has_data()) or
                                                        (self.high is not None and self.high.has_data()) or
                                                        (self.low is not None and self.low.has_data()) or
                                                        (self.medium is not None and self.medium.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.critical is not None and self.critical.has_operation()) or
                                                        (self.high is not None and self.high.has_operation()) or
                                                        (self.low is not None and self.low.has_operation()) or
                                                        (self.medium is not None and self.medium.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "local-rib-update" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "critical"):
                                                        if (self.critical is None):
                                                            self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical()
                                                            self.critical.parent = self
                                                            self._children_name_map["critical"] = "critical"
                                                        return self.critical

                                                    if (child_yang_name == "high"):
                                                        if (self.high is None):
                                                            self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High()
                                                            self.high.parent = self
                                                            self._children_name_map["high"] = "high"
                                                        return self.high

                                                    if (child_yang_name == "low"):
                                                        if (self.low is None):
                                                            self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low()
                                                            self.low.parent = self
                                                            self._children_name_map["low"] = "low"
                                                        return self.low

                                                    if (child_yang_name == "medium"):
                                                        if (self.medium is None):
                                                            self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium()
                                                            self.medium.parent = self
                                                            self._children_name_map["medium"] = "medium"
                                                        return self.medium

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class GlobalRibBuild(Entity):
                                                """
                                                Time to build the update to send to the global
                                                RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:   :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:   :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:   :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:   :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild, self).__init__()

                                                    self.yang_name = "global-rib-build"
                                                    self.yang_parent_name = "duration-breakdown"

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"
                                                    self._children_yang_names.add("critical")

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"
                                                    self._children_yang_names.add("high")

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._children_yang_names.add("low")

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"
                                                    self._children_yang_names.add("medium")


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "global-rib-build"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "critical" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "global-rib-build"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "high" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "global-rib-build"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "medium" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "global-rib-build"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "low" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.critical is not None and self.critical.has_data()) or
                                                        (self.high is not None and self.high.has_data()) or
                                                        (self.low is not None and self.low.has_data()) or
                                                        (self.medium is not None and self.medium.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.critical is not None and self.critical.has_operation()) or
                                                        (self.high is not None and self.high.has_operation()) or
                                                        (self.low is not None and self.low.has_operation()) or
                                                        (self.medium is not None and self.medium.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "global-rib-build" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "critical"):
                                                        if (self.critical is None):
                                                            self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical()
                                                            self.critical.parent = self
                                                            self._children_name_map["critical"] = "critical"
                                                        return self.critical

                                                    if (child_yang_name == "high"):
                                                        if (self.high is None):
                                                            self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High()
                                                            self.high.parent = self
                                                            self._children_name_map["high"] = "high"
                                                        return self.high

                                                    if (child_yang_name == "low"):
                                                        if (self.low is None):
                                                            self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low()
                                                            self.low.parent = self
                                                            self._children_name_map["low"] = "low"
                                                        return self.low

                                                    if (child_yang_name == "medium"):
                                                        if (self.medium is None):
                                                            self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium()
                                                            self.medium.parent = self
                                                            self._children_name_map["medium"] = "medium"
                                                        return self.medium

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass


                                            class GlobalRibSend(Entity):
                                                """
                                                Time to send the update to the global RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:   :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:   :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:   :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:   :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend, self).__init__()

                                                    self.yang_name = "global-rib-send"
                                                    self.yang_parent_name = "duration-breakdown"

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"
                                                    self._children_yang_names.add("critical")

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"
                                                    self._children_yang_names.add("high")

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._children_yang_names.add("low")

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"
                                                    self._children_yang_names.add("medium")


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "global-rib-send"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "critical" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "global-rib-send"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "high" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "global-rib-send"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "medium" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "global-rib-send"

                                                        self.cpu_duration = YLeaf(YType.uint32, "cpu-duration")

                                                        self.real_duration = YLeaf(YType.uint32, "real-duration")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("cpu_duration",
                                                                        "real_duration") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.cpu_duration.is_set or
                                                            self.real_duration.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.cpu_duration.yfilter != YFilter.not_set or
                                                            self.real_duration.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "low" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.cpu_duration.is_set or self.cpu_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.cpu_duration.get_name_leafdata())
                                                        if (self.real_duration.is_set or self.real_duration.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.real_duration.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "cpu-duration" or name == "real-duration"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "cpu-duration"):
                                                            self.cpu_duration = value
                                                            self.cpu_duration.value_namespace = name_space
                                                            self.cpu_duration.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "real-duration"):
                                                            self.real_duration = value
                                                            self.real_duration.value_namespace = name_space
                                                            self.real_duration.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        (self.critical is not None and self.critical.has_data()) or
                                                        (self.high is not None and self.high.has_data()) or
                                                        (self.low is not None and self.low.has_data()) or
                                                        (self.medium is not None and self.medium.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        (self.critical is not None and self.critical.has_operation()) or
                                                        (self.high is not None and self.high.has_operation()) or
                                                        (self.low is not None and self.low.has_operation()) or
                                                        (self.medium is not None and self.medium.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "global-rib-send" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "critical"):
                                                        if (self.critical is None):
                                                            self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical()
                                                            self.critical.parent = self
                                                            self._children_name_map["critical"] = "critical"
                                                        return self.critical

                                                    if (child_yang_name == "high"):
                                                        if (self.high is None):
                                                            self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High()
                                                            self.high.parent = self
                                                            self._children_name_map["high"] = "high"
                                                        return self.high

                                                    if (child_yang_name == "low"):
                                                        if (self.low is None):
                                                            self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low()
                                                            self.low.parent = self
                                                            self._children_name_map["low"] = "low"
                                                        return self.low

                                                    if (child_yang_name == "medium"):
                                                        if (self.medium is None):
                                                            self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium()
                                                            self.medium.parent = self
                                                            self._children_name_map["medium"] = "medium"
                                                        return self.medium

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    pass

                                            def has_data(self):
                                                return (
                                                    (self.global_rib_build is not None and self.global_rib_build.has_data()) or
                                                    (self.global_rib_send is not None and self.global_rib_send.has_data()) or
                                                    (self.local_rib_update is not None and self.local_rib_update.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.global_rib_build is not None and self.global_rib_build.has_operation()) or
                                                    (self.global_rib_send is not None and self.global_rib_send.has_operation()) or
                                                    (self.local_rib_update is not None and self.local_rib_update.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "duration-breakdown" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "global-rib-build"):
                                                    if (self.global_rib_build is None):
                                                        self.global_rib_build = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild()
                                                        self.global_rib_build.parent = self
                                                        self._children_name_map["global_rib_build"] = "global-rib-build"
                                                    return self.global_rib_build

                                                if (child_yang_name == "global-rib-send"):
                                                    if (self.global_rib_send is None):
                                                        self.global_rib_send = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend()
                                                        self.global_rib_send.parent = self
                                                        self._children_name_map["global_rib_send"] = "global-rib-send"
                                                    return self.global_rib_send

                                                if (child_yang_name == "local-rib-update"):
                                                    if (self.local_rib_update is None):
                                                        self.local_rib_update = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate()
                                                        self.local_rib_update.parent = self
                                                        self._children_name_map["local_rib_update"] = "local-rib-update"
                                                    return self.local_rib_update

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "global-rib-build" or name == "global-rib-send" or name == "local-rib-update"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class NodeCounts(Entity):
                                            """
                                            Node counts
                                            
                                            .. attribute:: per_priority_touched
                                            
                                            	Per\-priority count of nodes considered during route update
                                            	**type**\:   :py:class:`PerPriorityTouched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched>`
                                            
                                            .. attribute:: total_touched
                                            
                                            	Total number of nodes considered during route update
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts, self).__init__()

                                                self.yang_name = "node-counts"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.total_touched = YLeaf(YType.uint32, "total-touched")

                                                self.per_priority_touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched()
                                                self.per_priority_touched.parent = self
                                                self._children_name_map["per_priority_touched"] = "per-priority-touched"
                                                self._children_yang_names.add("per-priority-touched")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("total_touched") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts, self).__setattr__(name, value)


                                            class PerPriorityTouched(Entity):
                                                """
                                                Per\-priority count of nodes considered during
                                                route update
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched, self).__init__()

                                                    self.yang_name = "per-priority-touched"
                                                    self.yang_parent_name = "node-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "per-priority-touched" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.total_touched.is_set or
                                                    (self.per_priority_touched is not None and self.per_priority_touched.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.total_touched.yfilter != YFilter.not_set or
                                                    (self.per_priority_touched is not None and self.per_priority_touched.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "node-counts" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.total_touched.is_set or self.total_touched.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_touched.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "per-priority-touched"):
                                                    if (self.per_priority_touched is None):
                                                        self.per_priority_touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched()
                                                        self.per_priority_touched.parent = self
                                                        self._children_name_map["per_priority_touched"] = "per-priority-touched"
                                                    return self.per_priority_touched

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "per-priority-touched" or name == "total-touched"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "total-touched"):
                                                    self.total_touched = value
                                                    self.total_touched.value_namespace = name_space
                                                    self.total_touched.value_namespace_prefix = name_space_prefix


                                        class ItemCounts(Entity):
                                            """
                                            Prefix item counts
                                            
                                            .. attribute:: added
                                            
                                            	Number of prefixes added during calculation
                                            	**type**\:   :py:class:`Added <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added>`
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of prefixes deleted during calculation
                                            	**type**\:   :py:class:`Deleted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted>`
                                            
                                            .. attribute:: modified
                                            
                                            	Number of prefixes modified, i.e. a first hop and/or metric change
                                            	**type**\:   :py:class:`Modified <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified>`
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable prefixes in the database
                                            	**type**\:   :py:class:`Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable>`
                                            
                                            .. attribute:: touched
                                            
                                            	Number of prefixes considered whilst updating the routing table
                                            	**type**\:   :py:class:`Touched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched>`
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable prefixes in the database
                                            	**type**\:   :py:class:`Unreachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts, self).__init__()

                                                self.yang_name = "item-counts"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added()
                                                self.added.parent = self
                                                self._children_name_map["added"] = "added"
                                                self._children_yang_names.add("added")

                                                self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted()
                                                self.deleted.parent = self
                                                self._children_name_map["deleted"] = "deleted"
                                                self._children_yang_names.add("deleted")

                                                self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified()
                                                self.modified.parent = self
                                                self._children_name_map["modified"] = "modified"
                                                self._children_yang_names.add("modified")

                                                self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable()
                                                self.reachable.parent = self
                                                self._children_name_map["reachable"] = "reachable"
                                                self._children_yang_names.add("reachable")

                                                self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched()
                                                self.touched.parent = self
                                                self._children_name_map["touched"] = "touched"
                                                self._children_yang_names.add("touched")

                                                self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable()
                                                self.unreachable.parent = self
                                                self._children_name_map["unreachable"] = "unreachable"
                                                self._children_yang_names.add("unreachable")


                                            class Unreachable(Entity):
                                                """
                                                Number of unreachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable, self).__init__()

                                                    self.yang_name = "unreachable"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unreachable" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Reachable(Entity):
                                                """
                                                Number of reachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable, self).__init__()

                                                    self.yang_name = "reachable"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "reachable" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Added(Entity):
                                                """
                                                Number of prefixes added during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added, self).__init__()

                                                    self.yang_name = "added"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "added" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Deleted(Entity):
                                                """
                                                Number of prefixes deleted during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted, self).__init__()

                                                    self.yang_name = "deleted"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "deleted" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Modified(Entity):
                                                """
                                                Number of prefixes modified, i.e. a first hop
                                                and/or metric change
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified, self).__init__()

                                                    self.yang_name = "modified"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "modified" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Touched(Entity):
                                                """
                                                Number of prefixes considered whilst updating
                                                the routing table
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched, self).__init__()

                                                    self.yang_name = "touched"
                                                    self.yang_parent_name = "item-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "touched" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.added is not None and self.added.has_data()) or
                                                    (self.deleted is not None and self.deleted.has_data()) or
                                                    (self.modified is not None and self.modified.has_data()) or
                                                    (self.reachable is not None and self.reachable.has_data()) or
                                                    (self.touched is not None and self.touched.has_data()) or
                                                    (self.unreachable is not None and self.unreachable.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.added is not None and self.added.has_operation()) or
                                                    (self.deleted is not None and self.deleted.has_operation()) or
                                                    (self.modified is not None and self.modified.has_operation()) or
                                                    (self.reachable is not None and self.reachable.has_operation()) or
                                                    (self.touched is not None and self.touched.has_operation()) or
                                                    (self.unreachable is not None and self.unreachable.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "item-counts" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "added"):
                                                    if (self.added is None):
                                                        self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added()
                                                        self.added.parent = self
                                                        self._children_name_map["added"] = "added"
                                                    return self.added

                                                if (child_yang_name == "deleted"):
                                                    if (self.deleted is None):
                                                        self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted()
                                                        self.deleted.parent = self
                                                        self._children_name_map["deleted"] = "deleted"
                                                    return self.deleted

                                                if (child_yang_name == "modified"):
                                                    if (self.modified is None):
                                                        self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified()
                                                        self.modified.parent = self
                                                        self._children_name_map["modified"] = "modified"
                                                    return self.modified

                                                if (child_yang_name == "reachable"):
                                                    if (self.reachable is None):
                                                        self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable()
                                                        self.reachable.parent = self
                                                        self._children_name_map["reachable"] = "reachable"
                                                    return self.reachable

                                                if (child_yang_name == "touched"):
                                                    if (self.touched is None):
                                                        self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched()
                                                        self.touched.parent = self
                                                        self._children_name_map["touched"] = "touched"
                                                    return self.touched

                                                if (child_yang_name == "unreachable"):
                                                    if (self.unreachable is None):
                                                        self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable()
                                                        self.unreachable.parent = self
                                                        self._children_name_map["unreachable"] = "unreachable"
                                                    return self.unreachable

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "added" or name == "deleted" or name == "modified" or name == "reachable" or name == "touched" or name == "unreachable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class RouteCounts(Entity):
                                            """
                                            Distinct prefix counts
                                            
                                            .. attribute:: added
                                            
                                            	Number of prefixes added during calculation
                                            	**type**\:   :py:class:`Added <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added>`
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of prefixes deleted during calculation
                                            	**type**\:   :py:class:`Deleted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted>`
                                            
                                            .. attribute:: modified
                                            
                                            	Number of prefixes modified, i.e. a first hop and/or metric change
                                            	**type**\:   :py:class:`Modified <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified>`
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable prefixes in the database
                                            	**type**\:   :py:class:`Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable>`
                                            
                                            .. attribute:: touched
                                            
                                            	Number of prefixes considered whilst updating the routing table
                                            	**type**\:   :py:class:`Touched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched>`
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable prefixes in the database
                                            	**type**\:   :py:class:`Unreachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts, self).__init__()

                                                self.yang_name = "route-counts"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added()
                                                self.added.parent = self
                                                self._children_name_map["added"] = "added"
                                                self._children_yang_names.add("added")

                                                self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted()
                                                self.deleted.parent = self
                                                self._children_name_map["deleted"] = "deleted"
                                                self._children_yang_names.add("deleted")

                                                self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified()
                                                self.modified.parent = self
                                                self._children_name_map["modified"] = "modified"
                                                self._children_yang_names.add("modified")

                                                self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable()
                                                self.reachable.parent = self
                                                self._children_name_map["reachable"] = "reachable"
                                                self._children_yang_names.add("reachable")

                                                self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched()
                                                self.touched.parent = self
                                                self._children_name_map["touched"] = "touched"
                                                self._children_yang_names.add("touched")

                                                self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable()
                                                self.unreachable.parent = self
                                                self._children_name_map["unreachable"] = "unreachable"
                                                self._children_yang_names.add("unreachable")


                                            class Unreachable(Entity):
                                                """
                                                Number of unreachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable, self).__init__()

                                                    self.yang_name = "unreachable"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unreachable" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Reachable(Entity):
                                                """
                                                Number of reachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable, self).__init__()

                                                    self.yang_name = "reachable"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "reachable" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Added(Entity):
                                                """
                                                Number of prefixes added during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added, self).__init__()

                                                    self.yang_name = "added"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "added" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Deleted(Entity):
                                                """
                                                Number of prefixes deleted during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted, self).__init__()

                                                    self.yang_name = "deleted"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "deleted" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Modified(Entity):
                                                """
                                                Number of prefixes modified, i.e. a first hop
                                                and/or metric change
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified, self).__init__()

                                                    self.yang_name = "modified"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "modified" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix


                                            class Touched(Entity):
                                                """
                                                Number of prefixes considered whilst updating
                                                the routing table
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched, self).__init__()

                                                    self.yang_name = "touched"
                                                    self.yang_parent_name = "route-counts"

                                                    self.critical = YLeaf(YType.uint32, "critical")

                                                    self.high = YLeaf(YType.uint32, "high")

                                                    self.low = YLeaf(YType.uint32, "low")

                                                    self.medium = YLeaf(YType.uint32, "medium")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("critical",
                                                                    "high",
                                                                    "low",
                                                                    "medium") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.critical.is_set or
                                                        self.high.is_set or
                                                        self.low.is_set or
                                                        self.medium.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.critical.yfilter != YFilter.not_set or
                                                        self.high.yfilter != YFilter.not_set or
                                                        self.low.yfilter != YFilter.not_set or
                                                        self.medium.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "touched" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.critical.get_name_leafdata())
                                                    if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.high.get_name_leafdata())
                                                    if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.low.get_name_leafdata())
                                                    if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.medium.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "critical"):
                                                        self.critical = value
                                                        self.critical.value_namespace = name_space
                                                        self.critical.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "high"):
                                                        self.high = value
                                                        self.high.value_namespace = name_space
                                                        self.high.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "low"):
                                                        self.low = value
                                                        self.low.value_namespace = name_space
                                                        self.low.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "medium"):
                                                        self.medium = value
                                                        self.medium.value_namespace = name_space
                                                        self.medium.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    (self.added is not None and self.added.has_data()) or
                                                    (self.deleted is not None and self.deleted.has_data()) or
                                                    (self.modified is not None and self.modified.has_data()) or
                                                    (self.reachable is not None and self.reachable.has_data()) or
                                                    (self.touched is not None and self.touched.has_data()) or
                                                    (self.unreachable is not None and self.unreachable.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.added is not None and self.added.has_operation()) or
                                                    (self.deleted is not None and self.deleted.has_operation()) or
                                                    (self.modified is not None and self.modified.has_operation()) or
                                                    (self.reachable is not None and self.reachable.has_operation()) or
                                                    (self.touched is not None and self.touched.has_operation()) or
                                                    (self.unreachable is not None and self.unreachable.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "route-counts" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "added"):
                                                    if (self.added is None):
                                                        self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added()
                                                        self.added.parent = self
                                                        self._children_name_map["added"] = "added"
                                                    return self.added

                                                if (child_yang_name == "deleted"):
                                                    if (self.deleted is None):
                                                        self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted()
                                                        self.deleted.parent = self
                                                        self._children_name_map["deleted"] = "deleted"
                                                    return self.deleted

                                                if (child_yang_name == "modified"):
                                                    if (self.modified is None):
                                                        self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified()
                                                        self.modified.parent = self
                                                        self._children_name_map["modified"] = "modified"
                                                    return self.modified

                                                if (child_yang_name == "reachable"):
                                                    if (self.reachable is None):
                                                        self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable()
                                                        self.reachable.parent = self
                                                        self._children_name_map["reachable"] = "reachable"
                                                    return self.reachable

                                                if (child_yang_name == "touched"):
                                                    if (self.touched is None):
                                                        self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched()
                                                        self.touched.parent = self
                                                        self._children_name_map["touched"] = "touched"
                                                    return self.touched

                                                if (child_yang_name == "unreachable"):
                                                    if (self.unreachable is None):
                                                        self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable()
                                                        self.unreachable.parent = self
                                                        self._children_name_map["unreachable"] = "unreachable"
                                                    return self.unreachable

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "added" or name == "deleted" or name == "modified" or name == "reachable" or name == "touched" or name == "unreachable"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass


                                        class RibBatchCounts(Entity):
                                            """
                                            Number of RIB batches sent
                                            
                                            .. attribute:: critical
                                            
                                            	Critical priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high
                                            
                                            	High priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low
                                            
                                            	Low priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: medium
                                            
                                            	Medium priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts, self).__init__()

                                                self.yang_name = "rib-batch-counts"
                                                self.yang_parent_name = "route-update-statistics"

                                                self.critical = YLeaf(YType.uint32, "critical")

                                                self.high = YLeaf(YType.uint32, "high")

                                                self.low = YLeaf(YType.uint32, "low")

                                                self.medium = YLeaf(YType.uint32, "medium")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("critical",
                                                                "high",
                                                                "low",
                                                                "medium") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.critical.is_set or
                                                    self.high.is_set or
                                                    self.low.is_set or
                                                    self.medium.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.critical.yfilter != YFilter.not_set or
                                                    self.high.yfilter != YFilter.not_set or
                                                    self.low.yfilter != YFilter.not_set or
                                                    self.medium.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "rib-batch-counts" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.critical.get_name_leafdata())
                                                if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.high.get_name_leafdata())
                                                if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.low.get_name_leafdata())
                                                if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.medium.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "critical"):
                                                    self.critical = value
                                                    self.critical.value_namespace = name_space
                                                    self.critical.value_namespace_prefix = name_space_prefix
                                                if(value_path == "high"):
                                                    self.high = value
                                                    self.high.value_namespace = name_space
                                                    self.high.value_namespace_prefix = name_space_prefix
                                                if(value_path == "low"):
                                                    self.low = value
                                                    self.low.value_namespace = name_space
                                                    self.low.value_namespace_prefix = name_space_prefix
                                                if(value_path == "medium"):
                                                    self.medium = value
                                                    self.medium.value_namespace = name_space
                                                    self.medium.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.duration is not None and self.duration.has_data()) or
                                                (self.duration_breakdown is not None and self.duration_breakdown.has_data()) or
                                                (self.item_counts is not None and self.item_counts.has_data()) or
                                                (self.node_counts is not None and self.node_counts.has_data()) or
                                                (self.rib_batch_counts is not None and self.rib_batch_counts.has_data()) or
                                                (self.route_counts is not None and self.route_counts.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.duration is not None and self.duration.has_operation()) or
                                                (self.duration_breakdown is not None and self.duration_breakdown.has_operation()) or
                                                (self.item_counts is not None and self.item_counts.has_operation()) or
                                                (self.node_counts is not None and self.node_counts.has_operation()) or
                                                (self.rib_batch_counts is not None and self.rib_batch_counts.has_operation()) or
                                                (self.route_counts is not None and self.route_counts.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "route-update-statistics" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "duration"):
                                                if (self.duration is None):
                                                    self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration()
                                                    self.duration.parent = self
                                                    self._children_name_map["duration"] = "duration"
                                                return self.duration

                                            if (child_yang_name == "duration-breakdown"):
                                                if (self.duration_breakdown is None):
                                                    self.duration_breakdown = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown()
                                                    self.duration_breakdown.parent = self
                                                    self._children_name_map["duration_breakdown"] = "duration-breakdown"
                                                return self.duration_breakdown

                                            if (child_yang_name == "item-counts"):
                                                if (self.item_counts is None):
                                                    self.item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts()
                                                    self.item_counts.parent = self
                                                    self._children_name_map["item_counts"] = "item-counts"
                                                return self.item_counts

                                            if (child_yang_name == "node-counts"):
                                                if (self.node_counts is None):
                                                    self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts()
                                                    self.node_counts.parent = self
                                                    self._children_name_map["node_counts"] = "node-counts"
                                                return self.node_counts

                                            if (child_yang_name == "rib-batch-counts"):
                                                if (self.rib_batch_counts is None):
                                                    self.rib_batch_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts()
                                                    self.rib_batch_counts.parent = self
                                                    self._children_name_map["rib_batch_counts"] = "rib-batch-counts"
                                                return self.rib_batch_counts

                                            if (child_yang_name == "route-counts"):
                                                if (self.route_counts is None):
                                                    self.route_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts()
                                                    self.route_counts.parent = self
                                                    self._children_name_map["route_counts"] = "route-counts"
                                                return self.route_counts

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "duration" or name == "duration-breakdown" or name == "item-counts" or name == "node-counts" or name == "rib-batch-counts" or name == "route-counts"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.class_.is_set or
                                            self.next_wait_interval.is_set or
                                            self.updated_lsp_count.is_set or
                                            self.wait_enforced.is_set or
                                            (self.generic_data is not None and self.generic_data.has_data()) or
                                            (self.route_update_statistics is not None and self.route_update_statistics.has_data()) or
                                            (self.spt_calculation_statistics is not None and self.spt_calculation_statistics.has_data()) or
                                            (self.triggers is not None and self.triggers.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.class_.yfilter != YFilter.not_set or
                                            self.next_wait_interval.yfilter != YFilter.not_set or
                                            self.updated_lsp_count.yfilter != YFilter.not_set or
                                            self.wait_enforced.yfilter != YFilter.not_set or
                                            (self.generic_data is not None and self.generic_data.has_operation()) or
                                            (self.route_update_statistics is not None and self.route_update_statistics.has_operation()) or
                                            (self.spt_calculation_statistics is not None and self.spt_calculation_statistics.has_operation()) or
                                            (self.triggers is not None and self.triggers.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "log-entry" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.class_.is_set or self.class_.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.class_.get_name_leafdata())
                                        if (self.next_wait_interval.is_set or self.next_wait_interval.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.next_wait_interval.get_name_leafdata())
                                        if (self.updated_lsp_count.is_set or self.updated_lsp_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.updated_lsp_count.get_name_leafdata())
                                        if (self.wait_enforced.is_set or self.wait_enforced.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.wait_enforced.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "generic-data"):
                                            if (self.generic_data is None):
                                                self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData()
                                                self.generic_data.parent = self
                                                self._children_name_map["generic_data"] = "generic-data"
                                            return self.generic_data

                                        if (child_yang_name == "route-update-statistics"):
                                            if (self.route_update_statistics is None):
                                                self.route_update_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics()
                                                self.route_update_statistics.parent = self
                                                self._children_name_map["route_update_statistics"] = "route-update-statistics"
                                            return self.route_update_statistics

                                        if (child_yang_name == "spt-calculation-statistics"):
                                            if (self.spt_calculation_statistics is None):
                                                self.spt_calculation_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics()
                                                self.spt_calculation_statistics.parent = self
                                                self._children_name_map["spt_calculation_statistics"] = "spt-calculation-statistics"
                                            return self.spt_calculation_statistics

                                        if (child_yang_name == "triggers"):
                                            if (self.triggers is None):
                                                self.triggers = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers()
                                                self.triggers.parent = self
                                                self._children_name_map["triggers"] = "triggers"
                                            return self.triggers

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "generic-data" or name == "route-update-statistics" or name == "spt-calculation-statistics" or name == "triggers" or name == "class" or name == "next-wait-interval" or name == "updated-lsp-count" or name == "wait-enforced"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "class"):
                                            self.class_ = value
                                            self.class_.value_namespace = name_space
                                            self.class_.value_namespace_prefix = name_space_prefix
                                        if(value_path == "next-wait-interval"):
                                            self.next_wait_interval = value
                                            self.next_wait_interval.value_namespace = name_space
                                            self.next_wait_interval.value_namespace_prefix = name_space_prefix
                                        if(value_path == "updated-lsp-count"):
                                            self.updated_lsp_count = value
                                            self.updated_lsp_count.value_namespace = name_space
                                            self.updated_lsp_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "wait-enforced"):
                                            self.wait_enforced = value
                                            self.wait_enforced.value_namespace = name_space
                                            self.wait_enforced.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.log_entry:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.log_entry:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "spf-log" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "log-entry"):
                                        for c in self.log_entry:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.log_entry.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "log-entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class TeTunnels(Entity):
                                """
                                TE tunnels table. Only available within
                                the IPv4 Unicast topology.
                                
                                .. attribute:: te_tunnel
                                
                                	A single TE tunnel advertized by IS\-IS
                                	**type**\: list of    :py:class:`TeTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels, self).__init__()

                                    self.yang_name = "te-tunnels"
                                    self.yang_parent_name = "topology-level"

                                    self.te_tunnel = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels, self).__setattr__(name, value)


                                class TeTunnel(Entity):
                                    """
                                    A single TE tunnel advertized by IS\-IS
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: system_id
                                    
                                    	System ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: te_bandwidth
                                    
                                    	Tunnel bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_checkpoint_object_id
                                    
                                    	Tunnel checkpoint object ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_interface
                                    
                                    	Tunnel interface
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: te_mode_type
                                    
                                    	Tunnel metric mode
                                    	**type**\:   :py:class:`IsisMetricMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricMode>`
                                    
                                    .. attribute:: te_next_hop_ip_address
                                    
                                    	Tunnel next\-hop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_segment_routing_enabled
                                    
                                    	Indicates whether MPLS TE segment routing is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_segment_routing_exclude
                                    
                                    	Indicates whether Segment routing labeled traffic exclusion is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_segment_routing_strict_spf
                                    
                                    	Indicates whether MPLS TE segment routing strict SPF is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: te_system_id
                                    
                                    	Destination system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: teigp_metric
                                    
                                    	Tunnel metric
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: teipv4aa_enabled
                                    
                                    	Indicates whether MPLS TE IPv4 autoroute announce is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: teipv4fa_enabled
                                    
                                    	Indicates whether MPLS TE IPv4 forwarding adjacency is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: teipv6aa_enabled
                                    
                                    	Indicates whether MPLS TE IPv6 autoroute announce is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: teipv6fa_enabled
                                    
                                    	Indicates whether MPLS TE IPv6 forwarding adjacency is enabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel, self).__init__()

                                        self.yang_name = "te-tunnel"
                                        self.yang_parent_name = "te-tunnels"

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.system_id = YLeaf(YType.str, "system-id")

                                        self.te_bandwidth = YLeaf(YType.uint32, "te-bandwidth")

                                        self.te_checkpoint_object_id = YLeaf(YType.uint32, "te-checkpoint-object-id")

                                        self.te_interface = YLeaf(YType.str, "te-interface")

                                        self.te_mode_type = YLeaf(YType.enumeration, "te-mode-type")

                                        self.te_next_hop_ip_address = YLeaf(YType.str, "te-next-hop-ip-address")

                                        self.te_segment_routing_enabled = YLeaf(YType.boolean, "te-segment-routing-enabled")

                                        self.te_segment_routing_exclude = YLeaf(YType.boolean, "te-segment-routing-exclude")

                                        self.te_segment_routing_strict_spf = YLeaf(YType.boolean, "te-segment-routing-strict-spf")

                                        self.te_system_id = YLeaf(YType.str, "te-system-id")

                                        self.teigp_metric = YLeaf(YType.int32, "teigp-metric")

                                        self.teipv4aa_enabled = YLeaf(YType.boolean, "teipv4aa-enabled")

                                        self.teipv4fa_enabled = YLeaf(YType.boolean, "teipv4fa-enabled")

                                        self.teipv6aa_enabled = YLeaf(YType.boolean, "teipv6aa-enabled")

                                        self.teipv6fa_enabled = YLeaf(YType.boolean, "teipv6fa-enabled")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("interface_name",
                                                        "system_id",
                                                        "te_bandwidth",
                                                        "te_checkpoint_object_id",
                                                        "te_interface",
                                                        "te_mode_type",
                                                        "te_next_hop_ip_address",
                                                        "te_segment_routing_enabled",
                                                        "te_segment_routing_exclude",
                                                        "te_segment_routing_strict_spf",
                                                        "te_system_id",
                                                        "teigp_metric",
                                                        "teipv4aa_enabled",
                                                        "teipv4fa_enabled",
                                                        "teipv6aa_enabled",
                                                        "teipv6fa_enabled") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.interface_name.is_set or
                                            self.system_id.is_set or
                                            self.te_bandwidth.is_set or
                                            self.te_checkpoint_object_id.is_set or
                                            self.te_interface.is_set or
                                            self.te_mode_type.is_set or
                                            self.te_next_hop_ip_address.is_set or
                                            self.te_segment_routing_enabled.is_set or
                                            self.te_segment_routing_exclude.is_set or
                                            self.te_segment_routing_strict_spf.is_set or
                                            self.te_system_id.is_set or
                                            self.teigp_metric.is_set or
                                            self.teipv4aa_enabled.is_set or
                                            self.teipv4fa_enabled.is_set or
                                            self.teipv6aa_enabled.is_set or
                                            self.teipv6fa_enabled.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.interface_name.yfilter != YFilter.not_set or
                                            self.system_id.yfilter != YFilter.not_set or
                                            self.te_bandwidth.yfilter != YFilter.not_set or
                                            self.te_checkpoint_object_id.yfilter != YFilter.not_set or
                                            self.te_interface.yfilter != YFilter.not_set or
                                            self.te_mode_type.yfilter != YFilter.not_set or
                                            self.te_next_hop_ip_address.yfilter != YFilter.not_set or
                                            self.te_segment_routing_enabled.yfilter != YFilter.not_set or
                                            self.te_segment_routing_exclude.yfilter != YFilter.not_set or
                                            self.te_segment_routing_strict_spf.yfilter != YFilter.not_set or
                                            self.te_system_id.yfilter != YFilter.not_set or
                                            self.teigp_metric.yfilter != YFilter.not_set or
                                            self.teipv4aa_enabled.yfilter != YFilter.not_set or
                                            self.teipv4fa_enabled.yfilter != YFilter.not_set or
                                            self.teipv6aa_enabled.yfilter != YFilter.not_set or
                                            self.teipv6fa_enabled.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "te-tunnel" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_id.get_name_leafdata())
                                        if (self.te_bandwidth.is_set or self.te_bandwidth.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_bandwidth.get_name_leafdata())
                                        if (self.te_checkpoint_object_id.is_set or self.te_checkpoint_object_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_checkpoint_object_id.get_name_leafdata())
                                        if (self.te_interface.is_set or self.te_interface.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_interface.get_name_leafdata())
                                        if (self.te_mode_type.is_set or self.te_mode_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_mode_type.get_name_leafdata())
                                        if (self.te_next_hop_ip_address.is_set or self.te_next_hop_ip_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_next_hop_ip_address.get_name_leafdata())
                                        if (self.te_segment_routing_enabled.is_set or self.te_segment_routing_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_segment_routing_enabled.get_name_leafdata())
                                        if (self.te_segment_routing_exclude.is_set or self.te_segment_routing_exclude.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_segment_routing_exclude.get_name_leafdata())
                                        if (self.te_segment_routing_strict_spf.is_set or self.te_segment_routing_strict_spf.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_segment_routing_strict_spf.get_name_leafdata())
                                        if (self.te_system_id.is_set or self.te_system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.te_system_id.get_name_leafdata())
                                        if (self.teigp_metric.is_set or self.teigp_metric.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.teigp_metric.get_name_leafdata())
                                        if (self.teipv4aa_enabled.is_set or self.teipv4aa_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.teipv4aa_enabled.get_name_leafdata())
                                        if (self.teipv4fa_enabled.is_set or self.teipv4fa_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.teipv4fa_enabled.get_name_leafdata())
                                        if (self.teipv6aa_enabled.is_set or self.teipv6aa_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.teipv6aa_enabled.get_name_leafdata())
                                        if (self.teipv6fa_enabled.is_set or self.teipv6fa_enabled.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.teipv6fa_enabled.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface-name" or name == "system-id" or name == "te-bandwidth" or name == "te-checkpoint-object-id" or name == "te-interface" or name == "te-mode-type" or name == "te-next-hop-ip-address" or name == "te-segment-routing-enabled" or name == "te-segment-routing-exclude" or name == "te-segment-routing-strict-spf" or name == "te-system-id" or name == "teigp-metric" or name == "teipv4aa-enabled" or name == "teipv4fa-enabled" or name == "teipv6aa-enabled" or name == "teipv6fa-enabled"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "interface-name"):
                                            self.interface_name = value
                                            self.interface_name.value_namespace = name_space
                                            self.interface_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "system-id"):
                                            self.system_id = value
                                            self.system_id.value_namespace = name_space
                                            self.system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-bandwidth"):
                                            self.te_bandwidth = value
                                            self.te_bandwidth.value_namespace = name_space
                                            self.te_bandwidth.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-checkpoint-object-id"):
                                            self.te_checkpoint_object_id = value
                                            self.te_checkpoint_object_id.value_namespace = name_space
                                            self.te_checkpoint_object_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-interface"):
                                            self.te_interface = value
                                            self.te_interface.value_namespace = name_space
                                            self.te_interface.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-mode-type"):
                                            self.te_mode_type = value
                                            self.te_mode_type.value_namespace = name_space
                                            self.te_mode_type.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-next-hop-ip-address"):
                                            self.te_next_hop_ip_address = value
                                            self.te_next_hop_ip_address.value_namespace = name_space
                                            self.te_next_hop_ip_address.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-segment-routing-enabled"):
                                            self.te_segment_routing_enabled = value
                                            self.te_segment_routing_enabled.value_namespace = name_space
                                            self.te_segment_routing_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-segment-routing-exclude"):
                                            self.te_segment_routing_exclude = value
                                            self.te_segment_routing_exclude.value_namespace = name_space
                                            self.te_segment_routing_exclude.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-segment-routing-strict-spf"):
                                            self.te_segment_routing_strict_spf = value
                                            self.te_segment_routing_strict_spf.value_namespace = name_space
                                            self.te_segment_routing_strict_spf.value_namespace_prefix = name_space_prefix
                                        if(value_path == "te-system-id"):
                                            self.te_system_id = value
                                            self.te_system_id.value_namespace = name_space
                                            self.te_system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "teigp-metric"):
                                            self.teigp_metric = value
                                            self.teigp_metric.value_namespace = name_space
                                            self.teigp_metric.value_namespace_prefix = name_space_prefix
                                        if(value_path == "teipv4aa-enabled"):
                                            self.teipv4aa_enabled = value
                                            self.teipv4aa_enabled.value_namespace = name_space
                                            self.teipv4aa_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "teipv4fa-enabled"):
                                            self.teipv4fa_enabled = value
                                            self.teipv4fa_enabled.value_namespace = name_space
                                            self.teipv4fa_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "teipv6aa-enabled"):
                                            self.teipv6aa_enabled = value
                                            self.teipv6aa_enabled.value_namespace = name_space
                                            self.teipv6aa_enabled.value_namespace_prefix = name_space_prefix
                                        if(value_path == "teipv6fa-enabled"):
                                            self.teipv6fa_enabled = value
                                            self.teipv6fa_enabled.value_namespace = name_space
                                            self.teipv6fa_enabled.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.te_tunnel:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.te_tunnel:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "te-tunnels" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "te-tunnel"):
                                        for c in self.te_tunnel:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.te_tunnel.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "te-tunnel"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Ipv4LinkTopologies(Entity):
                                """
                                IPv4 IS Topology table
                                
                                .. attribute:: ipv4_link_topology
                                
                                	An IS in an IPv4 Link Topology
                                	**type**\: list of    :py:class:`Ipv4LinkTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies, self).__init__()

                                    self.yang_name = "ipv4-link-topologies"
                                    self.yang_parent_name = "topology-level"

                                    self.ipv4_link_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies, self).__setattr__(name, value)


                                class Ipv4LinkTopology(Entity):
                                    """
                                    An IS in an IPv4 Link Topology
                                    
                                    .. attribute:: system_id  <key>
                                    
                                    	System ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: advertised_prefix_item_counts
                                    
                                    	Per\-priority counts of prefix items advertised by the IS
                                    	**type**\:   :py:class:`AdvertisedPrefixItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts>`
                                    
                                    .. attribute:: is_attached
                                    
                                    	Is the IS attached?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_overloaded
                                    
                                    	Is the IS overloaded?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_participant
                                    
                                    	Does the IS participate in the topology?
                                    	**type**\:  bool
                                    
                                    .. attribute:: reachability_status
                                    
                                    	Is the IS reachable, and, if so, its status within the SPT
                                    	**type**\:   :py:class:`ReachabilityStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology, self).__init__()

                                        self.yang_name = "ipv4-link-topology"
                                        self.yang_parent_name = "ipv4-link-topologies"

                                        self.system_id = YLeaf(YType.str, "system-id")

                                        self.is_attached = YLeaf(YType.boolean, "is-attached")

                                        self.is_overloaded = YLeaf(YType.boolean, "is-overloaded")

                                        self.is_participant = YLeaf(YType.boolean, "is-participant")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts()
                                        self.advertised_prefix_item_counts.parent = self
                                        self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                        self._children_yang_names.add("advertised-prefix-item-counts")

                                        self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus()
                                        self.reachability_status.parent = self
                                        self._children_name_map["reachability_status"] = "reachability-status"
                                        self._children_yang_names.add("reachability-status")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_id",
                                                        "is_attached",
                                                        "is_overloaded",
                                                        "is_participant",
                                                        "source_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology, self).__setattr__(name, value)


                                    class ReachabilityStatus(Entity):
                                        """
                                        Is the IS reachable, and, if so, its status
                                        within the SPT
                                        
                                        .. attribute:: reachable_details
                                        
                                        	Status of the IS within the SPT
                                        	**type**\:   :py:class:`ReachableDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails>`
                                        
                                        .. attribute:: reachable_status
                                        
                                        	ReachableStatus
                                        	**type**\:   :py:class:`IsisReachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisReachable>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus, self).__init__()

                                            self.yang_name = "reachability-status"
                                            self.yang_parent_name = "ipv4-link-topology"

                                            self.reachable_status = YLeaf(YType.enumeration, "reachable-status")

                                            self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails()
                                            self.reachable_details.parent = self
                                            self._children_name_map["reachable_details"] = "reachable-details"
                                            self._children_yang_names.add("reachable-details")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reachable_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus, self).__setattr__(name, value)


                                        class ReachableDetails(Entity):
                                            """
                                            Status of the IS within the SPT
                                            
                                            .. attribute:: children_
                                            
                                            	Children of the IS within the SPT
                                            	**type**\: list of    :py:class:`Children_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children_>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops towards the IS
                                            	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath>`
                                            
                                            .. attribute:: multicast_root_distance
                                            
                                            	Distance to the IS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: parent_
                                            
                                            	Parents of the IS within the SPT
                                            	**type**\: list of    :py:class:`Parent_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent_>`
                                            
                                            .. attribute:: paths
                                            
                                            	First hops towards the IS
                                            	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths>`
                                            
                                            .. attribute:: root_distance
                                            
                                            	Distance to the IS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails, self).__init__()

                                                self.yang_name = "reachable-details"
                                                self.yang_parent_name = "reachability-status"

                                                self.multicast_root_distance = YLeaf(YType.uint32, "multicast-root-distance")

                                                self.root_distance = YLeaf(YType.uint32, "root-distance")

                                                self.children_ = YList(self)
                                                self.multicast_path = YList(self)
                                                self.parent_ = YList(self)
                                                self.paths = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("multicast_root_distance",
                                                                "root_distance") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails, self).__setattr__(name, value)


                                            class Paths(Entity):
                                                """
                                                First hops towards the IS
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup>`
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\:  str
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                    self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._children_yang_names.add("frr-backup")

                                                    self.uloop_explicit = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("egress_interface",
                                                                    "is_sr_exclude_tunnel_interface",
                                                                    "is_te_tunnel_interface",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "segment_routing_sid_value",
                                                                    "tag",
                                                                    "tunnel_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__setattr__(name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"

                                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                        self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                        self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                        self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                        self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                        self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                        self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                        self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                        self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                        self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                        self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                        self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                        self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                        self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                        self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                        self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                        self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                        self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                        self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                        self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                        self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                        self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                        self.weight = YLeaf(YType.uint32, "weight")

                                                        self.backup_repair = YList(self)
                                                        self.segment_routing_sid_value_entry = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("backup_repair_list_size",
                                                                        "egress_interface",
                                                                        "is_downstream",
                                                                        "is_epcfrr_lfa",
                                                                        "is_lc_disjoint",
                                                                        "is_node_protecting",
                                                                        "is_primary_path",
                                                                        "is_remote_lfa",
                                                                        "is_srlg_disjoint",
                                                                        "is_strict_spflfa",
                                                                        "is_tunnel_requested",
                                                                        "neighbor_address",
                                                                        "neighbor_id",
                                                                        "neighbor_snpa",
                                                                        "num_sid",
                                                                        "prefix_source_node_id",
                                                                        "remote_lfa_router_id",
                                                                        "remote_lfa_router_pid",
                                                                        "remote_lfa_system_id",
                                                                        "remote_lfa_system_pid",
                                                                        "segment_routing_sid_value",
                                                                        "tilfa_computation",
                                                                        "total_backup_distance",
                                                                        "tunnel_egress_interface",
                                                                        "weight") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__setattr__(name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                            self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                            self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                            self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("repair_element_node_id",
                                                                            "repair_element_type",
                                                                            "repair_ipv4_addr",
                                                                            "repair_ipv6_addr",
                                                                            "repair_label",
                                                                            "repair_strict_spf_label") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.repair_element_node_id.is_set or
                                                                self.repair_element_type.is_set or
                                                                self.repair_ipv4_addr.is_set or
                                                                self.repair_ipv6_addr.is_set or
                                                                self.repair_label.is_set or
                                                                self.repair_strict_spf_label.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.repair_element_node_id.yfilter != YFilter.not_set or
                                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                                self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                                self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                                self.repair_label.yfilter != YFilter.not_set or
                                                                self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "backup-repair" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                            if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                            if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                            if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "repair-element-node-id"):
                                                                self.repair_element_node_id = value
                                                                self.repair_element_node_id.value_namespace = name_space
                                                                self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-element-type"):
                                                                self.repair_element_type = value
                                                                self.repair_element_type.value_namespace = name_space
                                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv4-addr"):
                                                                self.repair_ipv4_addr = value
                                                                self.repair_ipv4_addr.value_namespace = name_space
                                                                self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv6-addr"):
                                                                self.repair_ipv6_addr = value
                                                                self.repair_ipv6_addr.value_namespace = name_space
                                                                self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-label"):
                                                                self.repair_label = value
                                                                self.repair_label.value_namespace = name_space
                                                                self.repair_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-strict-spf-label"):
                                                                self.repair_strict_spf_label = value
                                                                self.repair_strict_spf_label.value_namespace = name_space
                                                                self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.backup_repair_list_size.is_set or
                                                            self.egress_interface.is_set or
                                                            self.is_downstream.is_set or
                                                            self.is_epcfrr_lfa.is_set or
                                                            self.is_lc_disjoint.is_set or
                                                            self.is_node_protecting.is_set or
                                                            self.is_primary_path.is_set or
                                                            self.is_remote_lfa.is_set or
                                                            self.is_srlg_disjoint.is_set or
                                                            self.is_strict_spflfa.is_set or
                                                            self.is_tunnel_requested.is_set or
                                                            self.neighbor_address.is_set or
                                                            self.neighbor_id.is_set or
                                                            self.neighbor_snpa.is_set or
                                                            self.num_sid.is_set or
                                                            self.prefix_source_node_id.is_set or
                                                            self.remote_lfa_router_id.is_set or
                                                            self.remote_lfa_router_pid.is_set or
                                                            self.remote_lfa_system_id.is_set or
                                                            self.remote_lfa_system_pid.is_set or
                                                            self.segment_routing_sid_value.is_set or
                                                            self.tilfa_computation.is_set or
                                                            self.total_backup_distance.is_set or
                                                            self.tunnel_egress_interface.is_set or
                                                            self.weight.is_set)

                                                    def has_operation(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                            self.egress_interface.yfilter != YFilter.not_set or
                                                            self.is_downstream.yfilter != YFilter.not_set or
                                                            self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                            self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                            self.is_node_protecting.yfilter != YFilter.not_set or
                                                            self.is_primary_path.yfilter != YFilter.not_set or
                                                            self.is_remote_lfa.yfilter != YFilter.not_set or
                                                            self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                            self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                            self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                            self.neighbor_address.yfilter != YFilter.not_set or
                                                            self.neighbor_id.yfilter != YFilter.not_set or
                                                            self.neighbor_snpa.yfilter != YFilter.not_set or
                                                            self.num_sid.yfilter != YFilter.not_set or
                                                            self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                            self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                            self.tilfa_computation.yfilter != YFilter.not_set or
                                                            self.total_backup_distance.yfilter != YFilter.not_set or
                                                            self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                            self.weight.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "frr-backup" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                        if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                        if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                        if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                        if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                        if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                        if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                        if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                        if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                        if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                        if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                        if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                        if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                        if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                        if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                        if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                        if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                        if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                        if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                        if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                        if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.weight.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "backup-repair"):
                                                            for c in self.backup_repair:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.backup_repair.append(c)
                                                            return c

                                                        if (child_yang_name == "segment-routing-sid-value-entry"):
                                                            for c in self.segment_routing_sid_value_entry:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.segment_routing_sid_value_entry.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "backup-repair-list-size"):
                                                            self.backup_repair_list_size = value
                                                            self.backup_repair_list_size.value_namespace = name_space
                                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "egress-interface"):
                                                            self.egress_interface = value
                                                            self.egress_interface.value_namespace = name_space
                                                            self.egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-downstream"):
                                                            self.is_downstream = value
                                                            self.is_downstream.value_namespace = name_space
                                                            self.is_downstream.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-epcfrr-lfa"):
                                                            self.is_epcfrr_lfa = value
                                                            self.is_epcfrr_lfa.value_namespace = name_space
                                                            self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-lc-disjoint"):
                                                            self.is_lc_disjoint = value
                                                            self.is_lc_disjoint.value_namespace = name_space
                                                            self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-node-protecting"):
                                                            self.is_node_protecting = value
                                                            self.is_node_protecting.value_namespace = name_space
                                                            self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-primary-path"):
                                                            self.is_primary_path = value
                                                            self.is_primary_path.value_namespace = name_space
                                                            self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-remote-lfa"):
                                                            self.is_remote_lfa = value
                                                            self.is_remote_lfa.value_namespace = name_space
                                                            self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-srlg-disjoint"):
                                                            self.is_srlg_disjoint = value
                                                            self.is_srlg_disjoint.value_namespace = name_space
                                                            self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-strict-spflfa"):
                                                            self.is_strict_spflfa = value
                                                            self.is_strict_spflfa.value_namespace = name_space
                                                            self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-tunnel-requested"):
                                                            self.is_tunnel_requested = value
                                                            self.is_tunnel_requested.value_namespace = name_space
                                                            self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-address"):
                                                            self.neighbor_address = value
                                                            self.neighbor_address.value_namespace = name_space
                                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-id"):
                                                            self.neighbor_id = value
                                                            self.neighbor_id.value_namespace = name_space
                                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-snpa"):
                                                            self.neighbor_snpa = value
                                                            self.neighbor_snpa.value_namespace = name_space
                                                            self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-sid"):
                                                            self.num_sid = value
                                                            self.num_sid.value_namespace = name_space
                                                            self.num_sid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "prefix-source-node-id"):
                                                            self.prefix_source_node_id = value
                                                            self.prefix_source_node_id.value_namespace = name_space
                                                            self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-id"):
                                                            self.remote_lfa_router_id = value
                                                            self.remote_lfa_router_id.value_namespace = name_space
                                                            self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-pid"):
                                                            self.remote_lfa_router_pid = value
                                                            self.remote_lfa_router_pid.value_namespace = name_space
                                                            self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-id"):
                                                            self.remote_lfa_system_id = value
                                                            self.remote_lfa_system_id.value_namespace = name_space
                                                            self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-pid"):
                                                            self.remote_lfa_system_pid = value
                                                            self.remote_lfa_system_pid.value_namespace = name_space
                                                            self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segment-routing-sid-value"):
                                                            self.segment_routing_sid_value = value
                                                            self.segment_routing_sid_value.value_namespace = name_space
                                                            self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tilfa-computation"):
                                                            self.tilfa_computation = value
                                                            self.tilfa_computation.value_namespace = name_space
                                                            self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "total-backup-distance"):
                                                            self.total_backup_distance = value
                                                            self.total_backup_distance.value_namespace = name_space
                                                            self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-egress-interface"):
                                                            self.tunnel_egress_interface = value
                                                            self.tunnel_egress_interface.value_namespace = name_space
                                                            self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "weight"):
                                                            self.weight = value
                                                            self.weight.value_namespace = name_space
                                                            self.weight.value_namespace_prefix = name_space_prefix


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "uloop-explicit" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.egress_interface.is_set or
                                                        self.is_sr_exclude_tunnel_interface.is_set or
                                                        self.is_te_tunnel_interface.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_interface.is_set or
                                                        self.weight.is_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_data()))

                                                def has_operation(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "paths" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                    if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "frr-backup"):
                                                        if (self.frr_backup is None):
                                                            self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                            self.frr_backup.parent = self
                                                            self._children_name_map["frr_backup"] = "frr-backup"
                                                        return self.frr_backup

                                                    if (child_yang_name == "uloop-explicit"):
                                                        for c in self.uloop_explicit:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.uloop_explicit.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-sr-exclude-tunnel-interface"):
                                                        self.is_sr_exclude_tunnel_interface = value
                                                        self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                        self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-te-tunnel-interface"):
                                                        self.is_te_tunnel_interface = value
                                                        self.is_te_tunnel_interface.value_namespace = name_space
                                                        self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-interface"):
                                                        self.tunnel_interface = value
                                                        self.tunnel_interface.value_namespace = name_space
                                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops towards the IS
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\:  str
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                    self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._children_yang_names.add("frr-backup")

                                                    self.uloop_explicit = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("egress_interface",
                                                                    "is_sr_exclude_tunnel_interface",
                                                                    "is_te_tunnel_interface",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "segment_routing_sid_value",
                                                                    "tag",
                                                                    "tunnel_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__setattr__(name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"

                                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                        self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                        self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                        self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                        self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                        self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                        self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                        self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                        self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                        self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                        self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                        self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                        self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                        self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                        self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                        self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                        self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                        self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                        self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                        self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                        self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                        self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                        self.weight = YLeaf(YType.uint32, "weight")

                                                        self.backup_repair = YList(self)
                                                        self.segment_routing_sid_value_entry = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("backup_repair_list_size",
                                                                        "egress_interface",
                                                                        "is_downstream",
                                                                        "is_epcfrr_lfa",
                                                                        "is_lc_disjoint",
                                                                        "is_node_protecting",
                                                                        "is_primary_path",
                                                                        "is_remote_lfa",
                                                                        "is_srlg_disjoint",
                                                                        "is_strict_spflfa",
                                                                        "is_tunnel_requested",
                                                                        "neighbor_address",
                                                                        "neighbor_id",
                                                                        "neighbor_snpa",
                                                                        "num_sid",
                                                                        "prefix_source_node_id",
                                                                        "remote_lfa_router_id",
                                                                        "remote_lfa_router_pid",
                                                                        "remote_lfa_system_id",
                                                                        "remote_lfa_system_pid",
                                                                        "segment_routing_sid_value",
                                                                        "tilfa_computation",
                                                                        "total_backup_distance",
                                                                        "tunnel_egress_interface",
                                                                        "weight") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                            self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                            self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                            self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("repair_element_node_id",
                                                                            "repair_element_type",
                                                                            "repair_ipv4_addr",
                                                                            "repair_ipv6_addr",
                                                                            "repair_label",
                                                                            "repair_strict_spf_label") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.repair_element_node_id.is_set or
                                                                self.repair_element_type.is_set or
                                                                self.repair_ipv4_addr.is_set or
                                                                self.repair_ipv6_addr.is_set or
                                                                self.repair_label.is_set or
                                                                self.repair_strict_spf_label.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.repair_element_node_id.yfilter != YFilter.not_set or
                                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                                self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                                self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                                self.repair_label.yfilter != YFilter.not_set or
                                                                self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "backup-repair" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                            if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                            if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                            if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "repair-element-node-id"):
                                                                self.repair_element_node_id = value
                                                                self.repair_element_node_id.value_namespace = name_space
                                                                self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-element-type"):
                                                                self.repair_element_type = value
                                                                self.repair_element_type.value_namespace = name_space
                                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv4-addr"):
                                                                self.repair_ipv4_addr = value
                                                                self.repair_ipv4_addr.value_namespace = name_space
                                                                self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv6-addr"):
                                                                self.repair_ipv6_addr = value
                                                                self.repair_ipv6_addr.value_namespace = name_space
                                                                self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-label"):
                                                                self.repair_label = value
                                                                self.repair_label.value_namespace = name_space
                                                                self.repair_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-strict-spf-label"):
                                                                self.repair_strict_spf_label = value
                                                                self.repair_strict_spf_label.value_namespace = name_space
                                                                self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.backup_repair_list_size.is_set or
                                                            self.egress_interface.is_set or
                                                            self.is_downstream.is_set or
                                                            self.is_epcfrr_lfa.is_set or
                                                            self.is_lc_disjoint.is_set or
                                                            self.is_node_protecting.is_set or
                                                            self.is_primary_path.is_set or
                                                            self.is_remote_lfa.is_set or
                                                            self.is_srlg_disjoint.is_set or
                                                            self.is_strict_spflfa.is_set or
                                                            self.is_tunnel_requested.is_set or
                                                            self.neighbor_address.is_set or
                                                            self.neighbor_id.is_set or
                                                            self.neighbor_snpa.is_set or
                                                            self.num_sid.is_set or
                                                            self.prefix_source_node_id.is_set or
                                                            self.remote_lfa_router_id.is_set or
                                                            self.remote_lfa_router_pid.is_set or
                                                            self.remote_lfa_system_id.is_set or
                                                            self.remote_lfa_system_pid.is_set or
                                                            self.segment_routing_sid_value.is_set or
                                                            self.tilfa_computation.is_set or
                                                            self.total_backup_distance.is_set or
                                                            self.tunnel_egress_interface.is_set or
                                                            self.weight.is_set)

                                                    def has_operation(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                            self.egress_interface.yfilter != YFilter.not_set or
                                                            self.is_downstream.yfilter != YFilter.not_set or
                                                            self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                            self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                            self.is_node_protecting.yfilter != YFilter.not_set or
                                                            self.is_primary_path.yfilter != YFilter.not_set or
                                                            self.is_remote_lfa.yfilter != YFilter.not_set or
                                                            self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                            self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                            self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                            self.neighbor_address.yfilter != YFilter.not_set or
                                                            self.neighbor_id.yfilter != YFilter.not_set or
                                                            self.neighbor_snpa.yfilter != YFilter.not_set or
                                                            self.num_sid.yfilter != YFilter.not_set or
                                                            self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                            self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                            self.tilfa_computation.yfilter != YFilter.not_set or
                                                            self.total_backup_distance.yfilter != YFilter.not_set or
                                                            self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                            self.weight.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "frr-backup" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                        if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                        if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                        if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                        if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                        if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                        if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                        if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                        if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                        if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                        if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                        if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                        if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                        if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                        if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                        if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                        if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                        if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                        if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                        if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                        if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.weight.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "backup-repair"):
                                                            for c in self.backup_repair:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.backup_repair.append(c)
                                                            return c

                                                        if (child_yang_name == "segment-routing-sid-value-entry"):
                                                            for c in self.segment_routing_sid_value_entry:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.segment_routing_sid_value_entry.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "backup-repair-list-size"):
                                                            self.backup_repair_list_size = value
                                                            self.backup_repair_list_size.value_namespace = name_space
                                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "egress-interface"):
                                                            self.egress_interface = value
                                                            self.egress_interface.value_namespace = name_space
                                                            self.egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-downstream"):
                                                            self.is_downstream = value
                                                            self.is_downstream.value_namespace = name_space
                                                            self.is_downstream.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-epcfrr-lfa"):
                                                            self.is_epcfrr_lfa = value
                                                            self.is_epcfrr_lfa.value_namespace = name_space
                                                            self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-lc-disjoint"):
                                                            self.is_lc_disjoint = value
                                                            self.is_lc_disjoint.value_namespace = name_space
                                                            self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-node-protecting"):
                                                            self.is_node_protecting = value
                                                            self.is_node_protecting.value_namespace = name_space
                                                            self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-primary-path"):
                                                            self.is_primary_path = value
                                                            self.is_primary_path.value_namespace = name_space
                                                            self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-remote-lfa"):
                                                            self.is_remote_lfa = value
                                                            self.is_remote_lfa.value_namespace = name_space
                                                            self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-srlg-disjoint"):
                                                            self.is_srlg_disjoint = value
                                                            self.is_srlg_disjoint.value_namespace = name_space
                                                            self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-strict-spflfa"):
                                                            self.is_strict_spflfa = value
                                                            self.is_strict_spflfa.value_namespace = name_space
                                                            self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-tunnel-requested"):
                                                            self.is_tunnel_requested = value
                                                            self.is_tunnel_requested.value_namespace = name_space
                                                            self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-address"):
                                                            self.neighbor_address = value
                                                            self.neighbor_address.value_namespace = name_space
                                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-id"):
                                                            self.neighbor_id = value
                                                            self.neighbor_id.value_namespace = name_space
                                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-snpa"):
                                                            self.neighbor_snpa = value
                                                            self.neighbor_snpa.value_namespace = name_space
                                                            self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-sid"):
                                                            self.num_sid = value
                                                            self.num_sid.value_namespace = name_space
                                                            self.num_sid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "prefix-source-node-id"):
                                                            self.prefix_source_node_id = value
                                                            self.prefix_source_node_id.value_namespace = name_space
                                                            self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-id"):
                                                            self.remote_lfa_router_id = value
                                                            self.remote_lfa_router_id.value_namespace = name_space
                                                            self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-pid"):
                                                            self.remote_lfa_router_pid = value
                                                            self.remote_lfa_router_pid.value_namespace = name_space
                                                            self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-id"):
                                                            self.remote_lfa_system_id = value
                                                            self.remote_lfa_system_id.value_namespace = name_space
                                                            self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-pid"):
                                                            self.remote_lfa_system_pid = value
                                                            self.remote_lfa_system_pid.value_namespace = name_space
                                                            self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segment-routing-sid-value"):
                                                            self.segment_routing_sid_value = value
                                                            self.segment_routing_sid_value.value_namespace = name_space
                                                            self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tilfa-computation"):
                                                            self.tilfa_computation = value
                                                            self.tilfa_computation.value_namespace = name_space
                                                            self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "total-backup-distance"):
                                                            self.total_backup_distance = value
                                                            self.total_backup_distance.value_namespace = name_space
                                                            self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-egress-interface"):
                                                            self.tunnel_egress_interface = value
                                                            self.tunnel_egress_interface.value_namespace = name_space
                                                            self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "weight"):
                                                            self.weight = value
                                                            self.weight.value_namespace = name_space
                                                            self.weight.value_namespace_prefix = name_space_prefix


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "uloop-explicit" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.egress_interface.is_set or
                                                        self.is_sr_exclude_tunnel_interface.is_set or
                                                        self.is_te_tunnel_interface.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_interface.is_set or
                                                        self.weight.is_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_data()))

                                                def has_operation(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                    if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "frr-backup"):
                                                        if (self.frr_backup is None):
                                                            self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                            self.frr_backup.parent = self
                                                            self._children_name_map["frr_backup"] = "frr-backup"
                                                        return self.frr_backup

                                                    if (child_yang_name == "uloop-explicit"):
                                                        for c in self.uloop_explicit:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.uloop_explicit.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-sr-exclude-tunnel-interface"):
                                                        self.is_sr_exclude_tunnel_interface = value
                                                        self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                        self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-te-tunnel-interface"):
                                                        self.is_te_tunnel_interface = value
                                                        self.is_te_tunnel_interface.value_namespace = name_space
                                                        self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-interface"):
                                                        self.tunnel_interface = value
                                                        self.tunnel_interface.value_namespace = name_space
                                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class Parent_(Entity):
                                                """
                                                Parents of the IS within the SPT
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__init__()

                                                    self.yang_name = "parent"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.intermediate_pseudonode = YLeaf(YType.str, "intermediate-pseudonode")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("intermediate_pseudonode",
                                                                    "neighbor_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.intermediate_pseudonode.is_set or
                                                        self.neighbor_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.intermediate_pseudonode.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "parent" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.intermediate_pseudonode.is_set or self.intermediate_pseudonode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.intermediate_pseudonode.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "intermediate-pseudonode" or name == "neighbor-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "intermediate-pseudonode"):
                                                        self.intermediate_pseudonode = value
                                                        self.intermediate_pseudonode.value_namespace = name_space
                                                        self.intermediate_pseudonode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix


                                            class Children_(Entity):
                                                """
                                                Children of the IS within the SPT
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__init__()

                                                    self.yang_name = "children"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.intermediate_pseudonode = YLeaf(YType.str, "intermediate-pseudonode")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("intermediate_pseudonode",
                                                                    "neighbor_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.intermediate_pseudonode.is_set or
                                                        self.neighbor_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.intermediate_pseudonode.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "children" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.intermediate_pseudonode.is_set or self.intermediate_pseudonode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.intermediate_pseudonode.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "intermediate-pseudonode" or name == "neighbor-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "intermediate-pseudonode"):
                                                        self.intermediate_pseudonode = value
                                                        self.intermediate_pseudonode.value_namespace = name_space
                                                        self.intermediate_pseudonode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.children_:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.multicast_path:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.parent_:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.paths:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.multicast_root_distance.is_set or
                                                    self.root_distance.is_set)

                                            def has_operation(self):
                                                for c in self.children_:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.multicast_path:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.parent_:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.paths:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.multicast_root_distance.yfilter != YFilter.not_set or
                                                    self.root_distance.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "reachable-details" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.multicast_root_distance.is_set or self.multicast_root_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_root_distance.get_name_leafdata())
                                                if (self.root_distance.is_set or self.root_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.root_distance.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "children"):
                                                    for c in self.children_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.children_.append(c)
                                                    return c

                                                if (child_yang_name == "multicast-path"):
                                                    for c in self.multicast_path:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.multicast_path.append(c)
                                                    return c

                                                if (child_yang_name == "parent"):
                                                    for c in self.parent_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.parent_.append(c)
                                                    return c

                                                if (child_yang_name == "paths"):
                                                    for c in self.paths:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.paths.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "children" or name == "multicast-path" or name == "parent" or name == "paths" or name == "multicast-root-distance" or name == "root-distance"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "multicast-root-distance"):
                                                    self.multicast_root_distance = value
                                                    self.multicast_root_distance.value_namespace = name_space
                                                    self.multicast_root_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "root-distance"):
                                                    self.root_distance = value
                                                    self.root_distance.value_namespace = name_space
                                                    self.root_distance.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.reachable_status.is_set or
                                                (self.reachable_details is not None and self.reachable_details.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reachable_status.yfilter != YFilter.not_set or
                                                (self.reachable_details is not None and self.reachable_details.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "reachability-status" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reachable_status.is_set or self.reachable_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reachable_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "reachable-details"):
                                                if (self.reachable_details is None):
                                                    self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails()
                                                    self.reachable_details.parent = self
                                                    self._children_name_map["reachable_details"] = "reachable-details"
                                                return self.reachable_details

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reachable-details" or name == "reachable-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reachable-status"):
                                                self.reachable_status = value
                                                self.reachable_status.value_namespace = name_space
                                                self.reachable_status.value_namespace_prefix = name_space_prefix


                                    class AdvertisedPrefixItemCounts(Entity):
                                        """
                                        Per\-priority counts of prefix items advertised
                                        by the IS
                                        
                                        .. attribute:: critical
                                        
                                        	Critical priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high
                                        
                                        	High priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low
                                        
                                        	Low priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: medium
                                        
                                        	Medium priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts, self).__init__()

                                            self.yang_name = "advertised-prefix-item-counts"
                                            self.yang_parent_name = "ipv4-link-topology"

                                            self.critical = YLeaf(YType.uint32, "critical")

                                            self.high = YLeaf(YType.uint32, "high")

                                            self.low = YLeaf(YType.uint32, "low")

                                            self.medium = YLeaf(YType.uint32, "medium")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("critical",
                                                            "high",
                                                            "low",
                                                            "medium") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.critical.is_set or
                                                self.high.is_set or
                                                self.low.is_set or
                                                self.medium.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.critical.yfilter != YFilter.not_set or
                                                self.high.yfilter != YFilter.not_set or
                                                self.low.yfilter != YFilter.not_set or
                                                self.medium.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "advertised-prefix-item-counts" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.critical.get_name_leafdata())
                                            if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high.get_name_leafdata())
                                            if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low.get_name_leafdata())
                                            if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.medium.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "critical"):
                                                self.critical = value
                                                self.critical.value_namespace = name_space
                                                self.critical.value_namespace_prefix = name_space_prefix
                                            if(value_path == "high"):
                                                self.high = value
                                                self.high.value_namespace = name_space
                                                self.high.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low"):
                                                self.low = value
                                                self.low.value_namespace = name_space
                                                self.low.value_namespace_prefix = name_space_prefix
                                            if(value_path == "medium"):
                                                self.medium = value
                                                self.medium.value_namespace = name_space
                                                self.medium.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_id.is_set or
                                            self.is_attached.is_set or
                                            self.is_overloaded.is_set or
                                            self.is_participant.is_set or
                                            self.source_address.is_set or
                                            (self.advertised_prefix_item_counts is not None and self.advertised_prefix_item_counts.has_data()) or
                                            (self.reachability_status is not None and self.reachability_status.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_id.yfilter != YFilter.not_set or
                                            self.is_attached.yfilter != YFilter.not_set or
                                            self.is_overloaded.yfilter != YFilter.not_set or
                                            self.is_participant.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            (self.advertised_prefix_item_counts is not None and self.advertised_prefix_item_counts.has_operation()) or
                                            (self.reachability_status is not None and self.reachability_status.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipv4-link-topology" + "[system-id='" + self.system_id.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_id.get_name_leafdata())
                                        if (self.is_attached.is_set or self.is_attached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_attached.get_name_leafdata())
                                        if (self.is_overloaded.is_set or self.is_overloaded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_overloaded.get_name_leafdata())
                                        if (self.is_participant.is_set or self.is_participant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_participant.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "advertised-prefix-item-counts"):
                                            if (self.advertised_prefix_item_counts is None):
                                                self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts()
                                                self.advertised_prefix_item_counts.parent = self
                                                self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                            return self.advertised_prefix_item_counts

                                        if (child_yang_name == "reachability-status"):
                                            if (self.reachability_status is None):
                                                self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus()
                                                self.reachability_status.parent = self
                                                self._children_name_map["reachability_status"] = "reachability-status"
                                            return self.reachability_status

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "advertised-prefix-item-counts" or name == "reachability-status" or name == "system-id" or name == "is-attached" or name == "is-overloaded" or name == "is-participant" or name == "source-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-id"):
                                            self.system_id = value
                                            self.system_id.value_namespace = name_space
                                            self.system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-attached"):
                                            self.is_attached = value
                                            self.is_attached.value_namespace = name_space
                                            self.is_attached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-overloaded"):
                                            self.is_overloaded = value
                                            self.is_overloaded.value_namespace = name_space
                                            self.is_overloaded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-participant"):
                                            self.is_participant = value
                                            self.is_participant.value_namespace = name_space
                                            self.is_participant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ipv4_link_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ipv4_link_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv4-link-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ipv4-link-topology"):
                                        for c in self.ipv4_link_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ipv4_link_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv4-link-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class TopologySummary(Entity):
                                """
                                Summary information for a particular IS
                                Topology
                                
                                .. attribute:: pseudonode_node_count
                                
                                	Node Counts for Pseudonode nodes
                                	**type**\:   :py:class:`PseudonodeNodeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount>`
                                
                                .. attribute:: router_node_count
                                
                                	Node Counts for System nodes
                                	**type**\:   :py:class:`RouterNodeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary, self).__init__()

                                    self.yang_name = "topology-summary"
                                    self.yang_parent_name = "topology-level"

                                    self.pseudonode_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount()
                                    self.pseudonode_node_count.parent = self
                                    self._children_name_map["pseudonode_node_count"] = "pseudonode-node-count"
                                    self._children_yang_names.add("pseudonode-node-count")

                                    self.router_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount()
                                    self.router_node_count.parent = self
                                    self._children_name_map["router_node_count"] = "router-node-count"
                                    self._children_yang_names.add("router-node-count")


                                class RouterNodeCount(Entity):
                                    """
                                    Node Counts for System nodes
                                    
                                    .. attribute:: reachable_node_count
                                    
                                    	Number of nodes reachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_node_count
                                    
                                    	Number of nodes unreachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_participant_node_count
                                    
                                    	Number of participating nodes unreachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount, self).__init__()

                                        self.yang_name = "router-node-count"
                                        self.yang_parent_name = "topology-summary"

                                        self.reachable_node_count = YLeaf(YType.uint32, "reachable-node-count")

                                        self.unreachable_node_count = YLeaf(YType.uint32, "unreachable-node-count")

                                        self.unreachable_participant_node_count = YLeaf(YType.uint32, "unreachable-participant-node-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("reachable_node_count",
                                                        "unreachable_node_count",
                                                        "unreachable_participant_node_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.reachable_node_count.is_set or
                                            self.unreachable_node_count.is_set or
                                            self.unreachable_participant_node_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.reachable_node_count.yfilter != YFilter.not_set or
                                            self.unreachable_node_count.yfilter != YFilter.not_set or
                                            self.unreachable_participant_node_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "router-node-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.reachable_node_count.is_set or self.reachable_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reachable_node_count.get_name_leafdata())
                                        if (self.unreachable_node_count.is_set or self.unreachable_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unreachable_node_count.get_name_leafdata())
                                        if (self.unreachable_participant_node_count.is_set or self.unreachable_participant_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unreachable_participant_node_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "reachable-node-count" or name == "unreachable-node-count" or name == "unreachable-participant-node-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "reachable-node-count"):
                                            self.reachable_node_count = value
                                            self.reachable_node_count.value_namespace = name_space
                                            self.reachable_node_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unreachable-node-count"):
                                            self.unreachable_node_count = value
                                            self.unreachable_node_count.value_namespace = name_space
                                            self.unreachable_node_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unreachable-participant-node-count"):
                                            self.unreachable_participant_node_count = value
                                            self.unreachable_participant_node_count.value_namespace = name_space
                                            self.unreachable_participant_node_count.value_namespace_prefix = name_space_prefix


                                class PseudonodeNodeCount(Entity):
                                    """
                                    Node Counts for Pseudonode nodes
                                    
                                    .. attribute:: reachable_node_count
                                    
                                    	Number of nodes reachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_node_count
                                    
                                    	Number of nodes unreachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_participant_node_count
                                    
                                    	Number of participating nodes unreachable in SPT
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount, self).__init__()

                                        self.yang_name = "pseudonode-node-count"
                                        self.yang_parent_name = "topology-summary"

                                        self.reachable_node_count = YLeaf(YType.uint32, "reachable-node-count")

                                        self.unreachable_node_count = YLeaf(YType.uint32, "unreachable-node-count")

                                        self.unreachable_participant_node_count = YLeaf(YType.uint32, "unreachable-participant-node-count")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("reachable_node_count",
                                                        "unreachable_node_count",
                                                        "unreachable_participant_node_count") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.reachable_node_count.is_set or
                                            self.unreachable_node_count.is_set or
                                            self.unreachable_participant_node_count.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.reachable_node_count.yfilter != YFilter.not_set or
                                            self.unreachable_node_count.yfilter != YFilter.not_set or
                                            self.unreachable_participant_node_count.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "pseudonode-node-count" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.reachable_node_count.is_set or self.reachable_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reachable_node_count.get_name_leafdata())
                                        if (self.unreachable_node_count.is_set or self.unreachable_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unreachable_node_count.get_name_leafdata())
                                        if (self.unreachable_participant_node_count.is_set or self.unreachable_participant_node_count.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.unreachable_participant_node_count.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "reachable-node-count" or name == "unreachable-node-count" or name == "unreachable-participant-node-count"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "reachable-node-count"):
                                            self.reachable_node_count = value
                                            self.reachable_node_count.value_namespace = name_space
                                            self.reachable_node_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unreachable-node-count"):
                                            self.unreachable_node_count = value
                                            self.unreachable_node_count.value_namespace = name_space
                                            self.unreachable_node_count.value_namespace_prefix = name_space_prefix
                                        if(value_path == "unreachable-participant-node-count"):
                                            self.unreachable_participant_node_count = value
                                            self.unreachable_participant_node_count.value_namespace = name_space
                                            self.unreachable_participant_node_count.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.pseudonode_node_count is not None and self.pseudonode_node_count.has_data()) or
                                        (self.router_node_count is not None and self.router_node_count.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.pseudonode_node_count is not None and self.pseudonode_node_count.has_operation()) or
                                        (self.router_node_count is not None and self.router_node_count.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "topology-summary" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "pseudonode-node-count"):
                                        if (self.pseudonode_node_count is None):
                                            self.pseudonode_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount()
                                            self.pseudonode_node_count.parent = self
                                            self._children_name_map["pseudonode_node_count"] = "pseudonode-node-count"
                                        return self.pseudonode_node_count

                                    if (child_yang_name == "router-node-count"):
                                        if (self.router_node_count is None):
                                            self.router_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount()
                                            self.router_node_count.parent = self
                                            self._children_name_map["router_node_count"] = "router-node-count"
                                        return self.router_node_count

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pseudonode-node-count" or name == "router-node-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class Ipv6LinkTopologies(Entity):
                                """
                                IPv6 IS Topology table
                                
                                .. attribute:: ipv6_link_topology
                                
                                	An IS in an IPv6 Link Topology
                                	**type**\: list of    :py:class:`Ipv6LinkTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies, self).__init__()

                                    self.yang_name = "ipv6-link-topologies"
                                    self.yang_parent_name = "topology-level"

                                    self.ipv6_link_topology = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in () and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies, self).__setattr__(name, value)


                                class Ipv6LinkTopology(Entity):
                                    """
                                    An IS in an IPv6 Link Topology
                                    
                                    .. attribute:: system_id  <key>
                                    
                                    	System ID
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: advertised_prefix_item_counts
                                    
                                    	Per\-priority counts of prefix items advertised by the IS
                                    	**type**\:   :py:class:`AdvertisedPrefixItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts>`
                                    
                                    .. attribute:: is_attached
                                    
                                    	Is the IS attached?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_overloaded
                                    
                                    	Is the IS overloaded?
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_participant
                                    
                                    	Does the IS participate in the topology?
                                    	**type**\:  bool
                                    
                                    .. attribute:: reachability_status
                                    
                                    	Is the IS reachable, and, if so, its status within the SPT
                                    	**type**\:   :py:class:`ReachabilityStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology, self).__init__()

                                        self.yang_name = "ipv6-link-topology"
                                        self.yang_parent_name = "ipv6-link-topologies"

                                        self.system_id = YLeaf(YType.str, "system-id")

                                        self.is_attached = YLeaf(YType.boolean, "is-attached")

                                        self.is_overloaded = YLeaf(YType.boolean, "is-overloaded")

                                        self.is_participant = YLeaf(YType.boolean, "is-participant")

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts()
                                        self.advertised_prefix_item_counts.parent = self
                                        self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                        self._children_yang_names.add("advertised-prefix-item-counts")

                                        self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus()
                                        self.reachability_status.parent = self
                                        self._children_name_map["reachability_status"] = "reachability-status"
                                        self._children_yang_names.add("reachability-status")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("system_id",
                                                        "is_attached",
                                                        "is_overloaded",
                                                        "is_participant",
                                                        "source_address") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology, self).__setattr__(name, value)


                                    class ReachabilityStatus(Entity):
                                        """
                                        Is the IS reachable, and, if so, its status
                                        within the SPT
                                        
                                        .. attribute:: reachable_details
                                        
                                        	Status of the IS within the SPT
                                        	**type**\:   :py:class:`ReachableDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails>`
                                        
                                        .. attribute:: reachable_status
                                        
                                        	ReachableStatus
                                        	**type**\:   :py:class:`IsisReachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisReachable>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus, self).__init__()

                                            self.yang_name = "reachability-status"
                                            self.yang_parent_name = "ipv6-link-topology"

                                            self.reachable_status = YLeaf(YType.enumeration, "reachable-status")

                                            self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails()
                                            self.reachable_details.parent = self
                                            self._children_name_map["reachable_details"] = "reachable-details"
                                            self._children_yang_names.add("reachable-details")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reachable_status") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus, self).__setattr__(name, value)


                                        class ReachableDetails(Entity):
                                            """
                                            Status of the IS within the SPT
                                            
                                            .. attribute:: children_
                                            
                                            	Children of the IS within the SPT
                                            	**type**\: list of    :py:class:`Children_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children_>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops towards the IS
                                            	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath>`
                                            
                                            .. attribute:: multicast_root_distance
                                            
                                            	Distance to the IS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: parent_
                                            
                                            	Parents of the IS within the SPT
                                            	**type**\: list of    :py:class:`Parent_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent_>`
                                            
                                            .. attribute:: paths
                                            
                                            	First hops towards the IS
                                            	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths>`
                                            
                                            .. attribute:: root_distance
                                            
                                            	Distance to the IS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails, self).__init__()

                                                self.yang_name = "reachable-details"
                                                self.yang_parent_name = "reachability-status"

                                                self.multicast_root_distance = YLeaf(YType.uint32, "multicast-root-distance")

                                                self.root_distance = YLeaf(YType.uint32, "root-distance")

                                                self.children_ = YList(self)
                                                self.multicast_path = YList(self)
                                                self.parent_ = YList(self)
                                                self.paths = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("multicast_root_distance",
                                                                "root_distance") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails, self).__setattr__(name, value)


                                            class Paths(Entity):
                                                """
                                                First hops towards the IS
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup>`
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\:  str
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                    self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._children_yang_names.add("frr-backup")

                                                    self.uloop_explicit = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("egress_interface",
                                                                    "is_sr_exclude_tunnel_interface",
                                                                    "is_te_tunnel_interface",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "segment_routing_sid_value",
                                                                    "tag",
                                                                    "tunnel_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__setattr__(name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"

                                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                        self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                        self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                        self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                        self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                        self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                        self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                        self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                        self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                        self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                        self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                        self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                        self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                        self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                        self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                        self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                        self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                        self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                        self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                        self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                        self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                        self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                        self.weight = YLeaf(YType.uint32, "weight")

                                                        self.backup_repair = YList(self)
                                                        self.segment_routing_sid_value_entry = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("backup_repair_list_size",
                                                                        "egress_interface",
                                                                        "is_downstream",
                                                                        "is_epcfrr_lfa",
                                                                        "is_lc_disjoint",
                                                                        "is_node_protecting",
                                                                        "is_primary_path",
                                                                        "is_remote_lfa",
                                                                        "is_srlg_disjoint",
                                                                        "is_strict_spflfa",
                                                                        "is_tunnel_requested",
                                                                        "neighbor_address",
                                                                        "neighbor_id",
                                                                        "neighbor_snpa",
                                                                        "num_sid",
                                                                        "prefix_source_node_id",
                                                                        "remote_lfa_router_id",
                                                                        "remote_lfa_router_pid",
                                                                        "remote_lfa_system_id",
                                                                        "remote_lfa_system_pid",
                                                                        "segment_routing_sid_value",
                                                                        "tilfa_computation",
                                                                        "total_backup_distance",
                                                                        "tunnel_egress_interface",
                                                                        "weight") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__setattr__(name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                            self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                            self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                            self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("repair_element_node_id",
                                                                            "repair_element_type",
                                                                            "repair_ipv4_addr",
                                                                            "repair_ipv6_addr",
                                                                            "repair_label",
                                                                            "repair_strict_spf_label") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.repair_element_node_id.is_set or
                                                                self.repair_element_type.is_set or
                                                                self.repair_ipv4_addr.is_set or
                                                                self.repair_ipv6_addr.is_set or
                                                                self.repair_label.is_set or
                                                                self.repair_strict_spf_label.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.repair_element_node_id.yfilter != YFilter.not_set or
                                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                                self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                                self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                                self.repair_label.yfilter != YFilter.not_set or
                                                                self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "backup-repair" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                            if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                            if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                            if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "repair-element-node-id"):
                                                                self.repair_element_node_id = value
                                                                self.repair_element_node_id.value_namespace = name_space
                                                                self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-element-type"):
                                                                self.repair_element_type = value
                                                                self.repair_element_type.value_namespace = name_space
                                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv4-addr"):
                                                                self.repair_ipv4_addr = value
                                                                self.repair_ipv4_addr.value_namespace = name_space
                                                                self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv6-addr"):
                                                                self.repair_ipv6_addr = value
                                                                self.repair_ipv6_addr.value_namespace = name_space
                                                                self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-label"):
                                                                self.repair_label = value
                                                                self.repair_label.value_namespace = name_space
                                                                self.repair_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-strict-spf-label"):
                                                                self.repair_strict_spf_label = value
                                                                self.repair_strict_spf_label.value_namespace = name_space
                                                                self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.backup_repair_list_size.is_set or
                                                            self.egress_interface.is_set or
                                                            self.is_downstream.is_set or
                                                            self.is_epcfrr_lfa.is_set or
                                                            self.is_lc_disjoint.is_set or
                                                            self.is_node_protecting.is_set or
                                                            self.is_primary_path.is_set or
                                                            self.is_remote_lfa.is_set or
                                                            self.is_srlg_disjoint.is_set or
                                                            self.is_strict_spflfa.is_set or
                                                            self.is_tunnel_requested.is_set or
                                                            self.neighbor_address.is_set or
                                                            self.neighbor_id.is_set or
                                                            self.neighbor_snpa.is_set or
                                                            self.num_sid.is_set or
                                                            self.prefix_source_node_id.is_set or
                                                            self.remote_lfa_router_id.is_set or
                                                            self.remote_lfa_router_pid.is_set or
                                                            self.remote_lfa_system_id.is_set or
                                                            self.remote_lfa_system_pid.is_set or
                                                            self.segment_routing_sid_value.is_set or
                                                            self.tilfa_computation.is_set or
                                                            self.total_backup_distance.is_set or
                                                            self.tunnel_egress_interface.is_set or
                                                            self.weight.is_set)

                                                    def has_operation(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                            self.egress_interface.yfilter != YFilter.not_set or
                                                            self.is_downstream.yfilter != YFilter.not_set or
                                                            self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                            self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                            self.is_node_protecting.yfilter != YFilter.not_set or
                                                            self.is_primary_path.yfilter != YFilter.not_set or
                                                            self.is_remote_lfa.yfilter != YFilter.not_set or
                                                            self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                            self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                            self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                            self.neighbor_address.yfilter != YFilter.not_set or
                                                            self.neighbor_id.yfilter != YFilter.not_set or
                                                            self.neighbor_snpa.yfilter != YFilter.not_set or
                                                            self.num_sid.yfilter != YFilter.not_set or
                                                            self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                            self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                            self.tilfa_computation.yfilter != YFilter.not_set or
                                                            self.total_backup_distance.yfilter != YFilter.not_set or
                                                            self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                            self.weight.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "frr-backup" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                        if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                        if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                        if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                        if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                        if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                        if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                        if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                        if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                        if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                        if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                        if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                        if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                        if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                        if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                        if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                        if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                        if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                        if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                        if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                        if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.weight.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "backup-repair"):
                                                            for c in self.backup_repair:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.backup_repair.append(c)
                                                            return c

                                                        if (child_yang_name == "segment-routing-sid-value-entry"):
                                                            for c in self.segment_routing_sid_value_entry:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.segment_routing_sid_value_entry.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "backup-repair-list-size"):
                                                            self.backup_repair_list_size = value
                                                            self.backup_repair_list_size.value_namespace = name_space
                                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "egress-interface"):
                                                            self.egress_interface = value
                                                            self.egress_interface.value_namespace = name_space
                                                            self.egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-downstream"):
                                                            self.is_downstream = value
                                                            self.is_downstream.value_namespace = name_space
                                                            self.is_downstream.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-epcfrr-lfa"):
                                                            self.is_epcfrr_lfa = value
                                                            self.is_epcfrr_lfa.value_namespace = name_space
                                                            self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-lc-disjoint"):
                                                            self.is_lc_disjoint = value
                                                            self.is_lc_disjoint.value_namespace = name_space
                                                            self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-node-protecting"):
                                                            self.is_node_protecting = value
                                                            self.is_node_protecting.value_namespace = name_space
                                                            self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-primary-path"):
                                                            self.is_primary_path = value
                                                            self.is_primary_path.value_namespace = name_space
                                                            self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-remote-lfa"):
                                                            self.is_remote_lfa = value
                                                            self.is_remote_lfa.value_namespace = name_space
                                                            self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-srlg-disjoint"):
                                                            self.is_srlg_disjoint = value
                                                            self.is_srlg_disjoint.value_namespace = name_space
                                                            self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-strict-spflfa"):
                                                            self.is_strict_spflfa = value
                                                            self.is_strict_spflfa.value_namespace = name_space
                                                            self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-tunnel-requested"):
                                                            self.is_tunnel_requested = value
                                                            self.is_tunnel_requested.value_namespace = name_space
                                                            self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-address"):
                                                            self.neighbor_address = value
                                                            self.neighbor_address.value_namespace = name_space
                                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-id"):
                                                            self.neighbor_id = value
                                                            self.neighbor_id.value_namespace = name_space
                                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-snpa"):
                                                            self.neighbor_snpa = value
                                                            self.neighbor_snpa.value_namespace = name_space
                                                            self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-sid"):
                                                            self.num_sid = value
                                                            self.num_sid.value_namespace = name_space
                                                            self.num_sid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "prefix-source-node-id"):
                                                            self.prefix_source_node_id = value
                                                            self.prefix_source_node_id.value_namespace = name_space
                                                            self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-id"):
                                                            self.remote_lfa_router_id = value
                                                            self.remote_lfa_router_id.value_namespace = name_space
                                                            self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-pid"):
                                                            self.remote_lfa_router_pid = value
                                                            self.remote_lfa_router_pid.value_namespace = name_space
                                                            self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-id"):
                                                            self.remote_lfa_system_id = value
                                                            self.remote_lfa_system_id.value_namespace = name_space
                                                            self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-pid"):
                                                            self.remote_lfa_system_pid = value
                                                            self.remote_lfa_system_pid.value_namespace = name_space
                                                            self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segment-routing-sid-value"):
                                                            self.segment_routing_sid_value = value
                                                            self.segment_routing_sid_value.value_namespace = name_space
                                                            self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tilfa-computation"):
                                                            self.tilfa_computation = value
                                                            self.tilfa_computation.value_namespace = name_space
                                                            self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "total-backup-distance"):
                                                            self.total_backup_distance = value
                                                            self.total_backup_distance.value_namespace = name_space
                                                            self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-egress-interface"):
                                                            self.tunnel_egress_interface = value
                                                            self.tunnel_egress_interface.value_namespace = name_space
                                                            self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "weight"):
                                                            self.weight = value
                                                            self.weight.value_namespace = name_space
                                                            self.weight.value_namespace_prefix = name_space_prefix


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "uloop-explicit" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.egress_interface.is_set or
                                                        self.is_sr_exclude_tunnel_interface.is_set or
                                                        self.is_te_tunnel_interface.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_interface.is_set or
                                                        self.weight.is_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_data()))

                                                def has_operation(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "paths" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                    if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "frr-backup"):
                                                        if (self.frr_backup is None):
                                                            self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                            self.frr_backup.parent = self
                                                            self._children_name_map["frr_backup"] = "frr-backup"
                                                        return self.frr_backup

                                                    if (child_yang_name == "uloop-explicit"):
                                                        for c in self.uloop_explicit:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.uloop_explicit.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-sr-exclude-tunnel-interface"):
                                                        self.is_sr_exclude_tunnel_interface = value
                                                        self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                        self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-te-tunnel-interface"):
                                                        self.is_te_tunnel_interface = value
                                                        self.is_te_tunnel_interface.value_namespace = name_space
                                                        self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-interface"):
                                                        self.tunnel_interface = value
                                                        self.tunnel_interface.value_namespace = name_space
                                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops towards the IS
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\:  str
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                    self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._children_yang_names.add("frr-backup")

                                                    self.uloop_explicit = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("egress_interface",
                                                                    "is_sr_exclude_tunnel_interface",
                                                                    "is_te_tunnel_interface",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "segment_routing_sid_value",
                                                                    "tag",
                                                                    "tunnel_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__setattr__(name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"

                                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                        self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                        self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                        self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                        self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                        self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                        self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                        self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                        self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                        self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                        self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                        self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                        self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                        self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                        self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                        self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                        self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                        self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                        self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                        self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                        self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                        self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                        self.weight = YLeaf(YType.uint32, "weight")

                                                        self.backup_repair = YList(self)
                                                        self.segment_routing_sid_value_entry = YList(self)

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("backup_repair_list_size",
                                                                        "egress_interface",
                                                                        "is_downstream",
                                                                        "is_epcfrr_lfa",
                                                                        "is_lc_disjoint",
                                                                        "is_node_protecting",
                                                                        "is_primary_path",
                                                                        "is_remote_lfa",
                                                                        "is_srlg_disjoint",
                                                                        "is_strict_spflfa",
                                                                        "is_tunnel_requested",
                                                                        "neighbor_address",
                                                                        "neighbor_id",
                                                                        "neighbor_snpa",
                                                                        "num_sid",
                                                                        "prefix_source_node_id",
                                                                        "remote_lfa_router_id",
                                                                        "remote_lfa_router_pid",
                                                                        "remote_lfa_system_id",
                                                                        "remote_lfa_system_pid",
                                                                        "segment_routing_sid_value",
                                                                        "tilfa_computation",
                                                                        "total_backup_distance",
                                                                        "tunnel_egress_interface",
                                                                        "weight") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.entry = YLeaf(YType.uint32, "entry")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("entry") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return self.entry.is_set

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.entry.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "entry"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "entry"):
                                                                self.entry = value
                                                                self.entry.value_namespace = name_space
                                                                self.entry.value_namespace_prefix = name_space_prefix


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"

                                                            self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                            self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                            self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                            self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                            self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("repair_element_node_id",
                                                                            "repair_element_type",
                                                                            "repair_ipv4_addr",
                                                                            "repair_ipv6_addr",
                                                                            "repair_label",
                                                                            "repair_strict_spf_label") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.repair_element_node_id.is_set or
                                                                self.repair_element_type.is_set or
                                                                self.repair_ipv4_addr.is_set or
                                                                self.repair_ipv6_addr.is_set or
                                                                self.repair_label.is_set or
                                                                self.repair_strict_spf_label.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.repair_element_node_id.yfilter != YFilter.not_set or
                                                                self.repair_element_type.yfilter != YFilter.not_set or
                                                                self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                                self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                                self.repair_label.yfilter != YFilter.not_set or
                                                                self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "backup-repair" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                            if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                            if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                            if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                            if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                            if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "repair-element-node-id"):
                                                                self.repair_element_node_id = value
                                                                self.repair_element_node_id.value_namespace = name_space
                                                                self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-element-type"):
                                                                self.repair_element_type = value
                                                                self.repair_element_type.value_namespace = name_space
                                                                self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv4-addr"):
                                                                self.repair_ipv4_addr = value
                                                                self.repair_ipv4_addr.value_namespace = name_space
                                                                self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-ipv6-addr"):
                                                                self.repair_ipv6_addr = value
                                                                self.repair_ipv6_addr.value_namespace = name_space
                                                                self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-label"):
                                                                self.repair_label = value
                                                                self.repair_label.value_namespace = name_space
                                                                self.repair_label.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "repair-strict-spf-label"):
                                                                self.repair_strict_spf_label = value
                                                                self.repair_strict_spf_label.value_namespace = name_space
                                                                self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_data()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_data()):
                                                                return True
                                                        return (
                                                            self.backup_repair_list_size.is_set or
                                                            self.egress_interface.is_set or
                                                            self.is_downstream.is_set or
                                                            self.is_epcfrr_lfa.is_set or
                                                            self.is_lc_disjoint.is_set or
                                                            self.is_node_protecting.is_set or
                                                            self.is_primary_path.is_set or
                                                            self.is_remote_lfa.is_set or
                                                            self.is_srlg_disjoint.is_set or
                                                            self.is_strict_spflfa.is_set or
                                                            self.is_tunnel_requested.is_set or
                                                            self.neighbor_address.is_set or
                                                            self.neighbor_id.is_set or
                                                            self.neighbor_snpa.is_set or
                                                            self.num_sid.is_set or
                                                            self.prefix_source_node_id.is_set or
                                                            self.remote_lfa_router_id.is_set or
                                                            self.remote_lfa_router_pid.is_set or
                                                            self.remote_lfa_system_id.is_set or
                                                            self.remote_lfa_system_pid.is_set or
                                                            self.segment_routing_sid_value.is_set or
                                                            self.tilfa_computation.is_set or
                                                            self.total_backup_distance.is_set or
                                                            self.tunnel_egress_interface.is_set or
                                                            self.weight.is_set)

                                                    def has_operation(self):
                                                        for c in self.backup_repair:
                                                            if (c.has_operation()):
                                                                return True
                                                        for c in self.segment_routing_sid_value_entry:
                                                            if (c.has_operation()):
                                                                return True
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                            self.egress_interface.yfilter != YFilter.not_set or
                                                            self.is_downstream.yfilter != YFilter.not_set or
                                                            self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                            self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                            self.is_node_protecting.yfilter != YFilter.not_set or
                                                            self.is_primary_path.yfilter != YFilter.not_set or
                                                            self.is_remote_lfa.yfilter != YFilter.not_set or
                                                            self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                            self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                            self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                            self.neighbor_address.yfilter != YFilter.not_set or
                                                            self.neighbor_id.yfilter != YFilter.not_set or
                                                            self.neighbor_snpa.yfilter != YFilter.not_set or
                                                            self.num_sid.yfilter != YFilter.not_set or
                                                            self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                            self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                            self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                            self.tilfa_computation.yfilter != YFilter.not_set or
                                                            self.total_backup_distance.yfilter != YFilter.not_set or
                                                            self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                            self.weight.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "frr-backup" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                        if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                        if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                        if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                        if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                        if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                        if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                        if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                        if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                        if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                        if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                        if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                        if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                        if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                        if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                        if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                        if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                        if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                        if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                        if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                        if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                        if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                        if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                        if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.weight.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "backup-repair"):
                                                            for c in self.backup_repair:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.backup_repair.append(c)
                                                            return c

                                                        if (child_yang_name == "segment-routing-sid-value-entry"):
                                                            for c in self.segment_routing_sid_value_entry:
                                                                segment = c.get_segment_path()
                                                                if (segment_path == segment):
                                                                    return c
                                                            c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                            c.parent = self
                                                            local_reference_key = "ydk::seg::%s" % segment_path
                                                            self._local_refs[local_reference_key] = c
                                                            self.segment_routing_sid_value_entry.append(c)
                                                            return c

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "backup-repair-list-size"):
                                                            self.backup_repair_list_size = value
                                                            self.backup_repair_list_size.value_namespace = name_space
                                                            self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "egress-interface"):
                                                            self.egress_interface = value
                                                            self.egress_interface.value_namespace = name_space
                                                            self.egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-downstream"):
                                                            self.is_downstream = value
                                                            self.is_downstream.value_namespace = name_space
                                                            self.is_downstream.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-epcfrr-lfa"):
                                                            self.is_epcfrr_lfa = value
                                                            self.is_epcfrr_lfa.value_namespace = name_space
                                                            self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-lc-disjoint"):
                                                            self.is_lc_disjoint = value
                                                            self.is_lc_disjoint.value_namespace = name_space
                                                            self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-node-protecting"):
                                                            self.is_node_protecting = value
                                                            self.is_node_protecting.value_namespace = name_space
                                                            self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-primary-path"):
                                                            self.is_primary_path = value
                                                            self.is_primary_path.value_namespace = name_space
                                                            self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-remote-lfa"):
                                                            self.is_remote_lfa = value
                                                            self.is_remote_lfa.value_namespace = name_space
                                                            self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-srlg-disjoint"):
                                                            self.is_srlg_disjoint = value
                                                            self.is_srlg_disjoint.value_namespace = name_space
                                                            self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-strict-spflfa"):
                                                            self.is_strict_spflfa = value
                                                            self.is_strict_spflfa.value_namespace = name_space
                                                            self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "is-tunnel-requested"):
                                                            self.is_tunnel_requested = value
                                                            self.is_tunnel_requested.value_namespace = name_space
                                                            self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-address"):
                                                            self.neighbor_address = value
                                                            self.neighbor_address.value_namespace = name_space
                                                            self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-id"):
                                                            self.neighbor_id = value
                                                            self.neighbor_id.value_namespace = name_space
                                                            self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "neighbor-snpa"):
                                                            self.neighbor_snpa = value
                                                            self.neighbor_snpa.value_namespace = name_space
                                                            self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "num-sid"):
                                                            self.num_sid = value
                                                            self.num_sid.value_namespace = name_space
                                                            self.num_sid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "prefix-source-node-id"):
                                                            self.prefix_source_node_id = value
                                                            self.prefix_source_node_id.value_namespace = name_space
                                                            self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-id"):
                                                            self.remote_lfa_router_id = value
                                                            self.remote_lfa_router_id.value_namespace = name_space
                                                            self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-router-pid"):
                                                            self.remote_lfa_router_pid = value
                                                            self.remote_lfa_router_pid.value_namespace = name_space
                                                            self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-id"):
                                                            self.remote_lfa_system_id = value
                                                            self.remote_lfa_system_id.value_namespace = name_space
                                                            self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "remote-lfa-system-pid"):
                                                            self.remote_lfa_system_pid = value
                                                            self.remote_lfa_system_pid.value_namespace = name_space
                                                            self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "segment-routing-sid-value"):
                                                            self.segment_routing_sid_value = value
                                                            self.segment_routing_sid_value.value_namespace = name_space
                                                            self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tilfa-computation"):
                                                            self.tilfa_computation = value
                                                            self.tilfa_computation.value_namespace = name_space
                                                            self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "total-backup-distance"):
                                                            self.total_backup_distance = value
                                                            self.total_backup_distance.value_namespace = name_space
                                                            self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "tunnel-egress-interface"):
                                                            self.tunnel_egress_interface = value
                                                            self.tunnel_egress_interface.value_namespace = name_space
                                                            self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "weight"):
                                                            self.weight = value
                                                            self.weight.value_namespace = name_space
                                                            self.weight.value_namespace_prefix = name_space_prefix


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "uloop-explicit" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.egress_interface.is_set or
                                                        self.is_sr_exclude_tunnel_interface.is_set or
                                                        self.is_te_tunnel_interface.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tag.is_set or
                                                        self.tunnel_interface.is_set or
                                                        self.weight.is_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_data()))

                                                def has_operation(self):
                                                    for c in self.uloop_explicit:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tag.yfilter != YFilter.not_set or
                                                        self.tunnel_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set or
                                                        (self.frr_backup is not None and self.frr_backup.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-path" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                    if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tag.get_name_leafdata())
                                                    if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "frr-backup"):
                                                        if (self.frr_backup is None):
                                                            self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                            self.frr_backup.parent = self
                                                            self._children_name_map["frr_backup"] = "frr-backup"
                                                        return self.frr_backup

                                                    if (child_yang_name == "uloop-explicit"):
                                                        for c in self.uloop_explicit:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.uloop_explicit.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-sr-exclude-tunnel-interface"):
                                                        self.is_sr_exclude_tunnel_interface = value
                                                        self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                        self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-te-tunnel-interface"):
                                                        self.is_te_tunnel_interface = value
                                                        self.is_te_tunnel_interface.value_namespace = name_space
                                                        self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tag"):
                                                        self.tag = value
                                                        self.tag.value_namespace = name_space
                                                        self.tag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-interface"):
                                                        self.tunnel_interface = value
                                                        self.tunnel_interface.value_namespace = name_space
                                                        self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class Parent_(Entity):
                                                """
                                                Parents of the IS within the SPT
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__init__()

                                                    self.yang_name = "parent"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.intermediate_pseudonode = YLeaf(YType.str, "intermediate-pseudonode")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("intermediate_pseudonode",
                                                                    "neighbor_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent_, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.intermediate_pseudonode.is_set or
                                                        self.neighbor_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.intermediate_pseudonode.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "parent" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.intermediate_pseudonode.is_set or self.intermediate_pseudonode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.intermediate_pseudonode.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "intermediate-pseudonode" or name == "neighbor-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "intermediate-pseudonode"):
                                                        self.intermediate_pseudonode = value
                                                        self.intermediate_pseudonode.value_namespace = name_space
                                                        self.intermediate_pseudonode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix


                                            class Children_(Entity):
                                                """
                                                Children of the IS within the SPT
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__init__()

                                                    self.yang_name = "children"
                                                    self.yang_parent_name = "reachable-details"

                                                    self.intermediate_pseudonode = YLeaf(YType.str, "intermediate-pseudonode")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("intermediate_pseudonode",
                                                                    "neighbor_id") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children_, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.intermediate_pseudonode.is_set or
                                                        self.neighbor_id.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.intermediate_pseudonode.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "children" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.intermediate_pseudonode.is_set or self.intermediate_pseudonode.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.intermediate_pseudonode.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "intermediate-pseudonode" or name == "neighbor-id"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "intermediate-pseudonode"):
                                                        self.intermediate_pseudonode = value
                                                        self.intermediate_pseudonode.value_namespace = name_space
                                                        self.intermediate_pseudonode.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.children_:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.multicast_path:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.parent_:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.paths:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.multicast_root_distance.is_set or
                                                    self.root_distance.is_set)

                                            def has_operation(self):
                                                for c in self.children_:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.multicast_path:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.parent_:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.paths:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.multicast_root_distance.yfilter != YFilter.not_set or
                                                    self.root_distance.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "reachable-details" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.multicast_root_distance.is_set or self.multicast_root_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.multicast_root_distance.get_name_leafdata())
                                                if (self.root_distance.is_set or self.root_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.root_distance.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "children"):
                                                    for c in self.children_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.children_.append(c)
                                                    return c

                                                if (child_yang_name == "multicast-path"):
                                                    for c in self.multicast_path:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.multicast_path.append(c)
                                                    return c

                                                if (child_yang_name == "parent"):
                                                    for c in self.parent_:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent_()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.parent_.append(c)
                                                    return c

                                                if (child_yang_name == "paths"):
                                                    for c in self.paths:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.paths.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "children" or name == "multicast-path" or name == "parent" or name == "paths" or name == "multicast-root-distance" or name == "root-distance"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "multicast-root-distance"):
                                                    self.multicast_root_distance = value
                                                    self.multicast_root_distance.value_namespace = name_space
                                                    self.multicast_root_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "root-distance"):
                                                    self.root_distance = value
                                                    self.root_distance.value_namespace = name_space
                                                    self.root_distance.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.reachable_status.is_set or
                                                (self.reachable_details is not None and self.reachable_details.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reachable_status.yfilter != YFilter.not_set or
                                                (self.reachable_details is not None and self.reachable_details.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "reachability-status" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reachable_status.is_set or self.reachable_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reachable_status.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "reachable-details"):
                                                if (self.reachable_details is None):
                                                    self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails()
                                                    self.reachable_details.parent = self
                                                    self._children_name_map["reachable_details"] = "reachable-details"
                                                return self.reachable_details

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reachable-details" or name == "reachable-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reachable-status"):
                                                self.reachable_status = value
                                                self.reachable_status.value_namespace = name_space
                                                self.reachable_status.value_namespace_prefix = name_space_prefix


                                    class AdvertisedPrefixItemCounts(Entity):
                                        """
                                        Per\-priority counts of prefix items advertised
                                        by the IS
                                        
                                        .. attribute:: critical
                                        
                                        	Critical priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high
                                        
                                        	High priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low
                                        
                                        	Low priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: medium
                                        
                                        	Medium priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts, self).__init__()

                                            self.yang_name = "advertised-prefix-item-counts"
                                            self.yang_parent_name = "ipv6-link-topology"

                                            self.critical = YLeaf(YType.uint32, "critical")

                                            self.high = YLeaf(YType.uint32, "high")

                                            self.low = YLeaf(YType.uint32, "low")

                                            self.medium = YLeaf(YType.uint32, "medium")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("critical",
                                                            "high",
                                                            "low",
                                                            "medium") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.critical.is_set or
                                                self.high.is_set or
                                                self.low.is_set or
                                                self.medium.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.critical.yfilter != YFilter.not_set or
                                                self.high.yfilter != YFilter.not_set or
                                                self.low.yfilter != YFilter.not_set or
                                                self.medium.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "advertised-prefix-item-counts" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.critical.is_set or self.critical.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.critical.get_name_leafdata())
                                            if (self.high.is_set or self.high.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.high.get_name_leafdata())
                                            if (self.low.is_set or self.low.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.low.get_name_leafdata())
                                            if (self.medium.is_set or self.medium.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.medium.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "critical" or name == "high" or name == "low" or name == "medium"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "critical"):
                                                self.critical = value
                                                self.critical.value_namespace = name_space
                                                self.critical.value_namespace_prefix = name_space_prefix
                                            if(value_path == "high"):
                                                self.high = value
                                                self.high.value_namespace = name_space
                                                self.high.value_namespace_prefix = name_space_prefix
                                            if(value_path == "low"):
                                                self.low = value
                                                self.low.value_namespace = name_space
                                                self.low.value_namespace_prefix = name_space_prefix
                                            if(value_path == "medium"):
                                                self.medium = value
                                                self.medium.value_namespace = name_space
                                                self.medium.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.system_id.is_set or
                                            self.is_attached.is_set or
                                            self.is_overloaded.is_set or
                                            self.is_participant.is_set or
                                            self.source_address.is_set or
                                            (self.advertised_prefix_item_counts is not None and self.advertised_prefix_item_counts.has_data()) or
                                            (self.reachability_status is not None and self.reachability_status.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.system_id.yfilter != YFilter.not_set or
                                            self.is_attached.yfilter != YFilter.not_set or
                                            self.is_overloaded.yfilter != YFilter.not_set or
                                            self.is_participant.yfilter != YFilter.not_set or
                                            self.source_address.yfilter != YFilter.not_set or
                                            (self.advertised_prefix_item_counts is not None and self.advertised_prefix_item_counts.has_operation()) or
                                            (self.reachability_status is not None and self.reachability_status.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "ipv6-link-topology" + "[system-id='" + self.system_id.get() + "']" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.system_id.get_name_leafdata())
                                        if (self.is_attached.is_set or self.is_attached.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_attached.get_name_leafdata())
                                        if (self.is_overloaded.is_set or self.is_overloaded.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_overloaded.get_name_leafdata())
                                        if (self.is_participant.is_set or self.is_participant.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_participant.get_name_leafdata())
                                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.source_address.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "advertised-prefix-item-counts"):
                                            if (self.advertised_prefix_item_counts is None):
                                                self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts()
                                                self.advertised_prefix_item_counts.parent = self
                                                self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                            return self.advertised_prefix_item_counts

                                        if (child_yang_name == "reachability-status"):
                                            if (self.reachability_status is None):
                                                self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus()
                                                self.reachability_status.parent = self
                                                self._children_name_map["reachability_status"] = "reachability-status"
                                            return self.reachability_status

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "advertised-prefix-item-counts" or name == "reachability-status" or name == "system-id" or name == "is-attached" or name == "is-overloaded" or name == "is-participant" or name == "source-address"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "system-id"):
                                            self.system_id = value
                                            self.system_id.value_namespace = name_space
                                            self.system_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-attached"):
                                            self.is_attached = value
                                            self.is_attached.value_namespace = name_space
                                            self.is_attached.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-overloaded"):
                                            self.is_overloaded = value
                                            self.is_overloaded.value_namespace = name_space
                                            self.is_overloaded.value_namespace_prefix = name_space_prefix
                                        if(value_path == "is-participant"):
                                            self.is_participant = value
                                            self.is_participant.value_namespace = name_space
                                            self.is_participant.value_namespace_prefix = name_space_prefix
                                        if(value_path == "source-address"):
                                            self.source_address = value
                                            self.source_address.value_namespace = name_space
                                            self.source_address.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.ipv6_link_topology:
                                        if (c.has_data()):
                                            return True
                                    return False

                                def has_operation(self):
                                    for c in self.ipv6_link_topology:
                                        if (c.has_operation()):
                                            return True
                                    return self.yfilter != YFilter.not_set

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv6-link-topologies" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "ipv6-link-topology"):
                                        for c in self.ipv6_link_topology:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.ipv6_link_topology.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ipv6-link-topology"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass

                            def has_data(self):
                                return (
                                    self.level.is_set or
                                    (self.ipv4_link_topologies is not None and self.ipv4_link_topologies.has_data()) or
                                    (self.ipv6_link_topologies is not None and self.ipv6_link_topologies.has_data()) or
                                    (self.spf_log is not None and self.spf_log.has_data()) or
                                    (self.te_adjacency_log is not None and self.te_adjacency_log.has_data()) or
                                    (self.te_advertisements is not None and self.te_advertisements.has_data()) or
                                    (self.te_tunnels is not None and self.te_tunnels.has_data()) or
                                    (self.topology_summary is not None and self.topology_summary.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.level.yfilter != YFilter.not_set or
                                    (self.ipv4_link_topologies is not None and self.ipv4_link_topologies.has_operation()) or
                                    (self.ipv6_link_topologies is not None and self.ipv6_link_topologies.has_operation()) or
                                    (self.spf_log is not None and self.spf_log.has_operation()) or
                                    (self.te_adjacency_log is not None and self.te_adjacency_log.has_operation()) or
                                    (self.te_advertisements is not None and self.te_advertisements.has_operation()) or
                                    (self.te_tunnels is not None and self.te_tunnels.has_operation()) or
                                    (self.topology_summary is not None and self.topology_summary.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "topology-level" + "[level='" + self.level.get() + "']" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.level.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipv4-link-topologies"):
                                    if (self.ipv4_link_topologies is None):
                                        self.ipv4_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies()
                                        self.ipv4_link_topologies.parent = self
                                        self._children_name_map["ipv4_link_topologies"] = "ipv4-link-topologies"
                                    return self.ipv4_link_topologies

                                if (child_yang_name == "ipv6-link-topologies"):
                                    if (self.ipv6_link_topologies is None):
                                        self.ipv6_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies()
                                        self.ipv6_link_topologies.parent = self
                                        self._children_name_map["ipv6_link_topologies"] = "ipv6-link-topologies"
                                    return self.ipv6_link_topologies

                                if (child_yang_name == "spf-log"):
                                    if (self.spf_log is None):
                                        self.spf_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog()
                                        self.spf_log.parent = self
                                        self._children_name_map["spf_log"] = "spf-log"
                                    return self.spf_log

                                if (child_yang_name == "te-adjacency-log"):
                                    if (self.te_adjacency_log is None):
                                        self.te_adjacency_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog()
                                        self.te_adjacency_log.parent = self
                                        self._children_name_map["te_adjacency_log"] = "te-adjacency-log"
                                    return self.te_adjacency_log

                                if (child_yang_name == "te-advertisements"):
                                    if (self.te_advertisements is None):
                                        self.te_advertisements = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements()
                                        self.te_advertisements.parent = self
                                        self._children_name_map["te_advertisements"] = "te-advertisements"
                                    return self.te_advertisements

                                if (child_yang_name == "te-tunnels"):
                                    if (self.te_tunnels is None):
                                        self.te_tunnels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels()
                                        self.te_tunnels.parent = self
                                        self._children_name_map["te_tunnels"] = "te-tunnels"
                                    return self.te_tunnels

                                if (child_yang_name == "topology-summary"):
                                    if (self.topology_summary is None):
                                        self.topology_summary = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary()
                                        self.topology_summary.parent = self
                                        self._children_name_map["topology_summary"] = "topology-summary"
                                    return self.topology_summary

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4-link-topologies" or name == "ipv6-link-topologies" or name == "spf-log" or name == "te-adjacency-log" or name == "te-advertisements" or name == "te-tunnels" or name == "topology-summary" or name == "level"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "level"):
                                    self.level = value
                                    self.level.value_namespace = name_space
                                    self.level.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.topology_level:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.topology_level:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "topology-levels" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "topology-level"):
                                for c in self.topology_level:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.topology_level.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "topology-level"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ipv6Routes(Entity):
                        """
                        IPv6 local route
                        
                        .. attribute:: ipv6_route
                        
                        	An IPv6 route known to IS\-IS
                        	**type**\: list of    :py:class:`Ipv6Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes, self).__init__()

                            self.yang_name = "ipv6-routes"
                            self.yang_parent_name = "topology"

                            self.ipv6_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes, self).__setattr__(name, value)


                        class Ipv6Route(Entity):
                            """
                            An IPv6 route known to IS\-IS
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:   :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:   :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of    :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail>`
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:   :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route, self).__init__()

                                self.yang_name = "ipv6-route"
                                self.yang_parent_name = "ipv6-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"
                                self._children_yang_names.add("connected-status")

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"
                                self._children_yang_names.add("native-status")

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"
                                self._children_yang_names.add("redistributed-status")

                                self.per_level_advertising_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route, self).__setattr__(name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:   :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv6-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._children_yang_names.add("connected-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus, self).__setattr__(name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.connected_details is not None and self.connected_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.connected_details is not None and self.connected_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "connected-details"):
                                        if (self.connected_details is None):
                                            self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails()
                                            self.connected_details.parent = self
                                            self._children_name_map["connected_details"] = "connected-details"
                                        return self.connected_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "connected-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:   :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv6-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._children_yang_names.add("redistribution-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus, self).__setattr__(name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of    :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"

                                        self.isis_sh_route_redist_detail = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:   :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"

                                            self.level = YLeaf(YType.enumeration, "level")

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._children_yang_names.add("owner")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("level") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\:  str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:   :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"

                                                self.application_name = YLeaf(YType.str, "application-name")

                                                self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                                self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                                self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                                self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                                self.ospfv3_process_id = YLeaf(YType.str, "ospfv3-process-id")

                                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("application_name",
                                                                "bgp_as_number",
                                                                "eigrp_as_number",
                                                                "isis_instance_id",
                                                                "ospf_process_id",
                                                                "ospfv3_process_id",
                                                                "protocol") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.application_name.is_set or
                                                    self.bgp_as_number.is_set or
                                                    self.eigrp_as_number.is_set or
                                                    self.isis_instance_id.is_set or
                                                    self.ospf_process_id.is_set or
                                                    self.ospfv3_process_id.is_set or
                                                    self.protocol.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.application_name.yfilter != YFilter.not_set or
                                                    self.bgp_as_number.yfilter != YFilter.not_set or
                                                    self.eigrp_as_number.yfilter != YFilter.not_set or
                                                    self.isis_instance_id.yfilter != YFilter.not_set or
                                                    self.ospf_process_id.yfilter != YFilter.not_set or
                                                    self.ospfv3_process_id.yfilter != YFilter.not_set or
                                                    self.protocol.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "owner" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.application_name.is_set or self.application_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.application_name.get_name_leafdata())
                                                if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                                if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                                if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                                if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                                if (self.ospfv3_process_id.is_set or self.ospfv3_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospfv3_process_id.get_name_leafdata())
                                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "application-name" or name == "bgp-as-number" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "ospfv3-process-id" or name == "protocol"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "application-name"):
                                                    self.application_name = value
                                                    self.application_name.value_namespace = name_space
                                                    self.application_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bgp-as-number"):
                                                    self.bgp_as_number = value
                                                    self.bgp_as_number.value_namespace = name_space
                                                    self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "eigrp-as-number"):
                                                    self.eigrp_as_number = value
                                                    self.eigrp_as_number.value_namespace = name_space
                                                    self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "isis-instance-id"):
                                                    self.isis_instance_id = value
                                                    self.isis_instance_id.value_namespace = name_space
                                                    self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospf-process-id"):
                                                    self.ospf_process_id = value
                                                    self.ospf_process_id.value_namespace = name_space
                                                    self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospfv3-process-id"):
                                                    self.ospfv3_process_id = value
                                                    self.ospfv3_process_id.value_namespace = name_space
                                                    self.ospfv3_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol"):
                                                    self.protocol = value
                                                    self.protocol.value_namespace = name_space
                                                    self.protocol.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.level.is_set or
                                                (self.owner is not None and self.owner.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.level.yfilter != YFilter.not_set or
                                                (self.owner is not None and self.owner.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "isis-sh-route-redist-detail" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "owner"):
                                                if (self.owner is None):
                                                    self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                    self.owner.parent = self
                                                    self._children_name_map["owner"] = "owner"
                                                return self.owner

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "owner" or name == "level"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "level"):
                                                self.level = value
                                                self.level.value_namespace = name_space
                                                self.level.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "isis-sh-route-redist-detail"):
                                            for c in self.isis_sh_route_redist_detail:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.isis_sh_route_redist_detail.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "isis-sh-route-redist-detail"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistributed-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-details"):
                                        if (self.redistribution_details is None):
                                            self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails()
                                            self.redistribution_details.parent = self
                                            self._children_name_map["redistribution_details"] = "redistribution-details"
                                        return self.redistribution_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:   :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv6-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._children_yang_names.add("native-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus, self).__setattr__(name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of    :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup>`
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:   :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"
                                        self._children_yang_names.add("primary")

                                        self.backup = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails, self).__setattr__(name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "primary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.priority.is_set or
                                            (self.primary is not None and self.primary.has_data()))

                                    def has_operation(self):
                                        for c in self.backup:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            (self.primary is not None and self.primary.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "native-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup"):
                                            for c in self.backup:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup.append(c)
                                            return c

                                        if (child_yang_name == "primary"):
                                            if (self.primary is None):
                                                self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary()
                                                self.primary.parent = self
                                                self._children_name_map["primary"] = "primary"
                                            return self.primary

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup" or name == "primary" or name == "priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.native_details is not None and self.native_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.native_details is not None and self.native_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "native-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "native-details"):
                                        if (self.native_details is None):
                                            self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails()
                                            self.native_details.parent = self
                                            self._children_name_map["native_details"] = "native-details"
                                        return self.native_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "native-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:   :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\:  bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\:  bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\:  bool
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\:  bool
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid>`
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:   :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv6-route"

                                    self.advertising_origin = YLeaf(YType.enumeration, "advertising-origin")

                                    self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                    self.is_external_reachability = YLeaf(YType.boolean, "is-external-reachability")

                                    self.is_interarea = YLeaf(YType.boolean, "is-interarea")

                                    self.is_propagated = YLeaf(YType.boolean, "is-propagated")

                                    self.level = YLeaf(YType.enumeration, "level")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"
                                    self._children_yang_names.add("summarization-status")

                                    self.nodal_sid = YList(self)
                                    self.tags = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_origin",
                                                    "is_external_metric",
                                                    "is_external_reachability",
                                                    "is_interarea",
                                                    "is_propagated",
                                                    "level",
                                                    "metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail, self).__setattr__(name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:   :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._children_yang_names.add("summary-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_valid.is_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summarization-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "summary-prefix"):
                                            if (self.summary_prefix is None):
                                                self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                                self.summary_prefix.parent = self
                                                self._children_name_map["summary_prefix"] = "summary-prefix"
                                            return self.summary_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "summary-prefix" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tags" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.algorithm = YLeaf(YType.uint8, "algorithm")

                                        self.eflag = YLeaf(YType.uint8, "eflag")

                                        self.lflag = YLeaf(YType.uint8, "lflag")

                                        self.nflag = YLeaf(YType.uint8, "nflag")

                                        self.pflag = YLeaf(YType.uint8, "pflag")

                                        self.rflag = YLeaf(YType.uint8, "rflag")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.vflag = YLeaf(YType.uint8, "vflag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("algorithm",
                                                        "eflag",
                                                        "lflag",
                                                        "nflag",
                                                        "pflag",
                                                        "rflag",
                                                        "sid_value",
                                                        "vflag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.algorithm.is_set or
                                            self.eflag.is_set or
                                            self.lflag.is_set or
                                            self.nflag.is_set or
                                            self.pflag.is_set or
                                            self.rflag.is_set or
                                            self.sid_value.is_set or
                                            self.vflag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.algorithm.yfilter != YFilter.not_set or
                                            self.eflag.yfilter != YFilter.not_set or
                                            self.lflag.yfilter != YFilter.not_set or
                                            self.nflag.yfilter != YFilter.not_set or
                                            self.pflag.yfilter != YFilter.not_set or
                                            self.rflag.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.vflag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nodal-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.algorithm.get_name_leafdata())
                                        if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eflag.get_name_leafdata())
                                        if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lflag.get_name_leafdata())
                                        if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nflag.get_name_leafdata())
                                        if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pflag.get_name_leafdata())
                                        if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rflag.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vflag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "algorithm"):
                                            self.algorithm = value
                                            self.algorithm.value_namespace = name_space
                                            self.algorithm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eflag"):
                                            self.eflag = value
                                            self.eflag.value_namespace = name_space
                                            self.eflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lflag"):
                                            self.lflag = value
                                            self.lflag.value_namespace = name_space
                                            self.lflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nflag"):
                                            self.nflag = value
                                            self.nflag.value_namespace = name_space
                                            self.nflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pflag"):
                                            self.pflag = value
                                            self.pflag.value_namespace = name_space
                                            self.pflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rflag"):
                                            self.rflag = value
                                            self.rflag.value_namespace = name_space
                                            self.rflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vflag"):
                                            self.vflag = value
                                            self.vflag.value_namespace = name_space
                                            self.vflag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nodal_sid:
                                        if (c.has_data()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.advertising_origin.is_set or
                                        self.is_external_metric.is_set or
                                        self.is_external_reachability.is_set or
                                        self.is_interarea.is_set or
                                        self.is_propagated.is_set or
                                        self.level.is_set or
                                        self.metric.is_set or
                                        (self.summarization_status is not None and self.summarization_status.has_data()))

                                def has_operation(self):
                                    for c in self.nodal_sid:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_origin.yfilter != YFilter.not_set or
                                        self.is_external_metric.yfilter != YFilter.not_set or
                                        self.is_external_reachability.yfilter != YFilter.not_set or
                                        self.is_interarea.yfilter != YFilter.not_set or
                                        self.is_propagated.yfilter != YFilter.not_set or
                                        self.level.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        (self.summarization_status is not None and self.summarization_status.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-level-advertising-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_origin.is_set or self.advertising_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_origin.get_name_leafdata())
                                    if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                    if (self.is_external_reachability.is_set or self.is_external_reachability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_reachability.get_name_leafdata())
                                    if (self.is_interarea.is_set or self.is_interarea.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_interarea.get_name_leafdata())
                                    if (self.is_propagated.is_set or self.is_propagated.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_propagated.get_name_leafdata())
                                    if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.level.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nodal-sid"):
                                        for c in self.nodal_sid:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nodal_sid.append(c)
                                        return c

                                    if (child_yang_name == "summarization-status"):
                                        if (self.summarization_status is None):
                                            self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                            self.summarization_status.parent = self
                                            self._children_name_map["summarization_status"] = "summarization-status"
                                        return self.summarization_status

                                    if (child_yang_name == "tags"):
                                        for c in self.tags:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tags.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nodal-sid" or name == "summarization-status" or name == "tags" or name == "advertising-origin" or name == "is-external-metric" or name == "is-external-reachability" or name == "is-interarea" or name == "is-propagated" or name == "level" or name == "metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-origin"):
                                        self.advertising_origin = value
                                        self.advertising_origin.value_namespace = name_space
                                        self.advertising_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-metric"):
                                        self.is_external_metric = value
                                        self.is_external_metric.value_namespace = name_space
                                        self.is_external_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-reachability"):
                                        self.is_external_reachability = value
                                        self.is_external_reachability.value_namespace = name_space
                                        self.is_external_reachability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-interarea"):
                                        self.is_interarea = value
                                        self.is_interarea.value_namespace = name_space
                                        self.is_interarea.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-propagated"):
                                        self.is_propagated = value
                                        self.is_propagated.value_namespace = name_space
                                        self.is_propagated.value_namespace_prefix = name_space_prefix
                                    if(value_path == "level"):
                                        self.level = value
                                        self.level.value_namespace = name_space
                                        self.level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.connected_status is not None and self.connected_status.has_data()) or
                                    (self.native_status is not None and self.native_status.has_data()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_data()))

                            def has_operation(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.connected_status is not None and self.connected_status.has_operation()) or
                                    (self.native_status is not None and self.native_status.has_operation()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "connected-status"):
                                    if (self.connected_status is None):
                                        self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus()
                                        self.connected_status.parent = self
                                        self._children_name_map["connected_status"] = "connected-status"
                                    return self.connected_status

                                if (child_yang_name == "native-status"):
                                    if (self.native_status is None):
                                        self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus()
                                        self.native_status.parent = self
                                        self._children_name_map["native_status"] = "native-status"
                                    return self.native_status

                                if (child_yang_name == "per-level-advertising-detail"):
                                    for c in self.per_level_advertising_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_level_advertising_detail.append(c)
                                    return c

                                if (child_yang_name == "redistributed-status"):
                                    if (self.redistributed_status is None):
                                        self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus()
                                        self.redistributed_status.parent = self
                                        self._children_name_map["redistributed_status"] = "redistributed-status"
                                    return self.redistributed_status

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "connected-status" or name == "native-status" or name == "per-level-advertising-detail" or name == "redistributed-status" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ipv6_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ipv6_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv6-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv6-route"):
                                for c in self.ipv6_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ipv6_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv6-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ipv6FrrBackups(Entity):
                        """
                        IPv6 FRR table
                        
                        .. attribute:: ipv6frr_backup
                        
                        	FRR backup for an IPv6 network
                        	**type**\: list of    :py:class:`Ipv6FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups, self).__init__()

                            self.yang_name = "ipv6frr-backups"
                            self.yang_parent_name = "topology"

                            self.ipv6frr_backup = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups, self).__setattr__(name, value)


                        class Ipv6FrrBackup(Entity):
                            """
                            FRR backup for an IPv6 network
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:   :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:   :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of    :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail>`
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:   :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup, self).__init__()

                                self.yang_name = "ipv6frr-backup"
                                self.yang_parent_name = "ipv6frr-backups"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"
                                self._children_yang_names.add("connected-status")

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"
                                self._children_yang_names.add("native-status")

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"
                                self._children_yang_names.add("redistributed-status")

                                self.per_level_advertising_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup, self).__setattr__(name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:   :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv6frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._children_yang_names.add("connected-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus, self).__setattr__(name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.connected_details is not None and self.connected_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.connected_details is not None and self.connected_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "connected-details"):
                                        if (self.connected_details is None):
                                            self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus.ConnectedDetails()
                                            self.connected_details.parent = self
                                            self._children_name_map["connected_details"] = "connected-details"
                                        return self.connected_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "connected-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:   :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv6frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._children_yang_names.add("redistribution-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus, self).__setattr__(name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of    :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"

                                        self.isis_sh_route_redist_detail = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:   :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"

                                            self.level = YLeaf(YType.enumeration, "level")

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._children_yang_names.add("owner")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("level") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\:  str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:   :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"

                                                self.application_name = YLeaf(YType.str, "application-name")

                                                self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                                self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                                self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                                self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                                self.ospfv3_process_id = YLeaf(YType.str, "ospfv3-process-id")

                                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("application_name",
                                                                "bgp_as_number",
                                                                "eigrp_as_number",
                                                                "isis_instance_id",
                                                                "ospf_process_id",
                                                                "ospfv3_process_id",
                                                                "protocol") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.application_name.is_set or
                                                    self.bgp_as_number.is_set or
                                                    self.eigrp_as_number.is_set or
                                                    self.isis_instance_id.is_set or
                                                    self.ospf_process_id.is_set or
                                                    self.ospfv3_process_id.is_set or
                                                    self.protocol.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.application_name.yfilter != YFilter.not_set or
                                                    self.bgp_as_number.yfilter != YFilter.not_set or
                                                    self.eigrp_as_number.yfilter != YFilter.not_set or
                                                    self.isis_instance_id.yfilter != YFilter.not_set or
                                                    self.ospf_process_id.yfilter != YFilter.not_set or
                                                    self.ospfv3_process_id.yfilter != YFilter.not_set or
                                                    self.protocol.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "owner" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.application_name.is_set or self.application_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.application_name.get_name_leafdata())
                                                if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                                if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                                if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                                if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                                if (self.ospfv3_process_id.is_set or self.ospfv3_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospfv3_process_id.get_name_leafdata())
                                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "application-name" or name == "bgp-as-number" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "ospfv3-process-id" or name == "protocol"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "application-name"):
                                                    self.application_name = value
                                                    self.application_name.value_namespace = name_space
                                                    self.application_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bgp-as-number"):
                                                    self.bgp_as_number = value
                                                    self.bgp_as_number.value_namespace = name_space
                                                    self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "eigrp-as-number"):
                                                    self.eigrp_as_number = value
                                                    self.eigrp_as_number.value_namespace = name_space
                                                    self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "isis-instance-id"):
                                                    self.isis_instance_id = value
                                                    self.isis_instance_id.value_namespace = name_space
                                                    self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospf-process-id"):
                                                    self.ospf_process_id = value
                                                    self.ospf_process_id.value_namespace = name_space
                                                    self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospfv3-process-id"):
                                                    self.ospfv3_process_id = value
                                                    self.ospfv3_process_id.value_namespace = name_space
                                                    self.ospfv3_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol"):
                                                    self.protocol = value
                                                    self.protocol.value_namespace = name_space
                                                    self.protocol.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.level.is_set or
                                                (self.owner is not None and self.owner.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.level.yfilter != YFilter.not_set or
                                                (self.owner is not None and self.owner.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "isis-sh-route-redist-detail" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "owner"):
                                                if (self.owner is None):
                                                    self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                    self.owner.parent = self
                                                    self._children_name_map["owner"] = "owner"
                                                return self.owner

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "owner" or name == "level"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "level"):
                                                self.level = value
                                                self.level.value_namespace = name_space
                                                self.level.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "isis-sh-route-redist-detail"):
                                            for c in self.isis_sh_route_redist_detail:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.isis_sh_route_redist_detail.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "isis-sh-route-redist-detail"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistributed-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-details"):
                                        if (self.redistribution_details is None):
                                            self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus.RedistributionDetails()
                                            self.redistribution_details.parent = self
                                            self._children_name_map["redistribution_details"] = "redistribution-details"
                                        return self.redistribution_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:   :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv6frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._children_yang_names.add("native-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus, self).__setattr__(name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of    :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup>`
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:   :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"
                                        self._children_yang_names.add("primary")

                                        self.backup = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails, self).__setattr__(name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "primary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.priority.is_set or
                                            (self.primary is not None and self.primary.has_data()))

                                    def has_operation(self):
                                        for c in self.backup:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            (self.primary is not None and self.primary.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "native-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup"):
                                            for c in self.backup:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Backup()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup.append(c)
                                            return c

                                        if (child_yang_name == "primary"):
                                            if (self.primary is None):
                                                self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails.Primary()
                                                self.primary.parent = self
                                                self._children_name_map["primary"] = "primary"
                                            return self.primary

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup" or name == "primary" or name == "priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.native_details is not None and self.native_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.native_details is not None and self.native_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "native-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "native-details"):
                                        if (self.native_details is None):
                                            self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus.NativeDetails()
                                            self.native_details.parent = self
                                            self._children_name_map["native_details"] = "native-details"
                                        return self.native_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "native-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:   :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\:  bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\:  bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\:  bool
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\:  bool
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.NodalSid>`
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:   :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.Tags>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv6frr-backup"

                                    self.advertising_origin = YLeaf(YType.enumeration, "advertising-origin")

                                    self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                    self.is_external_reachability = YLeaf(YType.boolean, "is-external-reachability")

                                    self.is_interarea = YLeaf(YType.boolean, "is-interarea")

                                    self.is_propagated = YLeaf(YType.boolean, "is-propagated")

                                    self.level = YLeaf(YType.enumeration, "level")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"
                                    self._children_yang_names.add("summarization-status")

                                    self.nodal_sid = YList(self)
                                    self.tags = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_origin",
                                                    "is_external_metric",
                                                    "is_external_reachability",
                                                    "is_interarea",
                                                    "is_propagated",
                                                    "level",
                                                    "metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail, self).__setattr__(name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:   :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._children_yang_names.add("summary-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_valid.is_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summarization-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "summary-prefix"):
                                            if (self.summary_prefix is None):
                                                self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                                self.summary_prefix.parent = self
                                                self._children_name_map["summary_prefix"] = "summary-prefix"
                                            return self.summary_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "summary-prefix" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tags" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.algorithm = YLeaf(YType.uint8, "algorithm")

                                        self.eflag = YLeaf(YType.uint8, "eflag")

                                        self.lflag = YLeaf(YType.uint8, "lflag")

                                        self.nflag = YLeaf(YType.uint8, "nflag")

                                        self.pflag = YLeaf(YType.uint8, "pflag")

                                        self.rflag = YLeaf(YType.uint8, "rflag")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.vflag = YLeaf(YType.uint8, "vflag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("algorithm",
                                                        "eflag",
                                                        "lflag",
                                                        "nflag",
                                                        "pflag",
                                                        "rflag",
                                                        "sid_value",
                                                        "vflag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.algorithm.is_set or
                                            self.eflag.is_set or
                                            self.lflag.is_set or
                                            self.nflag.is_set or
                                            self.pflag.is_set or
                                            self.rflag.is_set or
                                            self.sid_value.is_set or
                                            self.vflag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.algorithm.yfilter != YFilter.not_set or
                                            self.eflag.yfilter != YFilter.not_set or
                                            self.lflag.yfilter != YFilter.not_set or
                                            self.nflag.yfilter != YFilter.not_set or
                                            self.pflag.yfilter != YFilter.not_set or
                                            self.rflag.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.vflag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nodal-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.algorithm.get_name_leafdata())
                                        if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eflag.get_name_leafdata())
                                        if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lflag.get_name_leafdata())
                                        if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nflag.get_name_leafdata())
                                        if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pflag.get_name_leafdata())
                                        if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rflag.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vflag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "algorithm"):
                                            self.algorithm = value
                                            self.algorithm.value_namespace = name_space
                                            self.algorithm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eflag"):
                                            self.eflag = value
                                            self.eflag.value_namespace = name_space
                                            self.eflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lflag"):
                                            self.lflag = value
                                            self.lflag.value_namespace = name_space
                                            self.lflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nflag"):
                                            self.nflag = value
                                            self.nflag.value_namespace = name_space
                                            self.nflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pflag"):
                                            self.pflag = value
                                            self.pflag.value_namespace = name_space
                                            self.pflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rflag"):
                                            self.rflag = value
                                            self.rflag.value_namespace = name_space
                                            self.rflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vflag"):
                                            self.vflag = value
                                            self.vflag.value_namespace = name_space
                                            self.vflag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nodal_sid:
                                        if (c.has_data()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.advertising_origin.is_set or
                                        self.is_external_metric.is_set or
                                        self.is_external_reachability.is_set or
                                        self.is_interarea.is_set or
                                        self.is_propagated.is_set or
                                        self.level.is_set or
                                        self.metric.is_set or
                                        (self.summarization_status is not None and self.summarization_status.has_data()))

                                def has_operation(self):
                                    for c in self.nodal_sid:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_origin.yfilter != YFilter.not_set or
                                        self.is_external_metric.yfilter != YFilter.not_set or
                                        self.is_external_reachability.yfilter != YFilter.not_set or
                                        self.is_interarea.yfilter != YFilter.not_set or
                                        self.is_propagated.yfilter != YFilter.not_set or
                                        self.level.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        (self.summarization_status is not None and self.summarization_status.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-level-advertising-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_origin.is_set or self.advertising_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_origin.get_name_leafdata())
                                    if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                    if (self.is_external_reachability.is_set or self.is_external_reachability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_reachability.get_name_leafdata())
                                    if (self.is_interarea.is_set or self.is_interarea.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_interarea.get_name_leafdata())
                                    if (self.is_propagated.is_set or self.is_propagated.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_propagated.get_name_leafdata())
                                    if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.level.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nodal-sid"):
                                        for c in self.nodal_sid:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.NodalSid()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nodal_sid.append(c)
                                        return c

                                    if (child_yang_name == "summarization-status"):
                                        if (self.summarization_status is None):
                                            self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                            self.summarization_status.parent = self
                                            self._children_name_map["summarization_status"] = "summarization-status"
                                        return self.summarization_status

                                    if (child_yang_name == "tags"):
                                        for c in self.tags:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail.Tags()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tags.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nodal-sid" or name == "summarization-status" or name == "tags" or name == "advertising-origin" or name == "is-external-metric" or name == "is-external-reachability" or name == "is-interarea" or name == "is-propagated" or name == "level" or name == "metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-origin"):
                                        self.advertising_origin = value
                                        self.advertising_origin.value_namespace = name_space
                                        self.advertising_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-metric"):
                                        self.is_external_metric = value
                                        self.is_external_metric.value_namespace = name_space
                                        self.is_external_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-reachability"):
                                        self.is_external_reachability = value
                                        self.is_external_reachability.value_namespace = name_space
                                        self.is_external_reachability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-interarea"):
                                        self.is_interarea = value
                                        self.is_interarea.value_namespace = name_space
                                        self.is_interarea.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-propagated"):
                                        self.is_propagated = value
                                        self.is_propagated.value_namespace = name_space
                                        self.is_propagated.value_namespace_prefix = name_space_prefix
                                    if(value_path == "level"):
                                        self.level = value
                                        self.level.value_namespace = name_space
                                        self.level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.connected_status is not None and self.connected_status.has_data()) or
                                    (self.native_status is not None and self.native_status.has_data()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_data()))

                            def has_operation(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.connected_status is not None and self.connected_status.has_operation()) or
                                    (self.native_status is not None and self.native_status.has_operation()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6frr-backup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "connected-status"):
                                    if (self.connected_status is None):
                                        self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.ConnectedStatus()
                                        self.connected_status.parent = self
                                        self._children_name_map["connected_status"] = "connected-status"
                                    return self.connected_status

                                if (child_yang_name == "native-status"):
                                    if (self.native_status is None):
                                        self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.NativeStatus()
                                        self.native_status.parent = self
                                        self._children_name_map["native_status"] = "native-status"
                                    return self.native_status

                                if (child_yang_name == "per-level-advertising-detail"):
                                    for c in self.per_level_advertising_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.PerLevelAdvertisingDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_level_advertising_detail.append(c)
                                    return c

                                if (child_yang_name == "redistributed-status"):
                                    if (self.redistributed_status is None):
                                        self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup.RedistributedStatus()
                                        self.redistributed_status.parent = self
                                        self._children_name_map["redistributed_status"] = "redistributed-status"
                                    return self.redistributed_status

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "connected-status" or name == "native-status" or name == "per-level-advertising-detail" or name == "redistributed-status" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ipv6frr_backup:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ipv6frr_backup:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv6frr-backups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv6frr-backup"):
                                for c in self.ipv6frr_backup:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups.Ipv6FrrBackup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ipv6frr_backup.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv6frr-backup"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ipv4FrrBackups(Entity):
                        """
                        IPv4 FRR table
                        
                        .. attribute:: ipv4frr_backup
                        
                        	FRR backup for an IPv4 network
                        	**type**\: list of    :py:class:`Ipv4FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups, self).__init__()

                            self.yang_name = "ipv4frr-backups"
                            self.yang_parent_name = "topology"

                            self.ipv4frr_backup = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups, self).__setattr__(name, value)


                        class Ipv4FrrBackup(Entity):
                            """
                            FRR backup for an IPv4 network
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:   :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:   :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of    :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail>`
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:   :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup, self).__init__()

                                self.yang_name = "ipv4frr-backup"
                                self.yang_parent_name = "ipv4frr-backups"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"
                                self._children_yang_names.add("connected-status")

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"
                                self._children_yang_names.add("native-status")

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"
                                self._children_yang_names.add("redistributed-status")

                                self.per_level_advertising_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup, self).__setattr__(name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:   :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv4frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._children_yang_names.add("connected-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus, self).__setattr__(name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.connected_details is not None and self.connected_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.connected_details is not None and self.connected_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "connected-details"):
                                        if (self.connected_details is None):
                                            self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus.ConnectedDetails()
                                            self.connected_details.parent = self
                                            self._children_name_map["connected_details"] = "connected-details"
                                        return self.connected_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "connected-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:   :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv4frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._children_yang_names.add("redistribution-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus, self).__setattr__(name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of    :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"

                                        self.isis_sh_route_redist_detail = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:   :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"

                                            self.level = YLeaf(YType.enumeration, "level")

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._children_yang_names.add("owner")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("level") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\:  str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:   :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"

                                                self.application_name = YLeaf(YType.str, "application-name")

                                                self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                                self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                                self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                                self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                                self.ospfv3_process_id = YLeaf(YType.str, "ospfv3-process-id")

                                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("application_name",
                                                                "bgp_as_number",
                                                                "eigrp_as_number",
                                                                "isis_instance_id",
                                                                "ospf_process_id",
                                                                "ospfv3_process_id",
                                                                "protocol") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.application_name.is_set or
                                                    self.bgp_as_number.is_set or
                                                    self.eigrp_as_number.is_set or
                                                    self.isis_instance_id.is_set or
                                                    self.ospf_process_id.is_set or
                                                    self.ospfv3_process_id.is_set or
                                                    self.protocol.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.application_name.yfilter != YFilter.not_set or
                                                    self.bgp_as_number.yfilter != YFilter.not_set or
                                                    self.eigrp_as_number.yfilter != YFilter.not_set or
                                                    self.isis_instance_id.yfilter != YFilter.not_set or
                                                    self.ospf_process_id.yfilter != YFilter.not_set or
                                                    self.ospfv3_process_id.yfilter != YFilter.not_set or
                                                    self.protocol.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "owner" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.application_name.is_set or self.application_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.application_name.get_name_leafdata())
                                                if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                                if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                                if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                                if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                                if (self.ospfv3_process_id.is_set or self.ospfv3_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospfv3_process_id.get_name_leafdata())
                                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "application-name" or name == "bgp-as-number" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "ospfv3-process-id" or name == "protocol"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "application-name"):
                                                    self.application_name = value
                                                    self.application_name.value_namespace = name_space
                                                    self.application_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bgp-as-number"):
                                                    self.bgp_as_number = value
                                                    self.bgp_as_number.value_namespace = name_space
                                                    self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "eigrp-as-number"):
                                                    self.eigrp_as_number = value
                                                    self.eigrp_as_number.value_namespace = name_space
                                                    self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "isis-instance-id"):
                                                    self.isis_instance_id = value
                                                    self.isis_instance_id.value_namespace = name_space
                                                    self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospf-process-id"):
                                                    self.ospf_process_id = value
                                                    self.ospf_process_id.value_namespace = name_space
                                                    self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospfv3-process-id"):
                                                    self.ospfv3_process_id = value
                                                    self.ospfv3_process_id.value_namespace = name_space
                                                    self.ospfv3_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol"):
                                                    self.protocol = value
                                                    self.protocol.value_namespace = name_space
                                                    self.protocol.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.level.is_set or
                                                (self.owner is not None and self.owner.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.level.yfilter != YFilter.not_set or
                                                (self.owner is not None and self.owner.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "isis-sh-route-redist-detail" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "owner"):
                                                if (self.owner is None):
                                                    self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                    self.owner.parent = self
                                                    self._children_name_map["owner"] = "owner"
                                                return self.owner

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "owner" or name == "level"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "level"):
                                                self.level = value
                                                self.level.value_namespace = name_space
                                                self.level.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "isis-sh-route-redist-detail"):
                                            for c in self.isis_sh_route_redist_detail:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.isis_sh_route_redist_detail.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "isis-sh-route-redist-detail"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistributed-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-details"):
                                        if (self.redistribution_details is None):
                                            self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus.RedistributionDetails()
                                            self.redistribution_details.parent = self
                                            self._children_name_map["redistribution_details"] = "redistribution-details"
                                        return self.redistribution_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:   :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv4frr-backup"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._children_yang_names.add("native-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus, self).__setattr__(name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of    :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup>`
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:   :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"
                                        self._children_yang_names.add("primary")

                                        self.backup = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails, self).__setattr__(name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "primary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.priority.is_set or
                                            (self.primary is not None and self.primary.has_data()))

                                    def has_operation(self):
                                        for c in self.backup:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            (self.primary is not None and self.primary.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "native-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup"):
                                            for c in self.backup:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Backup()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup.append(c)
                                            return c

                                        if (child_yang_name == "primary"):
                                            if (self.primary is None):
                                                self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails.Primary()
                                                self.primary.parent = self
                                                self._children_name_map["primary"] = "primary"
                                            return self.primary

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup" or name == "primary" or name == "priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.native_details is not None and self.native_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.native_details is not None and self.native_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "native-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "native-details"):
                                        if (self.native_details is None):
                                            self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus.NativeDetails()
                                            self.native_details.parent = self
                                            self._children_name_map["native_details"] = "native-details"
                                        return self.native_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "native-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:   :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\:  bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\:  bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\:  bool
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\:  bool
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.NodalSid>`
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:   :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.Tags>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv4frr-backup"

                                    self.advertising_origin = YLeaf(YType.enumeration, "advertising-origin")

                                    self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                    self.is_external_reachability = YLeaf(YType.boolean, "is-external-reachability")

                                    self.is_interarea = YLeaf(YType.boolean, "is-interarea")

                                    self.is_propagated = YLeaf(YType.boolean, "is-propagated")

                                    self.level = YLeaf(YType.enumeration, "level")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"
                                    self._children_yang_names.add("summarization-status")

                                    self.nodal_sid = YList(self)
                                    self.tags = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_origin",
                                                    "is_external_metric",
                                                    "is_external_reachability",
                                                    "is_interarea",
                                                    "is_propagated",
                                                    "level",
                                                    "metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail, self).__setattr__(name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:   :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._children_yang_names.add("summary-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_valid.is_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summarization-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "summary-prefix"):
                                            if (self.summary_prefix is None):
                                                self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                                self.summary_prefix.parent = self
                                                self._children_name_map["summary_prefix"] = "summary-prefix"
                                            return self.summary_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "summary-prefix" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tags" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.algorithm = YLeaf(YType.uint8, "algorithm")

                                        self.eflag = YLeaf(YType.uint8, "eflag")

                                        self.lflag = YLeaf(YType.uint8, "lflag")

                                        self.nflag = YLeaf(YType.uint8, "nflag")

                                        self.pflag = YLeaf(YType.uint8, "pflag")

                                        self.rflag = YLeaf(YType.uint8, "rflag")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.vflag = YLeaf(YType.uint8, "vflag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("algorithm",
                                                        "eflag",
                                                        "lflag",
                                                        "nflag",
                                                        "pflag",
                                                        "rflag",
                                                        "sid_value",
                                                        "vflag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.algorithm.is_set or
                                            self.eflag.is_set or
                                            self.lflag.is_set or
                                            self.nflag.is_set or
                                            self.pflag.is_set or
                                            self.rflag.is_set or
                                            self.sid_value.is_set or
                                            self.vflag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.algorithm.yfilter != YFilter.not_set or
                                            self.eflag.yfilter != YFilter.not_set or
                                            self.lflag.yfilter != YFilter.not_set or
                                            self.nflag.yfilter != YFilter.not_set or
                                            self.pflag.yfilter != YFilter.not_set or
                                            self.rflag.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.vflag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nodal-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.algorithm.get_name_leafdata())
                                        if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eflag.get_name_leafdata())
                                        if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lflag.get_name_leafdata())
                                        if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nflag.get_name_leafdata())
                                        if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pflag.get_name_leafdata())
                                        if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rflag.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vflag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "algorithm"):
                                            self.algorithm = value
                                            self.algorithm.value_namespace = name_space
                                            self.algorithm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eflag"):
                                            self.eflag = value
                                            self.eflag.value_namespace = name_space
                                            self.eflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lflag"):
                                            self.lflag = value
                                            self.lflag.value_namespace = name_space
                                            self.lflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nflag"):
                                            self.nflag = value
                                            self.nflag.value_namespace = name_space
                                            self.nflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pflag"):
                                            self.pflag = value
                                            self.pflag.value_namespace = name_space
                                            self.pflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rflag"):
                                            self.rflag = value
                                            self.rflag.value_namespace = name_space
                                            self.rflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vflag"):
                                            self.vflag = value
                                            self.vflag.value_namespace = name_space
                                            self.vflag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nodal_sid:
                                        if (c.has_data()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.advertising_origin.is_set or
                                        self.is_external_metric.is_set or
                                        self.is_external_reachability.is_set or
                                        self.is_interarea.is_set or
                                        self.is_propagated.is_set or
                                        self.level.is_set or
                                        self.metric.is_set or
                                        (self.summarization_status is not None and self.summarization_status.has_data()))

                                def has_operation(self):
                                    for c in self.nodal_sid:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_origin.yfilter != YFilter.not_set or
                                        self.is_external_metric.yfilter != YFilter.not_set or
                                        self.is_external_reachability.yfilter != YFilter.not_set or
                                        self.is_interarea.yfilter != YFilter.not_set or
                                        self.is_propagated.yfilter != YFilter.not_set or
                                        self.level.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        (self.summarization_status is not None and self.summarization_status.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-level-advertising-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_origin.is_set or self.advertising_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_origin.get_name_leafdata())
                                    if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                    if (self.is_external_reachability.is_set or self.is_external_reachability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_reachability.get_name_leafdata())
                                    if (self.is_interarea.is_set or self.is_interarea.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_interarea.get_name_leafdata())
                                    if (self.is_propagated.is_set or self.is_propagated.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_propagated.get_name_leafdata())
                                    if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.level.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nodal-sid"):
                                        for c in self.nodal_sid:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.NodalSid()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nodal_sid.append(c)
                                        return c

                                    if (child_yang_name == "summarization-status"):
                                        if (self.summarization_status is None):
                                            self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                            self.summarization_status.parent = self
                                            self._children_name_map["summarization_status"] = "summarization-status"
                                        return self.summarization_status

                                    if (child_yang_name == "tags"):
                                        for c in self.tags:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail.Tags()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tags.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nodal-sid" or name == "summarization-status" or name == "tags" or name == "advertising-origin" or name == "is-external-metric" or name == "is-external-reachability" or name == "is-interarea" or name == "is-propagated" or name == "level" or name == "metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-origin"):
                                        self.advertising_origin = value
                                        self.advertising_origin.value_namespace = name_space
                                        self.advertising_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-metric"):
                                        self.is_external_metric = value
                                        self.is_external_metric.value_namespace = name_space
                                        self.is_external_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-reachability"):
                                        self.is_external_reachability = value
                                        self.is_external_reachability.value_namespace = name_space
                                        self.is_external_reachability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-interarea"):
                                        self.is_interarea = value
                                        self.is_interarea.value_namespace = name_space
                                        self.is_interarea.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-propagated"):
                                        self.is_propagated = value
                                        self.is_propagated.value_namespace = name_space
                                        self.is_propagated.value_namespace_prefix = name_space_prefix
                                    if(value_path == "level"):
                                        self.level = value
                                        self.level.value_namespace = name_space
                                        self.level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.connected_status is not None and self.connected_status.has_data()) or
                                    (self.native_status is not None and self.native_status.has_data()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_data()))

                            def has_operation(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.connected_status is not None and self.connected_status.has_operation()) or
                                    (self.native_status is not None and self.native_status.has_operation()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4frr-backup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "connected-status"):
                                    if (self.connected_status is None):
                                        self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.ConnectedStatus()
                                        self.connected_status.parent = self
                                        self._children_name_map["connected_status"] = "connected-status"
                                    return self.connected_status

                                if (child_yang_name == "native-status"):
                                    if (self.native_status is None):
                                        self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.NativeStatus()
                                        self.native_status.parent = self
                                        self._children_name_map["native_status"] = "native-status"
                                    return self.native_status

                                if (child_yang_name == "per-level-advertising-detail"):
                                    for c in self.per_level_advertising_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.PerLevelAdvertisingDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_level_advertising_detail.append(c)
                                    return c

                                if (child_yang_name == "redistributed-status"):
                                    if (self.redistributed_status is None):
                                        self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup.RedistributedStatus()
                                        self.redistributed_status.parent = self
                                        self._children_name_map["redistributed_status"] = "redistributed-status"
                                    return self.redistributed_status

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "connected-status" or name == "native-status" or name == "per-level-advertising-detail" or name == "redistributed-status" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ipv4frr_backup:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ipv4frr_backup:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4frr-backups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4frr-backup"):
                                for c in self.ipv4frr_backup:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups.Ipv4FrrBackup()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ipv4frr_backup.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4frr-backup"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ipv4Routes(Entity):
                        """
                        IPv4 local route table
                        
                        .. attribute:: ipv4_route
                        
                        	An IPv4 route known to IS\-IS
                        	**type**\: list of    :py:class:`Ipv4Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes, self).__init__()

                            self.yang_name = "ipv4-routes"
                            self.yang_parent_name = "topology"

                            self.ipv4_route = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes, self).__setattr__(name, value)


                        class Ipv4Route(Entity):
                            """
                            An IPv4 route known to IS\-IS
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:   :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:   :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of    :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail>`
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:   :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route, self).__init__()

                                self.yang_name = "ipv4-route"
                                self.yang_parent_name = "ipv4-routes"

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"
                                self._children_yang_names.add("connected-status")

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"
                                self._children_yang_names.add("native-status")

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"
                                self._children_yang_names.add("redistributed-status")

                                self.per_level_advertising_detail = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("prefix",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route, self).__setattr__(name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:   :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv4-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._children_yang_names.add("connected-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus, self).__setattr__(name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"

                                        self.interface = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails, self).__setattr__(name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"

                                            self.entry = YLeaf(YType.str, "entry")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("entry") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.entry.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.entry.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "interface" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.entry.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "entry"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "entry"):
                                                self.entry = value
                                                self.entry.value_namespace = name_space
                                                self.entry.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.interface:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.interface:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "connected-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "interface"):
                                            for c in self.interface:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.interface.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "interface"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.connected_details is not None and self.connected_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.connected_details is not None and self.connected_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "connected-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "connected-details"):
                                        if (self.connected_details is None):
                                            self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails()
                                            self.connected_details.parent = self
                                            self._children_name_map["connected_details"] = "connected-details"
                                        return self.connected_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "connected-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:   :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv4-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._children_yang_names.add("redistribution-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus, self).__setattr__(name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of    :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"

                                        self.isis_sh_route_redist_detail = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in () and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails, self).__setattr__(name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:   :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"

                                            self.level = YLeaf(YType.enumeration, "level")

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._children_yang_names.add("owner")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("level") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__setattr__(name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\:  str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\:  str
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\:  str
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:   :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"

                                                self.application_name = YLeaf(YType.str, "application-name")

                                                self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                                self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                                self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                                self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                                self.ospfv3_process_id = YLeaf(YType.str, "ospfv3-process-id")

                                                self.protocol = YLeaf(YType.enumeration, "protocol")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("application_name",
                                                                "bgp_as_number",
                                                                "eigrp_as_number",
                                                                "isis_instance_id",
                                                                "ospf_process_id",
                                                                "ospfv3_process_id",
                                                                "protocol") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__setattr__(name, value)

                                            def has_data(self):
                                                return (
                                                    self.application_name.is_set or
                                                    self.bgp_as_number.is_set or
                                                    self.eigrp_as_number.is_set or
                                                    self.isis_instance_id.is_set or
                                                    self.ospf_process_id.is_set or
                                                    self.ospfv3_process_id.is_set or
                                                    self.protocol.is_set)

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.application_name.yfilter != YFilter.not_set or
                                                    self.bgp_as_number.yfilter != YFilter.not_set or
                                                    self.eigrp_as_number.yfilter != YFilter.not_set or
                                                    self.isis_instance_id.yfilter != YFilter.not_set or
                                                    self.ospf_process_id.yfilter != YFilter.not_set or
                                                    self.ospfv3_process_id.yfilter != YFilter.not_set or
                                                    self.protocol.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "owner" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.application_name.is_set or self.application_name.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.application_name.get_name_leafdata())
                                                if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                                if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                                if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                                if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                                if (self.ospfv3_process_id.is_set or self.ospfv3_process_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.ospfv3_process_id.get_name_leafdata())
                                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "application-name" or name == "bgp-as-number" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "ospfv3-process-id" or name == "protocol"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "application-name"):
                                                    self.application_name = value
                                                    self.application_name.value_namespace = name_space
                                                    self.application_name.value_namespace_prefix = name_space_prefix
                                                if(value_path == "bgp-as-number"):
                                                    self.bgp_as_number = value
                                                    self.bgp_as_number.value_namespace = name_space
                                                    self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "eigrp-as-number"):
                                                    self.eigrp_as_number = value
                                                    self.eigrp_as_number.value_namespace = name_space
                                                    self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                                if(value_path == "isis-instance-id"):
                                                    self.isis_instance_id = value
                                                    self.isis_instance_id.value_namespace = name_space
                                                    self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospf-process-id"):
                                                    self.ospf_process_id = value
                                                    self.ospf_process_id.value_namespace = name_space
                                                    self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "ospfv3-process-id"):
                                                    self.ospfv3_process_id = value
                                                    self.ospfv3_process_id.value_namespace = name_space
                                                    self.ospfv3_process_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "protocol"):
                                                    self.protocol = value
                                                    self.protocol.value_namespace = name_space
                                                    self.protocol.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.level.is_set or
                                                (self.owner is not None and self.owner.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.level.yfilter != YFilter.not_set or
                                                (self.owner is not None and self.owner.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "isis-sh-route-redist-detail" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "owner"):
                                                if (self.owner is None):
                                                    self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                    self.owner.parent = self
                                                    self._children_name_map["owner"] = "owner"
                                                return self.owner

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "owner" or name == "level"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "level"):
                                                self.level = value
                                                self.level.value_namespace = name_space
                                                self.level.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_data()):
                                                return True
                                        return False

                                    def has_operation(self):
                                        for c in self.isis_sh_route_redist_detail:
                                            if (c.has_operation()):
                                                return True
                                        return self.yfilter != YFilter.not_set

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "redistribution-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "isis-sh-route-redist-detail"):
                                            for c in self.isis_sh_route_redist_detail:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.isis_sh_route_redist_detail.append(c)
                                            return c

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "isis-sh-route-redist-detail"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        pass

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.redistribution_details is not None and self.redistribution_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "redistributed-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "redistribution-details"):
                                        if (self.redistribution_details is None):
                                            self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails()
                                            self.redistribution_details.parent = self
                                            self._children_name_map["redistribution_details"] = "redistribution-details"
                                        return self.redistribution_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "redistribution-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:   :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv4-route"

                                    self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._children_yang_names.add("native-details")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_valid") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus, self).__setattr__(name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of    :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup>`
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:   :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"

                                        self.priority = YLeaf(YType.enumeration, "priority")

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"
                                        self._children_yang_names.add("primary")

                                        self.backup = YList(self)

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("priority") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails, self).__setattr__(name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "primary" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of    :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\:  bool
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of    :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of    :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:   :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of    :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of    :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"

                                            self.administrative_distance = YLeaf(YType.uint16, "administrative-distance")

                                            self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.multicast_metric = YLeaf(YType.uint32, "multicast-metric")

                                            self.origin = YLeaf(YType.enumeration, "origin")

                                            self.explicit_path = YList(self)
                                            self.multicast_path = YList(self)
                                            self.multicast_source = YList(self)
                                            self.paths = YList(self)
                                            self.source = YList(self)
                                            self.srte_path = YList(self)
                                            self.ucmp_next_hop = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("administrative_distance",
                                                            "is_external_metric",
                                                            "metric",
                                                            "multicast_metric",
                                                            "origin") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup, self).__setattr__(name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "paths" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.total_ucmp_distance = YLeaf(YType.uint32, "total-ucmp-distance")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "total_ucmp_distance",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.total_ucmp_distance.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.total_ucmp_distance.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "ucmp-next-hop" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.total_ucmp_distance.is_set or self.total_ucmp_distance.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.total_ucmp_distance.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "total-ucmp-distance" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "total-ucmp-distance"):
                                                    self.total_ucmp_distance = value
                                                    self.total_ucmp_distance.value_namespace = name_space
                                                    self.total_ucmp_distance.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "srte-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\:  str
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:   :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\:  str
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of    :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"

                                                self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                self.is_sr_exclude_tunnel_interface = YLeaf(YType.boolean, "is-sr-exclude-tunnel-interface")

                                                self.is_te_tunnel_interface = YLeaf(YType.boolean, "is-te-tunnel-interface")

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_interface = YLeaf(YType.str, "tunnel-interface")

                                                self.weight = YLeaf(YType.uint32, "weight")

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._children_yang_names.add("frr-backup")

                                                self.uloop_explicit = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("egress_interface",
                                                                "is_sr_exclude_tunnel_interface",
                                                                "is_te_tunnel_interface",
                                                                "neighbor_address",
                                                                "neighbor_id",
                                                                "neighbor_snpa",
                                                                "segment_routing_sid_value",
                                                                "tag",
                                                                "tunnel_interface",
                                                                "weight") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__setattr__(name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of    :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:   :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\:  str
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.egress_interface = YLeaf(YType.str, "egress-interface")

                                                    self.is_downstream = YLeaf(YType.boolean, "is-downstream")

                                                    self.is_epcfrr_lfa = YLeaf(YType.boolean, "is-epcfrr-lfa")

                                                    self.is_lc_disjoint = YLeaf(YType.boolean, "is-lc-disjoint")

                                                    self.is_node_protecting = YLeaf(YType.boolean, "is-node-protecting")

                                                    self.is_primary_path = YLeaf(YType.boolean, "is-primary-path")

                                                    self.is_remote_lfa = YLeaf(YType.boolean, "is-remote-lfa")

                                                    self.is_srlg_disjoint = YLeaf(YType.boolean, "is-srlg-disjoint")

                                                    self.is_strict_spflfa = YLeaf(YType.boolean, "is-strict-spflfa")

                                                    self.is_tunnel_requested = YLeaf(YType.boolean, "is-tunnel-requested")

                                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                                    self.neighbor_snpa = YLeaf(YType.str, "neighbor-snpa")

                                                    self.num_sid = YLeaf(YType.uint32, "num-sid")

                                                    self.prefix_source_node_id = YLeaf(YType.str, "prefix-source-node-id")

                                                    self.remote_lfa_router_id = YLeaf(YType.str, "remote-lfa-router-id")

                                                    self.remote_lfa_router_pid = YLeaf(YType.str, "remote-lfa-router-pid")

                                                    self.remote_lfa_system_id = YLeaf(YType.str, "remote-lfa-system-id")

                                                    self.remote_lfa_system_pid = YLeaf(YType.str, "remote-lfa-system-pid")

                                                    self.segment_routing_sid_value = YLeaf(YType.uint32, "segment-routing-sid-value")

                                                    self.tilfa_computation = YLeaf(YType.enumeration, "tilfa-computation")

                                                    self.total_backup_distance = YLeaf(YType.uint32, "total-backup-distance")

                                                    self.tunnel_egress_interface = YLeaf(YType.str, "tunnel-egress-interface")

                                                    self.weight = YLeaf(YType.uint32, "weight")

                                                    self.backup_repair = YList(self)
                                                    self.segment_routing_sid_value_entry = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("backup_repair_list_size",
                                                                    "egress_interface",
                                                                    "is_downstream",
                                                                    "is_epcfrr_lfa",
                                                                    "is_lc_disjoint",
                                                                    "is_node_protecting",
                                                                    "is_primary_path",
                                                                    "is_remote_lfa",
                                                                    "is_srlg_disjoint",
                                                                    "is_strict_spflfa",
                                                                    "is_tunnel_requested",
                                                                    "neighbor_address",
                                                                    "neighbor_id",
                                                                    "neighbor_snpa",
                                                                    "num_sid",
                                                                    "prefix_source_node_id",
                                                                    "remote_lfa_router_id",
                                                                    "remote_lfa_router_pid",
                                                                    "remote_lfa_system_id",
                                                                    "remote_lfa_system_pid",
                                                                    "segment_routing_sid_value",
                                                                    "tilfa_computation",
                                                                    "total_backup_distance",
                                                                    "tunnel_egress_interface",
                                                                    "weight") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__setattr__(name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.entry = YLeaf(YType.uint32, "entry")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("entry") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.entry.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.entry.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "segment-routing-sid-value-entry" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "entry"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "entry"):
                                                            self.entry = value
                                                            self.entry.value_namespace = name_space
                                                            self.entry.value_namespace_prefix = name_space_prefix


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"

                                                        self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                        self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                        self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("repair_element_node_id",
                                                                        "repair_element_type",
                                                                        "repair_ipv4_addr",
                                                                        "repair_ipv6_addr",
                                                                        "repair_label",
                                                                        "repair_strict_spf_label") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.repair_element_node_id.is_set or
                                                            self.repair_element_type.is_set or
                                                            self.repair_ipv4_addr.is_set or
                                                            self.repair_ipv6_addr.is_set or
                                                            self.repair_label.is_set or
                                                            self.repair_strict_spf_label.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.repair_element_node_id.yfilter != YFilter.not_set or
                                                            self.repair_element_type.yfilter != YFilter.not_set or
                                                            self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                            self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                            self.repair_label.yfilter != YFilter.not_set or
                                                            self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "backup-repair" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                        if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                        if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                        if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                        if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                        if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "repair-element-node-id"):
                                                            self.repair_element_node_id = value
                                                            self.repair_element_node_id.value_namespace = name_space
                                                            self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-element-type"):
                                                            self.repair_element_type = value
                                                            self.repair_element_type.value_namespace = name_space
                                                            self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv4-addr"):
                                                            self.repair_ipv4_addr = value
                                                            self.repair_ipv4_addr.value_namespace = name_space
                                                            self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-ipv6-addr"):
                                                            self.repair_ipv6_addr = value
                                                            self.repair_ipv6_addr.value_namespace = name_space
                                                            self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-label"):
                                                            self.repair_label = value
                                                            self.repair_label.value_namespace = name_space
                                                            self.repair_label.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "repair-strict-spf-label"):
                                                            self.repair_strict_spf_label = value
                                                            self.repair_strict_spf_label.value_namespace = name_space
                                                            self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_data()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_data()):
                                                            return True
                                                    return (
                                                        self.backup_repair_list_size.is_set or
                                                        self.egress_interface.is_set or
                                                        self.is_downstream.is_set or
                                                        self.is_epcfrr_lfa.is_set or
                                                        self.is_lc_disjoint.is_set or
                                                        self.is_node_protecting.is_set or
                                                        self.is_primary_path.is_set or
                                                        self.is_remote_lfa.is_set or
                                                        self.is_srlg_disjoint.is_set or
                                                        self.is_strict_spflfa.is_set or
                                                        self.is_tunnel_requested.is_set or
                                                        self.neighbor_address.is_set or
                                                        self.neighbor_id.is_set or
                                                        self.neighbor_snpa.is_set or
                                                        self.num_sid.is_set or
                                                        self.prefix_source_node_id.is_set or
                                                        self.remote_lfa_router_id.is_set or
                                                        self.remote_lfa_router_pid.is_set or
                                                        self.remote_lfa_system_id.is_set or
                                                        self.remote_lfa_system_pid.is_set or
                                                        self.segment_routing_sid_value.is_set or
                                                        self.tilfa_computation.is_set or
                                                        self.total_backup_distance.is_set or
                                                        self.tunnel_egress_interface.is_set or
                                                        self.weight.is_set)

                                                def has_operation(self):
                                                    for c in self.backup_repair:
                                                        if (c.has_operation()):
                                                            return True
                                                    for c in self.segment_routing_sid_value_entry:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.backup_repair_list_size.yfilter != YFilter.not_set or
                                                        self.egress_interface.yfilter != YFilter.not_set or
                                                        self.is_downstream.yfilter != YFilter.not_set or
                                                        self.is_epcfrr_lfa.yfilter != YFilter.not_set or
                                                        self.is_lc_disjoint.yfilter != YFilter.not_set or
                                                        self.is_node_protecting.yfilter != YFilter.not_set or
                                                        self.is_primary_path.yfilter != YFilter.not_set or
                                                        self.is_remote_lfa.yfilter != YFilter.not_set or
                                                        self.is_srlg_disjoint.yfilter != YFilter.not_set or
                                                        self.is_strict_spflfa.yfilter != YFilter.not_set or
                                                        self.is_tunnel_requested.yfilter != YFilter.not_set or
                                                        self.neighbor_address.yfilter != YFilter.not_set or
                                                        self.neighbor_id.yfilter != YFilter.not_set or
                                                        self.neighbor_snpa.yfilter != YFilter.not_set or
                                                        self.num_sid.yfilter != YFilter.not_set or
                                                        self.prefix_source_node_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_router_pid.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_id.yfilter != YFilter.not_set or
                                                        self.remote_lfa_system_pid.yfilter != YFilter.not_set or
                                                        self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                        self.tilfa_computation.yfilter != YFilter.not_set or
                                                        self.total_backup_distance.yfilter != YFilter.not_set or
                                                        self.tunnel_egress_interface.yfilter != YFilter.not_set or
                                                        self.weight.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "frr-backup" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.backup_repair_list_size.is_set or self.backup_repair_list_size.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.backup_repair_list_size.get_name_leafdata())
                                                    if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                    if (self.is_downstream.is_set or self.is_downstream.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_downstream.get_name_leafdata())
                                                    if (self.is_epcfrr_lfa.is_set or self.is_epcfrr_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_epcfrr_lfa.get_name_leafdata())
                                                    if (self.is_lc_disjoint.is_set or self.is_lc_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_lc_disjoint.get_name_leafdata())
                                                    if (self.is_node_protecting.is_set or self.is_node_protecting.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_node_protecting.get_name_leafdata())
                                                    if (self.is_primary_path.is_set or self.is_primary_path.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_primary_path.get_name_leafdata())
                                                    if (self.is_remote_lfa.is_set or self.is_remote_lfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_remote_lfa.get_name_leafdata())
                                                    if (self.is_srlg_disjoint.is_set or self.is_srlg_disjoint.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_srlg_disjoint.get_name_leafdata())
                                                    if (self.is_strict_spflfa.is_set or self.is_strict_spflfa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_strict_spflfa.get_name_leafdata())
                                                    if (self.is_tunnel_requested.is_set or self.is_tunnel_requested.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_tunnel_requested.get_name_leafdata())
                                                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                    if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                    if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                    if (self.num_sid.is_set or self.num_sid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.num_sid.get_name_leafdata())
                                                    if (self.prefix_source_node_id.is_set or self.prefix_source_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.prefix_source_node_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_id.is_set or self.remote_lfa_router_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_id.get_name_leafdata())
                                                    if (self.remote_lfa_router_pid.is_set or self.remote_lfa_router_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_router_pid.get_name_leafdata())
                                                    if (self.remote_lfa_system_id.is_set or self.remote_lfa_system_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_id.get_name_leafdata())
                                                    if (self.remote_lfa_system_pid.is_set or self.remote_lfa_system_pid.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.remote_lfa_system_pid.get_name_leafdata())
                                                    if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                    if (self.tilfa_computation.is_set or self.tilfa_computation.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tilfa_computation.get_name_leafdata())
                                                    if (self.total_backup_distance.is_set or self.total_backup_distance.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.total_backup_distance.get_name_leafdata())
                                                    if (self.tunnel_egress_interface.is_set or self.tunnel_egress_interface.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.tunnel_egress_interface.get_name_leafdata())
                                                    if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.weight.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "backup-repair"):
                                                        for c in self.backup_repair:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.backup_repair.append(c)
                                                        return c

                                                    if (child_yang_name == "segment-routing-sid-value-entry"):
                                                        for c in self.segment_routing_sid_value_entry:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.segment_routing_sid_value_entry.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "backup-repair" or name == "segment-routing-sid-value-entry" or name == "backup-repair-list-size" or name == "egress-interface" or name == "is-downstream" or name == "is-epcfrr-lfa" or name == "is-lc-disjoint" or name == "is-node-protecting" or name == "is-primary-path" or name == "is-remote-lfa" or name == "is-srlg-disjoint" or name == "is-strict-spflfa" or name == "is-tunnel-requested" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "num-sid" or name == "prefix-source-node-id" or name == "remote-lfa-router-id" or name == "remote-lfa-router-pid" or name == "remote-lfa-system-id" or name == "remote-lfa-system-pid" or name == "segment-routing-sid-value" or name == "tilfa-computation" or name == "total-backup-distance" or name == "tunnel-egress-interface" or name == "weight"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "backup-repair-list-size"):
                                                        self.backup_repair_list_size = value
                                                        self.backup_repair_list_size.value_namespace = name_space
                                                        self.backup_repair_list_size.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "egress-interface"):
                                                        self.egress_interface = value
                                                        self.egress_interface.value_namespace = name_space
                                                        self.egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-downstream"):
                                                        self.is_downstream = value
                                                        self.is_downstream.value_namespace = name_space
                                                        self.is_downstream.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-epcfrr-lfa"):
                                                        self.is_epcfrr_lfa = value
                                                        self.is_epcfrr_lfa.value_namespace = name_space
                                                        self.is_epcfrr_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-lc-disjoint"):
                                                        self.is_lc_disjoint = value
                                                        self.is_lc_disjoint.value_namespace = name_space
                                                        self.is_lc_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-node-protecting"):
                                                        self.is_node_protecting = value
                                                        self.is_node_protecting.value_namespace = name_space
                                                        self.is_node_protecting.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-primary-path"):
                                                        self.is_primary_path = value
                                                        self.is_primary_path.value_namespace = name_space
                                                        self.is_primary_path.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-remote-lfa"):
                                                        self.is_remote_lfa = value
                                                        self.is_remote_lfa.value_namespace = name_space
                                                        self.is_remote_lfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-srlg-disjoint"):
                                                        self.is_srlg_disjoint = value
                                                        self.is_srlg_disjoint.value_namespace = name_space
                                                        self.is_srlg_disjoint.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-strict-spflfa"):
                                                        self.is_strict_spflfa = value
                                                        self.is_strict_spflfa.value_namespace = name_space
                                                        self.is_strict_spflfa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "is-tunnel-requested"):
                                                        self.is_tunnel_requested = value
                                                        self.is_tunnel_requested.value_namespace = name_space
                                                        self.is_tunnel_requested.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-address"):
                                                        self.neighbor_address = value
                                                        self.neighbor_address.value_namespace = name_space
                                                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-id"):
                                                        self.neighbor_id = value
                                                        self.neighbor_id.value_namespace = name_space
                                                        self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "neighbor-snpa"):
                                                        self.neighbor_snpa = value
                                                        self.neighbor_snpa.value_namespace = name_space
                                                        self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "num-sid"):
                                                        self.num_sid = value
                                                        self.num_sid.value_namespace = name_space
                                                        self.num_sid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "prefix-source-node-id"):
                                                        self.prefix_source_node_id = value
                                                        self.prefix_source_node_id.value_namespace = name_space
                                                        self.prefix_source_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-id"):
                                                        self.remote_lfa_router_id = value
                                                        self.remote_lfa_router_id.value_namespace = name_space
                                                        self.remote_lfa_router_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-router-pid"):
                                                        self.remote_lfa_router_pid = value
                                                        self.remote_lfa_router_pid.value_namespace = name_space
                                                        self.remote_lfa_router_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-id"):
                                                        self.remote_lfa_system_id = value
                                                        self.remote_lfa_system_id.value_namespace = name_space
                                                        self.remote_lfa_system_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "remote-lfa-system-pid"):
                                                        self.remote_lfa_system_pid = value
                                                        self.remote_lfa_system_pid.value_namespace = name_space
                                                        self.remote_lfa_system_pid.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "segment-routing-sid-value"):
                                                        self.segment_routing_sid_value = value
                                                        self.segment_routing_sid_value.value_namespace = name_space
                                                        self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tilfa-computation"):
                                                        self.tilfa_computation = value
                                                        self.tilfa_computation.value_namespace = name_space
                                                        self.tilfa_computation.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "total-backup-distance"):
                                                        self.total_backup_distance = value
                                                        self.total_backup_distance.value_namespace = name_space
                                                        self.total_backup_distance.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "tunnel-egress-interface"):
                                                        self.tunnel_egress_interface = value
                                                        self.tunnel_egress_interface.value_namespace = name_space
                                                        self.tunnel_egress_interface.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "weight"):
                                                        self.weight = value
                                                        self.weight.value_namespace = name_space
                                                        self.weight.value_namespace_prefix = name_space_prefix


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\:  str
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"

                                                    self.repair_element_node_id = YLeaf(YType.str, "repair-element-node-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_ipv4_addr = YLeaf(YType.str, "repair-ipv4-addr")

                                                    self.repair_ipv6_addr = YLeaf(YType.str, "repair-ipv6-addr")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")

                                                    self.repair_strict_spf_label = YLeaf(YType.uint32, "repair-strict-spf-label")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("repair_element_node_id",
                                                                    "repair_element_type",
                                                                    "repair_ipv4_addr",
                                                                    "repair_ipv6_addr",
                                                                    "repair_label",
                                                                    "repair_strict_spf_label") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.repair_element_node_id.is_set or
                                                        self.repair_element_type.is_set or
                                                        self.repair_ipv4_addr.is_set or
                                                        self.repair_ipv6_addr.is_set or
                                                        self.repair_label.is_set or
                                                        self.repair_strict_spf_label.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.repair_element_node_id.yfilter != YFilter.not_set or
                                                        self.repair_element_type.yfilter != YFilter.not_set or
                                                        self.repair_ipv4_addr.yfilter != YFilter.not_set or
                                                        self.repair_ipv6_addr.yfilter != YFilter.not_set or
                                                        self.repair_label.yfilter != YFilter.not_set or
                                                        self.repair_strict_spf_label.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "uloop-explicit" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.repair_element_node_id.is_set or self.repair_element_node_id.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_node_id.get_name_leafdata())
                                                    if (self.repair_element_type.is_set or self.repair_element_type.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_element_type.get_name_leafdata())
                                                    if (self.repair_ipv4_addr.is_set or self.repair_ipv4_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv4_addr.get_name_leafdata())
                                                    if (self.repair_ipv6_addr.is_set or self.repair_ipv6_addr.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_ipv6_addr.get_name_leafdata())
                                                    if (self.repair_label.is_set or self.repair_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_label.get_name_leafdata())
                                                    if (self.repair_strict_spf_label.is_set or self.repair_strict_spf_label.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.repair_strict_spf_label.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "repair-element-node-id" or name == "repair-element-type" or name == "repair-ipv4-addr" or name == "repair-ipv6-addr" or name == "repair-label" or name == "repair-strict-spf-label"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "repair-element-node-id"):
                                                        self.repair_element_node_id = value
                                                        self.repair_element_node_id.value_namespace = name_space
                                                        self.repair_element_node_id.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-element-type"):
                                                        self.repair_element_type = value
                                                        self.repair_element_type.value_namespace = name_space
                                                        self.repair_element_type.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv4-addr"):
                                                        self.repair_ipv4_addr = value
                                                        self.repair_ipv4_addr.value_namespace = name_space
                                                        self.repair_ipv4_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-ipv6-addr"):
                                                        self.repair_ipv6_addr = value
                                                        self.repair_ipv6_addr.value_namespace = name_space
                                                        self.repair_ipv6_addr.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-label"):
                                                        self.repair_label = value
                                                        self.repair_label.value_namespace = name_space
                                                        self.repair_label.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "repair-strict-spf-label"):
                                                        self.repair_strict_spf_label = value
                                                        self.repair_strict_spf_label.value_namespace = name_space
                                                        self.repair_strict_spf_label.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.egress_interface.is_set or
                                                    self.is_sr_exclude_tunnel_interface.is_set or
                                                    self.is_te_tunnel_interface.is_set or
                                                    self.neighbor_address.is_set or
                                                    self.neighbor_id.is_set or
                                                    self.neighbor_snpa.is_set or
                                                    self.segment_routing_sid_value.is_set or
                                                    self.tag.is_set or
                                                    self.tunnel_interface.is_set or
                                                    self.weight.is_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_data()))

                                            def has_operation(self):
                                                for c in self.uloop_explicit:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.egress_interface.yfilter != YFilter.not_set or
                                                    self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.is_te_tunnel_interface.yfilter != YFilter.not_set or
                                                    self.neighbor_address.yfilter != YFilter.not_set or
                                                    self.neighbor_id.yfilter != YFilter.not_set or
                                                    self.neighbor_snpa.yfilter != YFilter.not_set or
                                                    self.segment_routing_sid_value.yfilter != YFilter.not_set or
                                                    self.tag.yfilter != YFilter.not_set or
                                                    self.tunnel_interface.yfilter != YFilter.not_set or
                                                    self.weight.yfilter != YFilter.not_set or
                                                    (self.frr_backup is not None and self.frr_backup.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "explicit-path" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.egress_interface.is_set or self.egress_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.egress_interface.get_name_leafdata())
                                                if (self.is_sr_exclude_tunnel_interface.is_set or self.is_sr_exclude_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_sr_exclude_tunnel_interface.get_name_leafdata())
                                                if (self.is_te_tunnel_interface.is_set or self.is_te_tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.is_te_tunnel_interface.get_name_leafdata())
                                                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                                                if (self.neighbor_id.is_set or self.neighbor_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_id.get_name_leafdata())
                                                if (self.neighbor_snpa.is_set or self.neighbor_snpa.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.neighbor_snpa.get_name_leafdata())
                                                if (self.segment_routing_sid_value.is_set or self.segment_routing_sid_value.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.segment_routing_sid_value.get_name_leafdata())
                                                if (self.tag.is_set or self.tag.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tag.get_name_leafdata())
                                                if (self.tunnel_interface.is_set or self.tunnel_interface.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.tunnel_interface.get_name_leafdata())
                                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "frr-backup"):
                                                    if (self.frr_backup is None):
                                                        self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                        self.frr_backup.parent = self
                                                        self._children_name_map["frr_backup"] = "frr-backup"
                                                    return self.frr_backup

                                                if (child_yang_name == "uloop-explicit"):
                                                    for c in self.uloop_explicit:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.uloop_explicit.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "frr-backup" or name == "uloop-explicit" or name == "egress-interface" or name == "is-sr-exclude-tunnel-interface" or name == "is-te-tunnel-interface" or name == "neighbor-address" or name == "neighbor-id" or name == "neighbor-snpa" or name == "segment-routing-sid-value" or name == "tag" or name == "tunnel-interface" or name == "weight"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "egress-interface"):
                                                    self.egress_interface = value
                                                    self.egress_interface.value_namespace = name_space
                                                    self.egress_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-sr-exclude-tunnel-interface"):
                                                    self.is_sr_exclude_tunnel_interface = value
                                                    self.is_sr_exclude_tunnel_interface.value_namespace = name_space
                                                    self.is_sr_exclude_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "is-te-tunnel-interface"):
                                                    self.is_te_tunnel_interface = value
                                                    self.is_te_tunnel_interface.value_namespace = name_space
                                                    self.is_te_tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-address"):
                                                    self.neighbor_address = value
                                                    self.neighbor_address.value_namespace = name_space
                                                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-id"):
                                                    self.neighbor_id = value
                                                    self.neighbor_id.value_namespace = name_space
                                                    self.neighbor_id.value_namespace_prefix = name_space_prefix
                                                if(value_path == "neighbor-snpa"):
                                                    self.neighbor_snpa = value
                                                    self.neighbor_snpa.value_namespace = name_space
                                                    self.neighbor_snpa.value_namespace_prefix = name_space_prefix
                                                if(value_path == "segment-routing-sid-value"):
                                                    self.segment_routing_sid_value = value
                                                    self.segment_routing_sid_value.value_namespace = name_space
                                                    self.segment_routing_sid_value.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tag"):
                                                    self.tag = value
                                                    self.tag.value_namespace = name_space
                                                    self.tag.value_namespace_prefix = name_space_prefix
                                                if(value_path == "tunnel-interface"):
                                                    self.tunnel_interface = value
                                                    self.tunnel_interface.value_namespace = name_space
                                                    self.tunnel_interface.value_namespace_prefix = name_space_prefix
                                                if(value_path == "weight"):
                                                    self.weight = value
                                                    self.weight.value_namespace = name_space
                                                    self.weight.value_namespace_prefix = name_space_prefix


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"

                                                self.source_address = YLeaf(YType.str, "source-address")

                                                self.source_lsp_id = YLeaf(YType.str, "source-lsp-id")

                                                self.nodal_sid = YList(self)
                                                self.tags = YList(self)

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("source_address",
                                                                "source_lsp_id") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__setattr__(name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.entry = YLeaf(YType.uint32, "entry")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("entry") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.entry.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.entry.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "tags" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "entry"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "entry"):
                                                        self.entry = value
                                                        self.entry.value_namespace = name_space
                                                        self.entry.value_namespace_prefix = name_space_prefix


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"

                                                    self.algorithm = YLeaf(YType.uint8, "algorithm")

                                                    self.eflag = YLeaf(YType.uint8, "eflag")

                                                    self.lflag = YLeaf(YType.uint8, "lflag")

                                                    self.nflag = YLeaf(YType.uint8, "nflag")

                                                    self.pflag = YLeaf(YType.uint8, "pflag")

                                                    self.rflag = YLeaf(YType.uint8, "rflag")

                                                    self.sid_value = YLeaf(YType.uint32, "sid-value")

                                                    self.vflag = YLeaf(YType.uint8, "vflag")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("algorithm",
                                                                    "eflag",
                                                                    "lflag",
                                                                    "nflag",
                                                                    "pflag",
                                                                    "rflag",
                                                                    "sid_value",
                                                                    "vflag") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return (
                                                        self.algorithm.is_set or
                                                        self.eflag.is_set or
                                                        self.lflag.is_set or
                                                        self.nflag.is_set or
                                                        self.pflag.is_set or
                                                        self.rflag.is_set or
                                                        self.sid_value.is_set or
                                                        self.vflag.is_set)

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.algorithm.yfilter != YFilter.not_set or
                                                        self.eflag.yfilter != YFilter.not_set or
                                                        self.lflag.yfilter != YFilter.not_set or
                                                        self.nflag.yfilter != YFilter.not_set or
                                                        self.pflag.yfilter != YFilter.not_set or
                                                        self.rflag.yfilter != YFilter.not_set or
                                                        self.sid_value.yfilter != YFilter.not_set or
                                                        self.vflag.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "nodal-sid" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.algorithm.get_name_leafdata())
                                                    if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.eflag.get_name_leafdata())
                                                    if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.lflag.get_name_leafdata())
                                                    if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.nflag.get_name_leafdata())
                                                    if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.pflag.get_name_leafdata())
                                                    if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.rflag.get_name_leafdata())
                                                    if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.sid_value.get_name_leafdata())
                                                    if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.vflag.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "algorithm"):
                                                        self.algorithm = value
                                                        self.algorithm.value_namespace = name_space
                                                        self.algorithm.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "eflag"):
                                                        self.eflag = value
                                                        self.eflag.value_namespace = name_space
                                                        self.eflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "lflag"):
                                                        self.lflag = value
                                                        self.lflag.value_namespace = name_space
                                                        self.lflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "nflag"):
                                                        self.nflag = value
                                                        self.nflag.value_namespace = name_space
                                                        self.nflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "pflag"):
                                                        self.pflag = value
                                                        self.pflag.value_namespace = name_space
                                                        self.pflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "rflag"):
                                                        self.rflag = value
                                                        self.rflag.value_namespace = name_space
                                                        self.rflag.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "sid-value"):
                                                        self.sid_value = value
                                                        self.sid_value.value_namespace = name_space
                                                        self.sid_value.value_namespace_prefix = name_space_prefix
                                                    if(value_path == "vflag"):
                                                        self.vflag = value
                                                        self.vflag.value_namespace = name_space
                                                        self.vflag.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_data()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_data()):
                                                        return True
                                                return (
                                                    self.source_address.is_set or
                                                    self.source_lsp_id.is_set)

                                            def has_operation(self):
                                                for c in self.nodal_sid:
                                                    if (c.has_operation()):
                                                        return True
                                                for c in self.tags:
                                                    if (c.has_operation()):
                                                        return True
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.source_address.yfilter != YFilter.not_set or
                                                    self.source_lsp_id.yfilter != YFilter.not_set)

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "multicast-source" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_address.get_name_leafdata())
                                                if (self.source_lsp_id.is_set or self.source_lsp_id.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.source_lsp_id.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "nodal-sid"):
                                                    for c in self.nodal_sid:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.nodal_sid.append(c)
                                                    return c

                                                if (child_yang_name == "tags"):
                                                    for c in self.tags:
                                                        segment = c.get_segment_path()
                                                        if (segment_path == segment):
                                                            return c
                                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags()
                                                    c.parent = self
                                                    local_reference_key = "ydk::seg::%s" % segment_path
                                                    self._local_refs[local_reference_key] = c
                                                    self.tags.append(c)
                                                    return c

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "nodal-sid" or name == "tags" or name == "source-address" or name == "source-lsp-id"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "source-address"):
                                                    self.source_address = value
                                                    self.source_address.value_namespace = name_space
                                                    self.source_address.value_namespace_prefix = name_space_prefix
                                                if(value_path == "source-lsp-id"):
                                                    self.source_lsp_id = value
                                                    self.source_lsp_id.value_namespace = name_space
                                                    self.source_lsp_id.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.explicit_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_data()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_data()):
                                                    return True
                                            return (
                                                self.administrative_distance.is_set or
                                                self.is_external_metric.is_set or
                                                self.metric.is_set or
                                                self.multicast_metric.is_set or
                                                self.origin.is_set)

                                        def has_operation(self):
                                            for c in self.explicit_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.multicast_source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.paths:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.source:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.srte_path:
                                                if (c.has_operation()):
                                                    return True
                                            for c in self.ucmp_next_hop:
                                                if (c.has_operation()):
                                                    return True
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.administrative_distance.yfilter != YFilter.not_set or
                                                self.is_external_metric.yfilter != YFilter.not_set or
                                                self.metric.yfilter != YFilter.not_set or
                                                self.multicast_metric.yfilter != YFilter.not_set or
                                                self.origin.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "backup" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.administrative_distance.is_set or self.administrative_distance.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.administrative_distance.get_name_leafdata())
                                            if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.metric.get_name_leafdata())
                                            if (self.multicast_metric.is_set or self.multicast_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.multicast_metric.get_name_leafdata())
                                            if (self.origin.is_set or self.origin.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.origin.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "explicit-path"):
                                                for c in self.explicit_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.explicit_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-path"):
                                                for c in self.multicast_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_path.append(c)
                                                return c

                                            if (child_yang_name == "multicast-source"):
                                                for c in self.multicast_source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.multicast_source.append(c)
                                                return c

                                            if (child_yang_name == "paths"):
                                                for c in self.paths:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.paths.append(c)
                                                return c

                                            if (child_yang_name == "source"):
                                                for c in self.source:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.source.append(c)
                                                return c

                                            if (child_yang_name == "srte-path"):
                                                for c in self.srte_path:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.srte_path.append(c)
                                                return c

                                            if (child_yang_name == "ucmp-next-hop"):
                                                for c in self.ucmp_next_hop:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.ucmp_next_hop.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "explicit-path" or name == "multicast-path" or name == "multicast-source" or name == "paths" or name == "source" or name == "srte-path" or name == "ucmp-next-hop" or name == "administrative-distance" or name == "is-external-metric" or name == "metric" or name == "multicast-metric" or name == "origin"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "administrative-distance"):
                                                self.administrative_distance = value
                                                self.administrative_distance.value_namespace = name_space
                                                self.administrative_distance.value_namespace_prefix = name_space_prefix
                                            if(value_path == "is-external-metric"):
                                                self.is_external_metric = value
                                                self.is_external_metric.value_namespace = name_space
                                                self.is_external_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "metric"):
                                                self.metric = value
                                                self.metric.value_namespace = name_space
                                                self.metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "multicast-metric"):
                                                self.multicast_metric = value
                                                self.multicast_metric.value_namespace = name_space
                                                self.multicast_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "origin"):
                                                self.origin = value
                                                self.origin.value_namespace = name_space
                                                self.origin.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        for c in self.backup:
                                            if (c.has_data()):
                                                return True
                                        return (
                                            self.priority.is_set or
                                            (self.primary is not None and self.primary.has_data()))

                                    def has_operation(self):
                                        for c in self.backup:
                                            if (c.has_operation()):
                                                return True
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.priority.yfilter != YFilter.not_set or
                                            (self.primary is not None and self.primary.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "native-details" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.priority.is_set or self.priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.priority.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "backup"):
                                            for c in self.backup:
                                                segment = c.get_segment_path()
                                                if (segment_path == segment):
                                                    return c
                                            c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup()
                                            c.parent = self
                                            local_reference_key = "ydk::seg::%s" % segment_path
                                            self._local_refs[local_reference_key] = c
                                            self.backup.append(c)
                                            return c

                                        if (child_yang_name == "primary"):
                                            if (self.primary is None):
                                                self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary()
                                                self.primary.parent = self
                                                self._children_name_map["primary"] = "primary"
                                            return self.primary

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "backup" or name == "primary" or name == "priority"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "priority"):
                                            self.priority = value
                                            self.priority.value_namespace = name_space
                                            self.priority.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.is_valid.is_set or
                                        (self.native_details is not None and self.native_details.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_valid.yfilter != YFilter.not_set or
                                        (self.native_details is not None and self.native_details.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "native-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_valid.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "native-details"):
                                        if (self.native_details is None):
                                            self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails()
                                            self.native_details.parent = self
                                            self._children_name_map["native_details"] = "native-details"
                                        return self.native_details

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "native-details" or name == "is-valid"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-valid"):
                                        self.is_valid = value
                                        self.is_valid.value_namespace = name_space
                                        self.is_valid.value_namespace_prefix = name_space_prefix


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:   :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\:  bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\:  bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\:  bool
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\:  bool
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of    :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid>`
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:   :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of    :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv4-route"

                                    self.advertising_origin = YLeaf(YType.enumeration, "advertising-origin")

                                    self.is_external_metric = YLeaf(YType.boolean, "is-external-metric")

                                    self.is_external_reachability = YLeaf(YType.boolean, "is-external-reachability")

                                    self.is_interarea = YLeaf(YType.boolean, "is-interarea")

                                    self.is_propagated = YLeaf(YType.boolean, "is-propagated")

                                    self.level = YLeaf(YType.enumeration, "level")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"
                                    self._children_yang_names.add("summarization-status")

                                    self.nodal_sid = YList(self)
                                    self.tags = YList(self)

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("advertising_origin",
                                                    "is_external_metric",
                                                    "is_external_reachability",
                                                    "is_interarea",
                                                    "is_propagated",
                                                    "level",
                                                    "metric") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail, self).__setattr__(name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:   :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.is_valid = YLeaf(YType.enumeration, "is-valid")

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._children_yang_names.add("summary-prefix")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("is_valid") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__setattr__(name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("prefix",
                                                            "prefix_length") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__setattr__(name, value)

                                        def has_data(self):
                                            return (
                                                self.prefix.is_set or
                                                self.prefix_length.is_set)

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.prefix.yfilter != YFilter.not_set or
                                                self.prefix_length.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "summary-prefix" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "prefix" or name == "prefix-length"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "prefix"):
                                                self.prefix = value
                                                self.prefix.value_namespace = name_space
                                                self.prefix.value_namespace_prefix = name_space_prefix
                                            if(value_path == "prefix-length"):
                                                self.prefix_length = value
                                                self.prefix_length.value_namespace = name_space
                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.is_valid.is_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.is_valid.yfilter != YFilter.not_set or
                                            (self.summary_prefix is not None and self.summary_prefix.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "summarization-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.is_valid.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "summary-prefix"):
                                            if (self.summary_prefix is None):
                                                self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                                self.summary_prefix.parent = self
                                                self._children_name_map["summary_prefix"] = "summary-prefix"
                                            return self.summary_prefix

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "summary-prefix" or name == "is-valid"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "is-valid"):
                                            self.is_valid = value
                                            self.is_valid.value_namespace = name_space
                                            self.is_valid.value_namespace_prefix = name_space_prefix


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.entry = YLeaf(YType.uint32, "entry")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("entry") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.entry.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.entry.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "tags" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.entry.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "entry"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "entry"):
                                            self.entry = value
                                            self.entry.value_namespace = name_space
                                            self.entry.value_namespace_prefix = name_space_prefix


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"

                                        self.algorithm = YLeaf(YType.uint8, "algorithm")

                                        self.eflag = YLeaf(YType.uint8, "eflag")

                                        self.lflag = YLeaf(YType.uint8, "lflag")

                                        self.nflag = YLeaf(YType.uint8, "nflag")

                                        self.pflag = YLeaf(YType.uint8, "pflag")

                                        self.rflag = YLeaf(YType.uint8, "rflag")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.vflag = YLeaf(YType.uint8, "vflag")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("algorithm",
                                                        "eflag",
                                                        "lflag",
                                                        "nflag",
                                                        "pflag",
                                                        "rflag",
                                                        "sid_value",
                                                        "vflag") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.algorithm.is_set or
                                            self.eflag.is_set or
                                            self.lflag.is_set or
                                            self.nflag.is_set or
                                            self.pflag.is_set or
                                            self.rflag.is_set or
                                            self.sid_value.is_set or
                                            self.vflag.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.algorithm.yfilter != YFilter.not_set or
                                            self.eflag.yfilter != YFilter.not_set or
                                            self.lflag.yfilter != YFilter.not_set or
                                            self.nflag.yfilter != YFilter.not_set or
                                            self.pflag.yfilter != YFilter.not_set or
                                            self.rflag.yfilter != YFilter.not_set or
                                            self.sid_value.yfilter != YFilter.not_set or
                                            self.vflag.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "nodal-sid" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.algorithm.is_set or self.algorithm.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.algorithm.get_name_leafdata())
                                        if (self.eflag.is_set or self.eflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.eflag.get_name_leafdata())
                                        if (self.lflag.is_set or self.lflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.lflag.get_name_leafdata())
                                        if (self.nflag.is_set or self.nflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.nflag.get_name_leafdata())
                                        if (self.pflag.is_set or self.pflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.pflag.get_name_leafdata())
                                        if (self.rflag.is_set or self.rflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.rflag.get_name_leafdata())
                                        if (self.sid_value.is_set or self.sid_value.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.sid_value.get_name_leafdata())
                                        if (self.vflag.is_set or self.vflag.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vflag.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "algorithm" or name == "eflag" or name == "lflag" or name == "nflag" or name == "pflag" or name == "rflag" or name == "sid-value" or name == "vflag"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "algorithm"):
                                            self.algorithm = value
                                            self.algorithm.value_namespace = name_space
                                            self.algorithm.value_namespace_prefix = name_space_prefix
                                        if(value_path == "eflag"):
                                            self.eflag = value
                                            self.eflag.value_namespace = name_space
                                            self.eflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "lflag"):
                                            self.lflag = value
                                            self.lflag.value_namespace = name_space
                                            self.lflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "nflag"):
                                            self.nflag = value
                                            self.nflag.value_namespace = name_space
                                            self.nflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "pflag"):
                                            self.pflag = value
                                            self.pflag.value_namespace = name_space
                                            self.pflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "rflag"):
                                            self.rflag = value
                                            self.rflag.value_namespace = name_space
                                            self.rflag.value_namespace_prefix = name_space_prefix
                                        if(value_path == "sid-value"):
                                            self.sid_value = value
                                            self.sid_value.value_namespace = name_space
                                            self.sid_value.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vflag"):
                                            self.vflag = value
                                            self.vflag.value_namespace = name_space
                                            self.vflag.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    for c in self.nodal_sid:
                                        if (c.has_data()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_data()):
                                            return True
                                    return (
                                        self.advertising_origin.is_set or
                                        self.is_external_metric.is_set or
                                        self.is_external_reachability.is_set or
                                        self.is_interarea.is_set or
                                        self.is_propagated.is_set or
                                        self.level.is_set or
                                        self.metric.is_set or
                                        (self.summarization_status is not None and self.summarization_status.has_data()))

                                def has_operation(self):
                                    for c in self.nodal_sid:
                                        if (c.has_operation()):
                                            return True
                                    for c in self.tags:
                                        if (c.has_operation()):
                                            return True
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.advertising_origin.yfilter != YFilter.not_set or
                                        self.is_external_metric.yfilter != YFilter.not_set or
                                        self.is_external_reachability.yfilter != YFilter.not_set or
                                        self.is_interarea.yfilter != YFilter.not_set or
                                        self.is_propagated.yfilter != YFilter.not_set or
                                        self.level.yfilter != YFilter.not_set or
                                        self.metric.yfilter != YFilter.not_set or
                                        (self.summarization_status is not None and self.summarization_status.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-level-advertising-detail" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.advertising_origin.is_set or self.advertising_origin.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.advertising_origin.get_name_leafdata())
                                    if (self.is_external_metric.is_set or self.is_external_metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_metric.get_name_leafdata())
                                    if (self.is_external_reachability.is_set or self.is_external_reachability.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_external_reachability.get_name_leafdata())
                                    if (self.is_interarea.is_set or self.is_interarea.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_interarea.get_name_leafdata())
                                    if (self.is_propagated.is_set or self.is_propagated.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_propagated.get_name_leafdata())
                                    if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.level.get_name_leafdata())
                                    if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.metric.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "nodal-sid"):
                                        for c in self.nodal_sid:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.nodal_sid.append(c)
                                        return c

                                    if (child_yang_name == "summarization-status"):
                                        if (self.summarization_status is None):
                                            self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                            self.summarization_status.parent = self
                                            self._children_name_map["summarization_status"] = "summarization-status"
                                        return self.summarization_status

                                    if (child_yang_name == "tags"):
                                        for c in self.tags:
                                            segment = c.get_segment_path()
                                            if (segment_path == segment):
                                                return c
                                        c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags()
                                        c.parent = self
                                        local_reference_key = "ydk::seg::%s" % segment_path
                                        self._local_refs[local_reference_key] = c
                                        self.tags.append(c)
                                        return c

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "nodal-sid" or name == "summarization-status" or name == "tags" or name == "advertising-origin" or name == "is-external-metric" or name == "is-external-reachability" or name == "is-interarea" or name == "is-propagated" or name == "level" or name == "metric"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "advertising-origin"):
                                        self.advertising_origin = value
                                        self.advertising_origin.value_namespace = name_space
                                        self.advertising_origin.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-metric"):
                                        self.is_external_metric = value
                                        self.is_external_metric.value_namespace = name_space
                                        self.is_external_metric.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-external-reachability"):
                                        self.is_external_reachability = value
                                        self.is_external_reachability.value_namespace = name_space
                                        self.is_external_reachability.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-interarea"):
                                        self.is_interarea = value
                                        self.is_interarea.value_namespace = name_space
                                        self.is_interarea.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-propagated"):
                                        self.is_propagated = value
                                        self.is_propagated.value_namespace = name_space
                                        self.is_propagated.value_namespace_prefix = name_space_prefix
                                    if(value_path == "level"):
                                        self.level = value
                                        self.level.value_namespace = name_space
                                        self.level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "metric"):
                                        self.metric = value
                                        self.metric.value_namespace = name_space
                                        self.metric.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.prefix.is_set or
                                    self.prefix_length.is_set or
                                    (self.connected_status is not None and self.connected_status.has_data()) or
                                    (self.native_status is not None and self.native_status.has_data()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_data()))

                            def has_operation(self):
                                for c in self.per_level_advertising_detail:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.prefix.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    (self.connected_status is not None and self.connected_status.has_operation()) or
                                    (self.native_status is not None and self.native_status.has_operation()) or
                                    (self.redistributed_status is not None and self.redistributed_status.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-route" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "connected-status"):
                                    if (self.connected_status is None):
                                        self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus()
                                        self.connected_status.parent = self
                                        self._children_name_map["connected_status"] = "connected-status"
                                    return self.connected_status

                                if (child_yang_name == "native-status"):
                                    if (self.native_status is None):
                                        self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus()
                                        self.native_status.parent = self
                                        self._children_name_map["native_status"] = "native-status"
                                    return self.native_status

                                if (child_yang_name == "per-level-advertising-detail"):
                                    for c in self.per_level_advertising_detail:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_level_advertising_detail.append(c)
                                    return c

                                if (child_yang_name == "redistributed-status"):
                                    if (self.redistributed_status is None):
                                        self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus()
                                        self.redistributed_status.parent = self
                                        self._children_name_map["redistributed_status"] = "redistributed-status"
                                    return self.redistributed_status

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "connected-status" or name == "native-status" or name == "per-level-advertising-detail" or name == "redistributed-status" or name == "prefix" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "prefix"):
                                    self.prefix = value
                                    self.prefix.value_namespace = name_space
                                    self.prefix.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.ipv4_route:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.ipv4_route:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-routes" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4-route"):
                                for c in self.ipv4_route:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ipv4_route.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4-route"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.af_name.is_set or
                            self.saf_name.is_set or
                            self.topology_name.is_set or
                            (self.frr_summary is not None and self.frr_summary.has_data()) or
                            (self.ipv4_routes is not None and self.ipv4_routes.has_data()) or
                            (self.ipv4frr_backups is not None and self.ipv4frr_backups.has_data()) or
                            (self.ipv6_routes is not None and self.ipv6_routes.has_data()) or
                            (self.ipv6frr_backups is not None and self.ipv6frr_backups.has_data()) or
                            (self.topology_levels is not None and self.topology_levels.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.af_name.yfilter != YFilter.not_set or
                            self.saf_name.yfilter != YFilter.not_set or
                            self.topology_name.yfilter != YFilter.not_set or
                            (self.frr_summary is not None and self.frr_summary.has_operation()) or
                            (self.ipv4_routes is not None and self.ipv4_routes.has_operation()) or
                            (self.ipv4frr_backups is not None and self.ipv4frr_backups.has_operation()) or
                            (self.ipv6_routes is not None and self.ipv6_routes.has_operation()) or
                            (self.ipv6frr_backups is not None and self.ipv6frr_backups.has_operation()) or
                            (self.topology_levels is not None and self.topology_levels.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "topology" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.af_name.get_name_leafdata())
                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.topology_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "frr-summary"):
                            if (self.frr_summary is None):
                                self.frr_summary = Isis.Instances.Instance.Topologies.Topology.FrrSummary()
                                self.frr_summary.parent = self
                                self._children_name_map["frr_summary"] = "frr-summary"
                            return self.frr_summary

                        if (child_yang_name == "ipv4-routes"):
                            if (self.ipv4_routes is None):
                                self.ipv4_routes = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes()
                                self.ipv4_routes.parent = self
                                self._children_name_map["ipv4_routes"] = "ipv4-routes"
                            return self.ipv4_routes

                        if (child_yang_name == "ipv4frr-backups"):
                            if (self.ipv4frr_backups is None):
                                self.ipv4frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv4FrrBackups()
                                self.ipv4frr_backups.parent = self
                                self._children_name_map["ipv4frr_backups"] = "ipv4frr-backups"
                            return self.ipv4frr_backups

                        if (child_yang_name == "ipv6-routes"):
                            if (self.ipv6_routes is None):
                                self.ipv6_routes = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes()
                                self.ipv6_routes.parent = self
                                self._children_name_map["ipv6_routes"] = "ipv6-routes"
                            return self.ipv6_routes

                        if (child_yang_name == "ipv6frr-backups"):
                            if (self.ipv6frr_backups is None):
                                self.ipv6frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv6FrrBackups()
                                self.ipv6frr_backups.parent = self
                                self._children_name_map["ipv6frr_backups"] = "ipv6frr-backups"
                            return self.ipv6frr_backups

                        if (child_yang_name == "topology-levels"):
                            if (self.topology_levels is None):
                                self.topology_levels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels()
                                self.topology_levels.parent = self
                                self._children_name_map["topology_levels"] = "topology-levels"
                            return self.topology_levels

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "frr-summary" or name == "ipv4-routes" or name == "ipv4frr-backups" or name == "ipv6-routes" or name == "ipv6frr-backups" or name == "topology-levels" or name == "af-name" or name == "saf-name" or name == "topology-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "af-name"):
                            self.af_name = value
                            self.af_name.value_namespace = name_space
                            self.af_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "saf-name"):
                            self.saf_name = value
                            self.saf_name.value_namespace = name_space
                            self.saf_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "topology-name"):
                            self.topology_name = value
                            self.topology_name.value_namespace = name_space
                            self.topology_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.topology:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.topology:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "topologies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "topology"):
                        for c in self.topology:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Topologies.Topology()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.topology.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "topology"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NsrStatus(Entity):
                """
                NSR Status information
                
                .. attribute:: isis_nsr_infra
                
                	ISIS NSR Infra
                	**type**\:   :py:class:`IsisNsrInfra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra>`
                
                .. attribute:: isis_nsr_peer
                
                	ISIS NSR PEER STATUS
                	**type**\:   :py:class:`IsisNsrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer>`
                
                .. attribute:: isis_vm_state
                
                	ISIS VM STATE
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "instance"

                    self.isis_vm_state = YLeaf(YType.uint16, "isis-vm-state")

                    self.isis_nsr_infra = Isis.Instances.Instance.NsrStatus.IsisNsrInfra()
                    self.isis_nsr_infra.parent = self
                    self._children_name_map["isis_nsr_infra"] = "isis-nsr-infra"
                    self._children_yang_names.add("isis-nsr-infra")

                    self.isis_nsr_peer = Isis.Instances.Instance.NsrStatus.IsisNsrPeer()
                    self.isis_nsr_peer.parent = self
                    self._children_name_map["isis_nsr_peer"] = "isis-nsr-peer"
                    self._children_yang_names.add("isis-nsr-peer")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("isis_vm_state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.NsrStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.NsrStatus, self).__setattr__(name, value)


                class IsisNsrPeer(Entity):
                    """
                    ISIS NSR PEER STATUS
                    
                    .. attribute:: full_sync_achieved
                    
                    	full sync achieved
                    	**type**\: list of    :py:class:`FullSyncAchieved <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved>`
                    
                    .. attribute:: man_sync_count
                    
                    	man sync count
                    	**type**\: list of    :py:class:`ManSyncCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount>`
                    
                    .. attribute:: nsr_chg_count
                    
                    	nsr chg count
                    	**type**\: list of    :py:class:`NsrChgCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount>`
                    
                    .. attribute:: uptime
                    
                    	uptime
                    	**type**\: list of    :py:class:`Uptime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime>`
                    
                    .. attribute:: uptime_valid
                    
                    	uptime valid
                    	**type**\: list of    :py:class:`UptimeValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer, self).__init__()

                        self.yang_name = "isis-nsr-peer"
                        self.yang_parent_name = "nsr-status"

                        self.full_sync_achieved = YList(self)
                        self.man_sync_count = YList(self)
                        self.nsr_chg_count = YList(self)
                        self.uptime = YList(self)
                        self.uptime_valid = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer, self).__setattr__(name, value)


                    class FullSyncAchieved(Entity):
                        """
                        full sync achieved
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved, self).__init__()

                            self.yang_name = "full-sync-achieved"
                            self.yang_parent_name = "isis-nsr-peer"

                            self.entry = YLeaf(YType.uint32, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "full-sync-achieved" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix


                    class ManSyncCount(Entity):
                        """
                        man sync count
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount, self).__init__()

                            self.yang_name = "man-sync-count"
                            self.yang_parent_name = "isis-nsr-peer"

                            self.entry = YLeaf(YType.uint32, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "man-sync-count" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix


                    class NsrChgCount(Entity):
                        """
                        nsr chg count
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount, self).__init__()

                            self.yang_name = "nsr-chg-count"
                            self.yang_parent_name = "isis-nsr-peer"

                            self.entry = YLeaf(YType.uint32, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nsr-chg-count" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix


                    class Uptime(Entity):
                        """
                        uptime
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime, self).__init__()

                            self.yang_name = "uptime"
                            self.yang_parent_name = "isis-nsr-peer"

                            self.entry = YLeaf(YType.uint32, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "uptime" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix


                    class UptimeValid(Entity):
                        """
                        uptime valid
                        
                        .. attribute:: entry
                        
                        	Array entry
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid, self).__init__()

                            self.yang_name = "uptime-valid"
                            self.yang_parent_name = "isis-nsr-peer"

                            self.entry = YLeaf(YType.boolean, "entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("entry") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid, self).__setattr__(name, value)

                        def has_data(self):
                            return self.entry.is_set

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.entry.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "uptime-valid" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.entry.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "entry"):
                                self.entry = value
                                self.entry.value_namespace = name_space
                                self.entry.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.full_sync_achieved:
                            if (c.has_data()):
                                return True
                        for c in self.man_sync_count:
                            if (c.has_data()):
                                return True
                        for c in self.nsr_chg_count:
                            if (c.has_data()):
                                return True
                        for c in self.uptime:
                            if (c.has_data()):
                                return True
                        for c in self.uptime_valid:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.full_sync_achieved:
                            if (c.has_operation()):
                                return True
                        for c in self.man_sync_count:
                            if (c.has_operation()):
                                return True
                        for c in self.nsr_chg_count:
                            if (c.has_operation()):
                                return True
                        for c in self.uptime:
                            if (c.has_operation()):
                                return True
                        for c in self.uptime_valid:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "isis-nsr-peer" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "full-sync-achieved"):
                            for c in self.full_sync_achieved:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.full_sync_achieved.append(c)
                            return c

                        if (child_yang_name == "man-sync-count"):
                            for c in self.man_sync_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.man_sync_count.append(c)
                            return c

                        if (child_yang_name == "nsr-chg-count"):
                            for c in self.nsr_chg_count:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.nsr_chg_count.append(c)
                            return c

                        if (child_yang_name == "uptime"):
                            for c in self.uptime:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.uptime.append(c)
                            return c

                        if (child_yang_name == "uptime-valid"):
                            for c in self.uptime_valid:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.uptime_valid.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "full-sync-achieved" or name == "man-sync-count" or name == "nsr-chg-count" or name == "uptime" or name == "uptime-valid"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IsisNsrInfra(Entity):
                    """
                    ISIS NSR Infra
                    
                    .. attribute:: ds
                    
                    	ds
                    	**type**\:   :py:class:`Ds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds>`
                    
                    .. attribute:: gen
                    
                    	gen
                    	**type**\:   :py:class:`Gen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen>`
                    
                    .. attribute:: ncd
                    
                    	ncd
                    	**type**\: list of    :py:class:`Ncd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd>`
                    
                    .. attribute:: nii_idb
                    
                    	nii idb
                    	**type**\: list of    :py:class:`NiiIdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb>`
                    
                    .. attribute:: pm
                    
                    	pm
                    	**type**\:   :py:class:`Pm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm>`
                    
                    .. attribute:: te
                    
                    	te
                    	**type**\:   :py:class:`Te <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra, self).__init__()

                        self.yang_name = "isis-nsr-infra"
                        self.yang_parent_name = "nsr-status"

                        self.ds = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds()
                        self.ds.parent = self
                        self._children_name_map["ds"] = "ds"
                        self._children_yang_names.add("ds")

                        self.gen = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen()
                        self.gen.parent = self
                        self._children_name_map["gen"] = "gen"
                        self._children_yang_names.add("gen")

                        self.pm = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm()
                        self.pm.parent = self
                        self._children_name_map["pm"] = "pm"
                        self._children_yang_names.add("pm")

                        self.te = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te()
                        self.te.parent = self
                        self._children_name_map["te"] = "te"
                        self._children_yang_names.add("te")

                        self.ncd = YList(self)
                        self.nii_idb = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra, self).__setattr__(name, value)


                    class Gen(Entity):
                        """
                        gen
                        
                        .. attribute:: failover
                        
                        	failover
                        	**type**\:  bool
                        
                        .. attribute:: lanid_req_needed
                        
                        	lanid req needed
                        	**type**\:  bool
                        
                        .. attribute:: my_nodeid
                        
                        	my nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: my_process_id
                        
                        	my process id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsf_configured
                        
                        	nsf configured
                        	**type**\:  bool
                        
                        .. attribute:: nsr_configured
                        
                        	nsr configured
                        	**type**\:  bool
                        
                        .. attribute:: nsr_enabled
                        
                        	nsr enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_recv_err
                        
                        	nsr recv err
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_send_err
                        
                        	nsr send err
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_send_ready
                        
                        	nsr send ready
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: nsr_send_unready
                        
                        	nsr send unready
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pm_ha_role
                        
                        	pm ha role
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pm_issu_role
                        
                        	pm issu role
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: retry_flag
                        
                        	retry flag
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sysmgr_ha_role
                        
                        	sysmgr ha role
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen, self).__init__()

                            self.yang_name = "gen"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.failover = YLeaf(YType.boolean, "failover")

                            self.lanid_req_needed = YLeaf(YType.boolean, "lanid-req-needed")

                            self.my_nodeid = YLeaf(YType.uint32, "my-nodeid")

                            self.my_process_id = YLeaf(YType.uint32, "my-process-id")

                            self.nsf_configured = YLeaf(YType.boolean, "nsf-configured")

                            self.nsr_configured = YLeaf(YType.boolean, "nsr-configured")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_recv_err = YLeaf(YType.uint32, "nsr-recv-err")

                            self.nsr_send_err = YLeaf(YType.uint32, "nsr-send-err")

                            self.nsr_send_ready = YLeaf(YType.uint8, "nsr-send-ready")

                            self.nsr_send_unready = YLeaf(YType.uint8, "nsr-send-unready")

                            self.pm_ha_role = YLeaf(YType.uint8, "pm-ha-role")

                            self.pm_issu_role = YLeaf(YType.uint8, "pm-issu-role")

                            self.retry_flag = YLeaf(YType.uint32, "retry-flag")

                            self.sysmgr_ha_role = YLeaf(YType.uint8, "sysmgr-ha-role")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("failover",
                                            "lanid_req_needed",
                                            "my_nodeid",
                                            "my_process_id",
                                            "nsf_configured",
                                            "nsr_configured",
                                            "nsr_enabled",
                                            "nsr_recv_err",
                                            "nsr_send_err",
                                            "nsr_send_ready",
                                            "nsr_send_unready",
                                            "pm_ha_role",
                                            "pm_issu_role",
                                            "retry_flag",
                                            "sysmgr_ha_role") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.failover.is_set or
                                self.lanid_req_needed.is_set or
                                self.my_nodeid.is_set or
                                self.my_process_id.is_set or
                                self.nsf_configured.is_set or
                                self.nsr_configured.is_set or
                                self.nsr_enabled.is_set or
                                self.nsr_recv_err.is_set or
                                self.nsr_send_err.is_set or
                                self.nsr_send_ready.is_set or
                                self.nsr_send_unready.is_set or
                                self.pm_ha_role.is_set or
                                self.pm_issu_role.is_set or
                                self.retry_flag.is_set or
                                self.sysmgr_ha_role.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.failover.yfilter != YFilter.not_set or
                                self.lanid_req_needed.yfilter != YFilter.not_set or
                                self.my_nodeid.yfilter != YFilter.not_set or
                                self.my_process_id.yfilter != YFilter.not_set or
                                self.nsf_configured.yfilter != YFilter.not_set or
                                self.nsr_configured.yfilter != YFilter.not_set or
                                self.nsr_enabled.yfilter != YFilter.not_set or
                                self.nsr_recv_err.yfilter != YFilter.not_set or
                                self.nsr_send_err.yfilter != YFilter.not_set or
                                self.nsr_send_ready.yfilter != YFilter.not_set or
                                self.nsr_send_unready.yfilter != YFilter.not_set or
                                self.pm_ha_role.yfilter != YFilter.not_set or
                                self.pm_issu_role.yfilter != YFilter.not_set or
                                self.retry_flag.yfilter != YFilter.not_set or
                                self.sysmgr_ha_role.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "gen" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.failover.is_set or self.failover.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.failover.get_name_leafdata())
                            if (self.lanid_req_needed.is_set or self.lanid_req_needed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lanid_req_needed.get_name_leafdata())
                            if (self.my_nodeid.is_set or self.my_nodeid.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.my_nodeid.get_name_leafdata())
                            if (self.my_process_id.is_set or self.my_process_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.my_process_id.get_name_leafdata())
                            if (self.nsf_configured.is_set or self.nsf_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsf_configured.get_name_leafdata())
                            if (self.nsr_configured.is_set or self.nsr_configured.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_configured.get_name_leafdata())
                            if (self.nsr_enabled.is_set or self.nsr_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_enabled.get_name_leafdata())
                            if (self.nsr_recv_err.is_set or self.nsr_recv_err.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_recv_err.get_name_leafdata())
                            if (self.nsr_send_err.is_set or self.nsr_send_err.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_send_err.get_name_leafdata())
                            if (self.nsr_send_ready.is_set or self.nsr_send_ready.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_send_ready.get_name_leafdata())
                            if (self.nsr_send_unready.is_set or self.nsr_send_unready.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.nsr_send_unready.get_name_leafdata())
                            if (self.pm_ha_role.is_set or self.pm_ha_role.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pm_ha_role.get_name_leafdata())
                            if (self.pm_issu_role.is_set or self.pm_issu_role.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pm_issu_role.get_name_leafdata())
                            if (self.retry_flag.is_set or self.retry_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.retry_flag.get_name_leafdata())
                            if (self.sysmgr_ha_role.is_set or self.sysmgr_ha_role.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sysmgr_ha_role.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "failover" or name == "lanid-req-needed" or name == "my-nodeid" or name == "my-process-id" or name == "nsf-configured" or name == "nsr-configured" or name == "nsr-enabled" or name == "nsr-recv-err" or name == "nsr-send-err" or name == "nsr-send-ready" or name == "nsr-send-unready" or name == "pm-ha-role" or name == "pm-issu-role" or name == "retry-flag" or name == "sysmgr-ha-role"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "failover"):
                                self.failover = value
                                self.failover.value_namespace = name_space
                                self.failover.value_namespace_prefix = name_space_prefix
                            if(value_path == "lanid-req-needed"):
                                self.lanid_req_needed = value
                                self.lanid_req_needed.value_namespace = name_space
                                self.lanid_req_needed.value_namespace_prefix = name_space_prefix
                            if(value_path == "my-nodeid"):
                                self.my_nodeid = value
                                self.my_nodeid.value_namespace = name_space
                                self.my_nodeid.value_namespace_prefix = name_space_prefix
                            if(value_path == "my-process-id"):
                                self.my_process_id = value
                                self.my_process_id.value_namespace = name_space
                                self.my_process_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsf-configured"):
                                self.nsf_configured = value
                                self.nsf_configured.value_namespace = name_space
                                self.nsf_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-configured"):
                                self.nsr_configured = value
                                self.nsr_configured.value_namespace = name_space
                                self.nsr_configured.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-enabled"):
                                self.nsr_enabled = value
                                self.nsr_enabled.value_namespace = name_space
                                self.nsr_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-recv-err"):
                                self.nsr_recv_err = value
                                self.nsr_recv_err.value_namespace = name_space
                                self.nsr_recv_err.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-send-err"):
                                self.nsr_send_err = value
                                self.nsr_send_err.value_namespace = name_space
                                self.nsr_send_err.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-send-ready"):
                                self.nsr_send_ready = value
                                self.nsr_send_ready.value_namespace = name_space
                                self.nsr_send_ready.value_namespace_prefix = name_space_prefix
                            if(value_path == "nsr-send-unready"):
                                self.nsr_send_unready = value
                                self.nsr_send_unready.value_namespace = name_space
                                self.nsr_send_unready.value_namespace_prefix = name_space_prefix
                            if(value_path == "pm-ha-role"):
                                self.pm_ha_role = value
                                self.pm_ha_role.value_namespace = name_space
                                self.pm_ha_role.value_namespace_prefix = name_space_prefix
                            if(value_path == "pm-issu-role"):
                                self.pm_issu_role = value
                                self.pm_issu_role.value_namespace = name_space
                                self.pm_issu_role.value_namespace_prefix = name_space_prefix
                            if(value_path == "retry-flag"):
                                self.retry_flag = value
                                self.retry_flag.value_namespace = name_space
                                self.retry_flag.value_namespace_prefix = name_space_prefix
                            if(value_path == "sysmgr-ha-role"):
                                self.sysmgr_ha_role = value
                                self.sysmgr_ha_role.value_namespace = name_space
                                self.sysmgr_ha_role.value_namespace_prefix = name_space_prefix


                    class Pm(Entity):
                        """
                        pm
                        
                        .. attribute:: conn_cb
                        
                        	conn cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_status
                        
                        	conn status
                        	**type**\:  bool
                        
                        .. attribute:: disconn_cb
                        
                        	disconn cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reg
                        
                        	reg
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm, self).__init__()

                            self.yang_name = "pm"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.conn_cb = YLeaf(YType.uint8, "conn-cb")

                            self.conn_status = YLeaf(YType.boolean, "conn-status")

                            self.disconn_cb = YLeaf(YType.uint8, "disconn-cb")

                            self.reg = YLeaf(YType.uint8, "reg")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("conn_cb",
                                            "conn_status",
                                            "disconn_cb",
                                            "reg") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.conn_cb.is_set or
                                self.conn_status.is_set or
                                self.disconn_cb.is_set or
                                self.reg.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.conn_cb.yfilter != YFilter.not_set or
                                self.conn_status.yfilter != YFilter.not_set or
                                self.disconn_cb.yfilter != YFilter.not_set or
                                self.reg.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "pm" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.conn_cb.is_set or self.conn_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_cb.get_name_leafdata())
                            if (self.conn_status.is_set or self.conn_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_status.get_name_leafdata())
                            if (self.disconn_cb.is_set or self.disconn_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disconn_cb.get_name_leafdata())
                            if (self.reg.is_set or self.reg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reg.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "conn-cb" or name == "conn-status" or name == "disconn-cb" or name == "reg"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "conn-cb"):
                                self.conn_cb = value
                                self.conn_cb.value_namespace = name_space
                                self.conn_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "conn-status"):
                                self.conn_status = value
                                self.conn_status.value_namespace = name_space
                                self.conn_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "disconn-cb"):
                                self.disconn_cb = value
                                self.disconn_cb.value_namespace = name_space
                                self.disconn_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "reg"):
                                self.reg = value
                                self.reg.value_namespace = name_space
                                self.reg.value_namespace_prefix = name_space_prefix


                    class Ds(Entity):
                        """
                        ds
                        
                        .. attribute:: conn
                        
                        	conn
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_cb
                        
                        	conn cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_cb_ts
                        
                        	conn cb ts
                        	**type**\:   :py:class:`ConnCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs>`
                        
                        .. attribute:: conn_status
                        
                        	conn status
                        	**type**\:  bool
                        
                        .. attribute:: conn_status_ts
                        
                        	conn status ts
                        	**type**\:   :py:class:`ConnStatusTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs>`
                        
                        .. attribute:: conn_ts
                        
                        	conn ts
                        	**type**\:   :py:class:`ConnTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs>`
                        
                        .. attribute:: del_cb
                        
                        	del cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: del_cb_ts
                        
                        	del cb ts
                        	**type**\:   :py:class:`DelCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs>`
                        
                        .. attribute:: disconn_cb
                        
                        	disconn cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disconn_cb_ts
                        
                        	disconn cb ts
                        	**type**\:   :py:class:`DisconnCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs>`
                        
                        .. attribute:: notify_cb
                        
                        	notify cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: notify_cb_ts
                        
                        	notify cb ts
                        	**type**\:   :py:class:`NotifyCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs>`
                        
                        .. attribute:: notify_peer
                        
                        	notify peer
                        	**type**\: list of    :py:class:`NotifyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer>`
                        
                        .. attribute:: notify_peer_xr
                        
                        	notify peer xr
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: pub
                        
                        	pub
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pub_cb
                        
                        	pub cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pub_cb_ts
                        
                        	pub cb ts
                        	**type**\:   :py:class:`PubCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs>`
                        
                        .. attribute:: pub_ts
                        
                        	pub ts
                        	**type**\:   :py:class:`PubTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs>`
                        
                        .. attribute:: reg
                        
                        	reg
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reg_cb
                        
                        	reg cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reg_cb_ts
                        
                        	reg cb ts
                        	**type**\:   :py:class:`RegCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs>`
                        
                        .. attribute:: reg_ts
                        
                        	reg ts
                        	**type**\:   :py:class:`RegTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs>`
                        
                        .. attribute:: remove_srv
                        
                        	remove srv
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remove_srv_ts
                        
                        	remove srv ts
                        	**type**\:   :py:class:`RemoveSrvTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs>`
                        
                        .. attribute:: unreg
                        
                        	unreg
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: unreg_cb
                        
                        	unreg cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: unreg_cb_ts
                        
                        	unreg cb ts
                        	**type**\:   :py:class:`UnregCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs>`
                        
                        .. attribute:: unreg_ts
                        
                        	unreg ts
                        	**type**\:   :py:class:`UnregTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds, self).__init__()

                            self.yang_name = "ds"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.conn = YLeaf(YType.uint8, "conn")

                            self.conn_cb = YLeaf(YType.uint8, "conn-cb")

                            self.conn_status = YLeaf(YType.boolean, "conn-status")

                            self.del_cb = YLeaf(YType.uint8, "del-cb")

                            self.disconn_cb = YLeaf(YType.uint8, "disconn-cb")

                            self.notify_cb = YLeaf(YType.uint8, "notify-cb")

                            self.notify_peer_xr = YLeaf(YType.str, "notify-peer-xr")

                            self.pub = YLeaf(YType.uint8, "pub")

                            self.pub_cb = YLeaf(YType.uint8, "pub-cb")

                            self.reg = YLeaf(YType.uint8, "reg")

                            self.reg_cb = YLeaf(YType.uint8, "reg-cb")

                            self.remove_srv = YLeaf(YType.uint8, "remove-srv")

                            self.unreg = YLeaf(YType.uint8, "unreg")

                            self.unreg_cb = YLeaf(YType.uint8, "unreg-cb")

                            self.conn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs()
                            self.conn_cb_ts.parent = self
                            self._children_name_map["conn_cb_ts"] = "conn-cb-ts"
                            self._children_yang_names.add("conn-cb-ts")

                            self.conn_status_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs()
                            self.conn_status_ts.parent = self
                            self._children_name_map["conn_status_ts"] = "conn-status-ts"
                            self._children_yang_names.add("conn-status-ts")

                            self.conn_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs()
                            self.conn_ts.parent = self
                            self._children_name_map["conn_ts"] = "conn-ts"
                            self._children_yang_names.add("conn-ts")

                            self.del_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs()
                            self.del_cb_ts.parent = self
                            self._children_name_map["del_cb_ts"] = "del-cb-ts"
                            self._children_yang_names.add("del-cb-ts")

                            self.disconn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs()
                            self.disconn_cb_ts.parent = self
                            self._children_name_map["disconn_cb_ts"] = "disconn-cb-ts"
                            self._children_yang_names.add("disconn-cb-ts")

                            self.notify_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs()
                            self.notify_cb_ts.parent = self
                            self._children_name_map["notify_cb_ts"] = "notify-cb-ts"
                            self._children_yang_names.add("notify-cb-ts")

                            self.pub_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs()
                            self.pub_cb_ts.parent = self
                            self._children_name_map["pub_cb_ts"] = "pub-cb-ts"
                            self._children_yang_names.add("pub-cb-ts")

                            self.pub_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs()
                            self.pub_ts.parent = self
                            self._children_name_map["pub_ts"] = "pub-ts"
                            self._children_yang_names.add("pub-ts")

                            self.reg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs()
                            self.reg_cb_ts.parent = self
                            self._children_name_map["reg_cb_ts"] = "reg-cb-ts"
                            self._children_yang_names.add("reg-cb-ts")

                            self.reg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs()
                            self.reg_ts.parent = self
                            self._children_name_map["reg_ts"] = "reg-ts"
                            self._children_yang_names.add("reg-ts")

                            self.remove_srv_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs()
                            self.remove_srv_ts.parent = self
                            self._children_name_map["remove_srv_ts"] = "remove-srv-ts"
                            self._children_yang_names.add("remove-srv-ts")

                            self.unreg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs()
                            self.unreg_cb_ts.parent = self
                            self._children_name_map["unreg_cb_ts"] = "unreg-cb-ts"
                            self._children_yang_names.add("unreg-cb-ts")

                            self.unreg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs()
                            self.unreg_ts.parent = self
                            self._children_name_map["unreg_ts"] = "unreg-ts"
                            self._children_yang_names.add("unreg-ts")

                            self.notify_peer = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("conn",
                                            "conn_cb",
                                            "conn_status",
                                            "del_cb",
                                            "disconn_cb",
                                            "notify_cb",
                                            "notify_peer_xr",
                                            "pub",
                                            "pub_cb",
                                            "reg",
                                            "reg_cb",
                                            "remove_srv",
                                            "unreg",
                                            "unreg_cb") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds, self).__setattr__(name, value)


                        class ConnTs(Entity):
                            """
                            conn ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs, self).__init__()

                                self.yang_name = "conn-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "conn-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class ConnCbTs(Entity):
                            """
                            conn cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs, self).__init__()

                                self.yang_name = "conn-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "conn-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class PubTs(Entity):
                            """
                            pub ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs, self).__init__()

                                self.yang_name = "pub-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pub-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class PubCbTs(Entity):
                            """
                            pub cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs, self).__init__()

                                self.yang_name = "pub-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "pub-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class RegTs(Entity):
                            """
                            reg ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs, self).__init__()

                                self.yang_name = "reg-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "reg-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class RegCbTs(Entity):
                            """
                            reg cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs, self).__init__()

                                self.yang_name = "reg-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "reg-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class UnregTs(Entity):
                            """
                            unreg ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs, self).__init__()

                                self.yang_name = "unreg-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unreg-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class UnregCbTs(Entity):
                            """
                            unreg cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs, self).__init__()

                                self.yang_name = "unreg-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unreg-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class DisconnCbTs(Entity):
                            """
                            disconn cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs, self).__init__()

                                self.yang_name = "disconn-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "disconn-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class NotifyCbTs(Entity):
                            """
                            notify cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs, self).__init__()

                                self.yang_name = "notify-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "notify-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class DelCbTs(Entity):
                            """
                            del cb ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs, self).__init__()

                                self.yang_name = "del-cb-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "del-cb-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class RemoveSrvTs(Entity):
                            """
                            remove srv ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs, self).__init__()

                                self.yang_name = "remove-srv-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "remove-srv-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class ConnStatusTs(Entity):
                            """
                            conn status ts
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs, self).__init__()

                                self.yang_name = "conn-status-ts"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "conn-status-ts" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix


                        class NotifyPeer(Entity):
                            """
                            notify peer
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer, self).__init__()

                                self.yang_name = "notify-peer"
                                self.yang_parent_name = "ds"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "notify-peer" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.notify_peer:
                                if (c.has_data()):
                                    return True
                            return (
                                self.conn.is_set or
                                self.conn_cb.is_set or
                                self.conn_status.is_set or
                                self.del_cb.is_set or
                                self.disconn_cb.is_set or
                                self.notify_cb.is_set or
                                self.notify_peer_xr.is_set or
                                self.pub.is_set or
                                self.pub_cb.is_set or
                                self.reg.is_set or
                                self.reg_cb.is_set or
                                self.remove_srv.is_set or
                                self.unreg.is_set or
                                self.unreg_cb.is_set or
                                (self.conn_cb_ts is not None and self.conn_cb_ts.has_data()) or
                                (self.conn_status_ts is not None and self.conn_status_ts.has_data()) or
                                (self.conn_ts is not None and self.conn_ts.has_data()) or
                                (self.del_cb_ts is not None and self.del_cb_ts.has_data()) or
                                (self.disconn_cb_ts is not None and self.disconn_cb_ts.has_data()) or
                                (self.notify_cb_ts is not None and self.notify_cb_ts.has_data()) or
                                (self.pub_cb_ts is not None and self.pub_cb_ts.has_data()) or
                                (self.pub_ts is not None and self.pub_ts.has_data()) or
                                (self.reg_cb_ts is not None and self.reg_cb_ts.has_data()) or
                                (self.reg_ts is not None and self.reg_ts.has_data()) or
                                (self.remove_srv_ts is not None and self.remove_srv_ts.has_data()) or
                                (self.unreg_cb_ts is not None and self.unreg_cb_ts.has_data()) or
                                (self.unreg_ts is not None and self.unreg_ts.has_data()))

                        def has_operation(self):
                            for c in self.notify_peer:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.conn.yfilter != YFilter.not_set or
                                self.conn_cb.yfilter != YFilter.not_set or
                                self.conn_status.yfilter != YFilter.not_set or
                                self.del_cb.yfilter != YFilter.not_set or
                                self.disconn_cb.yfilter != YFilter.not_set or
                                self.notify_cb.yfilter != YFilter.not_set or
                                self.notify_peer_xr.yfilter != YFilter.not_set or
                                self.pub.yfilter != YFilter.not_set or
                                self.pub_cb.yfilter != YFilter.not_set or
                                self.reg.yfilter != YFilter.not_set or
                                self.reg_cb.yfilter != YFilter.not_set or
                                self.remove_srv.yfilter != YFilter.not_set or
                                self.unreg.yfilter != YFilter.not_set or
                                self.unreg_cb.yfilter != YFilter.not_set or
                                (self.conn_cb_ts is not None and self.conn_cb_ts.has_operation()) or
                                (self.conn_status_ts is not None and self.conn_status_ts.has_operation()) or
                                (self.conn_ts is not None and self.conn_ts.has_operation()) or
                                (self.del_cb_ts is not None and self.del_cb_ts.has_operation()) or
                                (self.disconn_cb_ts is not None and self.disconn_cb_ts.has_operation()) or
                                (self.notify_cb_ts is not None and self.notify_cb_ts.has_operation()) or
                                (self.pub_cb_ts is not None and self.pub_cb_ts.has_operation()) or
                                (self.pub_ts is not None and self.pub_ts.has_operation()) or
                                (self.reg_cb_ts is not None and self.reg_cb_ts.has_operation()) or
                                (self.reg_ts is not None and self.reg_ts.has_operation()) or
                                (self.remove_srv_ts is not None and self.remove_srv_ts.has_operation()) or
                                (self.unreg_cb_ts is not None and self.unreg_cb_ts.has_operation()) or
                                (self.unreg_ts is not None and self.unreg_ts.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ds" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.conn.is_set or self.conn.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn.get_name_leafdata())
                            if (self.conn_cb.is_set or self.conn_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_cb.get_name_leafdata())
                            if (self.conn_status.is_set or self.conn_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_status.get_name_leafdata())
                            if (self.del_cb.is_set or self.del_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.del_cb.get_name_leafdata())
                            if (self.disconn_cb.is_set or self.disconn_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.disconn_cb.get_name_leafdata())
                            if (self.notify_cb.is_set or self.notify_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.notify_cb.get_name_leafdata())
                            if (self.notify_peer_xr.is_set or self.notify_peer_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.notify_peer_xr.get_name_leafdata())
                            if (self.pub.is_set or self.pub.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pub.get_name_leafdata())
                            if (self.pub_cb.is_set or self.pub_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.pub_cb.get_name_leafdata())
                            if (self.reg.is_set or self.reg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reg.get_name_leafdata())
                            if (self.reg_cb.is_set or self.reg_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reg_cb.get_name_leafdata())
                            if (self.remove_srv.is_set or self.remove_srv.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.remove_srv.get_name_leafdata())
                            if (self.unreg.is_set or self.unreg.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unreg.get_name_leafdata())
                            if (self.unreg_cb.is_set or self.unreg_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.unreg_cb.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "conn-cb-ts"):
                                if (self.conn_cb_ts is None):
                                    self.conn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs()
                                    self.conn_cb_ts.parent = self
                                    self._children_name_map["conn_cb_ts"] = "conn-cb-ts"
                                return self.conn_cb_ts

                            if (child_yang_name == "conn-status-ts"):
                                if (self.conn_status_ts is None):
                                    self.conn_status_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs()
                                    self.conn_status_ts.parent = self
                                    self._children_name_map["conn_status_ts"] = "conn-status-ts"
                                return self.conn_status_ts

                            if (child_yang_name == "conn-ts"):
                                if (self.conn_ts is None):
                                    self.conn_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs()
                                    self.conn_ts.parent = self
                                    self._children_name_map["conn_ts"] = "conn-ts"
                                return self.conn_ts

                            if (child_yang_name == "del-cb-ts"):
                                if (self.del_cb_ts is None):
                                    self.del_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs()
                                    self.del_cb_ts.parent = self
                                    self._children_name_map["del_cb_ts"] = "del-cb-ts"
                                return self.del_cb_ts

                            if (child_yang_name == "disconn-cb-ts"):
                                if (self.disconn_cb_ts is None):
                                    self.disconn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs()
                                    self.disconn_cb_ts.parent = self
                                    self._children_name_map["disconn_cb_ts"] = "disconn-cb-ts"
                                return self.disconn_cb_ts

                            if (child_yang_name == "notify-cb-ts"):
                                if (self.notify_cb_ts is None):
                                    self.notify_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs()
                                    self.notify_cb_ts.parent = self
                                    self._children_name_map["notify_cb_ts"] = "notify-cb-ts"
                                return self.notify_cb_ts

                            if (child_yang_name == "notify-peer"):
                                for c in self.notify_peer:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.notify_peer.append(c)
                                return c

                            if (child_yang_name == "pub-cb-ts"):
                                if (self.pub_cb_ts is None):
                                    self.pub_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs()
                                    self.pub_cb_ts.parent = self
                                    self._children_name_map["pub_cb_ts"] = "pub-cb-ts"
                                return self.pub_cb_ts

                            if (child_yang_name == "pub-ts"):
                                if (self.pub_ts is None):
                                    self.pub_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs()
                                    self.pub_ts.parent = self
                                    self._children_name_map["pub_ts"] = "pub-ts"
                                return self.pub_ts

                            if (child_yang_name == "reg-cb-ts"):
                                if (self.reg_cb_ts is None):
                                    self.reg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs()
                                    self.reg_cb_ts.parent = self
                                    self._children_name_map["reg_cb_ts"] = "reg-cb-ts"
                                return self.reg_cb_ts

                            if (child_yang_name == "reg-ts"):
                                if (self.reg_ts is None):
                                    self.reg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs()
                                    self.reg_ts.parent = self
                                    self._children_name_map["reg_ts"] = "reg-ts"
                                return self.reg_ts

                            if (child_yang_name == "remove-srv-ts"):
                                if (self.remove_srv_ts is None):
                                    self.remove_srv_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs()
                                    self.remove_srv_ts.parent = self
                                    self._children_name_map["remove_srv_ts"] = "remove-srv-ts"
                                return self.remove_srv_ts

                            if (child_yang_name == "unreg-cb-ts"):
                                if (self.unreg_cb_ts is None):
                                    self.unreg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs()
                                    self.unreg_cb_ts.parent = self
                                    self._children_name_map["unreg_cb_ts"] = "unreg-cb-ts"
                                return self.unreg_cb_ts

                            if (child_yang_name == "unreg-ts"):
                                if (self.unreg_ts is None):
                                    self.unreg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs()
                                    self.unreg_ts.parent = self
                                    self._children_name_map["unreg_ts"] = "unreg-ts"
                                return self.unreg_ts

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "conn-cb-ts" or name == "conn-status-ts" or name == "conn-ts" or name == "del-cb-ts" or name == "disconn-cb-ts" or name == "notify-cb-ts" or name == "notify-peer" or name == "pub-cb-ts" or name == "pub-ts" or name == "reg-cb-ts" or name == "reg-ts" or name == "remove-srv-ts" or name == "unreg-cb-ts" or name == "unreg-ts" or name == "conn" or name == "conn-cb" or name == "conn-status" or name == "del-cb" or name == "disconn-cb" or name == "notify-cb" or name == "notify-peer-xr" or name == "pub" or name == "pub-cb" or name == "reg" or name == "reg-cb" or name == "remove-srv" or name == "unreg" or name == "unreg-cb"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "conn"):
                                self.conn = value
                                self.conn.value_namespace = name_space
                                self.conn.value_namespace_prefix = name_space_prefix
                            if(value_path == "conn-cb"):
                                self.conn_cb = value
                                self.conn_cb.value_namespace = name_space
                                self.conn_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "conn-status"):
                                self.conn_status = value
                                self.conn_status.value_namespace = name_space
                                self.conn_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "del-cb"):
                                self.del_cb = value
                                self.del_cb.value_namespace = name_space
                                self.del_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "disconn-cb"):
                                self.disconn_cb = value
                                self.disconn_cb.value_namespace = name_space
                                self.disconn_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "notify-cb"):
                                self.notify_cb = value
                                self.notify_cb.value_namespace = name_space
                                self.notify_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "notify-peer-xr"):
                                self.notify_peer_xr = value
                                self.notify_peer_xr.value_namespace = name_space
                                self.notify_peer_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "pub"):
                                self.pub = value
                                self.pub.value_namespace = name_space
                                self.pub.value_namespace_prefix = name_space_prefix
                            if(value_path == "pub-cb"):
                                self.pub_cb = value
                                self.pub_cb.value_namespace = name_space
                                self.pub_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "reg"):
                                self.reg = value
                                self.reg.value_namespace = name_space
                                self.reg.value_namespace_prefix = name_space_prefix
                            if(value_path == "reg-cb"):
                                self.reg_cb = value
                                self.reg_cb.value_namespace = name_space
                                self.reg_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "remove-srv"):
                                self.remove_srv = value
                                self.remove_srv.value_namespace = name_space
                                self.remove_srv.value_namespace_prefix = name_space_prefix
                            if(value_path == "unreg"):
                                self.unreg = value
                                self.unreg.value_namespace = name_space
                                self.unreg.value_namespace_prefix = name_space_prefix
                            if(value_path == "unreg-cb"):
                                self.unreg_cb = value
                                self.unreg_cb.value_namespace = name_space
                                self.unreg_cb.value_namespace_prefix = name_space_prefix


                    class Te(Entity):
                        """
                        te
                        
                        .. attribute:: adv_sync_data
                        
                        	adv sync data
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_up
                        
                        	conn up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: enabled
                        
                        	enabled
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: has_info_from_te
                        
                        	has info from te
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: link_purge_time_on
                        
                        	link purge time on
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: te_link_cb
                        
                        	te link cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: te_tunnel_cb
                        
                        	te tunnel cb
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tunnel_purge_time_on
                        
                        	tunnel purge time on
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te, self).__init__()

                            self.yang_name = "te"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.adv_sync_data = YLeaf(YType.uint8, "adv-sync-data")

                            self.conn_up = YLeaf(YType.uint8, "conn-up")

                            self.enabled = YLeaf(YType.uint8, "enabled")

                            self.has_info_from_te = YLeaf(YType.uint8, "has-info-from-te")

                            self.link_purge_time_on = YLeaf(YType.uint8, "link-purge-time-on")

                            self.te_link_cb = YLeaf(YType.uint8, "te-link-cb")

                            self.te_tunnel_cb = YLeaf(YType.uint8, "te-tunnel-cb")

                            self.tunnel_purge_time_on = YLeaf(YType.uint8, "tunnel-purge-time-on")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("adv_sync_data",
                                            "conn_up",
                                            "enabled",
                                            "has_info_from_te",
                                            "link_purge_time_on",
                                            "te_link_cb",
                                            "te_tunnel_cb",
                                            "tunnel_purge_time_on") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.adv_sync_data.is_set or
                                self.conn_up.is_set or
                                self.enabled.is_set or
                                self.has_info_from_te.is_set or
                                self.link_purge_time_on.is_set or
                                self.te_link_cb.is_set or
                                self.te_tunnel_cb.is_set or
                                self.tunnel_purge_time_on.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.adv_sync_data.yfilter != YFilter.not_set or
                                self.conn_up.yfilter != YFilter.not_set or
                                self.enabled.yfilter != YFilter.not_set or
                                self.has_info_from_te.yfilter != YFilter.not_set or
                                self.link_purge_time_on.yfilter != YFilter.not_set or
                                self.te_link_cb.yfilter != YFilter.not_set or
                                self.te_tunnel_cb.yfilter != YFilter.not_set or
                                self.tunnel_purge_time_on.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "te" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.adv_sync_data.is_set or self.adv_sync_data.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adv_sync_data.get_name_leafdata())
                            if (self.conn_up.is_set or self.conn_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_up.get_name_leafdata())
                            if (self.enabled.is_set or self.enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.enabled.get_name_leafdata())
                            if (self.has_info_from_te.is_set or self.has_info_from_te.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.has_info_from_te.get_name_leafdata())
                            if (self.link_purge_time_on.is_set or self.link_purge_time_on.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.link_purge_time_on.get_name_leafdata())
                            if (self.te_link_cb.is_set or self.te_link_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_link_cb.get_name_leafdata())
                            if (self.te_tunnel_cb.is_set or self.te_tunnel_cb.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_tunnel_cb.get_name_leafdata())
                            if (self.tunnel_purge_time_on.is_set or self.tunnel_purge_time_on.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_purge_time_on.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "adv-sync-data" or name == "conn-up" or name == "enabled" or name == "has-info-from-te" or name == "link-purge-time-on" or name == "te-link-cb" or name == "te-tunnel-cb" or name == "tunnel-purge-time-on"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "adv-sync-data"):
                                self.adv_sync_data = value
                                self.adv_sync_data.value_namespace = name_space
                                self.adv_sync_data.value_namespace_prefix = name_space_prefix
                            if(value_path == "conn-up"):
                                self.conn_up = value
                                self.conn_up.value_namespace = name_space
                                self.conn_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "enabled"):
                                self.enabled = value
                                self.enabled.value_namespace = name_space
                                self.enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "has-info-from-te"):
                                self.has_info_from_te = value
                                self.has_info_from_te.value_namespace = name_space
                                self.has_info_from_te.value_namespace_prefix = name_space_prefix
                            if(value_path == "link-purge-time-on"):
                                self.link_purge_time_on = value
                                self.link_purge_time_on.value_namespace = name_space
                                self.link_purge_time_on.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-link-cb"):
                                self.te_link_cb = value
                                self.te_link_cb.value_namespace = name_space
                                self.te_link_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-tunnel-cb"):
                                self.te_tunnel_cb = value
                                self.te_tunnel_cb.value_namespace = name_space
                                self.te_tunnel_cb.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-purge-time-on"):
                                self.tunnel_purge_time_on = value
                                self.tunnel_purge_time_on.value_namespace = name_space
                                self.tunnel_purge_time_on.value_namespace_prefix = name_space_prefix


                    class Ncd(Entity):
                        """
                        ncd
                        
                        .. attribute:: chksum
                        
                        	chksum
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: conn_up
                        
                        	conn up
                        	**type**\:  bool
                        
                        .. attribute:: endp_hdl
                        
                        	endp hdl
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: recv_cnt
                        
                        	recv cnt
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: send_seqnum
                        
                        	send seqnum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vm_idx
                        
                        	vm idx
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd, self).__init__()

                            self.yang_name = "ncd"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.chksum = YLeaf(YType.uint16, "chksum")

                            self.conn_up = YLeaf(YType.boolean, "conn-up")

                            self.endp_hdl = YLeaf(YType.uint8, "endp-hdl")

                            self.recv_cnt = YLeaf(YType.uint32, "recv-cnt")

                            self.send_seqnum = YLeaf(YType.uint32, "send-seqnum")

                            self.vm_idx = YLeaf(YType.uint8, "vm-idx")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("chksum",
                                            "conn_up",
                                            "endp_hdl",
                                            "recv_cnt",
                                            "send_seqnum",
                                            "vm_idx") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.chksum.is_set or
                                self.conn_up.is_set or
                                self.endp_hdl.is_set or
                                self.recv_cnt.is_set or
                                self.send_seqnum.is_set or
                                self.vm_idx.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.chksum.yfilter != YFilter.not_set or
                                self.conn_up.yfilter != YFilter.not_set or
                                self.endp_hdl.yfilter != YFilter.not_set or
                                self.recv_cnt.yfilter != YFilter.not_set or
                                self.send_seqnum.yfilter != YFilter.not_set or
                                self.vm_idx.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ncd" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.chksum.is_set or self.chksum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.chksum.get_name_leafdata())
                            if (self.conn_up.is_set or self.conn_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.conn_up.get_name_leafdata())
                            if (self.endp_hdl.is_set or self.endp_hdl.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.endp_hdl.get_name_leafdata())
                            if (self.recv_cnt.is_set or self.recv_cnt.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.recv_cnt.get_name_leafdata())
                            if (self.send_seqnum.is_set or self.send_seqnum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.send_seqnum.get_name_leafdata())
                            if (self.vm_idx.is_set or self.vm_idx.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vm_idx.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "chksum" or name == "conn-up" or name == "endp-hdl" or name == "recv-cnt" or name == "send-seqnum" or name == "vm-idx"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "chksum"):
                                self.chksum = value
                                self.chksum.value_namespace = name_space
                                self.chksum.value_namespace_prefix = name_space_prefix
                            if(value_path == "conn-up"):
                                self.conn_up = value
                                self.conn_up.value_namespace = name_space
                                self.conn_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "endp-hdl"):
                                self.endp_hdl = value
                                self.endp_hdl.value_namespace = name_space
                                self.endp_hdl.value_namespace_prefix = name_space_prefix
                            if(value_path == "recv-cnt"):
                                self.recv_cnt = value
                                self.recv_cnt.value_namespace = name_space
                                self.recv_cnt.value_namespace_prefix = name_space_prefix
                            if(value_path == "send-seqnum"):
                                self.send_seqnum = value
                                self.send_seqnum.value_namespace = name_space
                                self.send_seqnum.value_namespace_prefix = name_space_prefix
                            if(value_path == "vm-idx"):
                                self.vm_idx = value
                                self.vm_idx.value_namespace = name_space
                                self.vm_idx.value_namespace_prefix = name_space_prefix


                    class NiiIdb(Entity):
                        """
                        nii idb
                        
                        .. attribute:: brought_up
                        
                        	brought up
                        	**type**\:  bool
                        
                        .. attribute:: exist
                        
                        	exist
                        	**type**\:  bool
                        
                        .. attribute:: has_adj
                        
                        	has adj
                        	**type**\:  bool
                        
                        .. attribute:: retry_timer
                        
                        	retry timer
                        	**type**\:  bool
                        
                        .. attribute:: running
                        
                        	running
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb, self).__init__()

                            self.yang_name = "nii-idb"
                            self.yang_parent_name = "isis-nsr-infra"

                            self.brought_up = YLeaf(YType.boolean, "brought-up")

                            self.exist = YLeaf(YType.boolean, "exist")

                            self.has_adj = YLeaf(YType.boolean, "has-adj")

                            self.retry_timer = YLeaf(YType.boolean, "retry-timer")

                            self.running = YLeaf(YType.boolean, "running")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("brought_up",
                                            "exist",
                                            "has_adj",
                                            "retry_timer",
                                            "running") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.brought_up.is_set or
                                self.exist.is_set or
                                self.has_adj.is_set or
                                self.retry_timer.is_set or
                                self.running.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.brought_up.yfilter != YFilter.not_set or
                                self.exist.yfilter != YFilter.not_set or
                                self.has_adj.yfilter != YFilter.not_set or
                                self.retry_timer.yfilter != YFilter.not_set or
                                self.running.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "nii-idb" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.brought_up.is_set or self.brought_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.brought_up.get_name_leafdata())
                            if (self.exist.is_set or self.exist.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.exist.get_name_leafdata())
                            if (self.has_adj.is_set or self.has_adj.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.has_adj.get_name_leafdata())
                            if (self.retry_timer.is_set or self.retry_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.retry_timer.get_name_leafdata())
                            if (self.running.is_set or self.running.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.running.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "brought-up" or name == "exist" or name == "has-adj" or name == "retry-timer" or name == "running"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "brought-up"):
                                self.brought_up = value
                                self.brought_up.value_namespace = name_space
                                self.brought_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "exist"):
                                self.exist = value
                                self.exist.value_namespace = name_space
                                self.exist.value_namespace_prefix = name_space_prefix
                            if(value_path == "has-adj"):
                                self.has_adj = value
                                self.has_adj.value_namespace = name_space
                                self.has_adj.value_namespace_prefix = name_space_prefix
                            if(value_path == "retry-timer"):
                                self.retry_timer = value
                                self.retry_timer.value_namespace = name_space
                                self.retry_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "running"):
                                self.running = value
                                self.running.value_namespace = name_space
                                self.running.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ncd:
                            if (c.has_data()):
                                return True
                        for c in self.nii_idb:
                            if (c.has_data()):
                                return True
                        return (
                            (self.ds is not None and self.ds.has_data()) or
                            (self.gen is not None and self.gen.has_data()) or
                            (self.pm is not None and self.pm.has_data()) or
                            (self.te is not None and self.te.has_data()))

                    def has_operation(self):
                        for c in self.ncd:
                            if (c.has_operation()):
                                return True
                        for c in self.nii_idb:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.ds is not None and self.ds.has_operation()) or
                            (self.gen is not None and self.gen.has_operation()) or
                            (self.pm is not None and self.pm.has_operation()) or
                            (self.te is not None and self.te.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "isis-nsr-infra" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ds"):
                            if (self.ds is None):
                                self.ds = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds()
                                self.ds.parent = self
                                self._children_name_map["ds"] = "ds"
                            return self.ds

                        if (child_yang_name == "gen"):
                            if (self.gen is None):
                                self.gen = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen()
                                self.gen.parent = self
                                self._children_name_map["gen"] = "gen"
                            return self.gen

                        if (child_yang_name == "ncd"):
                            for c in self.ncd:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ncd.append(c)
                            return c

                        if (child_yang_name == "nii-idb"):
                            for c in self.nii_idb:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.nii_idb.append(c)
                            return c

                        if (child_yang_name == "pm"):
                            if (self.pm is None):
                                self.pm = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm()
                                self.pm.parent = self
                                self._children_name_map["pm"] = "pm"
                            return self.pm

                        if (child_yang_name == "te"):
                            if (self.te is None):
                                self.te = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te()
                                self.te.parent = self
                                self._children_name_map["te"] = "te"
                            return self.te

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ds" or name == "gen" or name == "ncd" or name == "nii-idb" or name == "pm" or name == "te"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.isis_vm_state.is_set or
                        (self.isis_nsr_infra is not None and self.isis_nsr_infra.has_data()) or
                        (self.isis_nsr_peer is not None and self.isis_nsr_peer.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.isis_vm_state.yfilter != YFilter.not_set or
                        (self.isis_nsr_infra is not None and self.isis_nsr_infra.has_operation()) or
                        (self.isis_nsr_peer is not None and self.isis_nsr_peer.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.isis_vm_state.is_set or self.isis_vm_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.isis_vm_state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "isis-nsr-infra"):
                        if (self.isis_nsr_infra is None):
                            self.isis_nsr_infra = Isis.Instances.Instance.NsrStatus.IsisNsrInfra()
                            self.isis_nsr_infra.parent = self
                            self._children_name_map["isis_nsr_infra"] = "isis-nsr-infra"
                        return self.isis_nsr_infra

                    if (child_yang_name == "isis-nsr-peer"):
                        if (self.isis_nsr_peer is None):
                            self.isis_nsr_peer = Isis.Instances.Instance.NsrStatus.IsisNsrPeer()
                            self.isis_nsr_peer.parent = self
                            self._children_name_map["isis_nsr_peer"] = "isis-nsr-peer"
                        return self.isis_nsr_peer

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "isis-nsr-infra" or name == "isis-nsr-peer" or name == "isis-vm-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "isis-vm-state"):
                        self.isis_vm_state = value
                        self.isis_vm_state.value_namespace = name_space
                        self.isis_vm_state.value_namespace_prefix = name_space_prefix


            class Interfaces(Entity):
                """
                Interface table
                
                .. attribute:: interface
                
                	Information about one IS\-IS interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "instance"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.Interfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.Interfaces, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Information about one IS\-IS interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: configured_circuit_type
                    
                    	Configured circuit type for the interface
                    	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: configured_status
                    
                    	Configured interface status
                    	**type**\:   :py:class:`ConfiguredStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus>`
                    
                    .. attribute:: interface_status_and_data
                    
                    	Information about the interface status and its data
                    	**type**\:   :py:class:`InterfaceStatusAndData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData>`
                    
                    .. attribute:: is_type
                    
                    	IS\-type of the router
                    	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: mesh_group
                    
                    	Interface mesh group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_intf
                    
                    	ISIS NSR Interface
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configured_circuit_type = YLeaf(YType.enumeration, "configured-circuit-type")

                        self.is_type = YLeaf(YType.enumeration, "is-type")

                        self.mesh_group = YLeaf(YType.uint32, "mesh-group")

                        self.nsr_intf = YLeaf(YType.boolean, "nsr-intf")

                        self.configured_status = Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus()
                        self.configured_status.parent = self
                        self._children_name_map["configured_status"] = "configured-status"
                        self._children_yang_names.add("configured-status")

                        self.interface_status_and_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData()
                        self.interface_status_and_data.parent = self
                        self._children_name_map["interface_status_and_data"] = "interface-status-and-data"
                        self._children_yang_names.add("interface-status-and-data")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configured_circuit_type",
                                        "is_type",
                                        "mesh_group",
                                        "nsr_intf") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Interfaces.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Interfaces.Interface, self).__setattr__(name, value)


                    class ConfiguredStatus(Entity):
                        """
                        Configured interface status
                        
                        .. attribute:: adjacency_form_status
                        
                        	Configured adjacency formation status
                        	**type**\:  bool
                        
                        .. attribute:: adv_prefix_status
                        
                        	Configured prefix advertisement status
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus, self).__init__()

                            self.yang_name = "configured-status"
                            self.yang_parent_name = "interface"

                            self.adjacency_form_status = YLeaf(YType.boolean, "adjacency-form-status")

                            self.adv_prefix_status = YLeaf(YType.boolean, "adv-prefix-status")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("adjacency_form_status",
                                            "adv_prefix_status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.adjacency_form_status.is_set or
                                self.adv_prefix_status.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.adjacency_form_status.yfilter != YFilter.not_set or
                                self.adv_prefix_status.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "configured-status" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.adjacency_form_status.is_set or self.adjacency_form_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adjacency_form_status.get_name_leafdata())
                            if (self.adv_prefix_status.is_set or self.adv_prefix_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.adv_prefix_status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "adjacency-form-status" or name == "adv-prefix-status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "adjacency-form-status"):
                                self.adjacency_form_status = value
                                self.adjacency_form_status.value_namespace = name_space
                                self.adjacency_form_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "adv-prefix-status"):
                                self.adv_prefix_status = value
                                self.adv_prefix_status.value_namespace = name_space
                                self.adv_prefix_status.value_namespace_prefix = name_space_prefix


                    class InterfaceStatusAndData(Entity):
                        """
                        Information about the interface status and its
                        data
                        
                        .. attribute:: disabled
                        
                        	The interface state if disabled
                        	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled>`
                        
                        .. attribute:: enabled
                        
                        	The interface state if enabled
                        	**type**\:   :py:class:`Enabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled>`
                        
                        .. attribute:: status
                        
                        	Status
                        	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData, self).__init__()

                            self.yang_name = "interface-status-and-data"
                            self.yang_parent_name = "interface"

                            self.status = YLeaf(YType.enumeration, "status")

                            self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled()
                            self.disabled.parent = self
                            self._children_name_map["disabled"] = "disabled"
                            self._children_yang_names.add("disabled")

                            self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled()
                            self.enabled.parent = self
                            self._children_name_map["enabled"] = "enabled"
                            self._children_yang_names.add("enabled")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("status") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData, self).__setattr__(name, value)


                        class Disabled(Entity):
                            """
                            The interface state if disabled
                            
                            .. attribute:: reason_code
                            
                            	Reason why the interface is disabled
                            	**type**\:   :py:class:`IsisIfDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfDisabledReason>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled, self).__init__()

                                self.yang_name = "disabled"
                                self.yang_parent_name = "interface-status-and-data"

                                self.reason_code = YLeaf(YType.enumeration, "reason-code")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("reason_code") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled, self).__setattr__(name, value)

                            def has_data(self):
                                return self.reason_code.is_set

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.reason_code.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "disabled" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reason_code.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "reason-code"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "reason-code"):
                                    self.reason_code = value
                                    self.reason_code.value_namespace = name_space
                                    self.reason_code.value_namespace_prefix = name_space_prefix


                        class Enabled(Entity):
                            """
                            The interface state if enabled
                            
                            .. attribute:: adjacency_form_status
                            
                            	Interface's Adjacency Formation status
                            	**type**\:   :py:class:`AdjacencyFormStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus>`
                            
                            .. attribute:: adv_prefix_status
                            
                            	Interface's Prefix Advertisement status
                            	**type**\:   :py:class:`AdvPrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus>`
                            
                            .. attribute:: bfd_data
                            
                            	The BFD data for the given interface
                            	**type**\:   :py:class:`BfdData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData>`
                            
                            .. attribute:: clns_data
                            
                            	Interface data specific to CLNS I/O services
                            	**type**\:   :py:class:`ClnsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData>`
                            
                            .. attribute:: enabled_circuit_type
                            
                            	Enabled Circuit type of the interface
                            	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                            
                            .. attribute:: interface_media_type
                            
                            	Media type of the interface
                            	**type**\:   :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                            
                            .. attribute:: local_circuit_number
                            
                            	Local Circuit Number of the interface
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: p2p_data
                            
                            	Data for an active P2P interface, NULL if not active or P2P
                            	**type**\:   :py:class:`P2PData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData>`
                            
                            .. attribute:: per_address_family_data
                            
                            	Array of address family information
                            	**type**\: list of    :py:class:`PerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData>`
                            
                            .. attribute:: per_area_data
                            
                            	Array of area information for an active interface
                            	**type**\: list of    :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData>`
                            
                            .. attribute:: per_topology_data
                            
                            	Array of topology information
                            	**type**\: list of    :py:class:`PerTopologyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData>`
                            
                            .. attribute:: rsi_srlg_registered
                            
                            	Rsi Srlg Registered
                            	**type**\:  bool
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of    :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled, self).__init__()

                                self.yang_name = "enabled"
                                self.yang_parent_name = "interface-status-and-data"

                                self.enabled_circuit_type = YLeaf(YType.enumeration, "enabled-circuit-type")

                                self.interface_media_type = YLeaf(YType.enumeration, "interface-media-type")

                                self.local_circuit_number = YLeaf(YType.uint8, "local-circuit-number")

                                self.rsi_srlg_registered = YLeaf(YType.boolean, "rsi-srlg-registered")

                                self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus()
                                self.adjacency_form_status.parent = self
                                self._children_name_map["adjacency_form_status"] = "adjacency-form-status"
                                self._children_yang_names.add("adjacency-form-status")

                                self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus()
                                self.adv_prefix_status.parent = self
                                self._children_name_map["adv_prefix_status"] = "adv-prefix-status"
                                self._children_yang_names.add("adv-prefix-status")

                                self.bfd_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData()
                                self.bfd_data.parent = self
                                self._children_name_map["bfd_data"] = "bfd-data"
                                self._children_yang_names.add("bfd-data")

                                self.clns_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData()
                                self.clns_data.parent = self
                                self._children_name_map["clns_data"] = "clns-data"
                                self._children_yang_names.add("clns-data")

                                self.p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData()
                                self.p2p_data.parent = self
                                self._children_name_map["p2p_data"] = "p2p-data"
                                self._children_yang_names.add("p2p-data")

                                self.per_address_family_data = YList(self)
                                self.per_area_data = YList(self)
                                self.per_topology_data = YList(self)
                                self.underlying_interface = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("enabled_circuit_type",
                                                "interface_media_type",
                                                "local_circuit_number",
                                                "rsi_srlg_registered") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled, self).__setattr__(name, value)


                            class AdjacencyFormStatus(Entity):
                                """
                                Interface's Adjacency Formation status
                                
                                .. attribute:: disabled
                                
                                	Disabled info for the adjacency formation status
                                	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled>`
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus, self).__init__()

                                    self.yang_name = "adjacency-form-status"
                                    self.yang_parent_name = "enabled"

                                    self.status = YLeaf(YType.enumeration, "status")

                                    self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled()
                                    self.disabled.parent = self
                                    self._children_name_map["disabled"] = "disabled"
                                    self._children_yang_names.add("disabled")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus, self).__setattr__(name, value)


                                class Disabled(Entity):
                                    """
                                    Disabled info for the adjacency formation status
                                    
                                    .. attribute:: reason_code
                                    
                                    	Reason why the interface is not able to form adjacencies
                                    	**type**\:   :py:class:`IsisIfAdjFormDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAdjFormDisabledReason>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled, self).__init__()

                                        self.yang_name = "disabled"
                                        self.yang_parent_name = "adjacency-form-status"

                                        self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("reason_code") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.reason_code.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.reason_code.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disabled" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reason_code.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "reason-code"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "reason-code"):
                                            self.reason_code = value
                                            self.reason_code.value_namespace = name_space
                                            self.reason_code.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.status.is_set or
                                        (self.disabled is not None and self.disabled.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.status.yfilter != YFilter.not_set or
                                        (self.disabled is not None and self.disabled.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adjacency-form-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "disabled"):
                                        if (self.disabled is None):
                                            self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled()
                                            self.disabled.parent = self
                                            self._children_name_map["disabled"] = "disabled"
                                        return self.disabled

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "disabled" or name == "status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "status"):
                                        self.status = value
                                        self.status.value_namespace = name_space
                                        self.status.value_namespace_prefix = name_space_prefix


                            class AdvPrefixStatus(Entity):
                                """
                                Interface's Prefix Advertisement status
                                
                                .. attribute:: disabled
                                
                                	Disabled info for the prefix advertisement status
                                	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled>`
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus, self).__init__()

                                    self.yang_name = "adv-prefix-status"
                                    self.yang_parent_name = "enabled"

                                    self.status = YLeaf(YType.enumeration, "status")

                                    self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled()
                                    self.disabled.parent = self
                                    self._children_name_map["disabled"] = "disabled"
                                    self._children_yang_names.add("disabled")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus, self).__setattr__(name, value)


                                class Disabled(Entity):
                                    """
                                    Disabled info for the prefix advertisement
                                    status
                                    
                                    .. attribute:: reason_code
                                    
                                    	Reason why the interface is not able to advertise prefixes
                                    	**type**\:   :py:class:`IsisIfAdvPrefixDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAdvPrefixDisabledReason>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled, self).__init__()

                                        self.yang_name = "disabled"
                                        self.yang_parent_name = "adv-prefix-status"

                                        self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("reason_code") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled, self).__setattr__(name, value)

                                    def has_data(self):
                                        return self.reason_code.is_set

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.reason_code.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "disabled" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.reason_code.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "reason-code"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "reason-code"):
                                            self.reason_code = value
                                            self.reason_code.value_namespace = name_space
                                            self.reason_code.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.status.is_set or
                                        (self.disabled is not None and self.disabled.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.status.yfilter != YFilter.not_set or
                                        (self.disabled is not None and self.disabled.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "adv-prefix-status" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "disabled"):
                                        if (self.disabled is None):
                                            self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled()
                                            self.disabled.parent = self
                                            self._children_name_map["disabled"] = "disabled"
                                        return self.disabled

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "disabled" or name == "status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "status"):
                                        self.status = value
                                        self.status.value_namespace = name_space
                                        self.status.value_namespace_prefix = name_space_prefix


                            class P2PData(Entity):
                                """
                                Data for an active P2P interface, NULL if not
                                active or P2P
                                
                                .. attribute:: extended_circuit_number
                                
                                	Extended Circuit Number valid for a P2P interface
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmit_lsp_interval
                                
                                	Time in ms until the next scheduled LSP is retransmitted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmit_lsp_queue_size
                                
                                	No. of LSPs queued to be retransmitted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_until_next_iih
                                
                                	Time in ms before the next IIH can be sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData, self).__init__()

                                    self.yang_name = "p2p-data"
                                    self.yang_parent_name = "enabled"

                                    self.extended_circuit_number = YLeaf(YType.uint32, "extended-circuit-number")

                                    self.retransmit_lsp_interval = YLeaf(YType.uint32, "retransmit-lsp-interval")

                                    self.retransmit_lsp_queue_size = YLeaf(YType.uint32, "retransmit-lsp-queue-size")

                                    self.time_until_next_iih = YLeaf(YType.uint32, "time-until-next-iih")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("extended_circuit_number",
                                                    "retransmit_lsp_interval",
                                                    "retransmit_lsp_queue_size",
                                                    "time_until_next_iih") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.extended_circuit_number.is_set or
                                        self.retransmit_lsp_interval.is_set or
                                        self.retransmit_lsp_queue_size.is_set or
                                        self.time_until_next_iih.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.extended_circuit_number.yfilter != YFilter.not_set or
                                        self.retransmit_lsp_interval.yfilter != YFilter.not_set or
                                        self.retransmit_lsp_queue_size.yfilter != YFilter.not_set or
                                        self.time_until_next_iih.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "p2p-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.extended_circuit_number.is_set or self.extended_circuit_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.extended_circuit_number.get_name_leafdata())
                                    if (self.retransmit_lsp_interval.is_set or self.retransmit_lsp_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_lsp_interval.get_name_leafdata())
                                    if (self.retransmit_lsp_queue_size.is_set or self.retransmit_lsp_queue_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.retransmit_lsp_queue_size.get_name_leafdata())
                                    if (self.time_until_next_iih.is_set or self.time_until_next_iih.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_until_next_iih.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "extended-circuit-number" or name == "retransmit-lsp-interval" or name == "retransmit-lsp-queue-size" or name == "time-until-next-iih"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "extended-circuit-number"):
                                        self.extended_circuit_number = value
                                        self.extended_circuit_number.value_namespace = name_space
                                        self.extended_circuit_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-lsp-interval"):
                                        self.retransmit_lsp_interval = value
                                        self.retransmit_lsp_interval.value_namespace = name_space
                                        self.retransmit_lsp_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "retransmit-lsp-queue-size"):
                                        self.retransmit_lsp_queue_size = value
                                        self.retransmit_lsp_queue_size.value_namespace = name_space
                                        self.retransmit_lsp_queue_size.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-until-next-iih"):
                                        self.time_until_next_iih = value
                                        self.time_until_next_iih.value_namespace = name_space
                                        self.time_until_next_iih.value_namespace_prefix = name_space_prefix


                            class BfdData(Entity):
                                """
                                The BFD data for the given interface
                                
                                .. attribute:: enabled
                                
                                	IPv4 BFD enabled status
                                	**type**\:  bool
                                
                                .. attribute:: interval
                                
                                	BFD hello minimum interval in milliseconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: ipv6_enabled
                                
                                	IPv6 BFD enabled status
                                	**type**\:  bool
                                
                                .. attribute:: multiplier
                                
                                	BFD hello multiplier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData, self).__init__()

                                    self.yang_name = "bfd-data"
                                    self.yang_parent_name = "enabled"

                                    self.enabled = YLeaf(YType.boolean, "enabled")

                                    self.interval = YLeaf(YType.uint32, "interval")

                                    self.ipv6_enabled = YLeaf(YType.boolean, "ipv6-enabled")

                                    self.multiplier = YLeaf(YType.uint32, "multiplier")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("enabled",
                                                    "interval",
                                                    "ipv6_enabled",
                                                    "multiplier") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.enabled.is_set or
                                        self.interval.is_set or
                                        self.ipv6_enabled.is_set or
                                        self.multiplier.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.enabled.yfilter != YFilter.not_set or
                                        self.interval.yfilter != YFilter.not_set or
                                        self.ipv6_enabled.yfilter != YFilter.not_set or
                                        self.multiplier.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "bfd-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.enabled.is_set or self.enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.enabled.get_name_leafdata())
                                    if (self.interval.is_set or self.interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.interval.get_name_leafdata())
                                    if (self.ipv6_enabled.is_set or self.ipv6_enabled.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_enabled.get_name_leafdata())
                                    if (self.multiplier.is_set or self.multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.multiplier.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "enabled" or name == "interval" or name == "ipv6-enabled" or name == "multiplier"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "enabled"):
                                        self.enabled = value
                                        self.enabled.value_namespace = name_space
                                        self.enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "interval"):
                                        self.interval = value
                                        self.interval.value_namespace = name_space
                                        self.interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-enabled"):
                                        self.ipv6_enabled = value
                                        self.ipv6_enabled.value_namespace = name_space
                                        self.ipv6_enabled.value_namespace_prefix = name_space_prefix
                                    if(value_path == "multiplier"):
                                        self.multiplier = value
                                        self.multiplier.value_namespace = name_space
                                        self.multiplier.value_namespace_prefix = name_space_prefix


                            class ClnsData(Entity):
                                """
                                Interface data specific to CLNS I/O services
                                
                                .. attribute:: clns_status
                                
                                	Is CLNS protcol up or if not, the reason why it is not up
                                	**type**\:   :py:class:`ClnsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus>`
                                
                                .. attribute:: last_lsp_id_transmitted
                                
                                	Last LSP ID Transmitted
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: last_lsp_level_transmitted
                                
                                	Level of the Last LSP Transmitted
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: lsp_transmit_requested_flag
                                
                                	TRUE if an LSP transmission has been requested
                                	**type**\:  bool
                                
                                .. attribute:: lsp_transmitted_flag
                                
                                	TRUE if an LSP transmission has been sent, indicates LastLSPLevelTransmitted and LastLSP\_IDTransmitted valid
                                	**type**\:  bool
                                
                                .. attribute:: lsp_txmitd_b2b_limit
                                
                                	Number of LSPs that can be sent back to back in the current window without exceeding the pacing limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_txmt_b2b_msecs
                                
                                	Time im msecs indicating the end of the window in which the 'back to back lsps to be sent' counter applies
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: media_specific_state
                                
                                	Media Specific CLNS state
                                	**type**\:   :py:class:`MediaSpecificState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState>`
                                
                                .. attribute:: mtu_info
                                
                                	A valid MTU or the reason for the MTU being invalid
                                	**type**\:   :py:class:`MtuInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo>`
                                
                                .. attribute:: snpa_state
                                
                                	SNPA state
                                	**type**\:   :py:class:`SnpaState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState>`
                                
                                .. attribute:: time_until_next_lsp
                                
                                	Time until next LSP may be sent (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData, self).__init__()

                                    self.yang_name = "clns-data"
                                    self.yang_parent_name = "enabled"

                                    self.last_lsp_id_transmitted = YLeaf(YType.str, "last-lsp-id-transmitted")

                                    self.last_lsp_level_transmitted = YLeaf(YType.enumeration, "last-lsp-level-transmitted")

                                    self.lsp_transmit_requested_flag = YLeaf(YType.boolean, "lsp-transmit-requested-flag")

                                    self.lsp_transmitted_flag = YLeaf(YType.boolean, "lsp-transmitted-flag")

                                    self.lsp_txmitd_b2b_limit = YLeaf(YType.uint32, "lsp-txmitd-b2b-limit")

                                    self.lsp_txmt_b2b_msecs = YLeaf(YType.uint32, "lsp-txmt-b2b-msecs")

                                    self.time_until_next_lsp = YLeaf(YType.uint32, "time-until-next-lsp")

                                    self.clns_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus()
                                    self.clns_status.parent = self
                                    self._children_name_map["clns_status"] = "clns-status"
                                    self._children_yang_names.add("clns-status")

                                    self.media_specific_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState()
                                    self.media_specific_state.parent = self
                                    self._children_name_map["media_specific_state"] = "media-specific-state"
                                    self._children_yang_names.add("media-specific-state")

                                    self.mtu_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo()
                                    self.mtu_info.parent = self
                                    self._children_name_map["mtu_info"] = "mtu-info"
                                    self._children_yang_names.add("mtu-info")

                                    self.snpa_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState()
                                    self.snpa_state.parent = self
                                    self._children_name_map["snpa_state"] = "snpa-state"
                                    self._children_yang_names.add("snpa-state")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("last_lsp_id_transmitted",
                                                    "last_lsp_level_transmitted",
                                                    "lsp_transmit_requested_flag",
                                                    "lsp_transmitted_flag",
                                                    "lsp_txmitd_b2b_limit",
                                                    "lsp_txmt_b2b_msecs",
                                                    "time_until_next_lsp") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData, self).__setattr__(name, value)


                                class ClnsStatus(Entity):
                                    """
                                    Is CLNS protcol up or if not, the reason why it
                                    is not up
                                    
                                    .. attribute:: clns_down_info
                                    
                                    	State describing why CLNS is down
                                    	**type**\:   :py:class:`ClnsDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:   :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus, self).__init__()

                                        self.yang_name = "clns-status"
                                        self.yang_parent_name = "clns-data"

                                        self.status = YLeaf(YType.enumeration, "status")

                                        self.clns_down_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo()
                                        self.clns_down_info.parent = self
                                        self._children_name_map["clns_down_info"] = "clns-down-info"
                                        self._children_yang_names.add("clns-down-info")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus, self).__setattr__(name, value)


                                    class ClnsDownInfo(Entity):
                                        """
                                        State describing why CLNS is down
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why CLNS is down
                                        	**type**\:   :py:class:`IsisIfClnsProtoDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsProtoDownReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo, self).__init__()

                                            self.yang_name = "clns-down-info"
                                            self.yang_parent_name = "clns-status"

                                            self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reason_code") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.reason_code.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reason_code.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "clns-down-info" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reason_code.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reason-code"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reason-code"):
                                                self.reason_code = value
                                                self.reason_code.value_namespace = name_space
                                                self.reason_code.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.status.is_set or
                                            (self.clns_down_info is not None and self.clns_down_info.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            (self.clns_down_info is not None and self.clns_down_info.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "clns-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "clns-down-info"):
                                            if (self.clns_down_info is None):
                                                self.clns_down_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo()
                                                self.clns_down_info.parent = self
                                                self._children_name_map["clns_down_info"] = "clns-down-info"
                                            return self.clns_down_info

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "clns-down-info" or name == "status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix


                                class MtuInfo(Entity):
                                    """
                                    A valid MTU or the reason for the MTU being
                                    invalid
                                    
                                    .. attribute:: invalid
                                    
                                    	Information pertaining to the invalid CLNS MTU
                                    	**type**\:   :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid>`
                                    
                                    .. attribute:: mtu
                                    
                                    	Valid MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo, self).__init__()

                                        self.yang_name = "mtu-info"
                                        self.yang_parent_name = "clns-data"

                                        self.mtu = YLeaf(YType.uint32, "mtu")

                                        self.status = YLeaf(YType.enumeration, "status")

                                        self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid()
                                        self.invalid.parent = self
                                        self._children_name_map["invalid"] = "invalid"
                                        self._children_yang_names.add("invalid")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("mtu",
                                                        "status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo, self).__setattr__(name, value)


                                    class Invalid(Entity):
                                        """
                                        Information pertaining to the invalid CLNS MTU
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the MTU is invalid
                                        	**type**\:   :py:class:`IsisIfClnsMtuInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsMtuInvalidReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid, self).__init__()

                                            self.yang_name = "invalid"
                                            self.yang_parent_name = "mtu-info"

                                            self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reason_code") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.reason_code.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reason_code.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "invalid" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reason_code.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reason-code"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reason-code"):
                                                self.reason_code = value
                                                self.reason_code.value_namespace = name_space
                                                self.reason_code.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.mtu.is_set or
                                            self.status.is_set or
                                            (self.invalid is not None and self.invalid.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.mtu.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            (self.invalid is not None and self.invalid.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "mtu-info" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.mtu.get_name_leafdata())
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "invalid"):
                                            if (self.invalid is None):
                                                self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid()
                                                self.invalid.parent = self
                                                self._children_name_map["invalid"] = "invalid"
                                            return self.invalid

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "invalid" or name == "mtu" or name == "status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "mtu"):
                                            self.mtu = value
                                            self.mtu.value_namespace = name_space
                                            self.mtu.value_namespace_prefix = name_space_prefix
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix


                                class SnpaState(Entity):
                                    """
                                    SNPA state
                                    
                                    .. attribute:: known
                                    
                                    	Information pertaining to the known SNPA state
                                    	**type**\:   :py:class:`Known <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:   :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                    
                                    .. attribute:: unknown
                                    
                                    	Information pertaining to the unknown SNPA state
                                    	**type**\:   :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState, self).__init__()

                                        self.yang_name = "snpa-state"
                                        self.yang_parent_name = "clns-data"

                                        self.status = YLeaf(YType.enumeration, "status")

                                        self.known = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known()
                                        self.known.parent = self
                                        self._children_name_map["known"] = "known"
                                        self._children_yang_names.add("known")

                                        self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown()
                                        self.unknown.parent = self
                                        self._children_name_map["unknown"] = "unknown"
                                        self._children_yang_names.add("unknown")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState, self).__setattr__(name, value)


                                    class Unknown(Entity):
                                        """
                                        Information pertaining to the unknown SNPA state
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the SNPA is unknown
                                        	**type**\:   :py:class:`IsisIfClnsSnpaUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsSnpaUnknownReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown, self).__init__()

                                            self.yang_name = "unknown"
                                            self.yang_parent_name = "snpa-state"

                                            self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reason_code") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.reason_code.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reason_code.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "unknown" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reason_code.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reason-code"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reason-code"):
                                                self.reason_code = value
                                                self.reason_code.value_namespace = name_space
                                                self.reason_code.value_namespace_prefix = name_space_prefix


                                    class Known(Entity):
                                        """
                                        Information pertaining to the known SNPA state
                                        
                                        .. attribute:: snpa
                                        
                                        	Valid SNPA
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known, self).__init__()

                                            self.yang_name = "known"
                                            self.yang_parent_name = "snpa-state"

                                            self.snpa = YLeaf(YType.str, "snpa")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("snpa") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.snpa.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.snpa.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "known" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.snpa.is_set or self.snpa.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.snpa.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "snpa"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "snpa"):
                                                self.snpa = value
                                                self.snpa.value_namespace = name_space
                                                self.snpa.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.status.is_set or
                                            (self.known is not None and self.known.has_data()) or
                                            (self.unknown is not None and self.unknown.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            (self.known is not None and self.known.has_operation()) or
                                            (self.unknown is not None and self.unknown.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "snpa-state" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "known"):
                                            if (self.known is None):
                                                self.known = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known()
                                                self.known.parent = self
                                                self._children_name_map["known"] = "known"
                                            return self.known

                                        if (child_yang_name == "unknown"):
                                            if (self.unknown is None):
                                                self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown()
                                                self.unknown.parent = self
                                                self._children_name_map["unknown"] = "unknown"
                                            return self.unknown

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "known" or name == "unknown" or name == "status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix


                                class MediaSpecificState(Entity):
                                    """
                                    Media Specific CLNS state
                                    
                                    .. attribute:: clns_lan_data
                                    
                                    	LAN state
                                    	**type**\:   :py:class:`ClnsLanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData>`
                                    
                                    .. attribute:: clns_media_type
                                    
                                    	CLNSMediaType
                                    	**type**\:   :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                                    
                                    .. attribute:: clns_p2p_data
                                    
                                    	Point\-to\-point state
                                    	**type**\:   :py:class:`ClnsP2PData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState, self).__init__()

                                        self.yang_name = "media-specific-state"
                                        self.yang_parent_name = "clns-data"

                                        self.clns_media_type = YLeaf(YType.enumeration, "clns-media-type")

                                        self.clns_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData()
                                        self.clns_lan_data.parent = self
                                        self._children_name_map["clns_lan_data"] = "clns-lan-data"
                                        self._children_yang_names.add("clns-lan-data")

                                        self.clns_p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData()
                                        self.clns_p2p_data.parent = self
                                        self._children_name_map["clns_p2p_data"] = "clns-p2p-data"
                                        self._children_yang_names.add("clns-p2p-data")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("clns_media_type") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState, self).__setattr__(name, value)


                                    class ClnsLanData(Entity):
                                        """
                                        LAN state
                                        
                                        .. attribute:: per_area_data
                                        
                                        	Array of per area CLNS data
                                        	**type**\: list of    :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData, self).__init__()

                                            self.yang_name = "clns-lan-data"
                                            self.yang_parent_name = "media-specific-state"

                                            self.per_area_data = YList(self)

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in () and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData, self).__setattr__(name, value)


                                        class PerAreaData(Entity):
                                            """
                                            Array of per area CLNS data
                                            
                                            .. attribute:: level
                                            
                                            	Level of the area
                                            	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                            
                                            .. attribute:: multicast_status
                                            
                                            	Multicast group membership status
                                            	**type**\:   :py:class:`MulticastStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData, self).__init__()

                                                self.yang_name = "per-area-data"
                                                self.yang_parent_name = "clns-lan-data"

                                                self.level = YLeaf(YType.enumeration, "level")

                                                self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus()
                                                self.multicast_status.parent = self
                                                self._children_name_map["multicast_status"] = "multicast-status"
                                                self._children_yang_names.add("multicast-status")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("level") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData, self).__setattr__(name, value)


                                            class MulticastStatus(Entity):
                                                """
                                                Multicast group membership status
                                                
                                                .. attribute:: invalid
                                                
                                                	Information pertaining to the invalid multicast status
                                                	**type**\:   :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid>`
                                                
                                                .. attribute:: status
                                                
                                                	Status
                                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus, self).__init__()

                                                    self.yang_name = "multicast-status"
                                                    self.yang_parent_name = "per-area-data"

                                                    self.status = YLeaf(YType.enumeration, "status")

                                                    self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid()
                                                    self.invalid.parent = self
                                                    self._children_name_map["invalid"] = "invalid"
                                                    self._children_yang_names.add("invalid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus, self).__setattr__(name, value)


                                                class Invalid(Entity):
                                                    """
                                                    Information pertaining to the invalid multicast
                                                    status
                                                    
                                                    .. attribute:: reason_code
                                                    
                                                    	Reason why the multicast status is invalid
                                                    	**type**\:   :py:class:`IsisIfMcastInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfMcastInvalidReason>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid, self).__init__()

                                                        self.yang_name = "invalid"
                                                        self.yang_parent_name = "multicast-status"

                                                        self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("reason_code") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.reason_code.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.reason_code.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "invalid" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "reason-code"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "reason-code"):
                                                            self.reason_code = value
                                                            self.reason_code.value_namespace = name_space
                                                            self.reason_code.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.status.is_set or
                                                        (self.invalid is not None and self.invalid.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.status.yfilter != YFilter.not_set or
                                                        (self.invalid is not None and self.invalid.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-status" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "invalid"):
                                                        if (self.invalid is None):
                                                            self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid()
                                                            self.invalid.parent = self
                                                            self._children_name_map["invalid"] = "invalid"
                                                        return self.invalid

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "invalid" or name == "status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "status"):
                                                        self.status = value
                                                        self.status.value_namespace = name_space
                                                        self.status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.level.is_set or
                                                    (self.multicast_status is not None and self.multicast_status.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.level.yfilter != YFilter.not_set or
                                                    (self.multicast_status is not None and self.multicast_status.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "per-area-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.level.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "multicast-status"):
                                                    if (self.multicast_status is None):
                                                        self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus()
                                                        self.multicast_status.parent = self
                                                        self._children_name_map["multicast_status"] = "multicast-status"
                                                    return self.multicast_status

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "multicast-status" or name == "level"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "level"):
                                                    self.level = value
                                                    self.level.value_namespace = name_space
                                                    self.level.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            for c in self.per_area_data:
                                                if (c.has_data()):
                                                    return True
                                            return False

                                        def has_operation(self):
                                            for c in self.per_area_data:
                                                if (c.has_operation()):
                                                    return True
                                            return self.yfilter != YFilter.not_set

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "clns-lan-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "per-area-data"):
                                                for c in self.per_area_data:
                                                    segment = c.get_segment_path()
                                                    if (segment_path == segment):
                                                        return c
                                                c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData()
                                                c.parent = self
                                                local_reference_key = "ydk::seg::%s" % segment_path
                                                self._local_refs[local_reference_key] = c
                                                self.per_area_data.append(c)
                                                return c

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "per-area-data"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass


                                    class ClnsP2PData(Entity):
                                        """
                                        Point\-to\-point state
                                        
                                        .. attribute:: p2p_over_lan_data
                                        
                                        	Point\-to\-point over LAN data
                                        	**type**\:   :py:class:`P2POverLanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData, self).__init__()

                                            self.yang_name = "clns-p2p-data"
                                            self.yang_parent_name = "media-specific-state"

                                            self.p2p_over_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData()
                                            self.p2p_over_lan_data.parent = self
                                            self._children_name_map["p2p_over_lan_data"] = "p2p-over-lan-data"
                                            self._children_yang_names.add("p2p-over-lan-data")


                                        class P2POverLanData(Entity):
                                            """
                                            Point\-to\-point over LAN data
                                            
                                            .. attribute:: multicast_status
                                            
                                            	Multicast group membership status
                                            	**type**\:   :py:class:`MulticastStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData, self).__init__()

                                                self.yang_name = "p2p-over-lan-data"
                                                self.yang_parent_name = "clns-p2p-data"

                                                self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus()
                                                self.multicast_status.parent = self
                                                self._children_name_map["multicast_status"] = "multicast-status"
                                                self._children_yang_names.add("multicast-status")


                                            class MulticastStatus(Entity):
                                                """
                                                Multicast group membership status
                                                
                                                .. attribute:: invalid
                                                
                                                	Information pertaining to the invalid multicast status
                                                	**type**\:   :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid>`
                                                
                                                .. attribute:: status
                                                
                                                	Status
                                                	**type**\:   :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus, self).__init__()

                                                    self.yang_name = "multicast-status"
                                                    self.yang_parent_name = "p2p-over-lan-data"

                                                    self.status = YLeaf(YType.enumeration, "status")

                                                    self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid()
                                                    self.invalid.parent = self
                                                    self._children_name_map["invalid"] = "invalid"
                                                    self._children_yang_names.add("invalid")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("status") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus, self).__setattr__(name, value)


                                                class Invalid(Entity):
                                                    """
                                                    Information pertaining to the invalid multicast
                                                    status
                                                    
                                                    .. attribute:: reason_code
                                                    
                                                    	Reason why the multicast status is invalid
                                                    	**type**\:   :py:class:`IsisIfMcastInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfMcastInvalidReason>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid, self).__init__()

                                                        self.yang_name = "invalid"
                                                        self.yang_parent_name = "multicast-status"

                                                        self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("reason_code") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return self.reason_code.is_set

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.reason_code.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "invalid" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "reason-code"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "reason-code"):
                                                            self.reason_code = value
                                                            self.reason_code.value_namespace = name_space
                                                            self.reason_code.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    return (
                                                        self.status.is_set or
                                                        (self.invalid is not None and self.invalid.has_data()))

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.status.yfilter != YFilter.not_set or
                                                        (self.invalid is not None and self.invalid.has_operation()))

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "multicast-status" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.status.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "invalid"):
                                                        if (self.invalid is None):
                                                            self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus.Invalid()
                                                            self.invalid.parent = self
                                                            self._children_name_map["invalid"] = "invalid"
                                                        return self.invalid

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "invalid" or name == "status"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "status"):
                                                        self.status = value
                                                        self.status.value_namespace = name_space
                                                        self.status.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (self.multicast_status is not None and self.multicast_status.has_data())

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    (self.multicast_status is not None and self.multicast_status.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "p2p-over-lan-data" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "multicast-status"):
                                                    if (self.multicast_status is None):
                                                        self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData.MulticastStatus()
                                                        self.multicast_status.parent = self
                                                        self._children_name_map["multicast_status"] = "multicast-status"
                                                    return self.multicast_status

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "multicast-status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                pass

                                        def has_data(self):
                                            return (self.p2p_over_lan_data is not None and self.p2p_over_lan_data.has_data())

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.p2p_over_lan_data is not None and self.p2p_over_lan_data.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "clns-p2p-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "p2p-over-lan-data"):
                                                if (self.p2p_over_lan_data is None):
                                                    self.p2p_over_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData.P2POverLanData()
                                                    self.p2p_over_lan_data.parent = self
                                                    self._children_name_map["p2p_over_lan_data"] = "p2p-over-lan-data"
                                                return self.p2p_over_lan_data

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "p2p-over-lan-data"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.clns_media_type.is_set or
                                            (self.clns_lan_data is not None and self.clns_lan_data.has_data()) or
                                            (self.clns_p2p_data is not None and self.clns_p2p_data.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.clns_media_type.yfilter != YFilter.not_set or
                                            (self.clns_lan_data is not None and self.clns_lan_data.has_operation()) or
                                            (self.clns_p2p_data is not None and self.clns_p2p_data.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "media-specific-state" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.clns_media_type.is_set or self.clns_media_type.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.clns_media_type.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "clns-lan-data"):
                                            if (self.clns_lan_data is None):
                                                self.clns_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData()
                                                self.clns_lan_data.parent = self
                                                self._children_name_map["clns_lan_data"] = "clns-lan-data"
                                            return self.clns_lan_data

                                        if (child_yang_name == "clns-p2p-data"):
                                            if (self.clns_p2p_data is None):
                                                self.clns_p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2PData()
                                                self.clns_p2p_data.parent = self
                                                self._children_name_map["clns_p2p_data"] = "clns-p2p-data"
                                            return self.clns_p2p_data

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "clns-lan-data" or name == "clns-p2p-data" or name == "clns-media-type"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "clns-media-type"):
                                            self.clns_media_type = value
                                            self.clns_media_type.value_namespace = name_space
                                            self.clns_media_type.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.last_lsp_id_transmitted.is_set or
                                        self.last_lsp_level_transmitted.is_set or
                                        self.lsp_transmit_requested_flag.is_set or
                                        self.lsp_transmitted_flag.is_set or
                                        self.lsp_txmitd_b2b_limit.is_set or
                                        self.lsp_txmt_b2b_msecs.is_set or
                                        self.time_until_next_lsp.is_set or
                                        (self.clns_status is not None and self.clns_status.has_data()) or
                                        (self.media_specific_state is not None and self.media_specific_state.has_data()) or
                                        (self.mtu_info is not None and self.mtu_info.has_data()) or
                                        (self.snpa_state is not None and self.snpa_state.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.last_lsp_id_transmitted.yfilter != YFilter.not_set or
                                        self.last_lsp_level_transmitted.yfilter != YFilter.not_set or
                                        self.lsp_transmit_requested_flag.yfilter != YFilter.not_set or
                                        self.lsp_transmitted_flag.yfilter != YFilter.not_set or
                                        self.lsp_txmitd_b2b_limit.yfilter != YFilter.not_set or
                                        self.lsp_txmt_b2b_msecs.yfilter != YFilter.not_set or
                                        self.time_until_next_lsp.yfilter != YFilter.not_set or
                                        (self.clns_status is not None and self.clns_status.has_operation()) or
                                        (self.media_specific_state is not None and self.media_specific_state.has_operation()) or
                                        (self.mtu_info is not None and self.mtu_info.has_operation()) or
                                        (self.snpa_state is not None and self.snpa_state.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "clns-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.last_lsp_id_transmitted.is_set or self.last_lsp_id_transmitted.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_lsp_id_transmitted.get_name_leafdata())
                                    if (self.last_lsp_level_transmitted.is_set or self.last_lsp_level_transmitted.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_lsp_level_transmitted.get_name_leafdata())
                                    if (self.lsp_transmit_requested_flag.is_set or self.lsp_transmit_requested_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_transmit_requested_flag.get_name_leafdata())
                                    if (self.lsp_transmitted_flag.is_set or self.lsp_transmitted_flag.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_transmitted_flag.get_name_leafdata())
                                    if (self.lsp_txmitd_b2b_limit.is_set or self.lsp_txmitd_b2b_limit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_txmitd_b2b_limit.get_name_leafdata())
                                    if (self.lsp_txmt_b2b_msecs.is_set or self.lsp_txmt_b2b_msecs.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_txmt_b2b_msecs.get_name_leafdata())
                                    if (self.time_until_next_lsp.is_set or self.time_until_next_lsp.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.time_until_next_lsp.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "clns-status"):
                                        if (self.clns_status is None):
                                            self.clns_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus()
                                            self.clns_status.parent = self
                                            self._children_name_map["clns_status"] = "clns-status"
                                        return self.clns_status

                                    if (child_yang_name == "media-specific-state"):
                                        if (self.media_specific_state is None):
                                            self.media_specific_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState()
                                            self.media_specific_state.parent = self
                                            self._children_name_map["media_specific_state"] = "media-specific-state"
                                        return self.media_specific_state

                                    if (child_yang_name == "mtu-info"):
                                        if (self.mtu_info is None):
                                            self.mtu_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo()
                                            self.mtu_info.parent = self
                                            self._children_name_map["mtu_info"] = "mtu-info"
                                        return self.mtu_info

                                    if (child_yang_name == "snpa-state"):
                                        if (self.snpa_state is None):
                                            self.snpa_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState()
                                            self.snpa_state.parent = self
                                            self._children_name_map["snpa_state"] = "snpa-state"
                                        return self.snpa_state

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "clns-status" or name == "media-specific-state" or name == "mtu-info" or name == "snpa-state" or name == "last-lsp-id-transmitted" or name == "last-lsp-level-transmitted" or name == "lsp-transmit-requested-flag" or name == "lsp-transmitted-flag" or name == "lsp-txmitd-b2b-limit" or name == "lsp-txmt-b2b-msecs" or name == "time-until-next-lsp"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "last-lsp-id-transmitted"):
                                        self.last_lsp_id_transmitted = value
                                        self.last_lsp_id_transmitted.value_namespace = name_space
                                        self.last_lsp_id_transmitted.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-lsp-level-transmitted"):
                                        self.last_lsp_level_transmitted = value
                                        self.last_lsp_level_transmitted.value_namespace = name_space
                                        self.last_lsp_level_transmitted.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-transmit-requested-flag"):
                                        self.lsp_transmit_requested_flag = value
                                        self.lsp_transmit_requested_flag.value_namespace = name_space
                                        self.lsp_transmit_requested_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-transmitted-flag"):
                                        self.lsp_transmitted_flag = value
                                        self.lsp_transmitted_flag.value_namespace = name_space
                                        self.lsp_transmitted_flag.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-txmitd-b2b-limit"):
                                        self.lsp_txmitd_b2b_limit = value
                                        self.lsp_txmitd_b2b_limit.value_namespace = name_space
                                        self.lsp_txmitd_b2b_limit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-txmt-b2b-msecs"):
                                        self.lsp_txmt_b2b_msecs = value
                                        self.lsp_txmt_b2b_msecs.value_namespace = name_space
                                        self.lsp_txmt_b2b_msecs.value_namespace_prefix = name_space_prefix
                                    if(value_path == "time-until-next-lsp"):
                                        self.time_until_next_lsp = value
                                        self.time_until_next_lsp.value_namespace = name_space
                                        self.time_until_next_lsp.value_namespace_prefix = name_space_prefix


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "enabled"

                                    self.entry = YLeaf(YType.str, "entry")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("entry") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.entry.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.entry.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "underlying-interface" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.entry.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "entry"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "entry"):
                                        self.entry = value
                                        self.entry.value_namespace = name_space
                                        self.entry.value_namespace_prefix = name_space_prefix


                            class PerAreaData(Entity):
                                """
                                Array of area information for an active
                                interface
                                
                                .. attribute:: adjacency_count
                                
                                	Number of adjacencies
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lan_data
                                
                                	LAN data, NULL iff interface has non\-LAN media type
                                	**type**\:   :py:class:`LanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData>`
                                
                                .. attribute:: level
                                
                                	Level of the area
                                	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: lsp_pacing_interval
                                
                                	LSP pacing time period (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: psnp_transmit_queue_size
                                
                                	No. of SNP entries queued to be transmitted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData, self).__init__()

                                    self.yang_name = "per-area-data"
                                    self.yang_parent_name = "enabled"

                                    self.adjacency_count = YLeaf(YType.uint32, "adjacency-count")

                                    self.level = YLeaf(YType.enumeration, "level")

                                    self.lsp_pacing_interval = YLeaf(YType.uint32, "lsp-pacing-interval")

                                    self.psnp_transmit_queue_size = YLeaf(YType.uint32, "psnp-transmit-queue-size")

                                    self.lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData()
                                    self.lan_data.parent = self
                                    self._children_name_map["lan_data"] = "lan-data"
                                    self._children_yang_names.add("lan-data")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("adjacency_count",
                                                    "level",
                                                    "lsp_pacing_interval",
                                                    "psnp_transmit_queue_size") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData, self).__setattr__(name, value)


                                class LanData(Entity):
                                    """
                                    LAN data, NULL iff interface has non\-LAN media
                                    type
                                    
                                    .. attribute:: are_we_dis
                                    
                                    	Flag indicating if this LAN circuit is the DIS
                                    	**type**\:  bool
                                    
                                    .. attribute:: circuit_lan_id
                                    
                                    	Circuit LAN ID
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: dispriority
                                    
                                    	Priority of current DIS on this LAN
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface's DIS\-election priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_until_next_iih
                                    
                                    	Time (ms) until next IIH
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData, self).__init__()

                                        self.yang_name = "lan-data"
                                        self.yang_parent_name = "per-area-data"

                                        self.are_we_dis = YLeaf(YType.boolean, "are-we-dis")

                                        self.circuit_lan_id = YLeaf(YType.str, "circuit-lan-id")

                                        self.dispriority = YLeaf(YType.uint8, "dispriority")

                                        self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                        self.time_until_next_iih = YLeaf(YType.uint32, "time-until-next-iih")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("are_we_dis",
                                                        "circuit_lan_id",
                                                        "dispriority",
                                                        "interface_priority",
                                                        "time_until_next_iih") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.are_we_dis.is_set or
                                            self.circuit_lan_id.is_set or
                                            self.dispriority.is_set or
                                            self.interface_priority.is_set or
                                            self.time_until_next_iih.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.are_we_dis.yfilter != YFilter.not_set or
                                            self.circuit_lan_id.yfilter != YFilter.not_set or
                                            self.dispriority.yfilter != YFilter.not_set or
                                            self.interface_priority.yfilter != YFilter.not_set or
                                            self.time_until_next_iih.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "lan-data" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.are_we_dis.is_set or self.are_we_dis.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.are_we_dis.get_name_leafdata())
                                        if (self.circuit_lan_id.is_set or self.circuit_lan_id.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.circuit_lan_id.get_name_leafdata())
                                        if (self.dispriority.is_set or self.dispriority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.dispriority.get_name_leafdata())
                                        if (self.interface_priority.is_set or self.interface_priority.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.interface_priority.get_name_leafdata())
                                        if (self.time_until_next_iih.is_set or self.time_until_next_iih.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.time_until_next_iih.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "are-we-dis" or name == "circuit-lan-id" or name == "dispriority" or name == "interface-priority" or name == "time-until-next-iih"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "are-we-dis"):
                                            self.are_we_dis = value
                                            self.are_we_dis.value_namespace = name_space
                                            self.are_we_dis.value_namespace_prefix = name_space_prefix
                                        if(value_path == "circuit-lan-id"):
                                            self.circuit_lan_id = value
                                            self.circuit_lan_id.value_namespace = name_space
                                            self.circuit_lan_id.value_namespace_prefix = name_space_prefix
                                        if(value_path == "dispriority"):
                                            self.dispriority = value
                                            self.dispriority.value_namespace = name_space
                                            self.dispriority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "interface-priority"):
                                            self.interface_priority = value
                                            self.interface_priority.value_namespace = name_space
                                            self.interface_priority.value_namespace_prefix = name_space_prefix
                                        if(value_path == "time-until-next-iih"):
                                            self.time_until_next_iih = value
                                            self.time_until_next_iih.value_namespace = name_space
                                            self.time_until_next_iih.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.adjacency_count.is_set or
                                        self.level.is_set or
                                        self.lsp_pacing_interval.is_set or
                                        self.psnp_transmit_queue_size.is_set or
                                        (self.lan_data is not None and self.lan_data.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.adjacency_count.yfilter != YFilter.not_set or
                                        self.level.yfilter != YFilter.not_set or
                                        self.lsp_pacing_interval.yfilter != YFilter.not_set or
                                        self.psnp_transmit_queue_size.yfilter != YFilter.not_set or
                                        (self.lan_data is not None and self.lan_data.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-area-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.adjacency_count.is_set or self.adjacency_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.adjacency_count.get_name_leafdata())
                                    if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.level.get_name_leafdata())
                                    if (self.lsp_pacing_interval.is_set or self.lsp_pacing_interval.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.lsp_pacing_interval.get_name_leafdata())
                                    if (self.psnp_transmit_queue_size.is_set or self.psnp_transmit_queue_size.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.psnp_transmit_queue_size.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "lan-data"):
                                        if (self.lan_data is None):
                                            self.lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData()
                                            self.lan_data.parent = self
                                            self._children_name_map["lan_data"] = "lan-data"
                                        return self.lan_data

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "lan-data" or name == "adjacency-count" or name == "level" or name == "lsp-pacing-interval" or name == "psnp-transmit-queue-size"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "adjacency-count"):
                                        self.adjacency_count = value
                                        self.adjacency_count.value_namespace = name_space
                                        self.adjacency_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "level"):
                                        self.level = value
                                        self.level.value_namespace = name_space
                                        self.level.value_namespace_prefix = name_space_prefix
                                    if(value_path == "lsp-pacing-interval"):
                                        self.lsp_pacing_interval = value
                                        self.lsp_pacing_interval.value_namespace = name_space
                                        self.lsp_pacing_interval.value_namespace_prefix = name_space_prefix
                                    if(value_path == "psnp-transmit-queue-size"):
                                        self.psnp_transmit_queue_size = value
                                        self.psnp_transmit_queue_size.value_namespace = name_space
                                        self.psnp_transmit_queue_size.value_namespace_prefix = name_space_prefix


                            class PerTopologyData(Entity):
                                """
                                Array of topology information
                                
                                .. attribute:: status
                                
                                	Status of the topology
                                	**type**\:   :py:class:`Status <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status>`
                                
                                .. attribute:: topology_id
                                
                                	Topology identifier
                                	**type**\:   :py:class:`TopologyId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData, self).__init__()

                                    self.yang_name = "per-topology-data"
                                    self.yang_parent_name = "enabled"

                                    self.status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status()
                                    self.status.parent = self
                                    self._children_name_map["status"] = "status"
                                    self._children_yang_names.add("status")

                                    self.topology_id = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId()
                                    self.topology_id.parent = self
                                    self._children_name_map["topology_id"] = "topology-id"
                                    self._children_yang_names.add("topology-id")


                                class TopologyId(Entity):
                                    """
                                    Topology identifier
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId, self).__init__()

                                        self.yang_name = "topology-id"
                                        self.yang_parent_name = "per-topology-data"

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.saf_name = YLeaf(YType.enumeration, "saf-name")

                                        self.topology_name = YLeaf(YType.str, "topology-name")

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af_name",
                                                        "saf_name",
                                                        "topology_name",
                                                        "vrf_name") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af_name.is_set or
                                            self.saf_name.is_set or
                                            self.topology_name.is_set or
                                            self.vrf_name.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af_name.yfilter != YFilter.not_set or
                                            self.saf_name.yfilter != YFilter.not_set or
                                            self.topology_name.yfilter != YFilter.not_set or
                                            self.vrf_name.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "topology-id" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                        if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.saf_name.get_name_leafdata())
                                        if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.topology_name.get_name_leafdata())
                                        if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.vrf_name.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af-name"):
                                            self.af_name = value
                                            self.af_name.value_namespace = name_space
                                            self.af_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "saf-name"):
                                            self.saf_name = value
                                            self.saf_name.value_namespace = name_space
                                            self.saf_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "topology-name"):
                                            self.topology_name = value
                                            self.topology_name.value_namespace = name_space
                                            self.topology_name.value_namespace_prefix = name_space_prefix
                                        if(value_path == "vrf-name"):
                                            self.vrf_name = value
                                            self.vrf_name.value_namespace = name_space
                                            self.vrf_name.value_namespace_prefix = name_space_prefix


                                class Status(Entity):
                                    """
                                    Status of the topology
                                    
                                    .. attribute:: disabled
                                    
                                    	Disabled information of a topology
                                    	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled>`
                                    
                                    .. attribute:: enabled
                                    
                                    	Enabled information of a topology
                                    	**type**\:   :py:class:`Enabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status, self).__init__()

                                        self.yang_name = "status"
                                        self.yang_parent_name = "per-topology-data"

                                        self.status = YLeaf(YType.enumeration, "status")

                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled()
                                        self.disabled.parent = self
                                        self._children_name_map["disabled"] = "disabled"
                                        self._children_yang_names.add("disabled")

                                        self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled()
                                        self.enabled.parent = self
                                        self._children_name_map["enabled"] = "enabled"
                                        self._children_yang_names.add("enabled")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status, self).__setattr__(name, value)


                                    class Disabled(Entity):
                                        """
                                        Disabled information of a topology
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the topology is disabled
                                        	**type**\:   :py:class:`IsisIfTopoDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoDisabledReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled, self).__init__()

                                            self.yang_name = "disabled"
                                            self.yang_parent_name = "status"

                                            self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reason_code") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.reason_code.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reason_code.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disabled" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reason_code.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reason-code"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reason-code"):
                                                self.reason_code = value
                                                self.reason_code.value_namespace = name_space
                                                self.reason_code.value_namespace_prefix = name_space_prefix


                                    class Enabled(Entity):
                                        """
                                        Enabled information of a topology
                                        
                                        .. attribute:: adjacency_form_status
                                        
                                        	Adjacency formation status of a topology
                                        	**type**\:   :py:class:`AdjacencyFormStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus>`
                                        
                                        .. attribute:: adv_prefix_status
                                        
                                        	Prefix advertisement status of a topology
                                        	**type**\:   :py:class:`AdvPrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus>`
                                        
                                        .. attribute:: ld_pv6_sync_status
                                        
                                        	Status of MPLS LDPv6 synchronization
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_sync_status
                                        
                                        	Status of MPLS LDP synchronization
                                        	**type**\:  bool
                                        
                                        .. attribute:: level1_lkgp_configured
                                        
                                        	Link\-Group configure status for L1
                                        	**type**\:  bool
                                        
                                        .. attribute:: level1_metric
                                        
                                        	L1 metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1_offset_metric
                                        
                                        	L1 metric\-offset for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1_weight
                                        
                                        	L1 metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1ldp_sync_enabled
                                        
                                        	MPLS LDP sync enabled status for L1
                                        	**type**\:  bool
                                        
                                        .. attribute:: level1pp_configured
                                        
                                        	PP configure status for L1
                                        	**type**\:  bool
                                        
                                        .. attribute:: level1pp_metric
                                        
                                        	L1 PP\-metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_lkgp_configured
                                        
                                        	Link\-Group configure status for L2
                                        	**type**\:  bool
                                        
                                        .. attribute:: level2_metric
                                        
                                        	L2 metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_offset_metric
                                        
                                        	L2 metric\-offset for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_weight
                                        
                                        	L2 metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2ldp_sync_enabled
                                        
                                        	MPLS LDP sync enabled status for L2
                                        	**type**\:  bool
                                        
                                        .. attribute:: level2pp_configured
                                        
                                        	PP configure status for L2
                                        	**type**\:  bool
                                        
                                        .. attribute:: level2pp_metric
                                        
                                        	L2 PP\-metric for this topology
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_bkp_label_supported
                                        
                                        	MPLS maximum number of backup labels supported
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: max_label_supported
                                        
                                        	MPLS maximum number of pri labels supported
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: max_srte_label_supported
                                        
                                        	MPLS maximum number of srte labels supported
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled, self).__init__()

                                            self.yang_name = "enabled"
                                            self.yang_parent_name = "status"

                                            self.ld_pv6_sync_status = YLeaf(YType.boolean, "ld-pv6-sync-status")

                                            self.ldp_sync_status = YLeaf(YType.boolean, "ldp-sync-status")

                                            self.level1_lkgp_configured = YLeaf(YType.boolean, "level1-lkgp-configured")

                                            self.level1_metric = YLeaf(YType.uint32, "level1-metric")

                                            self.level1_offset_metric = YLeaf(YType.uint32, "level1-offset-metric")

                                            self.level1_weight = YLeaf(YType.uint32, "level1-weight")

                                            self.level1ldp_sync_enabled = YLeaf(YType.boolean, "level1ldp-sync-enabled")

                                            self.level1pp_configured = YLeaf(YType.boolean, "level1pp-configured")

                                            self.level1pp_metric = YLeaf(YType.uint32, "level1pp-metric")

                                            self.level2_lkgp_configured = YLeaf(YType.boolean, "level2-lkgp-configured")

                                            self.level2_metric = YLeaf(YType.uint32, "level2-metric")

                                            self.level2_offset_metric = YLeaf(YType.uint32, "level2-offset-metric")

                                            self.level2_weight = YLeaf(YType.uint32, "level2-weight")

                                            self.level2ldp_sync_enabled = YLeaf(YType.boolean, "level2ldp-sync-enabled")

                                            self.level2pp_configured = YLeaf(YType.boolean, "level2pp-configured")

                                            self.level2pp_metric = YLeaf(YType.uint32, "level2pp-metric")

                                            self.max_bkp_label_supported = YLeaf(YType.uint8, "max-bkp-label-supported")

                                            self.max_label_supported = YLeaf(YType.uint8, "max-label-supported")

                                            self.max_srte_label_supported = YLeaf(YType.uint8, "max-srte-label-supported")

                                            self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus()
                                            self.adjacency_form_status.parent = self
                                            self._children_name_map["adjacency_form_status"] = "adjacency-form-status"
                                            self._children_yang_names.add("adjacency-form-status")

                                            self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus()
                                            self.adv_prefix_status.parent = self
                                            self._children_name_map["adv_prefix_status"] = "adv-prefix-status"
                                            self._children_yang_names.add("adv-prefix-status")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("ld_pv6_sync_status",
                                                            "ldp_sync_status",
                                                            "level1_lkgp_configured",
                                                            "level1_metric",
                                                            "level1_offset_metric",
                                                            "level1_weight",
                                                            "level1ldp_sync_enabled",
                                                            "level1pp_configured",
                                                            "level1pp_metric",
                                                            "level2_lkgp_configured",
                                                            "level2_metric",
                                                            "level2_offset_metric",
                                                            "level2_weight",
                                                            "level2ldp_sync_enabled",
                                                            "level2pp_configured",
                                                            "level2pp_metric",
                                                            "max_bkp_label_supported",
                                                            "max_label_supported",
                                                            "max_srte_label_supported") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled, self).__setattr__(name, value)


                                        class AdjacencyFormStatus(Entity):
                                            """
                                            Adjacency formation status of a topology
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state for the adjacency formation status of a topology
                                            	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus, self).__init__()

                                                self.yang_name = "adjacency-form-status"
                                                self.yang_parent_name = "enabled"

                                                self.status = YLeaf(YType.enumeration, "status")

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._children_yang_names.add("disabled")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus, self).__setattr__(name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state for the adjacency formation
                                                status of a topology
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the adjacency formation status of a topology is disabled
                                                	**type**\:   :py:class:`IsisIfTopoAdjFormDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoAdjFormDisabledReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "adjacency-form-status"

                                                    self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("reason_code") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.reason_code.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.reason_code.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disabled" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "reason-code"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "reason-code"):
                                                        self.reason_code = value
                                                        self.reason_code.value_namespace = name_space
                                                        self.reason_code.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.status.is_set or
                                                    (self.disabled is not None and self.disabled.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.status.yfilter != YFilter.not_set or
                                                    (self.disabled is not None and self.disabled.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adjacency-form-status" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "disabled"):
                                                    if (self.disabled is None):
                                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus.Disabled()
                                                        self.disabled.parent = self
                                                        self._children_name_map["disabled"] = "disabled"
                                                    return self.disabled

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "disabled" or name == "status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "status"):
                                                    self.status = value
                                                    self.status.value_namespace = name_space
                                                    self.status.value_namespace_prefix = name_space_prefix


                                        class AdvPrefixStatus(Entity):
                                            """
                                            Prefix advertisement status of a topology
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state for the prefix advertisement status of a topology
                                            	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus, self).__init__()

                                                self.yang_name = "adv-prefix-status"
                                                self.yang_parent_name = "enabled"

                                                self.status = YLeaf(YType.enumeration, "status")

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._children_yang_names.add("disabled")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus, self).__setattr__(name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state for the prefix advertisement
                                                status of a topology
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the prefix advertisement status of a topology is disabled
                                                	**type**\:   :py:class:`IsisIfTopoAdvPrefixDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoAdvPrefixDisabledReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "adv-prefix-status"

                                                    self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("reason_code") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.reason_code.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.reason_code.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disabled" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "reason-code"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "reason-code"):
                                                        self.reason_code = value
                                                        self.reason_code.value_namespace = name_space
                                                        self.reason_code.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.status.is_set or
                                                    (self.disabled is not None and self.disabled.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.status.yfilter != YFilter.not_set or
                                                    (self.disabled is not None and self.disabled.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "adv-prefix-status" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "disabled"):
                                                    if (self.disabled is None):
                                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus.Disabled()
                                                        self.disabled.parent = self
                                                        self._children_name_map["disabled"] = "disabled"
                                                    return self.disabled

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "disabled" or name == "status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "status"):
                                                    self.status = value
                                                    self.status.value_namespace = name_space
                                                    self.status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                self.ld_pv6_sync_status.is_set or
                                                self.ldp_sync_status.is_set or
                                                self.level1_lkgp_configured.is_set or
                                                self.level1_metric.is_set or
                                                self.level1_offset_metric.is_set or
                                                self.level1_weight.is_set or
                                                self.level1ldp_sync_enabled.is_set or
                                                self.level1pp_configured.is_set or
                                                self.level1pp_metric.is_set or
                                                self.level2_lkgp_configured.is_set or
                                                self.level2_metric.is_set or
                                                self.level2_offset_metric.is_set or
                                                self.level2_weight.is_set or
                                                self.level2ldp_sync_enabled.is_set or
                                                self.level2pp_configured.is_set or
                                                self.level2pp_metric.is_set or
                                                self.max_bkp_label_supported.is_set or
                                                self.max_label_supported.is_set or
                                                self.max_srte_label_supported.is_set or
                                                (self.adjacency_form_status is not None and self.adjacency_form_status.has_data()) or
                                                (self.adv_prefix_status is not None and self.adv_prefix_status.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.ld_pv6_sync_status.yfilter != YFilter.not_set or
                                                self.ldp_sync_status.yfilter != YFilter.not_set or
                                                self.level1_lkgp_configured.yfilter != YFilter.not_set or
                                                self.level1_metric.yfilter != YFilter.not_set or
                                                self.level1_offset_metric.yfilter != YFilter.not_set or
                                                self.level1_weight.yfilter != YFilter.not_set or
                                                self.level1ldp_sync_enabled.yfilter != YFilter.not_set or
                                                self.level1pp_configured.yfilter != YFilter.not_set or
                                                self.level1pp_metric.yfilter != YFilter.not_set or
                                                self.level2_lkgp_configured.yfilter != YFilter.not_set or
                                                self.level2_metric.yfilter != YFilter.not_set or
                                                self.level2_offset_metric.yfilter != YFilter.not_set or
                                                self.level2_weight.yfilter != YFilter.not_set or
                                                self.level2ldp_sync_enabled.yfilter != YFilter.not_set or
                                                self.level2pp_configured.yfilter != YFilter.not_set or
                                                self.level2pp_metric.yfilter != YFilter.not_set or
                                                self.max_bkp_label_supported.yfilter != YFilter.not_set or
                                                self.max_label_supported.yfilter != YFilter.not_set or
                                                self.max_srte_label_supported.yfilter != YFilter.not_set or
                                                (self.adjacency_form_status is not None and self.adjacency_form_status.has_operation()) or
                                                (self.adv_prefix_status is not None and self.adv_prefix_status.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "enabled" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.ld_pv6_sync_status.is_set or self.ld_pv6_sync_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ld_pv6_sync_status.get_name_leafdata())
                                            if (self.ldp_sync_status.is_set or self.ldp_sync_status.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.ldp_sync_status.get_name_leafdata())
                                            if (self.level1_lkgp_configured.is_set or self.level1_lkgp_configured.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1_lkgp_configured.get_name_leafdata())
                                            if (self.level1_metric.is_set or self.level1_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1_metric.get_name_leafdata())
                                            if (self.level1_offset_metric.is_set or self.level1_offset_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1_offset_metric.get_name_leafdata())
                                            if (self.level1_weight.is_set or self.level1_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1_weight.get_name_leafdata())
                                            if (self.level1ldp_sync_enabled.is_set or self.level1ldp_sync_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1ldp_sync_enabled.get_name_leafdata())
                                            if (self.level1pp_configured.is_set or self.level1pp_configured.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1pp_configured.get_name_leafdata())
                                            if (self.level1pp_metric.is_set or self.level1pp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level1pp_metric.get_name_leafdata())
                                            if (self.level2_lkgp_configured.is_set or self.level2_lkgp_configured.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2_lkgp_configured.get_name_leafdata())
                                            if (self.level2_metric.is_set or self.level2_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2_metric.get_name_leafdata())
                                            if (self.level2_offset_metric.is_set or self.level2_offset_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2_offset_metric.get_name_leafdata())
                                            if (self.level2_weight.is_set or self.level2_weight.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2_weight.get_name_leafdata())
                                            if (self.level2ldp_sync_enabled.is_set or self.level2ldp_sync_enabled.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2ldp_sync_enabled.get_name_leafdata())
                                            if (self.level2pp_configured.is_set or self.level2pp_configured.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2pp_configured.get_name_leafdata())
                                            if (self.level2pp_metric.is_set or self.level2pp_metric.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.level2pp_metric.get_name_leafdata())
                                            if (self.max_bkp_label_supported.is_set or self.max_bkp_label_supported.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.max_bkp_label_supported.get_name_leafdata())
                                            if (self.max_label_supported.is_set or self.max_label_supported.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.max_label_supported.get_name_leafdata())
                                            if (self.max_srte_label_supported.is_set or self.max_srte_label_supported.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.max_srte_label_supported.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "adjacency-form-status"):
                                                if (self.adjacency_form_status is None):
                                                    self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdjacencyFormStatus()
                                                    self.adjacency_form_status.parent = self
                                                    self._children_name_map["adjacency_form_status"] = "adjacency-form-status"
                                                return self.adjacency_form_status

                                            if (child_yang_name == "adv-prefix-status"):
                                                if (self.adv_prefix_status is None):
                                                    self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled.AdvPrefixStatus()
                                                    self.adv_prefix_status.parent = self
                                                    self._children_name_map["adv_prefix_status"] = "adv-prefix-status"
                                                return self.adv_prefix_status

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "adjacency-form-status" or name == "adv-prefix-status" or name == "ld-pv6-sync-status" or name == "ldp-sync-status" or name == "level1-lkgp-configured" or name == "level1-metric" or name == "level1-offset-metric" or name == "level1-weight" or name == "level1ldp-sync-enabled" or name == "level1pp-configured" or name == "level1pp-metric" or name == "level2-lkgp-configured" or name == "level2-metric" or name == "level2-offset-metric" or name == "level2-weight" or name == "level2ldp-sync-enabled" or name == "level2pp-configured" or name == "level2pp-metric" or name == "max-bkp-label-supported" or name == "max-label-supported" or name == "max-srte-label-supported"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "ld-pv6-sync-status"):
                                                self.ld_pv6_sync_status = value
                                                self.ld_pv6_sync_status.value_namespace = name_space
                                                self.ld_pv6_sync_status.value_namespace_prefix = name_space_prefix
                                            if(value_path == "ldp-sync-status"):
                                                self.ldp_sync_status = value
                                                self.ldp_sync_status.value_namespace = name_space
                                                self.ldp_sync_status.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1-lkgp-configured"):
                                                self.level1_lkgp_configured = value
                                                self.level1_lkgp_configured.value_namespace = name_space
                                                self.level1_lkgp_configured.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1-metric"):
                                                self.level1_metric = value
                                                self.level1_metric.value_namespace = name_space
                                                self.level1_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1-offset-metric"):
                                                self.level1_offset_metric = value
                                                self.level1_offset_metric.value_namespace = name_space
                                                self.level1_offset_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1-weight"):
                                                self.level1_weight = value
                                                self.level1_weight.value_namespace = name_space
                                                self.level1_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1ldp-sync-enabled"):
                                                self.level1ldp_sync_enabled = value
                                                self.level1ldp_sync_enabled.value_namespace = name_space
                                                self.level1ldp_sync_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1pp-configured"):
                                                self.level1pp_configured = value
                                                self.level1pp_configured.value_namespace = name_space
                                                self.level1pp_configured.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level1pp-metric"):
                                                self.level1pp_metric = value
                                                self.level1pp_metric.value_namespace = name_space
                                                self.level1pp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2-lkgp-configured"):
                                                self.level2_lkgp_configured = value
                                                self.level2_lkgp_configured.value_namespace = name_space
                                                self.level2_lkgp_configured.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2-metric"):
                                                self.level2_metric = value
                                                self.level2_metric.value_namespace = name_space
                                                self.level2_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2-offset-metric"):
                                                self.level2_offset_metric = value
                                                self.level2_offset_metric.value_namespace = name_space
                                                self.level2_offset_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2-weight"):
                                                self.level2_weight = value
                                                self.level2_weight.value_namespace = name_space
                                                self.level2_weight.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2ldp-sync-enabled"):
                                                self.level2ldp_sync_enabled = value
                                                self.level2ldp_sync_enabled.value_namespace = name_space
                                                self.level2ldp_sync_enabled.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2pp-configured"):
                                                self.level2pp_configured = value
                                                self.level2pp_configured.value_namespace = name_space
                                                self.level2pp_configured.value_namespace_prefix = name_space_prefix
                                            if(value_path == "level2pp-metric"):
                                                self.level2pp_metric = value
                                                self.level2pp_metric.value_namespace = name_space
                                                self.level2pp_metric.value_namespace_prefix = name_space_prefix
                                            if(value_path == "max-bkp-label-supported"):
                                                self.max_bkp_label_supported = value
                                                self.max_bkp_label_supported.value_namespace = name_space
                                                self.max_bkp_label_supported.value_namespace_prefix = name_space_prefix
                                            if(value_path == "max-label-supported"):
                                                self.max_label_supported = value
                                                self.max_label_supported.value_namespace = name_space
                                                self.max_label_supported.value_namespace_prefix = name_space_prefix
                                            if(value_path == "max-srte-label-supported"):
                                                self.max_srte_label_supported = value
                                                self.max_srte_label_supported.value_namespace = name_space
                                                self.max_srte_label_supported.value_namespace_prefix = name_space_prefix

                                    def has_data(self):
                                        return (
                                            self.status.is_set or
                                            (self.disabled is not None and self.disabled.has_data()) or
                                            (self.enabled is not None and self.enabled.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            (self.disabled is not None and self.disabled.has_operation()) or
                                            (self.enabled is not None and self.enabled.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "disabled"):
                                            if (self.disabled is None):
                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                            return self.disabled

                                        if (child_yang_name == "enabled"):
                                            if (self.enabled is None):
                                                self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled()
                                                self.enabled.parent = self
                                                self._children_name_map["enabled"] = "enabled"
                                            return self.enabled

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "disabled" or name == "enabled" or name == "status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        (self.status is not None and self.status.has_data()) or
                                        (self.topology_id is not None and self.topology_id.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        (self.status is not None and self.status.has_operation()) or
                                        (self.topology_id is not None and self.topology_id.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-topology-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "status"):
                                        if (self.status is None):
                                            self.status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status()
                                            self.status.parent = self
                                            self._children_name_map["status"] = "status"
                                        return self.status

                                    if (child_yang_name == "topology-id"):
                                        if (self.topology_id is None):
                                            self.topology_id = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId()
                                            self.topology_id.parent = self
                                            self._children_name_map["topology_id"] = "topology-id"
                                        return self.topology_id

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "status" or name == "topology-id"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    pass


                            class PerAddressFamilyData(Entity):
                                """
                                Array of address family information
                                
                                .. attribute:: af_name
                                
                                	Address Family Identifier of the interface
                                	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                
                                .. attribute:: af_status
                                
                                	Address Family status of the interface
                                	**type**\:   :py:class:`AfStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData, self).__init__()

                                    self.yang_name = "per-address-family-data"
                                    self.yang_parent_name = "enabled"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.af_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus()
                                    self.af_status.parent = self
                                    self._children_name_map["af_status"] = "af-status"
                                    self._children_yang_names.add("af-status")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData, self).__setattr__(name, value)


                                class AfStatus(Entity):
                                    """
                                    Address Family status of the interface
                                    
                                    .. attribute:: af_data
                                    
                                    	Enabled data for the AF of an interface
                                    	**type**\:   :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData>`
                                    
                                    .. attribute:: disabled
                                    
                                    	Disabled info for the AF of an interface
                                    	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus, self).__init__()

                                        self.yang_name = "af-status"
                                        self.yang_parent_name = "per-address-family-data"

                                        self.status = YLeaf(YType.enumeration, "status")

                                        self.af_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData()
                                        self.af_data.parent = self
                                        self._children_name_map["af_data"] = "af-data"
                                        self._children_yang_names.add("af-data")

                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled()
                                        self.disabled.parent = self
                                        self._children_name_map["disabled"] = "disabled"
                                        self._children_yang_names.add("disabled")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("status") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus, self).__setattr__(name, value)


                                    class Disabled(Entity):
                                        """
                                        Disabled info for the AF of an interface
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the Address Family is disabled
                                        	**type**\:   :py:class:`IsisIfAfDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfDisabledReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled, self).__init__()

                                            self.yang_name = "disabled"
                                            self.yang_parent_name = "af-status"

                                            self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                        def __setattr__(self, name, value):
                                            self._check_monkey_patching_error(name, value)
                                            with _handle_type_error():
                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                        "Please use list append or extend method."
                                                                        .format(value))
                                                if isinstance(value, Enum.YLeaf):
                                                    value = value.name
                                                if name in ("reason_code") and name in self.__dict__:
                                                    if isinstance(value, YLeaf):
                                                        self.__dict__[name].set(value.get())
                                                    elif isinstance(value, YLeafList):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled, self).__setattr__(name, value)
                                                    else:
                                                        self.__dict__[name].set(value)
                                                else:
                                                    if hasattr(value, "parent") and name != "parent":
                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                            value.parent = self
                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                            value.parent = self
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled, self).__setattr__(name, value)

                                        def has_data(self):
                                            return self.reason_code.is_set

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                self.reason_code.yfilter != YFilter.not_set)

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "disabled" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()
                                            if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                leaf_name_data.append(self.reason_code.get_name_leafdata())

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "reason-code"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            if(value_path == "reason-code"):
                                                self.reason_code = value
                                                self.reason_code.value_namespace = name_space
                                                self.reason_code.value_namespace_prefix = name_space_prefix


                                    class AfData(Entity):
                                        """
                                        Enabled data for the AF of an interface
                                        
                                        .. attribute:: forwarding_address_status
                                        
                                        	Forwarding status of the AF
                                        	**type**\:   :py:class:`ForwardingAddressStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus>`
                                        
                                        .. attribute:: prefix_status
                                        
                                        	Prefix status of the AF
                                        	**type**\:   :py:class:`PrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus>`
                                        
                                        .. attribute:: protocol_status
                                        
                                        	Protocol status of the AF
                                        	**type**\:   :py:class:`ProtocolStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "af-status"

                                            self.forwarding_address_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus()
                                            self.forwarding_address_status.parent = self
                                            self._children_name_map["forwarding_address_status"] = "forwarding-address-status"
                                            self._children_yang_names.add("forwarding-address-status")

                                            self.prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus()
                                            self.prefix_status.parent = self
                                            self._children_name_map["prefix_status"] = "prefix-status"
                                            self._children_yang_names.add("prefix-status")

                                            self.protocol_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus()
                                            self.protocol_status.parent = self
                                            self._children_name_map["protocol_status"] = "protocol-status"
                                            self._children_yang_names.add("protocol-status")


                                        class ProtocolStatus(Entity):
                                            """
                                            Protocol status of the AF
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state of the Address Family protocol
                                            	**type**\:   :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:   :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus, self).__init__()

                                                self.yang_name = "protocol-status"
                                                self.yang_parent_name = "af-data"

                                                self.status = YLeaf(YType.enumeration, "status")

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._children_yang_names.add("disabled")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus, self).__setattr__(name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state of the Address Family protocol
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the Address Family protocol status is down
                                                	**type**\:   :py:class:`IsisIfAfProtoDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfProtoDownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "protocol-status"

                                                    self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("reason_code") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.reason_code.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.reason_code.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "disabled" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "reason-code"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "reason-code"):
                                                        self.reason_code = value
                                                        self.reason_code.value_namespace = name_space
                                                        self.reason_code.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.status.is_set or
                                                    (self.disabled is not None and self.disabled.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.status.yfilter != YFilter.not_set or
                                                    (self.disabled is not None and self.disabled.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "protocol-status" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "disabled"):
                                                    if (self.disabled is None):
                                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled()
                                                        self.disabled.parent = self
                                                        self._children_name_map["disabled"] = "disabled"
                                                    return self.disabled

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "disabled" or name == "status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "status"):
                                                    self.status = value
                                                    self.status.value_namespace = name_space
                                                    self.status.value_namespace_prefix = name_space_prefix


                                        class ForwardingAddressStatus(Entity):
                                            """
                                            Forwarding status of the AF
                                            
                                            .. attribute:: forwarding_address_data
                                            
                                            	Known Forwarding address data
                                            	**type**\:   :py:class:`ForwardingAddressData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:   :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                            
                                            .. attribute:: unknown
                                            
                                            	Unknown forwarding address data
                                            	**type**\:   :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus, self).__init__()

                                                self.yang_name = "forwarding-address-status"
                                                self.yang_parent_name = "af-data"

                                                self.status = YLeaf(YType.enumeration, "status")

                                                self.forwarding_address_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData()
                                                self.forwarding_address_data.parent = self
                                                self._children_name_map["forwarding_address_data"] = "forwarding-address-data"
                                                self._children_yang_names.add("forwarding-address-data")

                                                self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown()
                                                self.unknown.parent = self
                                                self._children_name_map["unknown"] = "unknown"
                                                self._children_yang_names.add("unknown")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus, self).__setattr__(name, value)


                                            class Unknown(Entity):
                                                """
                                                Unknown forwarding address data
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the forwarding address(es) of an AF is(are) unknown
                                                	**type**\:   :py:class:`IsisIfAfFwdAddrUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfFwdAddrUnknownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown, self).__init__()

                                                    self.yang_name = "unknown"
                                                    self.yang_parent_name = "forwarding-address-status"

                                                    self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("reason_code") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.reason_code.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.reason_code.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "reason-code"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "reason-code"):
                                                        self.reason_code = value
                                                        self.reason_code.value_namespace = name_space
                                                        self.reason_code.value_namespace_prefix = name_space_prefix


                                            class ForwardingAddressData(Entity):
                                                """
                                                Known Forwarding address data
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Array of forwarding addresses
                                                	**type**\: list of    :py:class:`ForwardingAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress>`
                                                
                                                .. attribute:: unnumbered_interface_name
                                                
                                                	If the interface is unnumbered, then its name, else NULL
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData, self).__init__()

                                                    self.yang_name = "forwarding-address-data"
                                                    self.yang_parent_name = "forwarding-address-status"

                                                    self.unnumbered_interface_name = YLeaf(YType.str, "unnumbered-interface-name")

                                                    self.forwarding_address = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("unnumbered_interface_name") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData, self).__setattr__(name, value)


                                                class ForwardingAddress(Entity):
                                                    """
                                                    Array of forwarding addresses
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	AFName
                                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPV4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPV6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress, self).__init__()

                                                        self.yang_name = "forwarding-address"
                                                        self.yang_parent_name = "forwarding-address-data"

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("af_name",
                                                                        "ipv4",
                                                                        "ipv6") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress, self).__setattr__(name, value)

                                                    def has_data(self):
                                                        return (
                                                            self.af_name.is_set or
                                                            self.ipv4.is_set or
                                                            self.ipv6.is_set)

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.af_name.yfilter != YFilter.not_set or
                                                            self.ipv4.yfilter != YFilter.not_set or
                                                            self.ipv6.yfilter != YFilter.not_set)

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "forwarding-address" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.af_name.get_name_leafdata())
                                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "af-name" or name == "ipv4" or name == "ipv6"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "af-name"):
                                                            self.af_name = value
                                                            self.af_name.value_namespace = name_space
                                                            self.af_name.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ipv4"):
                                                            self.ipv4 = value
                                                            self.ipv4.value_namespace = name_space
                                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                                        if(value_path == "ipv6"):
                                                            self.ipv6 = value
                                                            self.ipv6.value_namespace = name_space
                                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.forwarding_address:
                                                        if (c.has_data()):
                                                            return True
                                                    return self.unnumbered_interface_name.is_set

                                                def has_operation(self):
                                                    for c in self.forwarding_address:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.unnumbered_interface_name.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "forwarding-address-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.unnumbered_interface_name.is_set or self.unnumbered_interface_name.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.unnumbered_interface_name.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "forwarding-address"):
                                                        for c in self.forwarding_address:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.forwarding_address.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "forwarding-address" or name == "unnumbered-interface-name"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "unnumbered-interface-name"):
                                                        self.unnumbered_interface_name = value
                                                        self.unnumbered_interface_name.value_namespace = name_space
                                                        self.unnumbered_interface_name.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.status.is_set or
                                                    (self.forwarding_address_data is not None and self.forwarding_address_data.has_data()) or
                                                    (self.unknown is not None and self.unknown.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.status.yfilter != YFilter.not_set or
                                                    (self.forwarding_address_data is not None and self.forwarding_address_data.has_operation()) or
                                                    (self.unknown is not None and self.unknown.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "forwarding-address-status" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "forwarding-address-data"):
                                                    if (self.forwarding_address_data is None):
                                                        self.forwarding_address_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData()
                                                        self.forwarding_address_data.parent = self
                                                        self._children_name_map["forwarding_address_data"] = "forwarding-address-data"
                                                    return self.forwarding_address_data

                                                if (child_yang_name == "unknown"):
                                                    if (self.unknown is None):
                                                        self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown()
                                                        self.unknown.parent = self
                                                        self._children_name_map["unknown"] = "unknown"
                                                    return self.unknown

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "forwarding-address-data" or name == "unknown" or name == "status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "status"):
                                                    self.status = value
                                                    self.status.value_namespace = name_space
                                                    self.status.value_namespace_prefix = name_space_prefix


                                        class PrefixStatus(Entity):
                                            """
                                            Prefix status of the AF
                                            
                                            .. attribute:: prefix_data
                                            
                                            	Global prefix data for the Address Family
                                            	**type**\:   :py:class:`PrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:   :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                            
                                            .. attribute:: unknown
                                            
                                            	Unknown state for the global prefixes
                                            	**type**\:   :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus, self).__init__()

                                                self.yang_name = "prefix-status"
                                                self.yang_parent_name = "af-data"

                                                self.status = YLeaf(YType.enumeration, "status")

                                                self.prefix_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData()
                                                self.prefix_data.parent = self
                                                self._children_name_map["prefix_data"] = "prefix-data"
                                                self._children_yang_names.add("prefix-data")

                                                self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown()
                                                self.unknown.parent = self
                                                self._children_name_map["unknown"] = "unknown"
                                                self._children_yang_names.add("unknown")

                                            def __setattr__(self, name, value):
                                                self._check_monkey_patching_error(name, value)
                                                with _handle_type_error():
                                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                            "Please use list append or extend method."
                                                                            .format(value))
                                                    if isinstance(value, Enum.YLeaf):
                                                        value = value.name
                                                    if name in ("status") and name in self.__dict__:
                                                        if isinstance(value, YLeaf):
                                                            self.__dict__[name].set(value.get())
                                                        elif isinstance(value, YLeafList):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus, self).__setattr__(name, value)
                                                        else:
                                                            self.__dict__[name].set(value)
                                                    else:
                                                        if hasattr(value, "parent") and name != "parent":
                                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                value.parent = self
                                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                value.parent = self
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus, self).__setattr__(name, value)


                                            class Unknown(Entity):
                                                """
                                                Unknown state for the global prefixes
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the global prefix(es) is(are) unknown
                                                	**type**\:   :py:class:`IsisIfAfPrefixUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfPrefixUnknownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown, self).__init__()

                                                    self.yang_name = "unknown"
                                                    self.yang_parent_name = "prefix-status"

                                                    self.reason_code = YLeaf(YType.enumeration, "reason-code")

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("reason_code") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown, self).__setattr__(name, value)

                                                def has_data(self):
                                                    return self.reason_code.is_set

                                                def has_operation(self):
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.reason_code.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "unknown" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.reason_code.is_set or self.reason_code.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.reason_code.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "reason-code"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "reason-code"):
                                                        self.reason_code = value
                                                        self.reason_code.value_namespace = name_space
                                                        self.reason_code.value_namespace_prefix = name_space_prefix


                                            class PrefixData(Entity):
                                                """
                                                Global prefix data for the Address Family
                                                
                                                .. attribute:: is_unnumbered
                                                
                                                	Is the interface unnumbered
                                                	**type**\:  bool
                                                
                                                .. attribute:: prefix
                                                
                                                	Array of global prefixes
                                                	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData, self).__init__()

                                                    self.yang_name = "prefix-data"
                                                    self.yang_parent_name = "prefix-status"

                                                    self.is_unnumbered = YLeaf(YType.boolean, "is-unnumbered")

                                                    self.prefix = YList(self)

                                                def __setattr__(self, name, value):
                                                    self._check_monkey_patching_error(name, value)
                                                    with _handle_type_error():
                                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                "Please use list append or extend method."
                                                                                .format(value))
                                                        if isinstance(value, Enum.YLeaf):
                                                            value = value.name
                                                        if name in ("is_unnumbered") and name in self.__dict__:
                                                            if isinstance(value, YLeaf):
                                                                self.__dict__[name].set(value.get())
                                                            elif isinstance(value, YLeafList):
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData, self).__setattr__(name, value)
                                                            else:
                                                                self.__dict__[name].set(value)
                                                        else:
                                                            if hasattr(value, "parent") and name != "parent":
                                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                    value.parent = self
                                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                    value.parent = self
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData, self).__setattr__(name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Array of global prefixes
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	AFName
                                                    	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	ipv4
                                                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4>`
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	ipv6
                                                    	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "prefix-data"

                                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                                        self.ipv4 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4()
                                                        self.ipv4.parent = self
                                                        self._children_name_map["ipv4"] = "ipv4"
                                                        self._children_yang_names.add("ipv4")

                                                        self.ipv6 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6()
                                                        self.ipv6.parent = self
                                                        self._children_name_map["ipv6"] = "ipv6"
                                                        self._children_yang_names.add("ipv6")

                                                    def __setattr__(self, name, value):
                                                        self._check_monkey_patching_error(name, value)
                                                        with _handle_type_error():
                                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                    "Please use list append or extend method."
                                                                                    .format(value))
                                                            if isinstance(value, Enum.YLeaf):
                                                                value = value.name
                                                            if name in ("af_name") and name in self.__dict__:
                                                                if isinstance(value, YLeaf):
                                                                    self.__dict__[name].set(value.get())
                                                                elif isinstance(value, YLeafList):
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix, self).__setattr__(name, value)
                                                                else:
                                                                    self.__dict__[name].set(value)
                                                            else:
                                                                if hasattr(value, "parent") and name != "parent":
                                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                        value.parent = self
                                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                        value.parent = self
                                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix, self).__setattr__(name, value)


                                                    class Ipv4(Entity):
                                                        """
                                                        ipv4
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4, self).__init__()

                                                            self.yang_name = "ipv4"
                                                            self.yang_parent_name = "prefix"

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("prefix",
                                                                            "prefix_length") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv4" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "prefix" or name == "prefix-length"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix


                                                    class Ipv6(Entity):
                                                        """
                                                        ipv6
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6, self).__init__()

                                                            self.yang_name = "ipv6"
                                                            self.yang_parent_name = "prefix"

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                        def __setattr__(self, name, value):
                                                            self._check_monkey_patching_error(name, value)
                                                            with _handle_type_error():
                                                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                                        "Please use list append or extend method."
                                                                                        .format(value))
                                                                if isinstance(value, Enum.YLeaf):
                                                                    value = value.name
                                                                if name in ("prefix",
                                                                            "prefix_length") and name in self.__dict__:
                                                                    if isinstance(value, YLeaf):
                                                                        self.__dict__[name].set(value.get())
                                                                    elif isinstance(value, YLeafList):
                                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6, self).__setattr__(name, value)
                                                                    else:
                                                                        self.__dict__[name].set(value)
                                                                else:
                                                                    if hasattr(value, "parent") and name != "parent":
                                                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                                            value.parent = self
                                                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                                                            value.parent = self
                                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6, self).__setattr__(name, value)

                                                        def has_data(self):
                                                            return (
                                                                self.prefix.is_set or
                                                                self.prefix_length.is_set)

                                                        def has_operation(self):
                                                            return (
                                                                self.yfilter != YFilter.not_set or
                                                                self.prefix.yfilter != YFilter.not_set or
                                                                self.prefix_length.yfilter != YFilter.not_set)

                                                        def get_segment_path(self):
                                                            path_buffer = ""
                                                            path_buffer = "ipv6" + path_buffer

                                                            return path_buffer

                                                        def get_entity_path(self, ancestor):
                                                            path_buffer = ""
                                                            if (ancestor is None):
                                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                            else:
                                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                            leaf_name_data = LeafDataList()
                                                            if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix.get_name_leafdata())
                                                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                                                leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                                            return entity_path

                                                        def get_child_by_name(self, child_yang_name, segment_path):
                                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                            if child is not None:
                                                                return child

                                                            return None

                                                        def has_leaf_or_child_of_name(self, name):
                                                            if(name == "prefix" or name == "prefix-length"):
                                                                return True
                                                            return False

                                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                                            if(value_path == "prefix"):
                                                                self.prefix = value
                                                                self.prefix.value_namespace = name_space
                                                                self.prefix.value_namespace_prefix = name_space_prefix
                                                            if(value_path == "prefix-length"):
                                                                self.prefix_length = value
                                                                self.prefix_length.value_namespace = name_space
                                                                self.prefix_length.value_namespace_prefix = name_space_prefix

                                                    def has_data(self):
                                                        return (
                                                            self.af_name.is_set or
                                                            (self.ipv4 is not None and self.ipv4.has_data()) or
                                                            (self.ipv6 is not None and self.ipv6.has_data()))

                                                    def has_operation(self):
                                                        return (
                                                            self.yfilter != YFilter.not_set or
                                                            self.af_name.yfilter != YFilter.not_set or
                                                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                                                            (self.ipv6 is not None and self.ipv6.has_operation()))

                                                    def get_segment_path(self):
                                                        path_buffer = ""
                                                        path_buffer = "prefix" + path_buffer

                                                        return path_buffer

                                                    def get_entity_path(self, ancestor):
                                                        path_buffer = ""
                                                        if (ancestor is None):
                                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                        else:
                                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                        leaf_name_data = LeafDataList()
                                                        if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                                            leaf_name_data.append(self.af_name.get_name_leafdata())

                                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                                        return entity_path

                                                    def get_child_by_name(self, child_yang_name, segment_path):
                                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                        if child is not None:
                                                            return child

                                                        if (child_yang_name == "ipv4"):
                                                            if (self.ipv4 is None):
                                                                self.ipv4 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4()
                                                                self.ipv4.parent = self
                                                                self._children_name_map["ipv4"] = "ipv4"
                                                            return self.ipv4

                                                        if (child_yang_name == "ipv6"):
                                                            if (self.ipv6 is None):
                                                                self.ipv6 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6()
                                                                self.ipv6.parent = self
                                                                self._children_name_map["ipv6"] = "ipv6"
                                                            return self.ipv6

                                                        return None

                                                    def has_leaf_or_child_of_name(self, name):
                                                        if(name == "ipv4" or name == "ipv6" or name == "af-name"):
                                                            return True
                                                        return False

                                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                                        if(value_path == "af-name"):
                                                            self.af_name = value
                                                            self.af_name.value_namespace = name_space
                                                            self.af_name.value_namespace_prefix = name_space_prefix

                                                def has_data(self):
                                                    for c in self.prefix:
                                                        if (c.has_data()):
                                                            return True
                                                    return self.is_unnumbered.is_set

                                                def has_operation(self):
                                                    for c in self.prefix:
                                                        if (c.has_operation()):
                                                            return True
                                                    return (
                                                        self.yfilter != YFilter.not_set or
                                                        self.is_unnumbered.yfilter != YFilter.not_set)

                                                def get_segment_path(self):
                                                    path_buffer = ""
                                                    path_buffer = "prefix-data" + path_buffer

                                                    return path_buffer

                                                def get_entity_path(self, ancestor):
                                                    path_buffer = ""
                                                    if (ancestor is None):
                                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                    else:
                                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                    leaf_name_data = LeafDataList()
                                                    if (self.is_unnumbered.is_set or self.is_unnumbered.yfilter != YFilter.not_set):
                                                        leaf_name_data.append(self.is_unnumbered.get_name_leafdata())

                                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                                    return entity_path

                                                def get_child_by_name(self, child_yang_name, segment_path):
                                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                    if child is not None:
                                                        return child

                                                    if (child_yang_name == "prefix"):
                                                        for c in self.prefix:
                                                            segment = c.get_segment_path()
                                                            if (segment_path == segment):
                                                                return c
                                                        c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix()
                                                        c.parent = self
                                                        local_reference_key = "ydk::seg::%s" % segment_path
                                                        self._local_refs[local_reference_key] = c
                                                        self.prefix.append(c)
                                                        return c

                                                    return None

                                                def has_leaf_or_child_of_name(self, name):
                                                    if(name == "prefix" or name == "is-unnumbered"):
                                                        return True
                                                    return False

                                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                                    if(value_path == "is-unnumbered"):
                                                        self.is_unnumbered = value
                                                        self.is_unnumbered.value_namespace = name_space
                                                        self.is_unnumbered.value_namespace_prefix = name_space_prefix

                                            def has_data(self):
                                                return (
                                                    self.status.is_set or
                                                    (self.prefix_data is not None and self.prefix_data.has_data()) or
                                                    (self.unknown is not None and self.unknown.has_data()))

                                            def has_operation(self):
                                                return (
                                                    self.yfilter != YFilter.not_set or
                                                    self.status.yfilter != YFilter.not_set or
                                                    (self.prefix_data is not None and self.prefix_data.has_operation()) or
                                                    (self.unknown is not None and self.unknown.has_operation()))

                                            def get_segment_path(self):
                                                path_buffer = ""
                                                path_buffer = "prefix-status" + path_buffer

                                                return path_buffer

                                            def get_entity_path(self, ancestor):
                                                path_buffer = ""
                                                if (ancestor is None):
                                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                                else:
                                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                                leaf_name_data = LeafDataList()
                                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                                    leaf_name_data.append(self.status.get_name_leafdata())

                                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                                return entity_path

                                            def get_child_by_name(self, child_yang_name, segment_path):
                                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                                if child is not None:
                                                    return child

                                                if (child_yang_name == "prefix-data"):
                                                    if (self.prefix_data is None):
                                                        self.prefix_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData()
                                                        self.prefix_data.parent = self
                                                        self._children_name_map["prefix_data"] = "prefix-data"
                                                    return self.prefix_data

                                                if (child_yang_name == "unknown"):
                                                    if (self.unknown is None):
                                                        self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown()
                                                        self.unknown.parent = self
                                                        self._children_name_map["unknown"] = "unknown"
                                                    return self.unknown

                                                return None

                                            def has_leaf_or_child_of_name(self, name):
                                                if(name == "prefix-data" or name == "unknown" or name == "status"):
                                                    return True
                                                return False

                                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                                if(value_path == "status"):
                                                    self.status = value
                                                    self.status.value_namespace = name_space
                                                    self.status.value_namespace_prefix = name_space_prefix

                                        def has_data(self):
                                            return (
                                                (self.forwarding_address_status is not None and self.forwarding_address_status.has_data()) or
                                                (self.prefix_status is not None and self.prefix_status.has_data()) or
                                                (self.protocol_status is not None and self.protocol_status.has_data()))

                                        def has_operation(self):
                                            return (
                                                self.yfilter != YFilter.not_set or
                                                (self.forwarding_address_status is not None and self.forwarding_address_status.has_operation()) or
                                                (self.prefix_status is not None and self.prefix_status.has_operation()) or
                                                (self.protocol_status is not None and self.protocol_status.has_operation()))

                                        def get_segment_path(self):
                                            path_buffer = ""
                                            path_buffer = "af-data" + path_buffer

                                            return path_buffer

                                        def get_entity_path(self, ancestor):
                                            path_buffer = ""
                                            if (ancestor is None):
                                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                            else:
                                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                            leaf_name_data = LeafDataList()

                                            entity_path = EntityPath(path_buffer, leaf_name_data)
                                            return entity_path

                                        def get_child_by_name(self, child_yang_name, segment_path):
                                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                            if child is not None:
                                                return child

                                            if (child_yang_name == "forwarding-address-status"):
                                                if (self.forwarding_address_status is None):
                                                    self.forwarding_address_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus()
                                                    self.forwarding_address_status.parent = self
                                                    self._children_name_map["forwarding_address_status"] = "forwarding-address-status"
                                                return self.forwarding_address_status

                                            if (child_yang_name == "prefix-status"):
                                                if (self.prefix_status is None):
                                                    self.prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus()
                                                    self.prefix_status.parent = self
                                                    self._children_name_map["prefix_status"] = "prefix-status"
                                                return self.prefix_status

                                            if (child_yang_name == "protocol-status"):
                                                if (self.protocol_status is None):
                                                    self.protocol_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus()
                                                    self.protocol_status.parent = self
                                                    self._children_name_map["protocol_status"] = "protocol-status"
                                                return self.protocol_status

                                            return None

                                        def has_leaf_or_child_of_name(self, name):
                                            if(name == "forwarding-address-status" or name == "prefix-status" or name == "protocol-status"):
                                                return True
                                            return False

                                        def set_value(self, value_path, value, name_space, name_space_prefix):
                                            pass

                                    def has_data(self):
                                        return (
                                            self.status.is_set or
                                            (self.af_data is not None and self.af_data.has_data()) or
                                            (self.disabled is not None and self.disabled.has_data()))

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.status.yfilter != YFilter.not_set or
                                            (self.af_data is not None and self.af_data.has_operation()) or
                                            (self.disabled is not None and self.disabled.has_operation()))

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "af-status" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.status.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        if (child_yang_name == "af-data"):
                                            if (self.af_data is None):
                                                self.af_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData()
                                                self.af_data.parent = self
                                                self._children_name_map["af_data"] = "af-data"
                                            return self.af_data

                                        if (child_yang_name == "disabled"):
                                            if (self.disabled is None):
                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                            return self.disabled

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af-data" or name == "disabled" or name == "status"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "status"):
                                            self.status = value
                                            self.status.value_namespace = name_space
                                            self.status.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        (self.af_status is not None and self.af_status.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        (self.af_status is not None and self.af_status.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "per-address-family-data" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "af-status"):
                                        if (self.af_status is None):
                                            self.af_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus()
                                            self.af_status.parent = self
                                            self._children_name_map["af_status"] = "af-status"
                                        return self.af_status

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-status" or name == "af-name"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.per_address_family_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.per_area_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.per_topology_data:
                                    if (c.has_data()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.enabled_circuit_type.is_set or
                                    self.interface_media_type.is_set or
                                    self.local_circuit_number.is_set or
                                    self.rsi_srlg_registered.is_set or
                                    (self.adjacency_form_status is not None and self.adjacency_form_status.has_data()) or
                                    (self.adv_prefix_status is not None and self.adv_prefix_status.has_data()) or
                                    (self.bfd_data is not None and self.bfd_data.has_data()) or
                                    (self.clns_data is not None and self.clns_data.has_data()) or
                                    (self.p2p_data is not None and self.p2p_data.has_data()))

                            def has_operation(self):
                                for c in self.per_address_family_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.per_area_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.per_topology_data:
                                    if (c.has_operation()):
                                        return True
                                for c in self.underlying_interface:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.enabled_circuit_type.yfilter != YFilter.not_set or
                                    self.interface_media_type.yfilter != YFilter.not_set or
                                    self.local_circuit_number.yfilter != YFilter.not_set or
                                    self.rsi_srlg_registered.yfilter != YFilter.not_set or
                                    (self.adjacency_form_status is not None and self.adjacency_form_status.has_operation()) or
                                    (self.adv_prefix_status is not None and self.adv_prefix_status.has_operation()) or
                                    (self.bfd_data is not None and self.bfd_data.has_operation()) or
                                    (self.clns_data is not None and self.clns_data.has_operation()) or
                                    (self.p2p_data is not None and self.p2p_data.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "enabled" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.enabled_circuit_type.is_set or self.enabled_circuit_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enabled_circuit_type.get_name_leafdata())
                                if (self.interface_media_type.is_set or self.interface_media_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_media_type.get_name_leafdata())
                                if (self.local_circuit_number.is_set or self.local_circuit_number.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.local_circuit_number.get_name_leafdata())
                                if (self.rsi_srlg_registered.is_set or self.rsi_srlg_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rsi_srlg_registered.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "adjacency-form-status"):
                                    if (self.adjacency_form_status is None):
                                        self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus()
                                        self.adjacency_form_status.parent = self
                                        self._children_name_map["adjacency_form_status"] = "adjacency-form-status"
                                    return self.adjacency_form_status

                                if (child_yang_name == "adv-prefix-status"):
                                    if (self.adv_prefix_status is None):
                                        self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus()
                                        self.adv_prefix_status.parent = self
                                        self._children_name_map["adv_prefix_status"] = "adv-prefix-status"
                                    return self.adv_prefix_status

                                if (child_yang_name == "bfd-data"):
                                    if (self.bfd_data is None):
                                        self.bfd_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData()
                                        self.bfd_data.parent = self
                                        self._children_name_map["bfd_data"] = "bfd-data"
                                    return self.bfd_data

                                if (child_yang_name == "clns-data"):
                                    if (self.clns_data is None):
                                        self.clns_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData()
                                        self.clns_data.parent = self
                                        self._children_name_map["clns_data"] = "clns-data"
                                    return self.clns_data

                                if (child_yang_name == "p2p-data"):
                                    if (self.p2p_data is None):
                                        self.p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2PData()
                                        self.p2p_data.parent = self
                                        self._children_name_map["p2p_data"] = "p2p-data"
                                    return self.p2p_data

                                if (child_yang_name == "per-address-family-data"):
                                    for c in self.per_address_family_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_address_family_data.append(c)
                                    return c

                                if (child_yang_name == "per-area-data"):
                                    for c in self.per_area_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_area_data.append(c)
                                    return c

                                if (child_yang_name == "per-topology-data"):
                                    for c in self.per_topology_data:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.per_topology_data.append(c)
                                    return c

                                if (child_yang_name == "underlying-interface"):
                                    for c in self.underlying_interface:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.underlying_interface.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "adjacency-form-status" or name == "adv-prefix-status" or name == "bfd-data" or name == "clns-data" or name == "p2p-data" or name == "per-address-family-data" or name == "per-area-data" or name == "per-topology-data" or name == "underlying-interface" or name == "enabled-circuit-type" or name == "interface-media-type" or name == "local-circuit-number" or name == "rsi-srlg-registered"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "enabled-circuit-type"):
                                    self.enabled_circuit_type = value
                                    self.enabled_circuit_type.value_namespace = name_space
                                    self.enabled_circuit_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-media-type"):
                                    self.interface_media_type = value
                                    self.interface_media_type.value_namespace = name_space
                                    self.interface_media_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "local-circuit-number"):
                                    self.local_circuit_number = value
                                    self.local_circuit_number.value_namespace = name_space
                                    self.local_circuit_number.value_namespace_prefix = name_space_prefix
                                if(value_path == "rsi-srlg-registered"):
                                    self.rsi_srlg_registered = value
                                    self.rsi_srlg_registered.value_namespace = name_space
                                    self.rsi_srlg_registered.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.status.is_set or
                                (self.disabled is not None and self.disabled.has_data()) or
                                (self.enabled is not None and self.enabled.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.status.yfilter != YFilter.not_set or
                                (self.disabled is not None and self.disabled.has_operation()) or
                                (self.enabled is not None and self.enabled.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-status-and-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.status.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "disabled"):
                                if (self.disabled is None):
                                    self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled()
                                    self.disabled.parent = self
                                    self._children_name_map["disabled"] = "disabled"
                                return self.disabled

                            if (child_yang_name == "enabled"):
                                if (self.enabled is None):
                                    self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled()
                                    self.enabled.parent = self
                                    self._children_name_map["enabled"] = "enabled"
                                return self.enabled

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "disabled" or name == "enabled" or name == "status"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "status"):
                                self.status = value
                                self.status.value_namespace = name_space
                                self.status.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configured_circuit_type.is_set or
                            self.is_type.is_set or
                            self.mesh_group.is_set or
                            self.nsr_intf.is_set or
                            (self.configured_status is not None and self.configured_status.has_data()) or
                            (self.interface_status_and_data is not None and self.interface_status_and_data.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configured_circuit_type.yfilter != YFilter.not_set or
                            self.is_type.yfilter != YFilter.not_set or
                            self.mesh_group.yfilter != YFilter.not_set or
                            self.nsr_intf.yfilter != YFilter.not_set or
                            (self.configured_status is not None and self.configured_status.has_operation()) or
                            (self.interface_status_and_data is not None and self.interface_status_and_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configured_circuit_type.is_set or self.configured_circuit_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configured_circuit_type.get_name_leafdata())
                        if (self.is_type.is_set or self.is_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_type.get_name_leafdata())
                        if (self.mesh_group.is_set or self.mesh_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mesh_group.get_name_leafdata())
                        if (self.nsr_intf.is_set or self.nsr_intf.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nsr_intf.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "configured-status"):
                            if (self.configured_status is None):
                                self.configured_status = Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus()
                                self.configured_status.parent = self
                                self._children_name_map["configured_status"] = "configured-status"
                            return self.configured_status

                        if (child_yang_name == "interface-status-and-data"):
                            if (self.interface_status_and_data is None):
                                self.interface_status_and_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData()
                                self.interface_status_and_data.parent = self
                                self._children_name_map["interface_status_and_data"] = "interface-status-and-data"
                            return self.interface_status_and_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configured-status" or name == "interface-status-and-data" or name == "interface-name" or name == "configured-circuit-type" or name == "is-type" or name == "mesh-group" or name == "nsr-intf"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configured-circuit-type"):
                            self.configured_circuit_type = value
                            self.configured_circuit_type.value_namespace = name_space
                            self.configured_circuit_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-type"):
                            self.is_type = value
                            self.is_type.value_namespace = name_space
                            self.is_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "mesh-group"):
                            self.mesh_group = value
                            self.mesh_group.value_namespace = name_space
                            self.mesh_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "nsr-intf"):
                            self.nsr_intf = value
                            self.nsr_intf.value_namespace = name_space
                            self.nsr_intf.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Interfaces.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class CheckpointAdjacencies(Entity):
                """
                Checkpointed adjacency table
                
                .. attribute:: checkpoint_adjacency
                
                	A checkpointed IS\-IS adjacency
                	**type**\: list of    :py:class:`CheckpointAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointAdjacencies, self).__init__()

                    self.yang_name = "checkpoint-adjacencies"
                    self.yang_parent_name = "instance"

                    self.checkpoint_adjacency = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.CheckpointAdjacencies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.CheckpointAdjacencies, self).__setattr__(name, value)


                class CheckpointAdjacency(Entity):
                    """
                    A checkpointed IS\-IS adjacency
                    
                    .. attribute:: checkpoint_adjacency_circuit_number
                    
                    	Neighbor circuit number
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_adjacency_holdtime
                    
                    	Adjacency holdtime (s)
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: checkpoint_adjacency_interface
                    
                    	Local interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: checkpoint_adjacency_lan_priority
                    
                    	Adjacency LAN priority
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_adjacency_level
                    
                    	Adjacency level
                    	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: checkpoint_adjacency_object_id
                    
                    	Checkpoint object ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_adjacency_per_address_family_next_hop
                    
                    	Per address family next hops
                    	**type**\: list of    :py:class:`CheckpointAdjacencyPerAddressFamilyNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop>`
                    
                    .. attribute:: checkpoint_adjacency_snpa
                    
                    	Neighbor SNPA
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: checkpoint_adjacency_system_id
                    
                    	Neighbor system ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:   :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: system_id
                    
                    	System ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency, self).__init__()

                        self.yang_name = "checkpoint-adjacency"
                        self.yang_parent_name = "checkpoint-adjacencies"

                        self.checkpoint_adjacency_circuit_number = YLeaf(YType.uint8, "checkpoint-adjacency-circuit-number")

                        self.checkpoint_adjacency_holdtime = YLeaf(YType.uint16, "checkpoint-adjacency-holdtime")

                        self.checkpoint_adjacency_interface = YLeaf(YType.str, "checkpoint-adjacency-interface")

                        self.checkpoint_adjacency_lan_priority = YLeaf(YType.uint8, "checkpoint-adjacency-lan-priority")

                        self.checkpoint_adjacency_level = YLeaf(YType.enumeration, "checkpoint-adjacency-level")

                        self.checkpoint_adjacency_object_id = YLeaf(YType.uint32, "checkpoint-adjacency-object-id")

                        self.checkpoint_adjacency_snpa = YLeaf(YType.str, "checkpoint-adjacency-snpa")

                        self.checkpoint_adjacency_system_id = YLeaf(YType.str, "checkpoint-adjacency-system-id")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.level = YLeaf(YType.enumeration, "level")

                        self.system_id = YLeaf(YType.str, "system-id")

                        self.checkpoint_adjacency_per_address_family_next_hop = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("checkpoint_adjacency_circuit_number",
                                        "checkpoint_adjacency_holdtime",
                                        "checkpoint_adjacency_interface",
                                        "checkpoint_adjacency_lan_priority",
                                        "checkpoint_adjacency_level",
                                        "checkpoint_adjacency_object_id",
                                        "checkpoint_adjacency_snpa",
                                        "checkpoint_adjacency_system_id",
                                        "interface_name",
                                        "level",
                                        "system_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency, self).__setattr__(name, value)


                    class CheckpointAdjacencyPerAddressFamilyNextHop(Entity):
                        """
                        Per address family next hops
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: ipv4
                        
                        	IPV4 address type
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	IPV6 address type
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop, self).__init__()

                            self.yang_name = "checkpoint-adjacency-per-address-family-next-hop"
                            self.yang_parent_name = "checkpoint-adjacency"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4 = YLeaf(YType.str, "ipv4")

                            self.ipv6 = YLeaf(YType.str, "ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4",
                                            "ipv6") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4.is_set or
                                self.ipv6.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4.yfilter != YFilter.not_set or
                                self.ipv6.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "checkpoint-adjacency-per-address-family-next-hop" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4.get_name_leafdata())
                            if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4" or name == "ipv6"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4"):
                                self.ipv4 = value
                                self.ipv4.value_namespace = name_space
                                self.ipv4.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6"):
                                self.ipv6 = value
                                self.ipv6.value_namespace = name_space
                                self.ipv6.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.checkpoint_adjacency_per_address_family_next_hop:
                            if (c.has_data()):
                                return True
                        return (
                            self.checkpoint_adjacency_circuit_number.is_set or
                            self.checkpoint_adjacency_holdtime.is_set or
                            self.checkpoint_adjacency_interface.is_set or
                            self.checkpoint_adjacency_lan_priority.is_set or
                            self.checkpoint_adjacency_level.is_set or
                            self.checkpoint_adjacency_object_id.is_set or
                            self.checkpoint_adjacency_snpa.is_set or
                            self.checkpoint_adjacency_system_id.is_set or
                            self.interface_name.is_set or
                            self.level.is_set or
                            self.system_id.is_set)

                    def has_operation(self):
                        for c in self.checkpoint_adjacency_per_address_family_next_hop:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_circuit_number.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_holdtime.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_interface.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_lan_priority.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_level.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_object_id.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_snpa.yfilter != YFilter.not_set or
                            self.checkpoint_adjacency_system_id.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set or
                            self.system_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-adjacency" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.checkpoint_adjacency_circuit_number.is_set or self.checkpoint_adjacency_circuit_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_circuit_number.get_name_leafdata())
                        if (self.checkpoint_adjacency_holdtime.is_set or self.checkpoint_adjacency_holdtime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_holdtime.get_name_leafdata())
                        if (self.checkpoint_adjacency_interface.is_set or self.checkpoint_adjacency_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_interface.get_name_leafdata())
                        if (self.checkpoint_adjacency_lan_priority.is_set or self.checkpoint_adjacency_lan_priority.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_lan_priority.get_name_leafdata())
                        if (self.checkpoint_adjacency_level.is_set or self.checkpoint_adjacency_level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_level.get_name_leafdata())
                        if (self.checkpoint_adjacency_object_id.is_set or self.checkpoint_adjacency_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_object_id.get_name_leafdata())
                        if (self.checkpoint_adjacency_snpa.is_set or self.checkpoint_adjacency_snpa.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_snpa.get_name_leafdata())
                        if (self.checkpoint_adjacency_system_id.is_set or self.checkpoint_adjacency_system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_adjacency_system_id.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())
                        if (self.system_id.is_set or self.system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.system_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "checkpoint-adjacency-per-address-family-next-hop"):
                            for c in self.checkpoint_adjacency_per_address_family_next_hop:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.checkpoint_adjacency_per_address_family_next_hop.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "checkpoint-adjacency-per-address-family-next-hop" or name == "checkpoint-adjacency-circuit-number" or name == "checkpoint-adjacency-holdtime" or name == "checkpoint-adjacency-interface" or name == "checkpoint-adjacency-lan-priority" or name == "checkpoint-adjacency-level" or name == "checkpoint-adjacency-object-id" or name == "checkpoint-adjacency-snpa" or name == "checkpoint-adjacency-system-id" or name == "interface-name" or name == "level" or name == "system-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "checkpoint-adjacency-circuit-number"):
                            self.checkpoint_adjacency_circuit_number = value
                            self.checkpoint_adjacency_circuit_number.value_namespace = name_space
                            self.checkpoint_adjacency_circuit_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-holdtime"):
                            self.checkpoint_adjacency_holdtime = value
                            self.checkpoint_adjacency_holdtime.value_namespace = name_space
                            self.checkpoint_adjacency_holdtime.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-interface"):
                            self.checkpoint_adjacency_interface = value
                            self.checkpoint_adjacency_interface.value_namespace = name_space
                            self.checkpoint_adjacency_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-lan-priority"):
                            self.checkpoint_adjacency_lan_priority = value
                            self.checkpoint_adjacency_lan_priority.value_namespace = name_space
                            self.checkpoint_adjacency_lan_priority.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-level"):
                            self.checkpoint_adjacency_level = value
                            self.checkpoint_adjacency_level.value_namespace = name_space
                            self.checkpoint_adjacency_level.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-object-id"):
                            self.checkpoint_adjacency_object_id = value
                            self.checkpoint_adjacency_object_id.value_namespace = name_space
                            self.checkpoint_adjacency_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-snpa"):
                            self.checkpoint_adjacency_snpa = value
                            self.checkpoint_adjacency_snpa.value_namespace = name_space
                            self.checkpoint_adjacency_snpa.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-adjacency-system-id"):
                            self.checkpoint_adjacency_system_id = value
                            self.checkpoint_adjacency_system_id.value_namespace = name_space
                            self.checkpoint_adjacency_system_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix
                        if(value_path == "system-id"):
                            self.system_id = value
                            self.system_id.value_namespace = name_space
                            self.system_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_adjacency:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_adjacency:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-adjacencies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-adjacency"):
                        for c in self.checkpoint_adjacency:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_adjacency.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-adjacency"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Srms(Entity):
                """
                Segment Routing Mapping Server operational
                data
                
                .. attribute:: policy
                
                	Policy operational data
                	**type**\:   :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Srms, self).__init__()

                    self.yang_name = "srms"
                    self.yang_parent_name = "instance"

                    self.policy = Isis.Instances.Instance.Srms.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"
                    self._children_yang_names.add("policy")


                class Policy(Entity):
                    """
                    Policy operational data
                    
                    .. attribute:: policy_ipv4
                    
                    	IPv4 policy operational data
                    	**type**\:   :py:class:`PolicyIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4>`
                    
                    .. attribute:: policy_ipv6
                    
                    	IPv6 policy operational data
                    	**type**\:   :py:class:`PolicyIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Srms.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "srms"

                        self.policy_ipv4 = Isis.Instances.Instance.Srms.Policy.PolicyIpv4()
                        self.policy_ipv4.parent = self
                        self._children_name_map["policy_ipv4"] = "policy-ipv4"
                        self._children_yang_names.add("policy-ipv4")

                        self.policy_ipv6 = Isis.Instances.Instance.Srms.Policy.PolicyIpv6()
                        self.policy_ipv6.parent = self
                        self._children_name_map["policy_ipv6"] = "policy-ipv6"
                        self._children_yang_names.add("policy-ipv6")


                    class PolicyIpv4(Entity):
                        """
                        IPv4 policy operational data
                        
                        .. attribute:: policy_ipv4_active
                        
                        	IPv4 active policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active>`
                        
                        .. attribute:: policy_ipv4_backup
                        
                        	IPv4 backup policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4, self).__init__()

                            self.yang_name = "policy-ipv4"
                            self.yang_parent_name = "policy"

                            self.policy_ipv4_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                            self.policy_ipv4_active.parent = self
                            self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"
                            self._children_yang_names.add("policy-ipv4-active")

                            self.policy_ipv4_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                            self.policy_ipv4_backup.parent = self
                            self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                            self._children_yang_names.add("policy-ipv4-backup")


                        class PolicyIpv4Active(Entity):
                            """
                            IPv4 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__init__()

                                self.yang_name = "policy-ipv4-active"
                                self.yang_parent_name = "policy-ipv4"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-active"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv4-active" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class PolicyIpv4Backup(Entity):
                            """
                            IPv4 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__init__()

                                self.yang_name = "policy-ipv4-backup"
                                self.yang_parent_name = "policy-ipv4"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-backup"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv4-backup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.policy_ipv4_active is not None and self.policy_ipv4_active.has_data()) or
                                (self.policy_ipv4_backup is not None and self.policy_ipv4_backup.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.policy_ipv4_active is not None and self.policy_ipv4_active.has_operation()) or
                                (self.policy_ipv4_backup is not None and self.policy_ipv4_backup.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "policy-ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "policy-ipv4-active"):
                                if (self.policy_ipv4_active is None):
                                    self.policy_ipv4_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                                    self.policy_ipv4_active.parent = self
                                    self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"
                                return self.policy_ipv4_active

                            if (child_yang_name == "policy-ipv4-backup"):
                                if (self.policy_ipv4_backup is None):
                                    self.policy_ipv4_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                                    self.policy_ipv4_backup.parent = self
                                    self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                                return self.policy_ipv4_backup

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "policy-ipv4-active" or name == "policy-ipv4-backup"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class PolicyIpv6(Entity):
                        """
                        IPv6 policy operational data
                        
                        .. attribute:: policy_ipv6_active
                        
                        	IPv6 active policy operational data
                        	**type**\:   :py:class:`PolicyIpv6Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active>`
                        
                        .. attribute:: policy_ipv6_backup
                        
                        	IPv6 backup policy operational data
                        	**type**\:   :py:class:`PolicyIpv6Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6, self).__init__()

                            self.yang_name = "policy-ipv6"
                            self.yang_parent_name = "policy"

                            self.policy_ipv6_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active()
                            self.policy_ipv6_active.parent = self
                            self._children_name_map["policy_ipv6_active"] = "policy-ipv6-active"
                            self._children_yang_names.add("policy-ipv6-active")

                            self.policy_ipv6_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup()
                            self.policy_ipv6_backup.parent = self
                            self._children_name_map["policy_ipv6_backup"] = "policy-ipv6-backup"
                            self._children_yang_names.add("policy-ipv6-backup")


                        class PolicyIpv6Backup(Entity):
                            """
                            IPv6 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup, self).__init__()

                                self.yang_name = "policy-ipv6-backup"
                                self.yang_parent_name = "policy-ipv6"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv6-backup"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv6-backup" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass


                        class PolicyIpv6Active(Entity):
                            """
                            IPv6 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active, self).__init__()

                                self.yang_name = "policy-ipv6-active"
                                self.yang_parent_name = "policy-ipv6"

                                self.policy_mi = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in () and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active, self).__setattr__(name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv6-active"

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("mi_id",
                                                    "area",
                                                    "flag_attached",
                                                    "last_prefix",
                                                    "last_sid_index",
                                                    "prefix",
                                                    "router",
                                                    "sid_count",
                                                    "sid_start",
                                                    "src") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi, self).__setattr__(name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")

                                    def __setattr__(self, name, value):
                                        self._check_monkey_patching_error(name, value)
                                        with _handle_type_error():
                                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                    "Please use list append or extend method."
                                                                    .format(value))
                                            if isinstance(value, Enum.YLeaf):
                                                value = value.name
                                            if name in ("af",
                                                        "ipv4",
                                                        "ipv6") and name in self.__dict__:
                                                if isinstance(value, YLeaf):
                                                    self.__dict__[name].set(value.get())
                                                elif isinstance(value, YLeafList):
                                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr, self).__setattr__(name, value)
                                                else:
                                                    self.__dict__[name].set(value)
                                            else:
                                                if hasattr(value, "parent") and name != "parent":
                                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                        value.parent = self
                                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                                        value.parent = self
                                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr, self).__setattr__(name, value)

                                    def has_data(self):
                                        return (
                                            self.af.is_set or
                                            self.ipv4.is_set or
                                            self.ipv6.is_set)

                                    def has_operation(self):
                                        return (
                                            self.yfilter != YFilter.not_set or
                                            self.af.yfilter != YFilter.not_set or
                                            self.ipv4.yfilter != YFilter.not_set or
                                            self.ipv6.yfilter != YFilter.not_set)

                                    def get_segment_path(self):
                                        path_buffer = ""
                                        path_buffer = "addr" + path_buffer

                                        return path_buffer

                                    def get_entity_path(self, ancestor):
                                        path_buffer = ""
                                        if (ancestor is None):
                                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                        else:
                                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                        leaf_name_data = LeafDataList()
                                        if (self.af.is_set or self.af.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.af.get_name_leafdata())
                                        if (self.ipv4.is_set or self.ipv4.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv4.get_name_leafdata())
                                        if (self.ipv6.is_set or self.ipv6.yfilter != YFilter.not_set):
                                            leaf_name_data.append(self.ipv6.get_name_leafdata())

                                        entity_path = EntityPath(path_buffer, leaf_name_data)
                                        return entity_path

                                    def get_child_by_name(self, child_yang_name, segment_path):
                                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                        if child is not None:
                                            return child

                                        return None

                                    def has_leaf_or_child_of_name(self, name):
                                        if(name == "af" or name == "ipv4" or name == "ipv6"):
                                            return True
                                        return False

                                    def set_value(self, value_path, value, name_space, name_space_prefix):
                                        if(value_path == "af"):
                                            self.af = value
                                            self.af.value_namespace = name_space
                                            self.af.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv4"):
                                            self.ipv4 = value
                                            self.ipv4.value_namespace = name_space
                                            self.ipv4.value_namespace_prefix = name_space_prefix
                                        if(value_path == "ipv6"):
                                            self.ipv6 = value
                                            self.ipv6.value_namespace = name_space
                                            self.ipv6.value_namespace_prefix = name_space_prefix

                                def has_data(self):
                                    return (
                                        self.mi_id.is_set or
                                        self.area.is_set or
                                        self.flag_attached.is_set or
                                        self.last_prefix.is_set or
                                        self.last_sid_index.is_set or
                                        self.prefix.is_set or
                                        self.router.is_set or
                                        self.sid_count.is_set or
                                        self.sid_start.is_set or
                                        self.src.is_set or
                                        (self.addr is not None and self.addr.has_data()))

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.mi_id.yfilter != YFilter.not_set or
                                        self.area.yfilter != YFilter.not_set or
                                        self.flag_attached.yfilter != YFilter.not_set or
                                        self.last_prefix.yfilter != YFilter.not_set or
                                        self.last_sid_index.yfilter != YFilter.not_set or
                                        self.prefix.yfilter != YFilter.not_set or
                                        self.router.yfilter != YFilter.not_set or
                                        self.sid_count.yfilter != YFilter.not_set or
                                        self.sid_start.yfilter != YFilter.not_set or
                                        self.src.yfilter != YFilter.not_set or
                                        (self.addr is not None and self.addr.has_operation()))

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "policy-mi" + "[mi-id='" + self.mi_id.get() + "']" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.mi_id.is_set or self.mi_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.mi_id.get_name_leafdata())
                                    if (self.area.is_set or self.area.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.area.get_name_leafdata())
                                    if (self.flag_attached.is_set or self.flag_attached.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.flag_attached.get_name_leafdata())
                                    if (self.last_prefix.is_set or self.last_prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_prefix.get_name_leafdata())
                                    if (self.last_sid_index.is_set or self.last_sid_index.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.last_sid_index.get_name_leafdata())
                                    if (self.prefix.is_set or self.prefix.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix.get_name_leafdata())
                                    if (self.router.is_set or self.router.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.router.get_name_leafdata())
                                    if (self.sid_count.is_set or self.sid_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_count.get_name_leafdata())
                                    if (self.sid_start.is_set or self.sid_start.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.sid_start.get_name_leafdata())
                                    if (self.src.is_set or self.src.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.src.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    if (child_yang_name == "addr"):
                                        if (self.addr is None):
                                            self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr()
                                            self.addr.parent = self
                                            self._children_name_map["addr"] = "addr"
                                        return self.addr

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "addr" or name == "mi-id" or name == "area" or name == "flag-attached" or name == "last-prefix" or name == "last-sid-index" or name == "prefix" or name == "router" or name == "sid-count" or name == "sid-start" or name == "src"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "mi-id"):
                                        self.mi_id = value
                                        self.mi_id.value_namespace = name_space
                                        self.mi_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "area"):
                                        self.area = value
                                        self.area.value_namespace = name_space
                                        self.area.value_namespace_prefix = name_space_prefix
                                    if(value_path == "flag-attached"):
                                        self.flag_attached = value
                                        self.flag_attached.value_namespace = name_space
                                        self.flag_attached.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-prefix"):
                                        self.last_prefix = value
                                        self.last_prefix.value_namespace = name_space
                                        self.last_prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "last-sid-index"):
                                        self.last_sid_index = value
                                        self.last_sid_index.value_namespace = name_space
                                        self.last_sid_index.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix"):
                                        self.prefix = value
                                        self.prefix.value_namespace = name_space
                                        self.prefix.value_namespace_prefix = name_space_prefix
                                    if(value_path == "router"):
                                        self.router = value
                                        self.router.value_namespace = name_space
                                        self.router.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-count"):
                                        self.sid_count = value
                                        self.sid_count.value_namespace = name_space
                                        self.sid_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "sid-start"):
                                        self.sid_start = value
                                        self.sid_start.value_namespace = name_space
                                        self.sid_start.value_namespace_prefix = name_space_prefix
                                    if(value_path == "src"):
                                        self.src = value
                                        self.src.value_namespace = name_space
                                        self.src.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.policy_mi:
                                    if (c.has_data()):
                                        return True
                                return False

                            def has_operation(self):
                                for c in self.policy_mi:
                                    if (c.has_operation()):
                                        return True
                                return self.yfilter != YFilter.not_set

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "policy-ipv6-active" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "policy-mi"):
                                    for c in self.policy_mi:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.policy_mi.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "policy-mi"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            return (
                                (self.policy_ipv6_active is not None and self.policy_ipv6_active.has_data()) or
                                (self.policy_ipv6_backup is not None and self.policy_ipv6_backup.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.policy_ipv6_active is not None and self.policy_ipv6_active.has_operation()) or
                                (self.policy_ipv6_backup is not None and self.policy_ipv6_backup.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "policy-ipv6" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "policy-ipv6-active"):
                                if (self.policy_ipv6_active is None):
                                    self.policy_ipv6_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active()
                                    self.policy_ipv6_active.parent = self
                                    self._children_name_map["policy_ipv6_active"] = "policy-ipv6-active"
                                return self.policy_ipv6_active

                            if (child_yang_name == "policy-ipv6-backup"):
                                if (self.policy_ipv6_backup is None):
                                    self.policy_ipv6_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup()
                                    self.policy_ipv6_backup.parent = self
                                    self._children_name_map["policy_ipv6_backup"] = "policy-ipv6-backup"
                                return self.policy_ipv6_backup

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "policy-ipv6-active" or name == "policy-ipv6-backup"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            (self.policy_ipv4 is not None and self.policy_ipv4.has_data()) or
                            (self.policy_ipv6 is not None and self.policy_ipv6.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.policy_ipv4 is not None and self.policy_ipv4.has_operation()) or
                            (self.policy_ipv6 is not None and self.policy_ipv6.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "policy-ipv4"):
                            if (self.policy_ipv4 is None):
                                self.policy_ipv4 = Isis.Instances.Instance.Srms.Policy.PolicyIpv4()
                                self.policy_ipv4.parent = self
                                self._children_name_map["policy_ipv4"] = "policy-ipv4"
                            return self.policy_ipv4

                        if (child_yang_name == "policy-ipv6"):
                            if (self.policy_ipv6 is None):
                                self.policy_ipv6 = Isis.Instances.Instance.Srms.Policy.PolicyIpv6()
                                self.policy_ipv6.parent = self
                                self._children_name_map["policy_ipv6"] = "policy-ipv6"
                            return self.policy_ipv6

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "policy-ipv4" or name == "policy-ipv6"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.policy is not None and self.policy.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.policy is not None and self.policy.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "srms" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "policy"):
                        if (self.policy is None):
                            self.policy = Isis.Instances.Instance.Srms.Policy()
                            self.policy.parent = self
                            self._children_name_map["policy"] = "policy"
                        return self.policy

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "policy"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class ErrorLog(Entity):
                """
                Log of errors and warnings
                
                .. attribute:: log_entry
                
                	Error Log entries
                	**type**\: list of    :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.ErrorLog, self).__init__()

                    self.yang_name = "error-log"
                    self.yang_parent_name = "instance"

                    self.log_entry = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.ErrorLog, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.ErrorLog, self).__setattr__(name, value)


                class LogEntry(Entity):
                    """
                    Error Log entries
                    
                    .. attribute:: error_code
                    
                    	Error code
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: error_log_level
                    
                    	Logging level
                    	**type**\:   :py:class:`IsisErrLogLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisErrLogLevel>`
                    
                    .. attribute:: error_reason
                    
                    	Error details
                    	**type**\:  str
                    
                    .. attribute:: generic_data
                    
                    	Generic entry data
                    	**type**\:   :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry.GenericData>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.ErrorLog.LogEntry, self).__init__()

                        self.yang_name = "log-entry"
                        self.yang_parent_name = "error-log"

                        self.error_code = YLeaf(YType.uint32, "error-code")

                        self.error_log_level = YLeaf(YType.enumeration, "error-log-level")

                        self.error_reason = YLeaf(YType.str, "error-reason")

                        self.generic_data = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData()
                        self.generic_data.parent = self
                        self._children_name_map["generic_data"] = "generic-data"
                        self._children_yang_names.add("generic-data")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("error_code",
                                        "error_log_level",
                                        "error_reason") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.ErrorLog.LogEntry, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.ErrorLog.LogEntry, self).__setattr__(name, value)


                    class GenericData(Entity):
                        """
                        Generic entry data
                        
                        .. attribute:: timestamp
                        
                        	Time in UTC relative to Jan 1st, 1970
                        	**type**\:   :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData, self).__init__()

                            self.yang_name = "generic-data"
                            self.yang_parent_name = "log-entry"

                            self.timestamp = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp()
                            self.timestamp.parent = self
                            self._children_name_map["timestamp"] = "timestamp"
                            self._children_yang_names.add("timestamp")


                        class Timestamp(Entity):
                            """
                            Time in UTC relative to Jan 1st, 1970
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp, self).__init__()

                                self.yang_name = "timestamp"
                                self.yang_parent_name = "generic-data"

                                self.nano_seconds = YLeaf(YType.uint32, "nano-seconds")

                                self.seconds = YLeaf(YType.uint32, "seconds")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("nano_seconds",
                                                "seconds") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.nano_seconds.is_set or
                                    self.seconds.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.nano_seconds.yfilter != YFilter.not_set or
                                    self.seconds.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "timestamp" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.nano_seconds.is_set or self.nano_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.nano_seconds.get_name_leafdata())
                                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.seconds.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "nano-seconds" or name == "seconds"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "nano-seconds"):
                                    self.nano_seconds = value
                                    self.nano_seconds.value_namespace = name_space
                                    self.nano_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "seconds"):
                                    self.seconds = value
                                    self.seconds.value_namespace = name_space
                                    self.seconds.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (self.timestamp is not None and self.timestamp.has_data())

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.timestamp is not None and self.timestamp.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "timestamp"):
                                if (self.timestamp is None):
                                    self.timestamp = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                return self.timestamp

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "timestamp"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass

                    def has_data(self):
                        return (
                            self.error_code.is_set or
                            self.error_log_level.is_set or
                            self.error_reason.is_set or
                            (self.generic_data is not None and self.generic_data.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.error_code.yfilter != YFilter.not_set or
                            self.error_log_level.yfilter != YFilter.not_set or
                            self.error_reason.yfilter != YFilter.not_set or
                            (self.generic_data is not None and self.generic_data.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "log-entry" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.error_code.is_set or self.error_code.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.error_code.get_name_leafdata())
                        if (self.error_log_level.is_set or self.error_log_level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.error_log_level.get_name_leafdata())
                        if (self.error_reason.is_set or self.error_reason.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.error_reason.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generic-data"):
                            if (self.generic_data is None):
                                self.generic_data = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"
                            return self.generic_data

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generic-data" or name == "error-code" or name == "error-log-level" or name == "error-reason"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "error-code"):
                            self.error_code = value
                            self.error_code.value_namespace = name_space
                            self.error_code.value_namespace_prefix = name_space_prefix
                        if(value_path == "error-log-level"):
                            self.error_log_level = value
                            self.error_log_level.value_namespace = name_space
                            self.error_log_level.value_namespace_prefix = name_space_prefix
                        if(value_path == "error-reason"):
                            self.error_reason = value
                            self.error_reason.value_namespace = name_space
                            self.error_reason.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.log_entry:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.log_entry:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "error-log" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "log-entry"):
                        for c in self.log_entry:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.ErrorLog.LogEntry()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.log_entry.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "log-entry"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class CheckpointInterfaces(Entity):
                """
                Checkpointed interface table
                
                .. attribute:: checkpoint_interface
                
                	Checkpointed information about one IS\-IS interface
                	**type**\: list of    :py:class:`CheckpointInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointInterfaces, self).__init__()

                    self.yang_name = "checkpoint-interfaces"
                    self.yang_parent_name = "instance"

                    self.checkpoint_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.CheckpointInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.CheckpointInterfaces, self).__setattr__(name, value)


                class CheckpointInterface(Entity):
                    """
                    Checkpointed information about one IS\-IS
                    interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: checkpoint_interface_handle
                    
                    	Local interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: checkpoint_object_id
                    
                    	Checkpoint object ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: dis_areas
                    
                    	Areas in which this system is DIS
                    	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: has_achieved_ld_pv6_sync
                    
                    	MPLS LDPv6 sync status
                    	**type**\:  bool
                    
                    .. attribute:: has_achieved_ldp_sync
                    
                    	MPLS LDP sync status
                    	**type**\:  bool
                    
                    .. attribute:: has_adjacency
                    
                    	TRUE if there is an adjacency on this interface
                    	**type**\:  bool
                    
                    .. attribute:: has_joined_mcast_group
                    
                    	TRUE if multicast group registration succeeded on this interface
                    	**type**\:  bool
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: local_circuit_number
                    
                    	Local circuit number
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: local_snpa
                    
                    	SNPA of this interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface, self).__init__()

                        self.yang_name = "checkpoint-interface"
                        self.yang_parent_name = "checkpoint-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.checkpoint_interface_handle = YLeaf(YType.str, "checkpoint-interface-handle")

                        self.checkpoint_object_id = YLeaf(YType.uint32, "checkpoint-object-id")

                        self.dis_areas = YLeaf(YType.enumeration, "dis-areas")

                        self.has_achieved_ld_pv6_sync = YLeaf(YType.boolean, "has-achieved-ld-pv6-sync")

                        self.has_achieved_ldp_sync = YLeaf(YType.boolean, "has-achieved-ldp-sync")

                        self.has_adjacency = YLeaf(YType.boolean, "has-adjacency")

                        self.has_joined_mcast_group = YLeaf(YType.boolean, "has-joined-mcast-group")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.local_circuit_number = YLeaf(YType.uint8, "local-circuit-number")

                        self.local_snpa = YLeaf(YType.str, "local-snpa")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "checkpoint_interface_handle",
                                        "checkpoint_object_id",
                                        "dis_areas",
                                        "has_achieved_ld_pv6_sync",
                                        "has_achieved_ldp_sync",
                                        "has_adjacency",
                                        "has_joined_mcast_group",
                                        "interface_name_xr",
                                        "local_circuit_number",
                                        "local_snpa") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.checkpoint_interface_handle.is_set or
                            self.checkpoint_object_id.is_set or
                            self.dis_areas.is_set or
                            self.has_achieved_ld_pv6_sync.is_set or
                            self.has_achieved_ldp_sync.is_set or
                            self.has_adjacency.is_set or
                            self.has_joined_mcast_group.is_set or
                            self.interface_name_xr.is_set or
                            self.local_circuit_number.is_set or
                            self.local_snpa.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.checkpoint_interface_handle.yfilter != YFilter.not_set or
                            self.checkpoint_object_id.yfilter != YFilter.not_set or
                            self.dis_areas.yfilter != YFilter.not_set or
                            self.has_achieved_ld_pv6_sync.yfilter != YFilter.not_set or
                            self.has_achieved_ldp_sync.yfilter != YFilter.not_set or
                            self.has_adjacency.yfilter != YFilter.not_set or
                            self.has_joined_mcast_group.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.local_circuit_number.yfilter != YFilter.not_set or
                            self.local_snpa.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.checkpoint_interface_handle.is_set or self.checkpoint_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_interface_handle.get_name_leafdata())
                        if (self.checkpoint_object_id.is_set or self.checkpoint_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_object_id.get_name_leafdata())
                        if (self.dis_areas.is_set or self.dis_areas.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dis_areas.get_name_leafdata())
                        if (self.has_achieved_ld_pv6_sync.is_set or self.has_achieved_ld_pv6_sync.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.has_achieved_ld_pv6_sync.get_name_leafdata())
                        if (self.has_achieved_ldp_sync.is_set or self.has_achieved_ldp_sync.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.has_achieved_ldp_sync.get_name_leafdata())
                        if (self.has_adjacency.is_set or self.has_adjacency.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.has_adjacency.get_name_leafdata())
                        if (self.has_joined_mcast_group.is_set or self.has_joined_mcast_group.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.has_joined_mcast_group.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.local_circuit_number.is_set or self.local_circuit_number.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_circuit_number.get_name_leafdata())
                        if (self.local_snpa.is_set or self.local_snpa.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.local_snpa.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-name" or name == "checkpoint-interface-handle" or name == "checkpoint-object-id" or name == "dis-areas" or name == "has-achieved-ld-pv6-sync" or name == "has-achieved-ldp-sync" or name == "has-adjacency" or name == "has-joined-mcast-group" or name == "interface-name-xr" or name == "local-circuit-number" or name == "local-snpa"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-interface-handle"):
                            self.checkpoint_interface_handle = value
                            self.checkpoint_interface_handle.value_namespace = name_space
                            self.checkpoint_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-object-id"):
                            self.checkpoint_object_id = value
                            self.checkpoint_object_id.value_namespace = name_space
                            self.checkpoint_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "dis-areas"):
                            self.dis_areas = value
                            self.dis_areas.value_namespace = name_space
                            self.dis_areas.value_namespace_prefix = name_space_prefix
                        if(value_path == "has-achieved-ld-pv6-sync"):
                            self.has_achieved_ld_pv6_sync = value
                            self.has_achieved_ld_pv6_sync.value_namespace = name_space
                            self.has_achieved_ld_pv6_sync.value_namespace_prefix = name_space_prefix
                        if(value_path == "has-achieved-ldp-sync"):
                            self.has_achieved_ldp_sync = value
                            self.has_achieved_ldp_sync.value_namespace = name_space
                            self.has_achieved_ldp_sync.value_namespace_prefix = name_space_prefix
                        if(value_path == "has-adjacency"):
                            self.has_adjacency = value
                            self.has_adjacency.value_namespace = name_space
                            self.has_adjacency.value_namespace_prefix = name_space_prefix
                        if(value_path == "has-joined-mcast-group"):
                            self.has_joined_mcast_group = value
                            self.has_joined_mcast_group.value_namespace = name_space
                            self.has_joined_mcast_group.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-circuit-number"):
                            self.local_circuit_number = value
                            self.local_circuit_number.value_namespace = name_space
                            self.local_circuit_number.value_namespace_prefix = name_space_prefix
                        if(value_path == "local-snpa"):
                            self.local_snpa = value
                            self.local_snpa.value_namespace = name_space
                            self.local_snpa.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-interface"):
                        for c in self.checkpoint_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStatistics(Entity):
                """
                Interface statistics table
                
                .. attribute:: interface_statistic
                
                	Statistics data for one IS\-IS interface
                	**type**\: list of    :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "instance"

                    self.interface_statistic = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.InterfaceStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.InterfaceStatistics, self).__setattr__(name, value)


                class InterfaceStatistic(Entity):
                    """
                    Statistics data for one IS\-IS interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_media_type
                    
                    	Interface media class
                    	**type**\:   :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                    
                    .. attribute:: p2p_statistics
                    
                    	P2P interface statistics. NULL for non\-P2P interfaces
                    	**type**\:   :py:class:`P2PStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics>`
                    
                    .. attribute:: per_area_data
                    
                    	Per\-area data
                    	**type**\: list of    :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData>`
                    
                    .. attribute:: traffic_interface
                    
                    	Interface to which traffic statistics apply
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_media_type = YLeaf(YType.enumeration, "interface-media-type")

                        self.traffic_interface = YLeaf(YType.str, "traffic-interface")

                        self.p2p_statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics()
                        self.p2p_statistics.parent = self
                        self._children_name_map["p2p_statistics"] = "p2p-statistics"
                        self._children_yang_names.add("p2p-statistics")

                        self.per_area_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "interface_media_type",
                                        "traffic_interface") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic, self).__setattr__(name, value)


                    class P2PStatistics(Entity):
                        """
                        P2P interface statistics. NULL for non\-P2P
                        interfaces
                        
                        .. attribute:: iih_count
                        
                        	IIH statistics
                        	**type**\:   :py:class:`IihCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount>`
                        
                        .. attribute:: lsp_retransmit_count
                        
                        	LSP retransmissions
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: memory_exhausted_iih_count
                        
                        	IIHs not sent due to memory exhaustion
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics, self).__init__()

                            self.yang_name = "p2p-statistics"
                            self.yang_parent_name = "interface-statistic"

                            self.lsp_retransmit_count = YLeaf(YType.uint32, "lsp-retransmit-count")

                            self.memory_exhausted_iih_count = YLeaf(YType.uint32, "memory-exhausted-iih-count")

                            self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount()
                            self.iih_count.parent = self
                            self._children_name_map["iih_count"] = "iih-count"
                            self._children_yang_names.add("iih-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("lsp_retransmit_count",
                                            "memory_exhausted_iih_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics, self).__setattr__(name, value)


                        class IihCount(Entity):
                            """
                            IIH statistics
                            
                            .. attribute:: pdu_receive_count
                            
                            	PDUs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pdu_send_count
                            
                            	PDUs sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount, self).__init__()

                                self.yang_name = "iih-count"
                                self.yang_parent_name = "p2p-statistics"

                                self.pdu_receive_count = YLeaf(YType.uint32, "pdu-receive-count")

                                self.pdu_send_count = YLeaf(YType.uint32, "pdu-send-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("pdu_receive_count",
                                                "pdu_send_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.pdu_receive_count.is_set or
                                    self.pdu_send_count.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.pdu_receive_count.yfilter != YFilter.not_set or
                                    self.pdu_send_count.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "iih-count" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.pdu_receive_count.is_set or self.pdu_receive_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pdu_receive_count.get_name_leafdata())
                                if (self.pdu_send_count.is_set or self.pdu_send_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.pdu_send_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "pdu-receive-count" or name == "pdu-send-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "pdu-receive-count"):
                                    self.pdu_receive_count = value
                                    self.pdu_receive_count.value_namespace = name_space
                                    self.pdu_receive_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "pdu-send-count"):
                                    self.pdu_send_count = value
                                    self.pdu_send_count.value_namespace = name_space
                                    self.pdu_send_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.lsp_retransmit_count.is_set or
                                self.memory_exhausted_iih_count.is_set or
                                (self.iih_count is not None and self.iih_count.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.lsp_retransmit_count.yfilter != YFilter.not_set or
                                self.memory_exhausted_iih_count.yfilter != YFilter.not_set or
                                (self.iih_count is not None and self.iih_count.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2p-statistics" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.lsp_retransmit_count.is_set or self.lsp_retransmit_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.lsp_retransmit_count.get_name_leafdata())
                            if (self.memory_exhausted_iih_count.is_set or self.memory_exhausted_iih_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.memory_exhausted_iih_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "iih-count"):
                                if (self.iih_count is None):
                                    self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics.IihCount()
                                    self.iih_count.parent = self
                                    self._children_name_map["iih_count"] = "iih-count"
                                return self.iih_count

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "iih-count" or name == "lsp-retransmit-count" or name == "memory-exhausted-iih-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "lsp-retransmit-count"):
                                self.lsp_retransmit_count = value
                                self.lsp_retransmit_count.value_namespace = name_space
                                self.lsp_retransmit_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "memory-exhausted-iih-count"):
                                self.memory_exhausted_iih_count = value
                                self.memory_exhausted_iih_count.value_namespace = name_space
                                self.memory_exhausted_iih_count.value_namespace_prefix = name_space_prefix


                    class PerAreaData(Entity):
                        """
                        Per\-area data
                        
                        .. attribute:: lan_data
                        
                        	LAN interface statistics. NULL for non\-LAN interfaces
                        	**type**\:   :py:class:`LanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData>`
                        
                        .. attribute:: level
                        
                        	Level of the area this data relates to
                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData, self).__init__()

                            self.yang_name = "per-area-data"
                            self.yang_parent_name = "interface-statistic"

                            self.level = YLeaf(YType.enumeration, "level")

                            self.lan_data = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData()
                            self.lan_data.parent = self
                            self._children_name_map["lan_data"] = "lan-data"
                            self._children_yang_names.add("lan-data")

                            self.statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._children_yang_names.add("statistics")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("level") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData, self).__setattr__(name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: csnp_count
                            
                            	CSNP statistics
                            	**type**\:   :py:class:`CsnpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount>`
                            
                            .. attribute:: lsp_count
                            
                            	LSP statistics
                            	**type**\:   :py:class:`LspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount>`
                            
                            .. attribute:: lsp_drop_count
                            
                            	Count of LSPs dropped due to minimum arrival time config
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsp_flooding_dup_count
                            
                            	Count of LSPs already received by neighbors and not flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: psnp_count
                            
                            	PSNP statistics
                            	**type**\:   :py:class:`PsnpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "per-area-data"

                                self.lsp_drop_count = YLeaf(YType.uint32, "lsp-drop-count")

                                self.lsp_flooding_dup_count = YLeaf(YType.uint32, "lsp-flooding-dup-count")

                                self.csnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount()
                                self.csnp_count.parent = self
                                self._children_name_map["csnp_count"] = "csnp-count"
                                self._children_yang_names.add("csnp-count")

                                self.lsp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount()
                                self.lsp_count.parent = self
                                self._children_name_map["lsp_count"] = "lsp-count"
                                self._children_yang_names.add("lsp-count")

                                self.psnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount()
                                self.psnp_count.parent = self
                                self._children_name_map["psnp_count"] = "psnp-count"
                                self._children_yang_names.add("psnp-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("lsp_drop_count",
                                                "lsp_flooding_dup_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics, self).__setattr__(name, value)


                            class LspCount(Entity):
                                """
                                LSP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount, self).__init__()

                                    self.yang_name = "lsp-count"
                                    self.yang_parent_name = "statistics"

                                    self.pdu_receive_count = YLeaf(YType.uint32, "pdu-receive-count")

                                    self.pdu_send_count = YLeaf(YType.uint32, "pdu-send-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pdu_receive_count",
                                                    "pdu_send_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.pdu_receive_count.is_set or
                                        self.pdu_send_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pdu_receive_count.yfilter != YFilter.not_set or
                                        self.pdu_send_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "lsp-count" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pdu_receive_count.is_set or self.pdu_receive_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_receive_count.get_name_leafdata())
                                    if (self.pdu_send_count.is_set or self.pdu_send_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_send_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pdu-receive-count" or name == "pdu-send-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pdu-receive-count"):
                                        self.pdu_receive_count = value
                                        self.pdu_receive_count.value_namespace = name_space
                                        self.pdu_receive_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pdu-send-count"):
                                        self.pdu_send_count = value
                                        self.pdu_send_count.value_namespace = name_space
                                        self.pdu_send_count.value_namespace_prefix = name_space_prefix


                            class CsnpCount(Entity):
                                """
                                CSNP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount, self).__init__()

                                    self.yang_name = "csnp-count"
                                    self.yang_parent_name = "statistics"

                                    self.pdu_receive_count = YLeaf(YType.uint32, "pdu-receive-count")

                                    self.pdu_send_count = YLeaf(YType.uint32, "pdu-send-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pdu_receive_count",
                                                    "pdu_send_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.pdu_receive_count.is_set or
                                        self.pdu_send_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pdu_receive_count.yfilter != YFilter.not_set or
                                        self.pdu_send_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "csnp-count" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pdu_receive_count.is_set or self.pdu_receive_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_receive_count.get_name_leafdata())
                                    if (self.pdu_send_count.is_set or self.pdu_send_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_send_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pdu-receive-count" or name == "pdu-send-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pdu-receive-count"):
                                        self.pdu_receive_count = value
                                        self.pdu_receive_count.value_namespace = name_space
                                        self.pdu_receive_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pdu-send-count"):
                                        self.pdu_send_count = value
                                        self.pdu_send_count.value_namespace = name_space
                                        self.pdu_send_count.value_namespace_prefix = name_space_prefix


                            class PsnpCount(Entity):
                                """
                                PSNP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount, self).__init__()

                                    self.yang_name = "psnp-count"
                                    self.yang_parent_name = "statistics"

                                    self.pdu_receive_count = YLeaf(YType.uint32, "pdu-receive-count")

                                    self.pdu_send_count = YLeaf(YType.uint32, "pdu-send-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pdu_receive_count",
                                                    "pdu_send_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.pdu_receive_count.is_set or
                                        self.pdu_send_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pdu_receive_count.yfilter != YFilter.not_set or
                                        self.pdu_send_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "psnp-count" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pdu_receive_count.is_set or self.pdu_receive_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_receive_count.get_name_leafdata())
                                    if (self.pdu_send_count.is_set or self.pdu_send_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_send_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pdu-receive-count" or name == "pdu-send-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pdu-receive-count"):
                                        self.pdu_receive_count = value
                                        self.pdu_receive_count.value_namespace = name_space
                                        self.pdu_receive_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pdu-send-count"):
                                        self.pdu_send_count = value
                                        self.pdu_send_count.value_namespace = name_space
                                        self.pdu_send_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.lsp_drop_count.is_set or
                                    self.lsp_flooding_dup_count.is_set or
                                    (self.csnp_count is not None and self.csnp_count.has_data()) or
                                    (self.lsp_count is not None and self.lsp_count.has_data()) or
                                    (self.psnp_count is not None and self.psnp_count.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.lsp_drop_count.yfilter != YFilter.not_set or
                                    self.lsp_flooding_dup_count.yfilter != YFilter.not_set or
                                    (self.csnp_count is not None and self.csnp_count.has_operation()) or
                                    (self.lsp_count is not None and self.lsp_count.has_operation()) or
                                    (self.psnp_count is not None and self.psnp_count.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "statistics" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.lsp_drop_count.is_set or self.lsp_drop_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_drop_count.get_name_leafdata())
                                if (self.lsp_flooding_dup_count.is_set or self.lsp_flooding_dup_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.lsp_flooding_dup_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "csnp-count"):
                                    if (self.csnp_count is None):
                                        self.csnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount()
                                        self.csnp_count.parent = self
                                        self._children_name_map["csnp_count"] = "csnp-count"
                                    return self.csnp_count

                                if (child_yang_name == "lsp-count"):
                                    if (self.lsp_count is None):
                                        self.lsp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount()
                                        self.lsp_count.parent = self
                                        self._children_name_map["lsp_count"] = "lsp-count"
                                    return self.lsp_count

                                if (child_yang_name == "psnp-count"):
                                    if (self.psnp_count is None):
                                        self.psnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount()
                                        self.psnp_count.parent = self
                                        self._children_name_map["psnp_count"] = "psnp-count"
                                    return self.psnp_count

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "csnp-count" or name == "lsp-count" or name == "psnp-count" or name == "lsp-drop-count" or name == "lsp-flooding-dup-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "lsp-drop-count"):
                                    self.lsp_drop_count = value
                                    self.lsp_drop_count.value_namespace = name_space
                                    self.lsp_drop_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "lsp-flooding-dup-count"):
                                    self.lsp_flooding_dup_count = value
                                    self.lsp_flooding_dup_count.value_namespace = name_space
                                    self.lsp_flooding_dup_count.value_namespace_prefix = name_space_prefix


                        class LanData(Entity):
                            """
                            LAN interface statistics. NULL for non\-LAN
                            interfaces
                            
                            .. attribute:: dis_election_count
                            
                            	DIS elections
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iih_count
                            
                            	IIH statistics
                            	**type**\:   :py:class:`IihCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount>`
                            
                            .. attribute:: memory_exhausted_iih_count
                            
                            	IIHs not sent due to memory exhaustion
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData, self).__init__()

                                self.yang_name = "lan-data"
                                self.yang_parent_name = "per-area-data"

                                self.dis_election_count = YLeaf(YType.uint32, "dis-election-count")

                                self.memory_exhausted_iih_count = YLeaf(YType.uint32, "memory-exhausted-iih-count")

                                self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount()
                                self.iih_count.parent = self
                                self._children_name_map["iih_count"] = "iih-count"
                                self._children_yang_names.add("iih-count")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("dis_election_count",
                                                "memory_exhausted_iih_count") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData, self).__setattr__(name, value)


                            class IihCount(Entity):
                                """
                                IIH statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount, self).__init__()

                                    self.yang_name = "iih-count"
                                    self.yang_parent_name = "lan-data"

                                    self.pdu_receive_count = YLeaf(YType.uint32, "pdu-receive-count")

                                    self.pdu_send_count = YLeaf(YType.uint32, "pdu-send-count")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("pdu_receive_count",
                                                    "pdu_send_count") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.pdu_receive_count.is_set or
                                        self.pdu_send_count.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.pdu_receive_count.yfilter != YFilter.not_set or
                                        self.pdu_send_count.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "iih-count" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.pdu_receive_count.is_set or self.pdu_receive_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_receive_count.get_name_leafdata())
                                    if (self.pdu_send_count.is_set or self.pdu_send_count.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.pdu_send_count.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "pdu-receive-count" or name == "pdu-send-count"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "pdu-receive-count"):
                                        self.pdu_receive_count = value
                                        self.pdu_receive_count.value_namespace = name_space
                                        self.pdu_receive_count.value_namespace_prefix = name_space_prefix
                                    if(value_path == "pdu-send-count"):
                                        self.pdu_send_count = value
                                        self.pdu_send_count.value_namespace = name_space
                                        self.pdu_send_count.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.dis_election_count.is_set or
                                    self.memory_exhausted_iih_count.is_set or
                                    (self.iih_count is not None and self.iih_count.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.dis_election_count.yfilter != YFilter.not_set or
                                    self.memory_exhausted_iih_count.yfilter != YFilter.not_set or
                                    (self.iih_count is not None and self.iih_count.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lan-data" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.dis_election_count.is_set or self.dis_election_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.dis_election_count.get_name_leafdata())
                                if (self.memory_exhausted_iih_count.is_set or self.memory_exhausted_iih_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.memory_exhausted_iih_count.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "iih-count"):
                                    if (self.iih_count is None):
                                        self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount()
                                        self.iih_count.parent = self
                                        self._children_name_map["iih_count"] = "iih-count"
                                    return self.iih_count

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "iih-count" or name == "dis-election-count" or name == "memory-exhausted-iih-count"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "dis-election-count"):
                                    self.dis_election_count = value
                                    self.dis_election_count.value_namespace = name_space
                                    self.dis_election_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "memory-exhausted-iih-count"):
                                    self.memory_exhausted_iih_count = value
                                    self.memory_exhausted_iih_count.value_namespace = name_space
                                    self.memory_exhausted_iih_count.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.level.is_set or
                                (self.lan_data is not None and self.lan_data.has_data()) or
                                (self.statistics is not None and self.statistics.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.level.yfilter != YFilter.not_set or
                                (self.lan_data is not None and self.lan_data.has_operation()) or
                                (self.statistics is not None and self.statistics.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "per-area-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.level.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "lan-data"):
                                if (self.lan_data is None):
                                    self.lan_data = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData()
                                    self.lan_data.parent = self
                                    self._children_name_map["lan_data"] = "lan-data"
                                return self.lan_data

                            if (child_yang_name == "statistics"):
                                if (self.statistics is None):
                                    self.statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                return self.statistics

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "lan-data" or name == "statistics" or name == "level"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "level"):
                                self.level = value
                                self.level.value_namespace = name_space
                                self.level.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.per_area_data:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.interface_media_type.is_set or
                            self.traffic_interface.is_set or
                            (self.p2p_statistics is not None and self.p2p_statistics.has_data()))

                    def has_operation(self):
                        for c in self.per_area_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_media_type.yfilter != YFilter.not_set or
                            self.traffic_interface.yfilter != YFilter.not_set or
                            (self.p2p_statistics is not None and self.p2p_statistics.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-statistic" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_media_type.is_set or self.interface_media_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_media_type.get_name_leafdata())
                        if (self.traffic_interface.is_set or self.traffic_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_interface.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2p-statistics"):
                            if (self.p2p_statistics is None):
                                self.p2p_statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2PStatistics()
                                self.p2p_statistics.parent = self
                                self._children_name_map["p2p_statistics"] = "p2p-statistics"
                            return self.p2p_statistics

                        if (child_yang_name == "per-area-data"):
                            for c in self.per_area_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.per_area_data.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2p-statistics" or name == "per-area-data" or name == "interface-name" or name == "interface-media-type" or name == "traffic-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-media-type"):
                            self.interface_media_type = value
                            self.interface_media_type.value_namespace = name_space
                            self.interface_media_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-interface"):
                            self.traffic_interface = value
                            self.traffic_interface.value_namespace = name_space
                            self.traffic_interface.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_statistic:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_statistic:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-statistic"):
                        for c in self.interface_statistic:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_statistic.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-statistic"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Protocol(Entity):
                """
                Basic protocol information about an IS\-IS
                instance
                
                .. attribute:: active_area_address
                
                	Active area addresses
                	**type**\: list of    :py:class:`ActiveAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.ActiveAreaAddress>`
                
                .. attribute:: adj_form_count
                
                	Adj Forming count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_full_count
                
                	Adj Full count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_stagger_enabled
                
                	Adjacency Stagger Enabled
                	**type**\:  bool
                
                .. attribute:: adj_stagger_init
                
                	Adjacency Stagger Initiall Number of Forming Neighbors Allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_stagger_max
                
                	Adjacency Stagger Max Number of Forming Neighbors Allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: configured_nsf_flavor
                
                	Configured NSF type
                	**type**\:   :py:class:`IsisNsfFlavor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisNsfFlavor>`
                
                .. attribute:: instance_id
                
                	instance id
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: last_restart_nsf_flavor
                
                	NSF type of last restart
                	**type**\:   :py:class:`IsisNsfFlavor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisNsfFlavor>`
                
                .. attribute:: last_restart_status
                
                	Last restart status
                	**type**\:   :py:class:`IsisStartupStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisStartupStatus>`
                
                .. attribute:: manual_area_address
                
                	Manual area addresses
                	**type**\: list of    :py:class:`ManualAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.ManualAreaAddress>`
                
                .. attribute:: nsap_system_id
                
                	Local system ID
                	**type**\:  str
                
                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                
                .. attribute:: per_topo_data
                
                	Per\-topology data
                	**type**\: list of    :py:class:`PerTopoData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData>`
                
                .. attribute:: remaining_time_for_next_nsf_restart
                
                	Time remaining until the next NSF restart may be attempted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: running_levels
                
                	Levels running
                	**type**\:   :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                
                .. attribute:: te_connection
                
                	TE connection
                	**type**\:   :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                
                .. attribute:: valid_nsap_system_id
                
                	Indicates if system ID valid
                	**type**\:  bool
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "instance"

                    self.adj_form_count = YLeaf(YType.uint32, "adj-form-count")

                    self.adj_full_count = YLeaf(YType.uint32, "adj-full-count")

                    self.adj_stagger_enabled = YLeaf(YType.boolean, "adj-stagger-enabled")

                    self.adj_stagger_init = YLeaf(YType.uint32, "adj-stagger-init")

                    self.adj_stagger_max = YLeaf(YType.uint32, "adj-stagger-max")

                    self.configured_nsf_flavor = YLeaf(YType.enumeration, "configured-nsf-flavor")

                    self.instance_id = YLeaf(YType.uint16, "instance-id")

                    self.last_restart_nsf_flavor = YLeaf(YType.enumeration, "last-restart-nsf-flavor")

                    self.last_restart_status = YLeaf(YType.enumeration, "last-restart-status")

                    self.nsap_system_id = YLeaf(YType.str, "nsap-system-id")

                    self.remaining_time_for_next_nsf_restart = YLeaf(YType.uint32, "remaining-time-for-next-nsf-restart")

                    self.running_levels = YLeaf(YType.enumeration, "running-levels")

                    self.te_connection = YLeaf(YType.enumeration, "te-connection")

                    self.valid_nsap_system_id = YLeaf(YType.boolean, "valid-nsap-system-id")

                    self.active_area_address = YList(self)
                    self.manual_area_address = YList(self)
                    self.per_topo_data = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("adj_form_count",
                                    "adj_full_count",
                                    "adj_stagger_enabled",
                                    "adj_stagger_init",
                                    "adj_stagger_max",
                                    "configured_nsf_flavor",
                                    "instance_id",
                                    "last_restart_nsf_flavor",
                                    "last_restart_status",
                                    "nsap_system_id",
                                    "remaining_time_for_next_nsf_restart",
                                    "running_levels",
                                    "te_connection",
                                    "valid_nsap_system_id") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.Protocol, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.Protocol, self).__setattr__(name, value)


                class ManualAreaAddress(Entity):
                    """
                    Manual area addresses
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.ManualAreaAddress, self).__init__()

                        self.yang_name = "manual-area-address"
                        self.yang_parent_name = "protocol"

                        self.entry = YLeaf(YType.str, "entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Protocol.ManualAreaAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Protocol.ManualAreaAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.entry.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "manual-area-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "entry"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry"):
                            self.entry = value
                            self.entry.value_namespace = name_space
                            self.entry.value_namespace_prefix = name_space_prefix


                class ActiveAreaAddress(Entity):
                    """
                    Active area addresses
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.ActiveAreaAddress, self).__init__()

                        self.yang_name = "active-area-address"
                        self.yang_parent_name = "protocol"

                        self.entry = YLeaf(YType.str, "entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("entry") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Protocol.ActiveAreaAddress, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Protocol.ActiveAreaAddress, self).__setattr__(name, value)

                    def has_data(self):
                        return self.entry.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.entry.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "active-area-address" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.entry.is_set or self.entry.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.entry.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "entry"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "entry"):
                            self.entry = value
                            self.entry.value_namespace = name_space
                            self.entry.value_namespace_prefix = name_space_prefix


                class PerTopoData(Entity):
                    """
                    Per\-topology data
                    
                    .. attribute:: advertise_passive_only
                    
                    	Advertise passive interface prefixes only
                    	**type**\:  bool
                    
                    .. attribute:: default_admin_distance
                    
                    	Default administrative distance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: id
                    
                    	Topology ID
                    	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.Id>`
                    
                    .. attribute:: per_area_data
                    
                    	Per\-area data
                    	**type**\: list of    :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData>`
                    
                    .. attribute:: redist_protocols_list
                    
                    	List of redistributed protocols
                    	**type**\:   :py:class:`RedistProtocolsList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList>`
                    
                    .. attribute:: wait_redist_complete
                    
                    	Waiting for redist complete RIB event
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.PerTopoData, self).__init__()

                        self.yang_name = "per-topo-data"
                        self.yang_parent_name = "protocol"

                        self.advertise_passive_only = YLeaf(YType.boolean, "advertise-passive-only")

                        self.default_admin_distance = YLeaf(YType.uint32, "default-admin-distance")

                        self.wait_redist_complete = YLeaf(YType.boolean, "wait-redist-complete")

                        self.id = Isis.Instances.Instance.Protocol.PerTopoData.Id()
                        self.id.parent = self
                        self._children_name_map["id"] = "id"
                        self._children_yang_names.add("id")

                        self.redist_protocols_list = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList()
                        self.redist_protocols_list.parent = self
                        self._children_name_map["redist_protocols_list"] = "redist-protocols-list"
                        self._children_yang_names.add("redist-protocols-list")

                        self.per_area_data = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("advertise_passive_only",
                                        "default_admin_distance",
                                        "wait_redist_complete") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.Protocol.PerTopoData, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.Protocol.PerTopoData, self).__setattr__(name, value)


                    class Id(Entity):
                        """
                        Topology ID
                        
                        .. attribute:: af_name
                        
                        	AF name
                        	**type**\:   :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: saf_name
                        
                        	Sub\-AF name
                        	**type**\:   :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                        
                        .. attribute:: topology_name
                        
                        	Topology Name
                        	**type**\:  str
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.Id, self).__init__()

                            self.yang_name = "id"
                            self.yang_parent_name = "per-topo-data"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")

                            self.topology_name = YLeaf(YType.str, "topology-name")

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "saf_name",
                                            "topology_name",
                                            "vrf_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Protocol.PerTopoData.Id, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Protocol.PerTopoData.Id, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.saf_name.is_set or
                                self.topology_name.is_set or
                                self.vrf_name.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.saf_name.yfilter != YFilter.not_set or
                                self.topology_name.yfilter != YFilter.not_set or
                                self.vrf_name.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "id" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.saf_name.is_set or self.saf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.saf_name.get_name_leafdata())
                            if (self.topology_name.is_set or self.topology_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.topology_name.get_name_leafdata())
                            if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "saf-name" or name == "topology-name" or name == "vrf-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "saf-name"):
                                self.saf_name = value
                                self.saf_name.value_namespace = name_space
                                self.saf_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "topology-name"):
                                self.topology_name = value
                                self.topology_name.value_namespace = name_space
                                self.topology_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-name"):
                                self.vrf_name = value
                                self.vrf_name.value_namespace = name_space
                                self.vrf_name.value_namespace_prefix = name_space_prefix


                    class RedistProtocolsList(Entity):
                        """
                        List of redistributed protocols
                        
                        .. attribute:: isis_sh_redist_entry
                        
                        	isis sh redist entry
                        	**type**\: list of    :py:class:`IsisShRedistEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList, self).__init__()

                            self.yang_name = "redist-protocols-list"
                            self.yang_parent_name = "per-topo-data"

                            self.isis_sh_redist_entry = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList, self).__setattr__(name, value)


                        class IsisShRedistEntry(Entity):
                            """
                            isis sh redist entry
                            
                            .. attribute:: protocol_details
                            
                            	Relevant details of the redistributed protocol
                            	**type**\:   :py:class:`ProtocolDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry, self).__init__()

                                self.yang_name = "isis-sh-redist-entry"
                                self.yang_parent_name = "redist-protocols-list"

                                self.protocol_details = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails()
                                self.protocol_details.parent = self
                                self._children_name_map["protocol_details"] = "protocol-details"
                                self._children_yang_names.add("protocol-details")


                            class ProtocolDetails(Entity):
                                """
                                Relevant details of the redistributed protocol
                                
                                .. attribute:: application_name
                                
                                	Application Name
                                	**type**\:  str
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System number
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	EIGRP Autonomous System number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	IS\-IS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: ospfv3_process_id
                                
                                	OSPFv3 process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails, self).__init__()

                                    self.yang_name = "protocol-details"
                                    self.yang_parent_name = "isis-sh-redist-entry"

                                    self.application_name = YLeaf(YType.str, "application-name")

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.ospfv3_process_id = YLeaf(YType.str, "ospfv3-process-id")

                                    self.protocol = YLeaf(YType.enumeration, "protocol")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("application_name",
                                                    "bgp_as_number",
                                                    "eigrp_as_number",
                                                    "isis_instance_id",
                                                    "ospf_process_id",
                                                    "ospfv3_process_id",
                                                    "protocol") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.application_name.is_set or
                                        self.bgp_as_number.is_set or
                                        self.eigrp_as_number.is_set or
                                        self.isis_instance_id.is_set or
                                        self.ospf_process_id.is_set or
                                        self.ospfv3_process_id.is_set or
                                        self.protocol.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.application_name.yfilter != YFilter.not_set or
                                        self.bgp_as_number.yfilter != YFilter.not_set or
                                        self.eigrp_as_number.yfilter != YFilter.not_set or
                                        self.isis_instance_id.yfilter != YFilter.not_set or
                                        self.ospf_process_id.yfilter != YFilter.not_set or
                                        self.ospfv3_process_id.yfilter != YFilter.not_set or
                                        self.protocol.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "protocol-details" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.application_name.is_set or self.application_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.application_name.get_name_leafdata())
                                    if (self.bgp_as_number.is_set or self.bgp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.bgp_as_number.get_name_leafdata())
                                    if (self.eigrp_as_number.is_set or self.eigrp_as_number.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.eigrp_as_number.get_name_leafdata())
                                    if (self.isis_instance_id.is_set or self.isis_instance_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.isis_instance_id.get_name_leafdata())
                                    if (self.ospf_process_id.is_set or self.ospf_process_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospf_process_id.get_name_leafdata())
                                    if (self.ospfv3_process_id.is_set or self.ospfv3_process_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ospfv3_process_id.get_name_leafdata())
                                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.protocol.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "application-name" or name == "bgp-as-number" or name == "eigrp-as-number" or name == "isis-instance-id" or name == "ospf-process-id" or name == "ospfv3-process-id" or name == "protocol"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "application-name"):
                                        self.application_name = value
                                        self.application_name.value_namespace = name_space
                                        self.application_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "bgp-as-number"):
                                        self.bgp_as_number = value
                                        self.bgp_as_number.value_namespace = name_space
                                        self.bgp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "eigrp-as-number"):
                                        self.eigrp_as_number = value
                                        self.eigrp_as_number.value_namespace = name_space
                                        self.eigrp_as_number.value_namespace_prefix = name_space_prefix
                                    if(value_path == "isis-instance-id"):
                                        self.isis_instance_id = value
                                        self.isis_instance_id.value_namespace = name_space
                                        self.isis_instance_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospf-process-id"):
                                        self.ospf_process_id = value
                                        self.ospf_process_id.value_namespace = name_space
                                        self.ospf_process_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ospfv3-process-id"):
                                        self.ospfv3_process_id = value
                                        self.ospfv3_process_id.value_namespace = name_space
                                        self.ospfv3_process_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "protocol"):
                                        self.protocol = value
                                        self.protocol.value_namespace = name_space
                                        self.protocol.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (self.protocol_details is not None and self.protocol_details.has_data())

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    (self.protocol_details is not None and self.protocol_details.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "isis-sh-redist-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "protocol-details"):
                                    if (self.protocol_details is None):
                                        self.protocol_details = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails()
                                        self.protocol_details.parent = self
                                        self._children_name_map["protocol_details"] = "protocol-details"
                                    return self.protocol_details

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "protocol-details"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                pass

                        def has_data(self):
                            for c in self.isis_sh_redist_entry:
                                if (c.has_data()):
                                    return True
                            return False

                        def has_operation(self):
                            for c in self.isis_sh_redist_entry:
                                if (c.has_operation()):
                                    return True
                            return self.yfilter != YFilter.not_set

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "redist-protocols-list" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "isis-sh-redist-entry"):
                                for c in self.isis_sh_redist_entry:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.isis_sh_redist_entry.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "isis-sh-redist-entry"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class PerAreaData(Entity):
                        """
                        Per\-area data
                        
                        .. attribute:: accepted_metric_style
                        
                        	Accept metric style
                        	**type**\:   :py:class:`IsisMetricStyle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricStyle>`
                        
                        .. attribute:: duration
                        
                        	SR microloop avoidance duration
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: generated_metric_style
                        
                        	Generate metric style
                        	**type**\:   :py:class:`IsisMetricStyle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricStyle>`
                        
                        .. attribute:: ispf_state
                        
                        	ISPF state
                        	**type**\:   :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                        
                        .. attribute:: level
                        
                        	The level this data refers to
                        	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rib_update_delay
                        
                        	Microloop RIB update delay
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_uloop_event
                        
                        	SR microloop avoidance event
                        	**type**\:   :py:class:`IsisUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUloopEvent>`
                        
                        .. attribute:: sr_uloop_far_node_id
                        
                        	SR microloop far node
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                        
                        .. attribute:: sr_uloop_is_active
                        
                        	Explicit paths installed in the RIB
                        	**type**\:  bool
                        
                        .. attribute:: sr_uloop_near_node_id
                        
                        	SR microloop near node
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                        
                        .. attribute:: te_enabled
                        
                        	Indicates whether MPLS TE is enabled
                        	**type**\:  bool
                        
                        .. attribute:: uloop_avoidance_type
                        
                        	Microloop avoidance type
                        	**type**\:   :py:class:`IsisUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUloopAvoidance>`
                        
                        .. attribute:: uses_default_link_topo_flag
                        
                        	Does this topology use the default link topology
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData, self).__init__()

                            self.yang_name = "per-area-data"
                            self.yang_parent_name = "per-topo-data"

                            self.accepted_metric_style = YLeaf(YType.enumeration, "accepted-metric-style")

                            self.duration = YLeaf(YType.uint32, "duration")

                            self.generated_metric_style = YLeaf(YType.enumeration, "generated-metric-style")

                            self.ispf_state = YLeaf(YType.enumeration, "ispf-state")

                            self.level = YLeaf(YType.enumeration, "level")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.rib_update_delay = YLeaf(YType.uint32, "rib-update-delay")

                            self.sr_uloop_event = YLeaf(YType.enumeration, "sr-uloop-event")

                            self.sr_uloop_far_node_id = YLeaf(YType.str, "sr-uloop-far-node-id")

                            self.sr_uloop_is_active = YLeaf(YType.boolean, "sr-uloop-is-active")

                            self.sr_uloop_near_node_id = YLeaf(YType.str, "sr-uloop-near-node-id")

                            self.te_enabled = YLeaf(YType.boolean, "te-enabled")

                            self.uloop_avoidance_type = YLeaf(YType.enumeration, "uloop-avoidance-type")

                            self.uses_default_link_topo_flag = YLeaf(YType.boolean, "uses-default-link-topo-flag")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("accepted_metric_style",
                                            "duration",
                                            "generated_metric_style",
                                            "ispf_state",
                                            "level",
                                            "metric",
                                            "rib_update_delay",
                                            "sr_uloop_event",
                                            "sr_uloop_far_node_id",
                                            "sr_uloop_is_active",
                                            "sr_uloop_near_node_id",
                                            "te_enabled",
                                            "uloop_avoidance_type",
                                            "uses_default_link_topo_flag") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.accepted_metric_style.is_set or
                                self.duration.is_set or
                                self.generated_metric_style.is_set or
                                self.ispf_state.is_set or
                                self.level.is_set or
                                self.metric.is_set or
                                self.rib_update_delay.is_set or
                                self.sr_uloop_event.is_set or
                                self.sr_uloop_far_node_id.is_set or
                                self.sr_uloop_is_active.is_set or
                                self.sr_uloop_near_node_id.is_set or
                                self.te_enabled.is_set or
                                self.uloop_avoidance_type.is_set or
                                self.uses_default_link_topo_flag.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.accepted_metric_style.yfilter != YFilter.not_set or
                                self.duration.yfilter != YFilter.not_set or
                                self.generated_metric_style.yfilter != YFilter.not_set or
                                self.ispf_state.yfilter != YFilter.not_set or
                                self.level.yfilter != YFilter.not_set or
                                self.metric.yfilter != YFilter.not_set or
                                self.rib_update_delay.yfilter != YFilter.not_set or
                                self.sr_uloop_event.yfilter != YFilter.not_set or
                                self.sr_uloop_far_node_id.yfilter != YFilter.not_set or
                                self.sr_uloop_is_active.yfilter != YFilter.not_set or
                                self.sr_uloop_near_node_id.yfilter != YFilter.not_set or
                                self.te_enabled.yfilter != YFilter.not_set or
                                self.uloop_avoidance_type.yfilter != YFilter.not_set or
                                self.uses_default_link_topo_flag.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "per-area-data" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.accepted_metric_style.is_set or self.accepted_metric_style.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.accepted_metric_style.get_name_leafdata())
                            if (self.duration.is_set or self.duration.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.duration.get_name_leafdata())
                            if (self.generated_metric_style.is_set or self.generated_metric_style.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generated_metric_style.get_name_leafdata())
                            if (self.ispf_state.is_set or self.ispf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ispf_state.get_name_leafdata())
                            if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.level.get_name_leafdata())
                            if (self.metric.is_set or self.metric.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.metric.get_name_leafdata())
                            if (self.rib_update_delay.is_set or self.rib_update_delay.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rib_update_delay.get_name_leafdata())
                            if (self.sr_uloop_event.is_set or self.sr_uloop_event.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_uloop_event.get_name_leafdata())
                            if (self.sr_uloop_far_node_id.is_set or self.sr_uloop_far_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_uloop_far_node_id.get_name_leafdata())
                            if (self.sr_uloop_is_active.is_set or self.sr_uloop_is_active.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_uloop_is_active.get_name_leafdata())
                            if (self.sr_uloop_near_node_id.is_set or self.sr_uloop_near_node_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sr_uloop_near_node_id.get_name_leafdata())
                            if (self.te_enabled.is_set or self.te_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.te_enabled.get_name_leafdata())
                            if (self.uloop_avoidance_type.is_set or self.uloop_avoidance_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uloop_avoidance_type.get_name_leafdata())
                            if (self.uses_default_link_topo_flag.is_set or self.uses_default_link_topo_flag.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uses_default_link_topo_flag.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "accepted-metric-style" or name == "duration" or name == "generated-metric-style" or name == "ispf-state" or name == "level" or name == "metric" or name == "rib-update-delay" or name == "sr-uloop-event" or name == "sr-uloop-far-node-id" or name == "sr-uloop-is-active" or name == "sr-uloop-near-node-id" or name == "te-enabled" or name == "uloop-avoidance-type" or name == "uses-default-link-topo-flag"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "accepted-metric-style"):
                                self.accepted_metric_style = value
                                self.accepted_metric_style.value_namespace = name_space
                                self.accepted_metric_style.value_namespace_prefix = name_space_prefix
                            if(value_path == "duration"):
                                self.duration = value
                                self.duration.value_namespace = name_space
                                self.duration.value_namespace_prefix = name_space_prefix
                            if(value_path == "generated-metric-style"):
                                self.generated_metric_style = value
                                self.generated_metric_style.value_namespace = name_space
                                self.generated_metric_style.value_namespace_prefix = name_space_prefix
                            if(value_path == "ispf-state"):
                                self.ispf_state = value
                                self.ispf_state.value_namespace = name_space
                                self.ispf_state.value_namespace_prefix = name_space_prefix
                            if(value_path == "level"):
                                self.level = value
                                self.level.value_namespace = name_space
                                self.level.value_namespace_prefix = name_space_prefix
                            if(value_path == "metric"):
                                self.metric = value
                                self.metric.value_namespace = name_space
                                self.metric.value_namespace_prefix = name_space_prefix
                            if(value_path == "rib-update-delay"):
                                self.rib_update_delay = value
                                self.rib_update_delay.value_namespace = name_space
                                self.rib_update_delay.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-uloop-event"):
                                self.sr_uloop_event = value
                                self.sr_uloop_event.value_namespace = name_space
                                self.sr_uloop_event.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-uloop-far-node-id"):
                                self.sr_uloop_far_node_id = value
                                self.sr_uloop_far_node_id.value_namespace = name_space
                                self.sr_uloop_far_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-uloop-is-active"):
                                self.sr_uloop_is_active = value
                                self.sr_uloop_is_active.value_namespace = name_space
                                self.sr_uloop_is_active.value_namespace_prefix = name_space_prefix
                            if(value_path == "sr-uloop-near-node-id"):
                                self.sr_uloop_near_node_id = value
                                self.sr_uloop_near_node_id.value_namespace = name_space
                                self.sr_uloop_near_node_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "te-enabled"):
                                self.te_enabled = value
                                self.te_enabled.value_namespace = name_space
                                self.te_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "uloop-avoidance-type"):
                                self.uloop_avoidance_type = value
                                self.uloop_avoidance_type.value_namespace = name_space
                                self.uloop_avoidance_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "uses-default-link-topo-flag"):
                                self.uses_default_link_topo_flag = value
                                self.uses_default_link_topo_flag.value_namespace = name_space
                                self.uses_default_link_topo_flag.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.per_area_data:
                            if (c.has_data()):
                                return True
                        return (
                            self.advertise_passive_only.is_set or
                            self.default_admin_distance.is_set or
                            self.wait_redist_complete.is_set or
                            (self.id is not None and self.id.has_data()) or
                            (self.redist_protocols_list is not None and self.redist_protocols_list.has_data()))

                    def has_operation(self):
                        for c in self.per_area_data:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.advertise_passive_only.yfilter != YFilter.not_set or
                            self.default_admin_distance.yfilter != YFilter.not_set or
                            self.wait_redist_complete.yfilter != YFilter.not_set or
                            (self.id is not None and self.id.has_operation()) or
                            (self.redist_protocols_list is not None and self.redist_protocols_list.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "per-topo-data" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.advertise_passive_only.is_set or self.advertise_passive_only.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.advertise_passive_only.get_name_leafdata())
                        if (self.default_admin_distance.is_set or self.default_admin_distance.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.default_admin_distance.get_name_leafdata())
                        if (self.wait_redist_complete.is_set or self.wait_redist_complete.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.wait_redist_complete.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "id"):
                            if (self.id is None):
                                self.id = Isis.Instances.Instance.Protocol.PerTopoData.Id()
                                self.id.parent = self
                                self._children_name_map["id"] = "id"
                            return self.id

                        if (child_yang_name == "per-area-data"):
                            for c in self.per_area_data:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.per_area_data.append(c)
                            return c

                        if (child_yang_name == "redist-protocols-list"):
                            if (self.redist_protocols_list is None):
                                self.redist_protocols_list = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList()
                                self.redist_protocols_list.parent = self
                                self._children_name_map["redist_protocols_list"] = "redist-protocols-list"
                            return self.redist_protocols_list

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "id" or name == "per-area-data" or name == "redist-protocols-list" or name == "advertise-passive-only" or name == "default-admin-distance" or name == "wait-redist-complete"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "advertise-passive-only"):
                            self.advertise_passive_only = value
                            self.advertise_passive_only.value_namespace = name_space
                            self.advertise_passive_only.value_namespace_prefix = name_space_prefix
                        if(value_path == "default-admin-distance"):
                            self.default_admin_distance = value
                            self.default_admin_distance.value_namespace = name_space
                            self.default_admin_distance.value_namespace_prefix = name_space_prefix
                        if(value_path == "wait-redist-complete"):
                            self.wait_redist_complete = value
                            self.wait_redist_complete.value_namespace = name_space
                            self.wait_redist_complete.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.active_area_address:
                        if (c.has_data()):
                            return True
                    for c in self.manual_area_address:
                        if (c.has_data()):
                            return True
                    for c in self.per_topo_data:
                        if (c.has_data()):
                            return True
                    return (
                        self.adj_form_count.is_set or
                        self.adj_full_count.is_set or
                        self.adj_stagger_enabled.is_set or
                        self.adj_stagger_init.is_set or
                        self.adj_stagger_max.is_set or
                        self.configured_nsf_flavor.is_set or
                        self.instance_id.is_set or
                        self.last_restart_nsf_flavor.is_set or
                        self.last_restart_status.is_set or
                        self.nsap_system_id.is_set or
                        self.remaining_time_for_next_nsf_restart.is_set or
                        self.running_levels.is_set or
                        self.te_connection.is_set or
                        self.valid_nsap_system_id.is_set)

                def has_operation(self):
                    for c in self.active_area_address:
                        if (c.has_operation()):
                            return True
                    for c in self.manual_area_address:
                        if (c.has_operation()):
                            return True
                    for c in self.per_topo_data:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.adj_form_count.yfilter != YFilter.not_set or
                        self.adj_full_count.yfilter != YFilter.not_set or
                        self.adj_stagger_enabled.yfilter != YFilter.not_set or
                        self.adj_stagger_init.yfilter != YFilter.not_set or
                        self.adj_stagger_max.yfilter != YFilter.not_set or
                        self.configured_nsf_flavor.yfilter != YFilter.not_set or
                        self.instance_id.yfilter != YFilter.not_set or
                        self.last_restart_nsf_flavor.yfilter != YFilter.not_set or
                        self.last_restart_status.yfilter != YFilter.not_set or
                        self.nsap_system_id.yfilter != YFilter.not_set or
                        self.remaining_time_for_next_nsf_restart.yfilter != YFilter.not_set or
                        self.running_levels.yfilter != YFilter.not_set or
                        self.te_connection.yfilter != YFilter.not_set or
                        self.valid_nsap_system_id.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "protocol" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.adj_form_count.is_set or self.adj_form_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adj_form_count.get_name_leafdata())
                    if (self.adj_full_count.is_set or self.adj_full_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adj_full_count.get_name_leafdata())
                    if (self.adj_stagger_enabled.is_set or self.adj_stagger_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adj_stagger_enabled.get_name_leafdata())
                    if (self.adj_stagger_init.is_set or self.adj_stagger_init.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adj_stagger_init.get_name_leafdata())
                    if (self.adj_stagger_max.is_set or self.adj_stagger_max.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.adj_stagger_max.get_name_leafdata())
                    if (self.configured_nsf_flavor.is_set or self.configured_nsf_flavor.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configured_nsf_flavor.get_name_leafdata())
                    if (self.instance_id.is_set or self.instance_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.instance_id.get_name_leafdata())
                    if (self.last_restart_nsf_flavor.is_set or self.last_restart_nsf_flavor.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_restart_nsf_flavor.get_name_leafdata())
                    if (self.last_restart_status.is_set or self.last_restart_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_restart_status.get_name_leafdata())
                    if (self.nsap_system_id.is_set or self.nsap_system_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nsap_system_id.get_name_leafdata())
                    if (self.remaining_time_for_next_nsf_restart.is_set or self.remaining_time_for_next_nsf_restart.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.remaining_time_for_next_nsf_restart.get_name_leafdata())
                    if (self.running_levels.is_set or self.running_levels.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.running_levels.get_name_leafdata())
                    if (self.te_connection.is_set or self.te_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.te_connection.get_name_leafdata())
                    if (self.valid_nsap_system_id.is_set or self.valid_nsap_system_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.valid_nsap_system_id.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "active-area-address"):
                        for c in self.active_area_address:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Protocol.ActiveAreaAddress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.active_area_address.append(c)
                        return c

                    if (child_yang_name == "manual-area-address"):
                        for c in self.manual_area_address:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Protocol.ManualAreaAddress()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.manual_area_address.append(c)
                        return c

                    if (child_yang_name == "per-topo-data"):
                        for c in self.per_topo_data:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.Protocol.PerTopoData()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.per_topo_data.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "active-area-address" or name == "manual-area-address" or name == "per-topo-data" or name == "adj-form-count" or name == "adj-full-count" or name == "adj-stagger-enabled" or name == "adj-stagger-init" or name == "adj-stagger-max" or name == "configured-nsf-flavor" or name == "instance-id" or name == "last-restart-nsf-flavor" or name == "last-restart-status" or name == "nsap-system-id" or name == "remaining-time-for-next-nsf-restart" or name == "running-levels" or name == "te-connection" or name == "valid-nsap-system-id"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "adj-form-count"):
                        self.adj_form_count = value
                        self.adj_form_count.value_namespace = name_space
                        self.adj_form_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "adj-full-count"):
                        self.adj_full_count = value
                        self.adj_full_count.value_namespace = name_space
                        self.adj_full_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "adj-stagger-enabled"):
                        self.adj_stagger_enabled = value
                        self.adj_stagger_enabled.value_namespace = name_space
                        self.adj_stagger_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "adj-stagger-init"):
                        self.adj_stagger_init = value
                        self.adj_stagger_init.value_namespace = name_space
                        self.adj_stagger_init.value_namespace_prefix = name_space_prefix
                    if(value_path == "adj-stagger-max"):
                        self.adj_stagger_max = value
                        self.adj_stagger_max.value_namespace = name_space
                        self.adj_stagger_max.value_namespace_prefix = name_space_prefix
                    if(value_path == "configured-nsf-flavor"):
                        self.configured_nsf_flavor = value
                        self.configured_nsf_flavor.value_namespace = name_space
                        self.configured_nsf_flavor.value_namespace_prefix = name_space_prefix
                    if(value_path == "instance-id"):
                        self.instance_id = value
                        self.instance_id.value_namespace = name_space
                        self.instance_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-restart-nsf-flavor"):
                        self.last_restart_nsf_flavor = value
                        self.last_restart_nsf_flavor.value_namespace = name_space
                        self.last_restart_nsf_flavor.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-restart-status"):
                        self.last_restart_status = value
                        self.last_restart_status.value_namespace = name_space
                        self.last_restart_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "nsap-system-id"):
                        self.nsap_system_id = value
                        self.nsap_system_id.value_namespace = name_space
                        self.nsap_system_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "remaining-time-for-next-nsf-restart"):
                        self.remaining_time_for_next_nsf_restart = value
                        self.remaining_time_for_next_nsf_restart.value_namespace = name_space
                        self.remaining_time_for_next_nsf_restart.value_namespace_prefix = name_space_prefix
                    if(value_path == "running-levels"):
                        self.running_levels = value
                        self.running_levels.value_namespace = name_space
                        self.running_levels.value_namespace_prefix = name_space_prefix
                    if(value_path == "te-connection"):
                        self.te_connection = value
                        self.te_connection.value_namespace = name_space
                        self.te_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "valid-nsap-system-id"):
                        self.valid_nsap_system_id = value
                        self.valid_nsap_system_id.value_namespace = name_space
                        self.valid_nsap_system_id.value_namespace_prefix = name_space_prefix


            class NeighborSummaries(Entity):
                """
                Neighbor\-summary table
                
                .. attribute:: neighbor_summary
                
                	Neighbor\-summary data for a single interface
                	**type**\: list of    :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "instance"

                    self.neighbor_summary = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.NeighborSummaries, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.NeighborSummaries, self).__setattr__(name, value)


                class NeighborSummary(Entity):
                    """
                    Neighbor\-summary data for a single interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: level12_neigbors
                    
                    	L12 neighbors
                    	**type**\:   :py:class:`Level12Neigbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors>`
                    
                    .. attribute:: level1_neighbors
                    
                    	L1\-only neighbors
                    	**type**\:   :py:class:`Level1Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors>`
                    
                    .. attribute:: level2_neighbors
                    
                    	L2\-only neighbors
                    	**type**\:   :py:class:`Level2Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.level12_neigbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors()
                        self.level12_neigbors.parent = self
                        self._children_name_map["level12_neigbors"] = "level12-neigbors"
                        self._children_yang_names.add("level12-neigbors")

                        self.level1_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors()
                        self.level1_neighbors.parent = self
                        self._children_name_map["level1_neighbors"] = "level1-neighbors"
                        self._children_yang_names.add("level1-neighbors")

                        self.level2_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors()
                        self.level2_neighbors.parent = self
                        self._children_name_map["level2_neighbors"] = "level2-neighbors"
                        self._children_yang_names.add("level2-neighbors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary, self).__setattr__(name, value)


                    class Level1Neighbors(Entity):
                        """
                        L1\-only neighbors
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors, self).__init__()

                            self.yang_name = "level1-neighbors"
                            self.yang_parent_name = "neighbor-summary"

                            self.neighbor_down_count = YLeaf(YType.uint32, "neighbor-down-count")

                            self.neighbor_init_count = YLeaf(YType.uint32, "neighbor-init-count")

                            self.neighbor_up_count = YLeaf(YType.uint32, "neighbor-up-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("neighbor_down_count",
                                            "neighbor_init_count",
                                            "neighbor_up_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.neighbor_down_count.is_set or
                                self.neighbor_init_count.is_set or
                                self.neighbor_up_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.neighbor_down_count.yfilter != YFilter.not_set or
                                self.neighbor_init_count.yfilter != YFilter.not_set or
                                self.neighbor_up_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "level1-neighbors" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.neighbor_down_count.is_set or self.neighbor_down_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_down_count.get_name_leafdata())
                            if (self.neighbor_init_count.is_set or self.neighbor_init_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_init_count.get_name_leafdata())
                            if (self.neighbor_up_count.is_set or self.neighbor_up_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_up_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-down-count" or name == "neighbor-init-count" or name == "neighbor-up-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "neighbor-down-count"):
                                self.neighbor_down_count = value
                                self.neighbor_down_count.value_namespace = name_space
                                self.neighbor_down_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-init-count"):
                                self.neighbor_init_count = value
                                self.neighbor_init_count.value_namespace = name_space
                                self.neighbor_init_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-up-count"):
                                self.neighbor_up_count = value
                                self.neighbor_up_count.value_namespace = name_space
                                self.neighbor_up_count.value_namespace_prefix = name_space_prefix


                    class Level2Neighbors(Entity):
                        """
                        L2\-only neighbors
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors, self).__init__()

                            self.yang_name = "level2-neighbors"
                            self.yang_parent_name = "neighbor-summary"

                            self.neighbor_down_count = YLeaf(YType.uint32, "neighbor-down-count")

                            self.neighbor_init_count = YLeaf(YType.uint32, "neighbor-init-count")

                            self.neighbor_up_count = YLeaf(YType.uint32, "neighbor-up-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("neighbor_down_count",
                                            "neighbor_init_count",
                                            "neighbor_up_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.neighbor_down_count.is_set or
                                self.neighbor_init_count.is_set or
                                self.neighbor_up_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.neighbor_down_count.yfilter != YFilter.not_set or
                                self.neighbor_init_count.yfilter != YFilter.not_set or
                                self.neighbor_up_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "level2-neighbors" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.neighbor_down_count.is_set or self.neighbor_down_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_down_count.get_name_leafdata())
                            if (self.neighbor_init_count.is_set or self.neighbor_init_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_init_count.get_name_leafdata())
                            if (self.neighbor_up_count.is_set or self.neighbor_up_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_up_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-down-count" or name == "neighbor-init-count" or name == "neighbor-up-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "neighbor-down-count"):
                                self.neighbor_down_count = value
                                self.neighbor_down_count.value_namespace = name_space
                                self.neighbor_down_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-init-count"):
                                self.neighbor_init_count = value
                                self.neighbor_init_count.value_namespace = name_space
                                self.neighbor_init_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-up-count"):
                                self.neighbor_up_count = value
                                self.neighbor_up_count.value_namespace = name_space
                                self.neighbor_up_count.value_namespace_prefix = name_space_prefix


                    class Level12Neigbors(Entity):
                        """
                        L12 neighbors
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors, self).__init__()

                            self.yang_name = "level12-neigbors"
                            self.yang_parent_name = "neighbor-summary"

                            self.neighbor_down_count = YLeaf(YType.uint32, "neighbor-down-count")

                            self.neighbor_init_count = YLeaf(YType.uint32, "neighbor-init-count")

                            self.neighbor_up_count = YLeaf(YType.uint32, "neighbor-up-count")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("neighbor_down_count",
                                            "neighbor_init_count",
                                            "neighbor_up_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.neighbor_down_count.is_set or
                                self.neighbor_init_count.is_set or
                                self.neighbor_up_count.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.neighbor_down_count.yfilter != YFilter.not_set or
                                self.neighbor_init_count.yfilter != YFilter.not_set or
                                self.neighbor_up_count.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "level12-neigbors" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.neighbor_down_count.is_set or self.neighbor_down_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_down_count.get_name_leafdata())
                            if (self.neighbor_init_count.is_set or self.neighbor_init_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_init_count.get_name_leafdata())
                            if (self.neighbor_up_count.is_set or self.neighbor_up_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.neighbor_up_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "neighbor-down-count" or name == "neighbor-init-count" or name == "neighbor-up-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "neighbor-down-count"):
                                self.neighbor_down_count = value
                                self.neighbor_down_count.value_namespace = name_space
                                self.neighbor_down_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-init-count"):
                                self.neighbor_init_count = value
                                self.neighbor_init_count.value_namespace = name_space
                                self.neighbor_init_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "neighbor-up-count"):
                                self.neighbor_up_count = value
                                self.neighbor_up_count.value_namespace = name_space
                                self.neighbor_up_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            (self.level12_neigbors is not None and self.level12_neigbors.has_data()) or
                            (self.level1_neighbors is not None and self.level1_neighbors.has_data()) or
                            (self.level2_neighbors is not None and self.level2_neighbors.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            (self.level12_neigbors is not None and self.level12_neigbors.has_operation()) or
                            (self.level1_neighbors is not None and self.level1_neighbors.has_operation()) or
                            (self.level2_neighbors is not None and self.level2_neighbors.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "level12-neigbors"):
                            if (self.level12_neigbors is None):
                                self.level12_neigbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors()
                                self.level12_neigbors.parent = self
                                self._children_name_map["level12_neigbors"] = "level12-neigbors"
                            return self.level12_neigbors

                        if (child_yang_name == "level1-neighbors"):
                            if (self.level1_neighbors is None):
                                self.level1_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors()
                                self.level1_neighbors.parent = self
                                self._children_name_map["level1_neighbors"] = "level1-neighbors"
                            return self.level1_neighbors

                        if (child_yang_name == "level2-neighbors"):
                            if (self.level2_neighbors is None):
                                self.level2_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors()
                                self.level2_neighbors.parent = self
                                self._children_name_map["level2_neighbors"] = "level2-neighbors"
                            return self.level2_neighbors

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "level12-neigbors" or name == "level1-neighbors" or name == "level2-neighbors" or name == "interface-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_summary:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.neighbor_summary:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-summaries" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "neighbor-summary"):
                        for c in self.neighbor_summary:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.NeighborSummaries.NeighborSummary()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_summary.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class CheckpointLsps(Entity):
                """
                Checkpointed LSP table
                
                .. attribute:: checkpoint_lsp
                
                	A checkpointed IS\-IS LSP
                	**type**\: list of    :py:class:`CheckpointLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointLsps.CheckpointLsp>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointLsps, self).__init__()

                    self.yang_name = "checkpoint-lsps"
                    self.yang_parent_name = "instance"

                    self.checkpoint_lsp = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.CheckpointLsps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.CheckpointLsps, self).__setattr__(name, value)


                class CheckpointLsp(Entity):
                    """
                    A checkpointed IS\-IS LSP
                    
                    .. attribute:: checkpoint_lsp_id
                    
                    	LSP ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                    
                    .. attribute:: checkpoint_lsp_level
                    
                    	LSP level
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_lsp_local_flag
                    
                    	TRUE if this is a local LSP
                    	**type**\:  bool
                    
                    .. attribute:: checkpoint_lsp_object_id
                    
                    	LSP Checkpoint table object ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:   :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: lsp_id
                    
                    	LSP ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointLsps.CheckpointLsp, self).__init__()

                        self.yang_name = "checkpoint-lsp"
                        self.yang_parent_name = "checkpoint-lsps"

                        self.checkpoint_lsp_id = YLeaf(YType.str, "checkpoint-lsp-id")

                        self.checkpoint_lsp_level = YLeaf(YType.uint8, "checkpoint-lsp-level")

                        self.checkpoint_lsp_local_flag = YLeaf(YType.boolean, "checkpoint-lsp-local-flag")

                        self.checkpoint_lsp_object_id = YLeaf(YType.uint32, "checkpoint-lsp-object-id")

                        self.level = YLeaf(YType.enumeration, "level")

                        self.lsp_id = YLeaf(YType.str, "lsp-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("checkpoint_lsp_id",
                                        "checkpoint_lsp_level",
                                        "checkpoint_lsp_local_flag",
                                        "checkpoint_lsp_object_id",
                                        "level",
                                        "lsp_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.CheckpointLsps.CheckpointLsp, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.CheckpointLsps.CheckpointLsp, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.checkpoint_lsp_id.is_set or
                            self.checkpoint_lsp_level.is_set or
                            self.checkpoint_lsp_local_flag.is_set or
                            self.checkpoint_lsp_object_id.is_set or
                            self.level.is_set or
                            self.lsp_id.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.checkpoint_lsp_id.yfilter != YFilter.not_set or
                            self.checkpoint_lsp_level.yfilter != YFilter.not_set or
                            self.checkpoint_lsp_local_flag.yfilter != YFilter.not_set or
                            self.checkpoint_lsp_object_id.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set or
                            self.lsp_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-lsp" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.checkpoint_lsp_id.is_set or self.checkpoint_lsp_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_lsp_id.get_name_leafdata())
                        if (self.checkpoint_lsp_level.is_set or self.checkpoint_lsp_level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_lsp_level.get_name_leafdata())
                        if (self.checkpoint_lsp_local_flag.is_set or self.checkpoint_lsp_local_flag.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_lsp_local_flag.get_name_leafdata())
                        if (self.checkpoint_lsp_object_id.is_set or self.checkpoint_lsp_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_lsp_object_id.get_name_leafdata())
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())
                        if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "checkpoint-lsp-id" or name == "checkpoint-lsp-level" or name == "checkpoint-lsp-local-flag" or name == "checkpoint-lsp-object-id" or name == "level" or name == "lsp-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "checkpoint-lsp-id"):
                            self.checkpoint_lsp_id = value
                            self.checkpoint_lsp_id.value_namespace = name_space
                            self.checkpoint_lsp_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-lsp-level"):
                            self.checkpoint_lsp_level = value
                            self.checkpoint_lsp_level.value_namespace = name_space
                            self.checkpoint_lsp_level.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-lsp-local-flag"):
                            self.checkpoint_lsp_local_flag = value
                            self.checkpoint_lsp_local_flag.value_namespace = name_space
                            self.checkpoint_lsp_local_flag.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-lsp-object-id"):
                            self.checkpoint_lsp_object_id = value
                            self.checkpoint_lsp_object_id.value_namespace = name_space
                            self.checkpoint_lsp_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-id"):
                            self.lsp_id = value
                            self.lsp_id.value_namespace = name_space
                            self.lsp_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_lsp:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_lsp:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-lsps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-lsp"):
                        for c in self.checkpoint_lsp:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.CheckpointLsps.CheckpointLsp()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_lsp.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-lsp"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class MeshGroups(Entity):
                """
                Mesh\-group information
                
                .. attribute:: mesh_group_configured_interface_list
                
                	List of mesh\-group\-configured interfaces
                	**type**\:   :py:class:`MeshGroupConfiguredInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.MeshGroups, self).__init__()

                    self.yang_name = "mesh-groups"
                    self.yang_parent_name = "instance"

                    self.mesh_group_configured_interface_list = Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList()
                    self.mesh_group_configured_interface_list.parent = self
                    self._children_name_map["mesh_group_configured_interface_list"] = "mesh-group-configured-interface-list"
                    self._children_yang_names.add("mesh-group-configured-interface-list")


                class MeshGroupConfiguredInterfaceList(Entity):
                    """
                    List of mesh\-group\-configured interfaces
                    
                    .. attribute:: isis_sh_mesh_entry
                    
                    	isis sh mesh entry
                    	**type**\: list of    :py:class:`IsisShMeshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList, self).__init__()

                        self.yang_name = "mesh-group-configured-interface-list"
                        self.yang_parent_name = "mesh-groups"

                        self.isis_sh_mesh_entry = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList, self).__setattr__(name, value)


                    class IsisShMeshEntry(Entity):
                        """
                        isis sh mesh entry
                        
                        .. attribute:: mesh_group_interface
                        
                        	This interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mesh_group_number
                        
                        	Mesh\-group number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry, self).__init__()

                            self.yang_name = "isis-sh-mesh-entry"
                            self.yang_parent_name = "mesh-group-configured-interface-list"

                            self.mesh_group_interface = YLeaf(YType.str, "mesh-group-interface")

                            self.mesh_group_number = YLeaf(YType.uint32, "mesh-group-number")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("mesh_group_interface",
                                            "mesh_group_number") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.mesh_group_interface.is_set or
                                self.mesh_group_number.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.mesh_group_interface.yfilter != YFilter.not_set or
                                self.mesh_group_number.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "isis-sh-mesh-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.mesh_group_interface.is_set or self.mesh_group_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mesh_group_interface.get_name_leafdata())
                            if (self.mesh_group_number.is_set or self.mesh_group_number.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mesh_group_number.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "mesh-group-interface" or name == "mesh-group-number"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "mesh-group-interface"):
                                self.mesh_group_interface = value
                                self.mesh_group_interface.value_namespace = name_space
                                self.mesh_group_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "mesh-group-number"):
                                self.mesh_group_number = value
                                self.mesh_group_number.value_namespace = name_space
                                self.mesh_group_number.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.isis_sh_mesh_entry:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.isis_sh_mesh_entry:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "mesh-group-configured-interface-list" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "isis-sh-mesh-entry"):
                            for c in self.isis_sh_mesh_entry:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.isis_sh_mesh_entry.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "isis-sh-mesh-entry"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (self.mesh_group_configured_interface_list is not None and self.mesh_group_configured_interface_list.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.mesh_group_configured_interface_list is not None and self.mesh_group_configured_interface_list.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "mesh-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "mesh-group-configured-interface-list"):
                        if (self.mesh_group_configured_interface_list is None):
                            self.mesh_group_configured_interface_list = Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList()
                            self.mesh_group_configured_interface_list.parent = self
                            self._children_name_map["mesh_group_configured_interface_list"] = "mesh-group-configured-interface-list"
                        return self.mesh_group_configured_interface_list

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "mesh-group-configured-interface-list"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NsrStatistics(Entity):
                """
                NSR Statistics information
                
                .. attribute:: isis_nsr_stats_data
                
                	ISIS NSR STATS Data
                	**type**\:   :py:class:`IsisNsrStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData>`
                
                .. attribute:: isis_vm_state
                
                	ISIS VM STATE
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.NsrStatistics, self).__init__()

                    self.yang_name = "nsr-statistics"
                    self.yang_parent_name = "instance"

                    self.isis_vm_state = YLeaf(YType.uint16, "isis-vm-state")

                    self.isis_nsr_stats_data = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData()
                    self.isis_nsr_stats_data.parent = self
                    self._children_name_map["isis_nsr_stats_data"] = "isis-nsr-stats-data"
                    self._children_yang_names.add("isis-nsr-stats-data")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("isis_vm_state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.NsrStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.NsrStatistics, self).__setattr__(name, value)


                class IsisNsrStatsData(Entity):
                    """
                    ISIS NSR STATS Data
                    
                    .. attribute:: peer
                    
                    	peer
                    	**type**\: list of    :py:class:`Peer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer>`
                    
                    .. attribute:: self
                    
                    	self
                    	**type**\:   :py:class:`Self <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData, self).__init__()

                        self.yang_name = "isis-nsr-stats-data"
                        self.yang_parent_name = "nsr-statistics"

                        self.self = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self()
                        self.self.parent = self
                        self._children_name_map["self"] = "self"
                        self._children_yang_names.add("self")

                        self.peer = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData, self).__setattr__(name, value)


                    class Self(Entity):
                        """
                        self
                        
                        .. attribute:: no_of_ipv4_routes
                        
                        	no of ipv4 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_ipv6_routes
                        
                        	no of ipv6 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l1_adj
                        
                        	no of l1 adj
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l1_lsp
                        
                        	no of l1 lsp
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l2_adj
                        
                        	no of l2 adj
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l2_lsp
                        
                        	no of l2 lsp
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_lan_interface
                        
                        	no of lan interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_live_interface
                        
                        	no of live interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_loopback_interface
                        
                        	no of loopback interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ptp_interface
                        
                        	no of ptp interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_links
                        
                        	no of te links
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_tunnels
                        
                        	no of te tunnels
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seqnum
                        
                        	seqnum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self, self).__init__()

                            self.yang_name = "self"
                            self.yang_parent_name = "isis-nsr-stats-data"

                            self.no_of_ipv4_routes = YLeaf(YType.uint32, "no-of-ipv4-routes")

                            self.no_of_ipv6_routes = YLeaf(YType.uint32, "no-of-ipv6-routes")

                            self.no_of_l1_adj = YLeaf(YType.uint16, "no-of-l1-adj")

                            self.no_of_l1_lsp = YLeaf(YType.uint32, "no-of-l1-lsp")

                            self.no_of_l2_adj = YLeaf(YType.uint16, "no-of-l2-adj")

                            self.no_of_l2_lsp = YLeaf(YType.uint32, "no-of-l2-lsp")

                            self.no_of_lan_interface = YLeaf(YType.uint16, "no-of-lan-interface")

                            self.no_of_live_interface = YLeaf(YType.uint16, "no-of-live-interface")

                            self.no_of_loopback_interface = YLeaf(YType.uint16, "no-of-loopback-interface")

                            self.no_of_ptp_interface = YLeaf(YType.uint16, "no-of-ptp-interface")

                            self.no_of_te_links = YLeaf(YType.uint16, "no-of-te-links")

                            self.no_of_te_tunnels = YLeaf(YType.uint16, "no-of-te-tunnels")

                            self.seqnum = YLeaf(YType.uint32, "seqnum")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("no_of_ipv4_routes",
                                            "no_of_ipv6_routes",
                                            "no_of_l1_adj",
                                            "no_of_l1_lsp",
                                            "no_of_l2_adj",
                                            "no_of_l2_lsp",
                                            "no_of_lan_interface",
                                            "no_of_live_interface",
                                            "no_of_loopback_interface",
                                            "no_of_ptp_interface",
                                            "no_of_te_links",
                                            "no_of_te_tunnels",
                                            "seqnum") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.no_of_ipv4_routes.is_set or
                                self.no_of_ipv6_routes.is_set or
                                self.no_of_l1_adj.is_set or
                                self.no_of_l1_lsp.is_set or
                                self.no_of_l2_adj.is_set or
                                self.no_of_l2_lsp.is_set or
                                self.no_of_lan_interface.is_set or
                                self.no_of_live_interface.is_set or
                                self.no_of_loopback_interface.is_set or
                                self.no_of_ptp_interface.is_set or
                                self.no_of_te_links.is_set or
                                self.no_of_te_tunnels.is_set or
                                self.seqnum.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.no_of_ipv4_routes.yfilter != YFilter.not_set or
                                self.no_of_ipv6_routes.yfilter != YFilter.not_set or
                                self.no_of_l1_adj.yfilter != YFilter.not_set or
                                self.no_of_l1_lsp.yfilter != YFilter.not_set or
                                self.no_of_l2_adj.yfilter != YFilter.not_set or
                                self.no_of_l2_lsp.yfilter != YFilter.not_set or
                                self.no_of_lan_interface.yfilter != YFilter.not_set or
                                self.no_of_live_interface.yfilter != YFilter.not_set or
                                self.no_of_loopback_interface.yfilter != YFilter.not_set or
                                self.no_of_ptp_interface.yfilter != YFilter.not_set or
                                self.no_of_te_links.yfilter != YFilter.not_set or
                                self.no_of_te_tunnels.yfilter != YFilter.not_set or
                                self.seqnum.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "self" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.no_of_ipv4_routes.is_set or self.no_of_ipv4_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ipv4_routes.get_name_leafdata())
                            if (self.no_of_ipv6_routes.is_set or self.no_of_ipv6_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ipv6_routes.get_name_leafdata())
                            if (self.no_of_l1_adj.is_set or self.no_of_l1_adj.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l1_adj.get_name_leafdata())
                            if (self.no_of_l1_lsp.is_set or self.no_of_l1_lsp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l1_lsp.get_name_leafdata())
                            if (self.no_of_l2_adj.is_set or self.no_of_l2_adj.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l2_adj.get_name_leafdata())
                            if (self.no_of_l2_lsp.is_set or self.no_of_l2_lsp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l2_lsp.get_name_leafdata())
                            if (self.no_of_lan_interface.is_set or self.no_of_lan_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_lan_interface.get_name_leafdata())
                            if (self.no_of_live_interface.is_set or self.no_of_live_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_live_interface.get_name_leafdata())
                            if (self.no_of_loopback_interface.is_set or self.no_of_loopback_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_loopback_interface.get_name_leafdata())
                            if (self.no_of_ptp_interface.is_set or self.no_of_ptp_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ptp_interface.get_name_leafdata())
                            if (self.no_of_te_links.is_set or self.no_of_te_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_te_links.get_name_leafdata())
                            if (self.no_of_te_tunnels.is_set or self.no_of_te_tunnels.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_te_tunnels.get_name_leafdata())
                            if (self.seqnum.is_set or self.seqnum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seqnum.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "no-of-ipv4-routes" or name == "no-of-ipv6-routes" or name == "no-of-l1-adj" or name == "no-of-l1-lsp" or name == "no-of-l2-adj" or name == "no-of-l2-lsp" or name == "no-of-lan-interface" or name == "no-of-live-interface" or name == "no-of-loopback-interface" or name == "no-of-ptp-interface" or name == "no-of-te-links" or name == "no-of-te-tunnels" or name == "seqnum"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "no-of-ipv4-routes"):
                                self.no_of_ipv4_routes = value
                                self.no_of_ipv4_routes.value_namespace = name_space
                                self.no_of_ipv4_routes.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-ipv6-routes"):
                                self.no_of_ipv6_routes = value
                                self.no_of_ipv6_routes.value_namespace = name_space
                                self.no_of_ipv6_routes.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l1-adj"):
                                self.no_of_l1_adj = value
                                self.no_of_l1_adj.value_namespace = name_space
                                self.no_of_l1_adj.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l1-lsp"):
                                self.no_of_l1_lsp = value
                                self.no_of_l1_lsp.value_namespace = name_space
                                self.no_of_l1_lsp.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l2-adj"):
                                self.no_of_l2_adj = value
                                self.no_of_l2_adj.value_namespace = name_space
                                self.no_of_l2_adj.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l2-lsp"):
                                self.no_of_l2_lsp = value
                                self.no_of_l2_lsp.value_namespace = name_space
                                self.no_of_l2_lsp.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-lan-interface"):
                                self.no_of_lan_interface = value
                                self.no_of_lan_interface.value_namespace = name_space
                                self.no_of_lan_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-live-interface"):
                                self.no_of_live_interface = value
                                self.no_of_live_interface.value_namespace = name_space
                                self.no_of_live_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-loopback-interface"):
                                self.no_of_loopback_interface = value
                                self.no_of_loopback_interface.value_namespace = name_space
                                self.no_of_loopback_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-ptp-interface"):
                                self.no_of_ptp_interface = value
                                self.no_of_ptp_interface.value_namespace = name_space
                                self.no_of_ptp_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-te-links"):
                                self.no_of_te_links = value
                                self.no_of_te_links.value_namespace = name_space
                                self.no_of_te_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-te-tunnels"):
                                self.no_of_te_tunnels = value
                                self.no_of_te_tunnels.value_namespace = name_space
                                self.no_of_te_tunnels.value_namespace_prefix = name_space_prefix
                            if(value_path == "seqnum"):
                                self.seqnum = value
                                self.seqnum.value_namespace = name_space
                                self.seqnum.value_namespace_prefix = name_space_prefix


                    class Peer(Entity):
                        """
                        peer
                        
                        .. attribute:: no_of_ipv4_routes
                        
                        	no of ipv4 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_ipv6_routes
                        
                        	no of ipv6 routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l1_adj
                        
                        	no of l1 adj
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l1_lsp
                        
                        	no of l1 lsp
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l2_adj
                        
                        	no of l2 adj
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l2_lsp
                        
                        	no of l2 lsp
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_lan_interface
                        
                        	no of lan interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_live_interface
                        
                        	no of live interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_loopback_interface
                        
                        	no of loopback interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ptp_interface
                        
                        	no of ptp interface
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_links
                        
                        	no of te links
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_tunnels
                        
                        	no of te tunnels
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: seqnum
                        
                        	seqnum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "isis-nsr-stats-data"

                            self.no_of_ipv4_routes = YLeaf(YType.uint32, "no-of-ipv4-routes")

                            self.no_of_ipv6_routes = YLeaf(YType.uint32, "no-of-ipv6-routes")

                            self.no_of_l1_adj = YLeaf(YType.uint16, "no-of-l1-adj")

                            self.no_of_l1_lsp = YLeaf(YType.uint32, "no-of-l1-lsp")

                            self.no_of_l2_adj = YLeaf(YType.uint16, "no-of-l2-adj")

                            self.no_of_l2_lsp = YLeaf(YType.uint32, "no-of-l2-lsp")

                            self.no_of_lan_interface = YLeaf(YType.uint16, "no-of-lan-interface")

                            self.no_of_live_interface = YLeaf(YType.uint16, "no-of-live-interface")

                            self.no_of_loopback_interface = YLeaf(YType.uint16, "no-of-loopback-interface")

                            self.no_of_ptp_interface = YLeaf(YType.uint16, "no-of-ptp-interface")

                            self.no_of_te_links = YLeaf(YType.uint16, "no-of-te-links")

                            self.no_of_te_tunnels = YLeaf(YType.uint16, "no-of-te-tunnels")

                            self.seqnum = YLeaf(YType.uint32, "seqnum")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("no_of_ipv4_routes",
                                            "no_of_ipv6_routes",
                                            "no_of_l1_adj",
                                            "no_of_l1_lsp",
                                            "no_of_l2_adj",
                                            "no_of_l2_lsp",
                                            "no_of_lan_interface",
                                            "no_of_live_interface",
                                            "no_of_loopback_interface",
                                            "no_of_ptp_interface",
                                            "no_of_te_links",
                                            "no_of_te_tunnels",
                                            "seqnum") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.no_of_ipv4_routes.is_set or
                                self.no_of_ipv6_routes.is_set or
                                self.no_of_l1_adj.is_set or
                                self.no_of_l1_lsp.is_set or
                                self.no_of_l2_adj.is_set or
                                self.no_of_l2_lsp.is_set or
                                self.no_of_lan_interface.is_set or
                                self.no_of_live_interface.is_set or
                                self.no_of_loopback_interface.is_set or
                                self.no_of_ptp_interface.is_set or
                                self.no_of_te_links.is_set or
                                self.no_of_te_tunnels.is_set or
                                self.seqnum.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.no_of_ipv4_routes.yfilter != YFilter.not_set or
                                self.no_of_ipv6_routes.yfilter != YFilter.not_set or
                                self.no_of_l1_adj.yfilter != YFilter.not_set or
                                self.no_of_l1_lsp.yfilter != YFilter.not_set or
                                self.no_of_l2_adj.yfilter != YFilter.not_set or
                                self.no_of_l2_lsp.yfilter != YFilter.not_set or
                                self.no_of_lan_interface.yfilter != YFilter.not_set or
                                self.no_of_live_interface.yfilter != YFilter.not_set or
                                self.no_of_loopback_interface.yfilter != YFilter.not_set or
                                self.no_of_ptp_interface.yfilter != YFilter.not_set or
                                self.no_of_te_links.yfilter != YFilter.not_set or
                                self.no_of_te_tunnels.yfilter != YFilter.not_set or
                                self.seqnum.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "peer" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.no_of_ipv4_routes.is_set or self.no_of_ipv4_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ipv4_routes.get_name_leafdata())
                            if (self.no_of_ipv6_routes.is_set or self.no_of_ipv6_routes.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ipv6_routes.get_name_leafdata())
                            if (self.no_of_l1_adj.is_set or self.no_of_l1_adj.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l1_adj.get_name_leafdata())
                            if (self.no_of_l1_lsp.is_set or self.no_of_l1_lsp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l1_lsp.get_name_leafdata())
                            if (self.no_of_l2_adj.is_set or self.no_of_l2_adj.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l2_adj.get_name_leafdata())
                            if (self.no_of_l2_lsp.is_set or self.no_of_l2_lsp.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_l2_lsp.get_name_leafdata())
                            if (self.no_of_lan_interface.is_set or self.no_of_lan_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_lan_interface.get_name_leafdata())
                            if (self.no_of_live_interface.is_set or self.no_of_live_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_live_interface.get_name_leafdata())
                            if (self.no_of_loopback_interface.is_set or self.no_of_loopback_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_loopback_interface.get_name_leafdata())
                            if (self.no_of_ptp_interface.is_set or self.no_of_ptp_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_ptp_interface.get_name_leafdata())
                            if (self.no_of_te_links.is_set or self.no_of_te_links.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_te_links.get_name_leafdata())
                            if (self.no_of_te_tunnels.is_set or self.no_of_te_tunnels.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.no_of_te_tunnels.get_name_leafdata())
                            if (self.seqnum.is_set or self.seqnum.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.seqnum.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "no-of-ipv4-routes" or name == "no-of-ipv6-routes" or name == "no-of-l1-adj" or name == "no-of-l1-lsp" or name == "no-of-l2-adj" or name == "no-of-l2-lsp" or name == "no-of-lan-interface" or name == "no-of-live-interface" or name == "no-of-loopback-interface" or name == "no-of-ptp-interface" or name == "no-of-te-links" or name == "no-of-te-tunnels" or name == "seqnum"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "no-of-ipv4-routes"):
                                self.no_of_ipv4_routes = value
                                self.no_of_ipv4_routes.value_namespace = name_space
                                self.no_of_ipv4_routes.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-ipv6-routes"):
                                self.no_of_ipv6_routes = value
                                self.no_of_ipv6_routes.value_namespace = name_space
                                self.no_of_ipv6_routes.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l1-adj"):
                                self.no_of_l1_adj = value
                                self.no_of_l1_adj.value_namespace = name_space
                                self.no_of_l1_adj.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l1-lsp"):
                                self.no_of_l1_lsp = value
                                self.no_of_l1_lsp.value_namespace = name_space
                                self.no_of_l1_lsp.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l2-adj"):
                                self.no_of_l2_adj = value
                                self.no_of_l2_adj.value_namespace = name_space
                                self.no_of_l2_adj.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-l2-lsp"):
                                self.no_of_l2_lsp = value
                                self.no_of_l2_lsp.value_namespace = name_space
                                self.no_of_l2_lsp.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-lan-interface"):
                                self.no_of_lan_interface = value
                                self.no_of_lan_interface.value_namespace = name_space
                                self.no_of_lan_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-live-interface"):
                                self.no_of_live_interface = value
                                self.no_of_live_interface.value_namespace = name_space
                                self.no_of_live_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-loopback-interface"):
                                self.no_of_loopback_interface = value
                                self.no_of_loopback_interface.value_namespace = name_space
                                self.no_of_loopback_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-ptp-interface"):
                                self.no_of_ptp_interface = value
                                self.no_of_ptp_interface.value_namespace = name_space
                                self.no_of_ptp_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-te-links"):
                                self.no_of_te_links = value
                                self.no_of_te_links.value_namespace = name_space
                                self.no_of_te_links.value_namespace_prefix = name_space_prefix
                            if(value_path == "no-of-te-tunnels"):
                                self.no_of_te_tunnels = value
                                self.no_of_te_tunnels.value_namespace = name_space
                                self.no_of_te_tunnels.value_namespace_prefix = name_space_prefix
                            if(value_path == "seqnum"):
                                self.seqnum = value
                                self.seqnum.value_namespace = name_space
                                self.seqnum.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.peer:
                            if (c.has_data()):
                                return True
                        return (self.self is not None and self.self.has_data())

                    def has_operation(self):
                        for c in self.peer:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.self is not None and self.self.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "isis-nsr-stats-data" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "peer"):
                            for c in self.peer:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.peer.append(c)
                            return c

                        if (child_yang_name == "self"):
                            if (self.self is None):
                                self.self = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self()
                                self.self.parent = self
                                self._children_name_map["self"] = "self"
                            return self.self

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "peer" or name == "self"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.isis_vm_state.is_set or
                        (self.isis_nsr_stats_data is not None and self.isis_nsr_stats_data.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.isis_vm_state.yfilter != YFilter.not_set or
                        (self.isis_nsr_stats_data is not None and self.isis_nsr_stats_data.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.isis_vm_state.is_set or self.isis_vm_state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.isis_vm_state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "isis-nsr-stats-data"):
                        if (self.isis_nsr_stats_data is None):
                            self.isis_nsr_stats_data = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData()
                            self.isis_nsr_stats_data.parent = self
                            self._children_name_map["isis_nsr_stats_data"] = "isis-nsr-stats-data"
                        return self.isis_nsr_stats_data

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "isis-nsr-stats-data" or name == "isis-vm-state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "isis-vm-state"):
                        self.isis_vm_state = value
                        self.isis_vm_state.value_namespace = name_space
                        self.isis_vm_state.value_namespace_prefix = name_space_prefix


            class CheckpointTeTunnels(Entity):
                """
                Checkpointed TE tunnel table
                
                .. attribute:: checkpoint_te_tunnel
                
                	A checkpointed TE tunnel
                	**type**\: list of    :py:class:`CheckpointTeTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointTeTunnels, self).__init__()

                    self.yang_name = "checkpoint-te-tunnels"
                    self.yang_parent_name = "instance"

                    self.checkpoint_te_tunnel = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Isis.Instances.Instance.CheckpointTeTunnels, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Isis.Instances.Instance.CheckpointTeTunnels, self).__setattr__(name, value)


                class CheckpointTeTunnel(Entity):
                    """
                    A checkpointed TE tunnel
                    
                    .. attribute:: checkpoint_te_bandwidth
                    
                    	Tunnel bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_te_flags
                    
                    	Tunnel flags
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_te_interface
                    
                    	Tunnel interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: checkpoint_te_level
                    
                    	TE database level
                    	**type**\:   :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: checkpoint_te_metric
                    
                    	Tunnel metric
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: checkpoint_te_metric_mode
                    
                    	Tunnel metric mode
                    	**type**\:   :py:class:`IsisMetricMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricMode>`
                    
                    .. attribute:: checkpoint_te_nexthop
                    
                    	Tunnel next\-hop IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: checkpoint_te_object_id
                    
                    	Tunnel checkpoint object ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_te_system_id
                    
                    	Destination system ID
                    	**type**\:  str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:   :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel, self).__init__()

                        self.yang_name = "checkpoint-te-tunnel"
                        self.yang_parent_name = "checkpoint-te-tunnels"

                        self.checkpoint_te_bandwidth = YLeaf(YType.uint32, "checkpoint-te-bandwidth")

                        self.checkpoint_te_flags = YLeaf(YType.uint32, "checkpoint-te-flags")

                        self.checkpoint_te_interface = YLeaf(YType.str, "checkpoint-te-interface")

                        self.checkpoint_te_level = YLeaf(YType.enumeration, "checkpoint-te-level")

                        self.checkpoint_te_metric = YLeaf(YType.int32, "checkpoint-te-metric")

                        self.checkpoint_te_metric_mode = YLeaf(YType.enumeration, "checkpoint-te-metric-mode")

                        self.checkpoint_te_nexthop = YLeaf(YType.str, "checkpoint-te-nexthop")

                        self.checkpoint_te_object_id = YLeaf(YType.uint32, "checkpoint-te-object-id")

                        self.checkpoint_te_system_id = YLeaf(YType.str, "checkpoint-te-system-id")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.level = YLeaf(YType.enumeration, "level")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("checkpoint_te_bandwidth",
                                        "checkpoint_te_flags",
                                        "checkpoint_te_interface",
                                        "checkpoint_te_level",
                                        "checkpoint_te_metric",
                                        "checkpoint_te_metric_mode",
                                        "checkpoint_te_nexthop",
                                        "checkpoint_te_object_id",
                                        "checkpoint_te_system_id",
                                        "interface_name",
                                        "level") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.checkpoint_te_bandwidth.is_set or
                            self.checkpoint_te_flags.is_set or
                            self.checkpoint_te_interface.is_set or
                            self.checkpoint_te_level.is_set or
                            self.checkpoint_te_metric.is_set or
                            self.checkpoint_te_metric_mode.is_set or
                            self.checkpoint_te_nexthop.is_set or
                            self.checkpoint_te_object_id.is_set or
                            self.checkpoint_te_system_id.is_set or
                            self.interface_name.is_set or
                            self.level.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.checkpoint_te_bandwidth.yfilter != YFilter.not_set or
                            self.checkpoint_te_flags.yfilter != YFilter.not_set or
                            self.checkpoint_te_interface.yfilter != YFilter.not_set or
                            self.checkpoint_te_level.yfilter != YFilter.not_set or
                            self.checkpoint_te_metric.yfilter != YFilter.not_set or
                            self.checkpoint_te_metric_mode.yfilter != YFilter.not_set or
                            self.checkpoint_te_nexthop.yfilter != YFilter.not_set or
                            self.checkpoint_te_object_id.yfilter != YFilter.not_set or
                            self.checkpoint_te_system_id.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.level.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "checkpoint-te-tunnel" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.checkpoint_te_bandwidth.is_set or self.checkpoint_te_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_bandwidth.get_name_leafdata())
                        if (self.checkpoint_te_flags.is_set or self.checkpoint_te_flags.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_flags.get_name_leafdata())
                        if (self.checkpoint_te_interface.is_set or self.checkpoint_te_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_interface.get_name_leafdata())
                        if (self.checkpoint_te_level.is_set or self.checkpoint_te_level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_level.get_name_leafdata())
                        if (self.checkpoint_te_metric.is_set or self.checkpoint_te_metric.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_metric.get_name_leafdata())
                        if (self.checkpoint_te_metric_mode.is_set or self.checkpoint_te_metric_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_metric_mode.get_name_leafdata())
                        if (self.checkpoint_te_nexthop.is_set or self.checkpoint_te_nexthop.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_nexthop.get_name_leafdata())
                        if (self.checkpoint_te_object_id.is_set or self.checkpoint_te_object_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_object_id.get_name_leafdata())
                        if (self.checkpoint_te_system_id.is_set or self.checkpoint_te_system_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checkpoint_te_system_id.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.level.is_set or self.level.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.level.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "checkpoint-te-bandwidth" or name == "checkpoint-te-flags" or name == "checkpoint-te-interface" or name == "checkpoint-te-level" or name == "checkpoint-te-metric" or name == "checkpoint-te-metric-mode" or name == "checkpoint-te-nexthop" or name == "checkpoint-te-object-id" or name == "checkpoint-te-system-id" or name == "interface-name" or name == "level"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "checkpoint-te-bandwidth"):
                            self.checkpoint_te_bandwidth = value
                            self.checkpoint_te_bandwidth.value_namespace = name_space
                            self.checkpoint_te_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-flags"):
                            self.checkpoint_te_flags = value
                            self.checkpoint_te_flags.value_namespace = name_space
                            self.checkpoint_te_flags.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-interface"):
                            self.checkpoint_te_interface = value
                            self.checkpoint_te_interface.value_namespace = name_space
                            self.checkpoint_te_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-level"):
                            self.checkpoint_te_level = value
                            self.checkpoint_te_level.value_namespace = name_space
                            self.checkpoint_te_level.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-metric"):
                            self.checkpoint_te_metric = value
                            self.checkpoint_te_metric.value_namespace = name_space
                            self.checkpoint_te_metric.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-metric-mode"):
                            self.checkpoint_te_metric_mode = value
                            self.checkpoint_te_metric_mode.value_namespace = name_space
                            self.checkpoint_te_metric_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-nexthop"):
                            self.checkpoint_te_nexthop = value
                            self.checkpoint_te_nexthop.value_namespace = name_space
                            self.checkpoint_te_nexthop.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-object-id"):
                            self.checkpoint_te_object_id = value
                            self.checkpoint_te_object_id.value_namespace = name_space
                            self.checkpoint_te_object_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "checkpoint-te-system-id"):
                            self.checkpoint_te_system_id = value
                            self.checkpoint_te_system_id.value_namespace = name_space
                            self.checkpoint_te_system_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "level"):
                            self.level = value
                            self.level.value_namespace = name_space
                            self.level.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.checkpoint_te_tunnel:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.checkpoint_te_tunnel:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "checkpoint-te-tunnels" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "checkpoint-te-tunnel"):
                        for c in self.checkpoint_te_tunnel:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.checkpoint_te_tunnel.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "checkpoint-te-tunnel"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.instance_name.is_set or
                    (self.checkpoint_adjacencies is not None and self.checkpoint_adjacencies.has_data()) or
                    (self.checkpoint_interfaces is not None and self.checkpoint_interfaces.has_data()) or
                    (self.checkpoint_lsps is not None and self.checkpoint_lsps.has_data()) or
                    (self.checkpoint_te_tunnels is not None and self.checkpoint_te_tunnels.has_data()) or
                    (self.error_log is not None and self.error_log.has_data()) or
                    (self.host_names is not None and self.host_names.has_data()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()) or
                    (self.levels is not None and self.levels.has_data()) or
                    (self.mesh_groups is not None and self.mesh_groups.has_data()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_data()) or
                    (self.neighbors is not None and self.neighbors.has_data()) or
                    (self.nsr_statistics is not None and self.nsr_statistics.has_data()) or
                    (self.nsr_status is not None and self.nsr_status.has_data()) or
                    (self.protocol is not None and self.protocol.has_data()) or
                    (self.srms is not None and self.srms.has_data()) or
                    (self.statistics_global is not None and self.statistics_global.has_data()) or
                    (self.topologies is not None and self.topologies.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.instance_name.yfilter != YFilter.not_set or
                    (self.checkpoint_adjacencies is not None and self.checkpoint_adjacencies.has_operation()) or
                    (self.checkpoint_interfaces is not None and self.checkpoint_interfaces.has_operation()) or
                    (self.checkpoint_lsps is not None and self.checkpoint_lsps.has_operation()) or
                    (self.checkpoint_te_tunnels is not None and self.checkpoint_te_tunnels.has_operation()) or
                    (self.error_log is not None and self.error_log.has_operation()) or
                    (self.host_names is not None and self.host_names.has_operation()) or
                    (self.interface_statistics is not None and self.interface_statistics.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()) or
                    (self.levels is not None and self.levels.has_operation()) or
                    (self.mesh_groups is not None and self.mesh_groups.has_operation()) or
                    (self.neighbor_summaries is not None and self.neighbor_summaries.has_operation()) or
                    (self.neighbors is not None and self.neighbors.has_operation()) or
                    (self.nsr_statistics is not None and self.nsr_statistics.has_operation()) or
                    (self.nsr_status is not None and self.nsr_status.has_operation()) or
                    (self.protocol is not None and self.protocol.has_operation()) or
                    (self.srms is not None and self.srms.has_operation()) or
                    (self.statistics_global is not None and self.statistics_global.has_operation()) or
                    (self.topologies is not None and self.topologies.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "instance" + "[instance-name='" + self.instance_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-clns-isis-oper:isis/instances/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.instance_name.is_set or self.instance_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "checkpoint-adjacencies"):
                    if (self.checkpoint_adjacencies is None):
                        self.checkpoint_adjacencies = Isis.Instances.Instance.CheckpointAdjacencies()
                        self.checkpoint_adjacencies.parent = self
                        self._children_name_map["checkpoint_adjacencies"] = "checkpoint-adjacencies"
                    return self.checkpoint_adjacencies

                if (child_yang_name == "checkpoint-interfaces"):
                    if (self.checkpoint_interfaces is None):
                        self.checkpoint_interfaces = Isis.Instances.Instance.CheckpointInterfaces()
                        self.checkpoint_interfaces.parent = self
                        self._children_name_map["checkpoint_interfaces"] = "checkpoint-interfaces"
                    return self.checkpoint_interfaces

                if (child_yang_name == "checkpoint-lsps"):
                    if (self.checkpoint_lsps is None):
                        self.checkpoint_lsps = Isis.Instances.Instance.CheckpointLsps()
                        self.checkpoint_lsps.parent = self
                        self._children_name_map["checkpoint_lsps"] = "checkpoint-lsps"
                    return self.checkpoint_lsps

                if (child_yang_name == "checkpoint-te-tunnels"):
                    if (self.checkpoint_te_tunnels is None):
                        self.checkpoint_te_tunnels = Isis.Instances.Instance.CheckpointTeTunnels()
                        self.checkpoint_te_tunnels.parent = self
                        self._children_name_map["checkpoint_te_tunnels"] = "checkpoint-te-tunnels"
                    return self.checkpoint_te_tunnels

                if (child_yang_name == "error-log"):
                    if (self.error_log is None):
                        self.error_log = Isis.Instances.Instance.ErrorLog()
                        self.error_log.parent = self
                        self._children_name_map["error_log"] = "error-log"
                    return self.error_log

                if (child_yang_name == "host-names"):
                    if (self.host_names is None):
                        self.host_names = Isis.Instances.Instance.HostNames()
                        self.host_names.parent = self
                        self._children_name_map["host_names"] = "host-names"
                    return self.host_names

                if (child_yang_name == "interface-statistics"):
                    if (self.interface_statistics is None):
                        self.interface_statistics = Isis.Instances.Instance.InterfaceStatistics()
                        self.interface_statistics.parent = self
                        self._children_name_map["interface_statistics"] = "interface-statistics"
                    return self.interface_statistics

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Isis.Instances.Instance.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                if (child_yang_name == "levels"):
                    if (self.levels is None):
                        self.levels = Isis.Instances.Instance.Levels()
                        self.levels.parent = self
                        self._children_name_map["levels"] = "levels"
                    return self.levels

                if (child_yang_name == "mesh-groups"):
                    if (self.mesh_groups is None):
                        self.mesh_groups = Isis.Instances.Instance.MeshGroups()
                        self.mesh_groups.parent = self
                        self._children_name_map["mesh_groups"] = "mesh-groups"
                    return self.mesh_groups

                if (child_yang_name == "neighbor-summaries"):
                    if (self.neighbor_summaries is None):
                        self.neighbor_summaries = Isis.Instances.Instance.NeighborSummaries()
                        self.neighbor_summaries.parent = self
                        self._children_name_map["neighbor_summaries"] = "neighbor-summaries"
                    return self.neighbor_summaries

                if (child_yang_name == "neighbors"):
                    if (self.neighbors is None):
                        self.neighbors = Isis.Instances.Instance.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                    return self.neighbors

                if (child_yang_name == "nsr-statistics"):
                    if (self.nsr_statistics is None):
                        self.nsr_statistics = Isis.Instances.Instance.NsrStatistics()
                        self.nsr_statistics.parent = self
                        self._children_name_map["nsr_statistics"] = "nsr-statistics"
                    return self.nsr_statistics

                if (child_yang_name == "nsr-status"):
                    if (self.nsr_status is None):
                        self.nsr_status = Isis.Instances.Instance.NsrStatus()
                        self.nsr_status.parent = self
                        self._children_name_map["nsr_status"] = "nsr-status"
                    return self.nsr_status

                if (child_yang_name == "protocol"):
                    if (self.protocol is None):
                        self.protocol = Isis.Instances.Instance.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"
                    return self.protocol

                if (child_yang_name == "srms"):
                    if (self.srms is None):
                        self.srms = Isis.Instances.Instance.Srms()
                        self.srms.parent = self
                        self._children_name_map["srms"] = "srms"
                    return self.srms

                if (child_yang_name == "statistics-global"):
                    if (self.statistics_global is None):
                        self.statistics_global = Isis.Instances.Instance.StatisticsGlobal()
                        self.statistics_global.parent = self
                        self._children_name_map["statistics_global"] = "statistics-global"
                    return self.statistics_global

                if (child_yang_name == "topologies"):
                    if (self.topologies is None):
                        self.topologies = Isis.Instances.Instance.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                    return self.topologies

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "checkpoint-adjacencies" or name == "checkpoint-interfaces" or name == "checkpoint-lsps" or name == "checkpoint-te-tunnels" or name == "error-log" or name == "host-names" or name == "interface-statistics" or name == "interfaces" or name == "levels" or name == "mesh-groups" or name == "neighbor-summaries" or name == "neighbors" or name == "nsr-statistics" or name == "nsr-status" or name == "protocol" or name == "srms" or name == "statistics-global" or name == "topologies" or name == "instance-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "instance-name"):
                    self.instance_name = value
                    self.instance_name.value_namespace = name_space
                    self.instance_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.instance:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.instance:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "instances" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-clns-isis-oper:isis/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "instance"):
                for c in self.instance:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Isis.Instances.Instance()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.instance.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "instance"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (self.instances is not None and self.instances.has_data())

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.instances is not None and self.instances.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-clns-isis-oper:isis" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "instances"):
            if (self.instances is None):
                self.instances = Isis.Instances()
                self.instances.parent = self
                self._children_name_map["instances"] = "instances"
            return self.instances

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "instances"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Isis()
        return self._top_entity

